const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-01-01";
pub const sdk_id: []const u8 = "Database Migration Service";
pub const arn_namespace: []const u8 = "dms";
pub const endpoint_prefix: []const u8 = "dms";
pub const sigv4_name: []const u8 = "dms";
pub const name: []const u8 = "AmazonDMSv20160101";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-01-01",
    sdk_id: []const u8 = "Database Migration Service",
    arn_namespace: []const u8 = "dms",
    endpoint_prefix: []const u8 = "dms",
    sigv4_name: []const u8 = "dms",
    name: []const u8 = "AmazonDMSv20160101",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags_to_resource: struct {
    action_name: []const u8 = "AddTagsToResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags_to_resource) } {
            return .{ .service_metadata = service_metadata, .action = add_tags_to_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const apply_pending_maintenance_action: struct {
    action_name: []const u8 = "ApplyPendingMaintenanceAction",
    Request: type = struct {
        replication_instance_arn: []const u8,
        apply_action: []const u8,
        opt_in_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .apply_action = "ApplyAction",
                .opt_in_type = "OptInType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(apply_pending_maintenance_action) } {
            return .{ .service_metadata = service_metadata, .action = apply_pending_maintenance_action };
        }
    },
    Response: type = struct {
        resource_pending_maintenance_actions: ?ResourcePendingMaintenanceActions = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_pending_maintenance_actions = "ResourcePendingMaintenanceActions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const cancel_replication_task_assessment_run: struct {
    action_name: []const u8 = "CancelReplicationTaskAssessmentRun",
    Request: type = struct {
        replication_task_assessment_run_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run_arn = "ReplicationTaskAssessmentRunArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_replication_task_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = cancel_replication_task_assessment_run };
        }
    },
    Response: type = struct {
        replication_task_assessment_run: ?ReplicationTaskAssessmentRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run = "ReplicationTaskAssessmentRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const create_endpoint: struct {
    action_name: []const u8 = "CreateEndpoint",
    Request: type = struct {
        endpoint_identifier: []const u8,
        endpoint_type: []const u8,
        engine_name: []const u8,
        username: ?[]const u8 = null,
        password: ?[]const u8 = null,
        server_name: ?[]const u8 = null,
        port: ?i64 = null,
        database_name: ?[]const u8 = null,
        extra_connection_attributes: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        certificate_arn: ?[]const u8 = null,
        ssl_mode: ?[]const u8 = null,
        service_access_role_arn: ?[]const u8 = null,
        external_table_definition: ?[]const u8 = null,
        dynamo_db_settings: ?DynamoDbSettings = null,
        s3_settings: ?S3Settings = null,
        dms_transfer_settings: ?DmsTransferSettings = null,
        mongo_db_settings: ?MongoDbSettings = null,
        kinesis_settings: ?KinesisSettings = null,
        kafka_settings: ?KafkaSettings = null,
        elasticsearch_settings: ?ElasticsearchSettings = null,
        neptune_settings: ?NeptuneSettings = null,
        redshift_settings: ?RedshiftSettings = null,
        postgre_sql_settings: ?PostgreSQLSettings = null,
        my_sql_settings: ?MySQLSettings = null,
        oracle_settings: ?OracleSettings = null,
        sybase_settings: ?SybaseSettings = null,
        microsoft_sql_server_settings: ?MicrosoftSQLServerSettings = null,
        ibm_db2_settings: ?IBMDb2Settings = null,
        resource_identifier: ?[]const u8 = null,
        doc_db_settings: ?DocDbSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_identifier = "EndpointIdentifier",
                .endpoint_type = "EndpointType",
                .engine_name = "EngineName",
                .username = "Username",
                .password = "Password",
                .server_name = "ServerName",
                .port = "Port",
                .database_name = "DatabaseName",
                .extra_connection_attributes = "ExtraConnectionAttributes",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
                .certificate_arn = "CertificateArn",
                .ssl_mode = "SslMode",
                .service_access_role_arn = "ServiceAccessRoleArn",
                .external_table_definition = "ExternalTableDefinition",
                .dynamo_db_settings = "DynamoDbSettings",
                .s3_settings = "S3Settings",
                .dms_transfer_settings = "DmsTransferSettings",
                .mongo_db_settings = "MongoDbSettings",
                .kinesis_settings = "KinesisSettings",
                .kafka_settings = "KafkaSettings",
                .elasticsearch_settings = "ElasticsearchSettings",
                .neptune_settings = "NeptuneSettings",
                .redshift_settings = "RedshiftSettings",
                .postgre_sql_settings = "PostgreSQLSettings",
                .my_sql_settings = "MySQLSettings",
                .oracle_settings = "OracleSettings",
                .sybase_settings = "SybaseSettings",
                .microsoft_sql_server_settings = "MicrosoftSQLServerSettings",
                .ibm_db2_settings = "IBMDb2Settings",
                .resource_identifier = "ResourceIdentifier",
                .doc_db_settings = "DocDbSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "Endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        S3AccessDenied,
    },
} = .{};
pub const create_event_subscription: struct {
    action_name: []const u8 = "CreateEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: []const u8,
        source_type: ?[]const u8 = null,
        event_categories: ?[][]const u8 = null,
        source_ids: ?[][]const u8 = null,
        enabled: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .event_categories = "EventCategories",
                .source_ids = "SourceIds",
                .enabled = "Enabled",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = create_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSThrottling,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        SNSInvalidTopic,
        SNSNoAuthorization,
    },
} = .{};
pub const create_replication_instance: struct {
    action_name: []const u8 = "CreateReplicationInstance",
    Request: type = struct {
        replication_instance_identifier: []const u8,
        allocated_storage: ?i64 = null,
        replication_instance_class: []const u8,
        vpc_security_group_ids: ?[][]const u8 = null,
        availability_zone: ?[]const u8 = null,
        replication_subnet_group_identifier: ?[]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        multi_az: ?bool = null,
        engine_version: ?[]const u8 = null,
        auto_minor_version_upgrade: ?bool = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,
        publicly_accessible: ?bool = null,
        dns_name_servers: ?[]const u8 = null,
        resource_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_identifier = "ReplicationInstanceIdentifier",
                .allocated_storage = "AllocatedStorage",
                .replication_instance_class = "ReplicationInstanceClass",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .availability_zone = "AvailabilityZone",
                .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .multi_az = "MultiAZ",
                .engine_version = "EngineVersion",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
                .publicly_accessible = "PubliclyAccessible",
                .dns_name_servers = "DnsNameServers",
                .resource_identifier = "ResourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_instance };
        }
    },
    Response: type = struct {
        replication_instance: ?ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance = "ReplicationInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InsufficientResourceCapacity,
        InvalidResourceState,
        InvalidSubnet,
        KMSKeyNotAccessible,
        ReplicationSubnetGroupDoesNotCoverEnoughAZs,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
        StorageQuotaExceeded,
    },
} = .{};
pub const create_replication_subnet_group: struct {
    action_name: []const u8 = "CreateReplicationSubnetGroup",
    Request: type = struct {
        replication_subnet_group_identifier: []const u8,
        replication_subnet_group_description: []const u8,
        subnet_ids: [][]const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
                .replication_subnet_group_description = "ReplicationSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_subnet_group };
        }
    },
    Response: type = struct {
        replication_subnet_group: ?ReplicationSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group = "ReplicationSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidSubnet,
        ReplicationSubnetGroupDoesNotCoverEnoughAZs,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const create_replication_task: struct {
    action_name: []const u8 = "CreateReplicationTask",
    Request: type = struct {
        replication_task_identifier: []const u8,
        source_endpoint_arn: []const u8,
        target_endpoint_arn: []const u8,
        replication_instance_arn: []const u8,
        migration_type: []const u8,
        table_mappings: []const u8,
        replication_task_settings: ?[]const u8 = null,
        cdc_start_time: ?i64 = null,
        cdc_start_position: ?[]const u8 = null,
        cdc_stop_position: ?[]const u8 = null,
        tags: ?[]Tag = null,
        task_data: ?[]const u8 = null,
        resource_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_identifier = "ReplicationTaskIdentifier",
                .source_endpoint_arn = "SourceEndpointArn",
                .target_endpoint_arn = "TargetEndpointArn",
                .replication_instance_arn = "ReplicationInstanceArn",
                .migration_type = "MigrationType",
                .table_mappings = "TableMappings",
                .replication_task_settings = "ReplicationTaskSettings",
                .cdc_start_time = "CdcStartTime",
                .cdc_start_position = "CdcStartPosition",
                .cdc_stop_position = "CdcStopPosition",
                .tags = "Tags",
                .task_data = "TaskData",
                .resource_identifier = "ResourceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = create_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const delete_certificate: struct {
    action_name: []const u8 = "DeleteCertificate",
    Request: type = struct {
        certificate_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_arn = "CertificateArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_certificate) } {
            return .{ .service_metadata = service_metadata, .action = delete_certificate };
        }
    },
    Response: type = struct {
        certificate: ?Certificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        endpoint_arn: []const u8,
        replication_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .replication_instance_arn = "ReplicationInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_endpoint: struct {
    action_name: []const u8 = "DeleteEndpoint",
    Request: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "Endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_event_subscription: struct {
    action_name: []const u8 = "DeleteEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = delete_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_instance: struct {
    action_name: []const u8 = "DeleteReplicationInstance",
    Request: type = struct {
        replication_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_instance };
        }
    },
    Response: type = struct {
        replication_instance: ?ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance = "ReplicationInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_subnet_group: struct {
    action_name: []const u8 = "DeleteReplicationSubnetGroup",
    Request: type = struct {
        replication_subnet_group_identifier: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_subnet_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_task: struct {
    action_name: []const u8 = "DeleteReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const delete_replication_task_assessment_run: struct {
    action_name: []const u8 = "DeleteReplicationTaskAssessmentRun",
    Request: type = struct {
        replication_task_assessment_run_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run_arn = "ReplicationTaskAssessmentRunArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_replication_task_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = delete_replication_task_assessment_run };
        }
    },
    Response: type = struct {
        replication_task_assessment_run: ?ReplicationTaskAssessmentRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run = "ReplicationTaskAssessmentRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_account_attributes: struct {
    action_name: []const u8 = "DescribeAccountAttributes",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_attributes) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_attributes };
        }
    },
    Response: type = struct {
        account_quotas: ?[]struct {
            account_quota_name: ?[]const u8 = null,
            used: ?i64 = null,
            max: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_quota_name = "AccountQuotaName",
                    .used = "Used",
                    .max = "Max",
                };
                return @field(mappings, field_name);
            }
        } = null,
        unique_account_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_quotas = "AccountQuotas",
                .unique_account_identifier = "UniqueAccountIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_applicable_individual_assessments: struct {
    action_name: []const u8 = "DescribeApplicableIndividualAssessments",
    Request: type = struct {
        replication_task_arn: ?[]const u8 = null,
        replication_instance_arn: ?[]const u8 = null,
        source_engine_name: ?[]const u8 = null,
        target_engine_name: ?[]const u8 = null,
        migration_type: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .replication_instance_arn = "ReplicationInstanceArn",
                .source_engine_name = "SourceEngineName",
                .target_engine_name = "TargetEngineName",
                .migration_type = "MigrationType",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_applicable_individual_assessments) } {
            return .{ .service_metadata = service_metadata, .action = describe_applicable_individual_assessments };
        }
    },
    Response: type = struct {
        individual_assessment_names: ?[][]const u8 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .individual_assessment_names = "IndividualAssessmentNames",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_certificates: struct {
    action_name: []const u8 = "DescribeCertificates",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_certificates) } {
            return .{ .service_metadata = service_metadata, .action = describe_certificates };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        certificates: ?[]Certificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .certificates = "Certificates",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_connections: struct {
    action_name: []const u8 = "DescribeConnections",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connections) } {
            return .{ .service_metadata = service_metadata, .action = describe_connections };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        connections: ?[]Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .connections = "Connections",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_endpoints: struct {
    action_name: []const u8 = "DescribeEndpoints",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoints };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        endpoints: ?[]Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .endpoints = "Endpoints",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_endpoint_settings: struct {
    action_name: []const u8 = "DescribeEndpointSettings",
    Request: type = struct {
        engine_name: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .engine_name = "EngineName",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint_settings };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        endpoint_settings: ?[]struct {
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            enum_values: ?[][]const u8 = null,
            sensitive: ?bool = null,
            units: ?[]const u8 = null,
            applicability: ?[]const u8 = null,
            int_value_min: ?i64 = null,
            int_value_max: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .type = "Type",
                    .enum_values = "EnumValues",
                    .sensitive = "Sensitive",
                    .units = "Units",
                    .applicability = "Applicability",
                    .int_value_min = "IntValueMin",
                    .int_value_max = "IntValueMax",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .endpoint_settings = "EndpointSettings",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_endpoint_types: struct {
    action_name: []const u8 = "DescribeEndpointTypes",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint_types) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint_types };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        supported_endpoint_types: ?[]struct {
            engine_name: ?[]const u8 = null,
            supports_cdc: ?bool = null,
            endpoint_type: ?[]const u8 = null,
            replication_instance_engine_minimum_version: ?[]const u8 = null,
            engine_display_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine_name = "EngineName",
                    .supports_cdc = "SupportsCDC",
                    .endpoint_type = "EndpointType",
                    .replication_instance_engine_minimum_version = "ReplicationInstanceEngineMinimumVersion",
                    .engine_display_name = "EngineDisplayName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .supported_endpoint_types = "SupportedEndpointTypes",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_categories: struct {
    action_name: []const u8 = "DescribeEventCategories",
    Request: type = struct {
        source_type: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_type = "SourceType",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_categories) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_categories };
        }
    },
    Response: type = struct {
        event_category_group_list: ?[]struct {
            source_type: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_type = "SourceType",
                    .event_categories = "EventCategories",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_category_group_list = "EventCategoryGroupList",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_events: struct {
    action_name: []const u8 = "DescribeEvents",
    Request: type = struct {
        source_identifier: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        duration: ?i64 = null,
        event_categories: ?[][]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_identifier = "SourceIdentifier",
                .source_type = "SourceType",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .duration = "Duration",
                .event_categories = "EventCategories",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_events) } {
            return .{ .service_metadata = service_metadata, .action = describe_events };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        events: ?[]struct {
            source_identifier: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            message: ?[]const u8 = null,
            event_categories: ?[][]const u8 = null,
            date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_identifier = "SourceIdentifier",
                    .source_type = "SourceType",
                    .message = "Message",
                    .event_categories = "EventCategories",
                    .date = "Date",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .events = "Events",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_event_subscriptions: struct {
    action_name: []const u8 = "DescribeEventSubscriptions",
    Request: type = struct {
        subscription_name: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_event_subscriptions) } {
            return .{ .service_metadata = service_metadata, .action = describe_event_subscriptions };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        event_subscriptions_list: ?[]EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .event_subscriptions_list = "EventSubscriptionsList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_orderable_replication_instances: struct {
    action_name: []const u8 = "DescribeOrderableReplicationInstances",
    Request: type = struct {
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_orderable_replication_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_orderable_replication_instances };
        }
    },
    Response: type = struct {
        orderable_replication_instances: ?[]struct {
            engine_version: ?[]const u8 = null,
            replication_instance_class: ?[]const u8 = null,
            storage_type: ?[]const u8 = null,
            min_allocated_storage: ?i64 = null,
            max_allocated_storage: ?i64 = null,
            default_allocated_storage: ?i64 = null,
            included_allocated_storage: ?i64 = null,
            availability_zones: ?[][]const u8 = null,
            release_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .engine_version = "EngineVersion",
                    .replication_instance_class = "ReplicationInstanceClass",
                    .storage_type = "StorageType",
                    .min_allocated_storage = "MinAllocatedStorage",
                    .max_allocated_storage = "MaxAllocatedStorage",
                    .default_allocated_storage = "DefaultAllocatedStorage",
                    .included_allocated_storage = "IncludedAllocatedStorage",
                    .availability_zones = "AvailabilityZones",
                    .release_status = "ReleaseStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .orderable_replication_instances = "OrderableReplicationInstances",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_pending_maintenance_actions: struct {
    action_name: []const u8 = "DescribePendingMaintenanceActions",
    Request: type = struct {
        replication_instance_arn: ?[]const u8 = null,
        filters: ?[]Filter = null,
        marker: ?[]const u8 = null,
        max_records: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .filters = "Filters",
                .marker = "Marker",
                .max_records = "MaxRecords",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pending_maintenance_actions) } {
            return .{ .service_metadata = service_metadata, .action = describe_pending_maintenance_actions };
        }
    },
    Response: type = struct {
        pending_maintenance_actions: ?[]ResourcePendingMaintenanceActions = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pending_maintenance_actions = "PendingMaintenanceActions",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_refresh_schemas_status: struct {
    action_name: []const u8 = "DescribeRefreshSchemasStatus",
    Request: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_refresh_schemas_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_refresh_schemas_status };
        }
    },
    Response: type = struct {
        refresh_schemas_status: ?RefreshSchemasStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .refresh_schemas_status = "RefreshSchemasStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_instances: struct {
    action_name: []const u8 = "DescribeReplicationInstances",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_instances) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_instances };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_instances: ?[]ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_instances = "ReplicationInstances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_instance_task_logs: struct {
    action_name: []const u8 = "DescribeReplicationInstanceTaskLogs",
    Request: type = struct {
        replication_instance_arn: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_instance_task_logs) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_instance_task_logs };
        }
    },
    Response: type = struct {
        replication_instance_arn: ?[]const u8 = null,
        replication_instance_task_logs: ?[]struct {
            replication_task_name: ?[]const u8 = null,
            replication_task_arn: ?[]const u8 = null,
            replication_instance_task_log_size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_task_name = "ReplicationTaskName",
                    .replication_task_arn = "ReplicationTaskArn",
                    .replication_instance_task_log_size = "ReplicationInstanceTaskLogSize",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .replication_instance_task_logs = "ReplicationInstanceTaskLogs",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_subnet_groups: struct {
    action_name: []const u8 = "DescribeReplicationSubnetGroups",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_subnet_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_subnet_groups };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_subnet_groups: ?[]ReplicationSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_subnet_groups = "ReplicationSubnetGroups",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_task_assessment_results: struct {
    action_name: []const u8 = "DescribeReplicationTaskAssessmentResults",
    Request: type = struct {
        replication_task_arn: ?[]const u8 = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_task_assessment_results) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_task_assessment_results };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        bucket_name: ?[]const u8 = null,
        replication_task_assessment_results: ?[]struct {
            replication_task_identifier: ?[]const u8 = null,
            replication_task_arn: ?[]const u8 = null,
            replication_task_last_assessment_date: ?i64 = null,
            assessment_status: ?[]const u8 = null,
            assessment_results_file: ?[]const u8 = null,
            assessment_results: ?[]const u8 = null,
            s3_object_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_task_identifier = "ReplicationTaskIdentifier",
                    .replication_task_arn = "ReplicationTaskArn",
                    .replication_task_last_assessment_date = "ReplicationTaskLastAssessmentDate",
                    .assessment_status = "AssessmentStatus",
                    .assessment_results_file = "AssessmentResultsFile",
                    .assessment_results = "AssessmentResults",
                    .s3_object_url = "S3ObjectUrl",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .bucket_name = "BucketName",
                .replication_task_assessment_results = "ReplicationTaskAssessmentResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_task_assessment_runs: struct {
    action_name: []const u8 = "DescribeReplicationTaskAssessmentRuns",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_task_assessment_runs) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_task_assessment_runs };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_task_assessment_runs: ?[]ReplicationTaskAssessmentRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_task_assessment_runs = "ReplicationTaskAssessmentRuns",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_task_individual_assessments: struct {
    action_name: []const u8 = "DescribeReplicationTaskIndividualAssessments",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_task_individual_assessments) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_task_individual_assessments };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_task_individual_assessments: ?[]struct {
            replication_task_individual_assessment_arn: ?[]const u8 = null,
            replication_task_assessment_run_arn: ?[]const u8 = null,
            individual_assessment_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            replication_task_individual_assessment_start_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .replication_task_individual_assessment_arn = "ReplicationTaskIndividualAssessmentArn",
                    .replication_task_assessment_run_arn = "ReplicationTaskAssessmentRunArn",
                    .individual_assessment_name = "IndividualAssessmentName",
                    .status = "Status",
                    .replication_task_individual_assessment_start_date = "ReplicationTaskIndividualAssessmentStartDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_task_individual_assessments = "ReplicationTaskIndividualAssessments",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_replication_tasks: struct {
    action_name: []const u8 = "DescribeReplicationTasks",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        without_settings: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "Filters",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .without_settings = "WithoutSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_replication_tasks) } {
            return .{ .service_metadata = service_metadata, .action = describe_replication_tasks };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        replication_tasks: ?[]ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .replication_tasks = "ReplicationTasks",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_schemas: struct {
    action_name: []const u8 = "DescribeSchemas",
    Request: type = struct {
        endpoint_arn: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_schemas) } {
            return .{ .service_metadata = service_metadata, .action = describe_schemas };
        }
    },
    Response: type = struct {
        marker: ?[]const u8 = null,
        schemas: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .marker = "Marker",
                .schemas = "Schemas",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const describe_table_statistics: struct {
    action_name: []const u8 = "DescribeTableStatistics",
    Request: type = struct {
        replication_task_arn: []const u8,
        max_records: ?i64 = null,
        marker: ?[]const u8 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .max_records = "MaxRecords",
                .marker = "Marker",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_table_statistics) } {
            return .{ .service_metadata = service_metadata, .action = describe_table_statistics };
        }
    },
    Response: type = struct {
        replication_task_arn: ?[]const u8 = null,
        table_statistics: ?[]struct {
            schema_name: ?[]const u8 = null,
            table_name: ?[]const u8 = null,
            inserts: ?i64 = null,
            deletes: ?i64 = null,
            updates: ?i64 = null,
            ddls: ?i64 = null,
            full_load_rows: ?i64 = null,
            full_load_condtnl_chk_failed_rows: ?i64 = null,
            full_load_error_rows: ?i64 = null,
            full_load_start_time: ?i64 = null,
            full_load_end_time: ?i64 = null,
            full_load_reloaded: ?bool = null,
            last_update_time: ?i64 = null,
            table_state: ?[]const u8 = null,
            validation_pending_records: ?i64 = null,
            validation_failed_records: ?i64 = null,
            validation_suspended_records: ?i64 = null,
            validation_state: ?[]const u8 = null,
            validation_state_details: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schema_name = "SchemaName",
                    .table_name = "TableName",
                    .inserts = "Inserts",
                    .deletes = "Deletes",
                    .updates = "Updates",
                    .ddls = "Ddls",
                    .full_load_rows = "FullLoadRows",
                    .full_load_condtnl_chk_failed_rows = "FullLoadCondtnlChkFailedRows",
                    .full_load_error_rows = "FullLoadErrorRows",
                    .full_load_start_time = "FullLoadStartTime",
                    .full_load_end_time = "FullLoadEndTime",
                    .full_load_reloaded = "FullLoadReloaded",
                    .last_update_time = "LastUpdateTime",
                    .table_state = "TableState",
                    .validation_pending_records = "ValidationPendingRecords",
                    .validation_failed_records = "ValidationFailedRecords",
                    .validation_suspended_records = "ValidationSuspendedRecords",
                    .validation_state = "ValidationState",
                    .validation_state_details = "ValidationStateDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,
        marker: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .table_statistics = "TableStatistics",
                .marker = "Marker",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const import_certificate: struct {
    action_name: []const u8 = "ImportCertificate",
    Request: type = struct {
        certificate_identifier: []const u8,
        certificate_pem: ?[]const u8 = null,
        certificate_wallet: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate_identifier = "CertificateIdentifier",
                .certificate_pem = "CertificatePem",
                .certificate_wallet = "CertificateWallet",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_certificate) } {
            return .{ .service_metadata = service_metadata, .action = import_certificate };
        }
    },
    Response: type = struct {
        certificate: ?Certificate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidCertificate,
        ResourceAlreadyExists,
        ResourceQuotaExceeded,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const modify_endpoint: struct {
    action_name: []const u8 = "ModifyEndpoint",
    Request: type = struct {
        endpoint_arn: []const u8,
        endpoint_identifier: ?[]const u8 = null,
        endpoint_type: ?[]const u8 = null,
        engine_name: ?[]const u8 = null,
        username: ?[]const u8 = null,
        password: ?[]const u8 = null,
        server_name: ?[]const u8 = null,
        port: ?i64 = null,
        database_name: ?[]const u8 = null,
        extra_connection_attributes: ?[]const u8 = null,
        certificate_arn: ?[]const u8 = null,
        ssl_mode: ?[]const u8 = null,
        service_access_role_arn: ?[]const u8 = null,
        external_table_definition: ?[]const u8 = null,
        dynamo_db_settings: ?DynamoDbSettings = null,
        s3_settings: ?S3Settings = null,
        dms_transfer_settings: ?DmsTransferSettings = null,
        mongo_db_settings: ?MongoDbSettings = null,
        kinesis_settings: ?KinesisSettings = null,
        kafka_settings: ?KafkaSettings = null,
        elasticsearch_settings: ?ElasticsearchSettings = null,
        neptune_settings: ?NeptuneSettings = null,
        redshift_settings: ?RedshiftSettings = null,
        postgre_sql_settings: ?PostgreSQLSettings = null,
        my_sql_settings: ?MySQLSettings = null,
        oracle_settings: ?OracleSettings = null,
        sybase_settings: ?SybaseSettings = null,
        microsoft_sql_server_settings: ?MicrosoftSQLServerSettings = null,
        ibm_db2_settings: ?IBMDb2Settings = null,
        doc_db_settings: ?DocDbSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .endpoint_identifier = "EndpointIdentifier",
                .endpoint_type = "EndpointType",
                .engine_name = "EngineName",
                .username = "Username",
                .password = "Password",
                .server_name = "ServerName",
                .port = "Port",
                .database_name = "DatabaseName",
                .extra_connection_attributes = "ExtraConnectionAttributes",
                .certificate_arn = "CertificateArn",
                .ssl_mode = "SslMode",
                .service_access_role_arn = "ServiceAccessRoleArn",
                .external_table_definition = "ExternalTableDefinition",
                .dynamo_db_settings = "DynamoDbSettings",
                .s3_settings = "S3Settings",
                .dms_transfer_settings = "DmsTransferSettings",
                .mongo_db_settings = "MongoDbSettings",
                .kinesis_settings = "KinesisSettings",
                .kafka_settings = "KafkaSettings",
                .elasticsearch_settings = "ElasticsearchSettings",
                .neptune_settings = "NeptuneSettings",
                .redshift_settings = "RedshiftSettings",
                .postgre_sql_settings = "PostgreSQLSettings",
                .my_sql_settings = "MySQLSettings",
                .oracle_settings = "OracleSettings",
                .sybase_settings = "SybaseSettings",
                .microsoft_sql_server_settings = "MicrosoftSQLServerSettings",
                .ibm_db2_settings = "IBMDb2Settings",
                .doc_db_settings = "DocDbSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = modify_endpoint };
        }
    },
    Response: type = struct {
        endpoint: ?Endpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint = "Endpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const modify_event_subscription: struct {
    action_name: []const u8 = "ModifyEventSubscription",
    Request: type = struct {
        subscription_name: []const u8,
        sns_topic_arn: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        event_categories: ?[][]const u8 = null,
        enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscription_name = "SubscriptionName",
                .sns_topic_arn = "SnsTopicArn",
                .source_type = "SourceType",
                .event_categories = "EventCategories",
                .enabled = "Enabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_event_subscription) } {
            return .{ .service_metadata = service_metadata, .action = modify_event_subscription };
        }
    },
    Response: type = struct {
        event_subscription: ?EventSubscription = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .event_subscription = "EventSubscription",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        KMSAccessDenied,
        KMSDisabled,
        KMSInvalidState,
        KMSNotFound,
        KMSThrottling,
        ResourceNotFound,
        ResourceQuotaExceeded,
        SNSInvalidTopic,
        SNSNoAuthorization,
    },
} = .{};
pub const modify_replication_instance: struct {
    action_name: []const u8 = "ModifyReplicationInstance",
    Request: type = struct {
        replication_instance_arn: []const u8,
        allocated_storage: ?i64 = null,
        apply_immediately: ?bool = null,
        replication_instance_class: ?[]const u8 = null,
        vpc_security_group_ids: ?[][]const u8 = null,
        preferred_maintenance_window: ?[]const u8 = null,
        multi_az: ?bool = null,
        engine_version: ?[]const u8 = null,
        allow_major_version_upgrade: ?bool = null,
        auto_minor_version_upgrade: ?bool = null,
        replication_instance_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .allocated_storage = "AllocatedStorage",
                .apply_immediately = "ApplyImmediately",
                .replication_instance_class = "ReplicationInstanceClass",
                .vpc_security_group_ids = "VpcSecurityGroupIds",
                .preferred_maintenance_window = "PreferredMaintenanceWindow",
                .multi_az = "MultiAZ",
                .engine_version = "EngineVersion",
                .allow_major_version_upgrade = "AllowMajorVersionUpgrade",
                .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
                .replication_instance_identifier = "ReplicationInstanceIdentifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_instance) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_instance };
        }
    },
    Response: type = struct {
        replication_instance: ?ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance = "ReplicationInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InsufficientResourceCapacity,
        InvalidResourceState,
        ResourceAlreadyExists,
        ResourceNotFound,
        StorageQuotaExceeded,
        UpgradeDependencyFailure,
    },
} = .{};
pub const modify_replication_subnet_group: struct {
    action_name: []const u8 = "ModifyReplicationSubnetGroup",
    Request: type = struct {
        replication_subnet_group_identifier: []const u8,
        replication_subnet_group_description: ?[]const u8 = null,
        subnet_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
                .replication_subnet_group_description = "ReplicationSubnetGroupDescription",
                .subnet_ids = "SubnetIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_subnet_group) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_subnet_group };
        }
    },
    Response: type = struct {
        replication_subnet_group: ?ReplicationSubnetGroup = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_subnet_group = "ReplicationSubnetGroup",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidSubnet,
        ReplicationSubnetGroupDoesNotCoverEnoughAZs,
        ResourceNotFound,
        ResourceQuotaExceeded,
        SubnetAlreadyInUse,
    },
} = .{};
pub const modify_replication_task: struct {
    action_name: []const u8 = "ModifyReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,
        replication_task_identifier: ?[]const u8 = null,
        migration_type: ?[]const u8 = null,
        table_mappings: ?[]const u8 = null,
        replication_task_settings: ?[]const u8 = null,
        cdc_start_time: ?i64 = null,
        cdc_start_position: ?[]const u8 = null,
        cdc_stop_position: ?[]const u8 = null,
        task_data: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .replication_task_identifier = "ReplicationTaskIdentifier",
                .migration_type = "MigrationType",
                .table_mappings = "TableMappings",
                .replication_task_settings = "ReplicationTaskSettings",
                .cdc_start_time = "CdcStartTime",
                .cdc_start_position = "CdcStartPosition",
                .cdc_stop_position = "CdcStopPosition",
                .task_data = "TaskData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = modify_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceAlreadyExists,
        ResourceNotFound,
    },
} = .{};
pub const move_replication_task: struct {
    action_name: []const u8 = "MoveReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,
        target_replication_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .target_replication_instance_arn = "TargetReplicationInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(move_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = move_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceNotFound,
    },
} = .{};
pub const reboot_replication_instance: struct {
    action_name: []const u8 = "RebootReplicationInstance",
    Request: type = struct {
        replication_instance_arn: []const u8,
        force_failover: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .force_failover = "ForceFailover",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_replication_instance) } {
            return .{ .service_metadata = service_metadata, .action = reboot_replication_instance };
        }
    },
    Response: type = struct {
        replication_instance: ?ReplicationInstance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance = "ReplicationInstance",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const refresh_schemas: struct {
    action_name: []const u8 = "RefreshSchemas",
    Request: type = struct {
        endpoint_arn: []const u8,
        replication_instance_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
                .replication_instance_arn = "ReplicationInstanceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(refresh_schemas) } {
            return .{ .service_metadata = service_metadata, .action = refresh_schemas };
        }
    },
    Response: type = struct {
        refresh_schemas_status: ?RefreshSchemasStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .refresh_schemas_status = "RefreshSchemasStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};
pub const reload_tables: struct {
    action_name: []const u8 = "ReloadTables",
    Request: type = struct {
        replication_task_arn: []const u8,
        tables_to_reload: []struct {
            schema_name: []const u8,
            table_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schema_name = "SchemaName",
                    .table_name = "TableName",
                };
                return @field(mappings, field_name);
            }
        },
        reload_option: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .tables_to_reload = "TablesToReload",
                .reload_option = "ReloadOption",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reload_tables) } {
            return .{ .service_metadata = service_metadata, .action = reload_tables };
        }
    },
    Response: type = struct {
        replication_task_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const remove_tags_from_resource: struct {
    action_name: []const u8 = "RemoveTagsFromResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags_from_resource) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags_from_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const start_replication_task: struct {
    action_name: []const u8 = "StartReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,
        start_replication_task_type: []const u8,
        cdc_start_time: ?i64 = null,
        cdc_start_position: ?[]const u8 = null,
        cdc_stop_position: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .start_replication_task_type = "StartReplicationTaskType",
                .cdc_start_time = "CdcStartTime",
                .cdc_start_position = "CdcStartPosition",
                .cdc_stop_position = "CdcStopPosition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = start_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_replication_task_assessment: struct {
    action_name: []const u8 = "StartReplicationTaskAssessment",
    Request: type = struct {
        replication_task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_replication_task_assessment) } {
            return .{ .service_metadata = service_metadata, .action = start_replication_task_assessment };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_replication_task_assessment_run: struct {
    action_name: []const u8 = "StartReplicationTaskAssessmentRun",
    Request: type = struct {
        replication_task_arn: []const u8,
        service_access_role_arn: []const u8,
        result_location_bucket: []const u8,
        result_location_folder: ?[]const u8 = null,
        result_encryption_mode: ?[]const u8 = null,
        result_kms_key_arn: ?[]const u8 = null,
        assessment_run_name: []const u8,
        include_only: ?[][]const u8 = null,
        exclude: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
                .service_access_role_arn = "ServiceAccessRoleArn",
                .result_location_bucket = "ResultLocationBucket",
                .result_location_folder = "ResultLocationFolder",
                .result_encryption_mode = "ResultEncryptionMode",
                .result_kms_key_arn = "ResultKmsKeyArn",
                .assessment_run_name = "AssessmentRunName",
                .include_only = "IncludeOnly",
                .exclude = "Exclude",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_replication_task_assessment_run) } {
            return .{ .service_metadata = service_metadata, .action = start_replication_task_assessment_run };
        }
    },
    Response: type = struct {
        replication_task_assessment_run: ?ReplicationTaskAssessmentRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_assessment_run = "ReplicationTaskAssessmentRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSAccessDenied,
        KMSDisabled,
        KMS,
        KMSInvalidState,
        KMSKeyNotAccessible,
        KMSNotFound,
        ResourceAlreadyExists,
        ResourceNotFound,
        S3AccessDenied,
        S3ResourceNotFound,
    },
} = .{};
pub const stop_replication_task: struct {
    action_name: []const u8 = "StopReplicationTask",
    Request: type = struct {
        replication_task_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task_arn = "ReplicationTaskArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_replication_task) } {
            return .{ .service_metadata = service_metadata, .action = stop_replication_task };
        }
    },
    Response: type = struct {
        replication_task: ?ReplicationTask = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_task = "ReplicationTask",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const test_connection: struct {
    action_name: []const u8 = "TestConnection",
    Request: type = struct {
        replication_instance_arn: []const u8,
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_instance_arn = "ReplicationInstanceArn",
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_connection) } {
            return .{ .service_metadata = service_metadata, .action = test_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        KMSKeyNotAccessible,
        ResourceNotFound,
        ResourceQuotaExceeded,
    },
} = .{};

pub const Connection = struct {
    replication_instance_arn: ?[]const u8 = null,
    endpoint_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    last_failure_message: ?[]const u8 = null,
    endpoint_identifier: ?[]const u8 = null,
    replication_instance_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_instance_arn = "ReplicationInstanceArn",
            .endpoint_arn = "EndpointArn",
            .status = "Status",
            .last_failure_message = "LastFailureMessage",
            .endpoint_identifier = "EndpointIdentifier",
            .replication_instance_identifier = "ReplicationInstanceIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTask = struct {
    replication_task_identifier: ?[]const u8 = null,
    source_endpoint_arn: ?[]const u8 = null,
    target_endpoint_arn: ?[]const u8 = null,
    replication_instance_arn: ?[]const u8 = null,
    migration_type: ?[]const u8 = null,
    table_mappings: ?[]const u8 = null,
    replication_task_settings: ?[]const u8 = null,
    status: ?[]const u8 = null,
    last_failure_message: ?[]const u8 = null,
    stop_reason: ?[]const u8 = null,
    replication_task_creation_date: ?i64 = null,
    replication_task_start_date: ?i64 = null,
    cdc_start_position: ?[]const u8 = null,
    cdc_stop_position: ?[]const u8 = null,
    recovery_checkpoint: ?[]const u8 = null,
    replication_task_arn: ?[]const u8 = null,
    replication_task_stats: ?ReplicationTaskStats = null,
    task_data: ?[]const u8 = null,
    target_replication_instance_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_task_identifier = "ReplicationTaskIdentifier",
            .source_endpoint_arn = "SourceEndpointArn",
            .target_endpoint_arn = "TargetEndpointArn",
            .replication_instance_arn = "ReplicationInstanceArn",
            .migration_type = "MigrationType",
            .table_mappings = "TableMappings",
            .replication_task_settings = "ReplicationTaskSettings",
            .status = "Status",
            .last_failure_message = "LastFailureMessage",
            .stop_reason = "StopReason",
            .replication_task_creation_date = "ReplicationTaskCreationDate",
            .replication_task_start_date = "ReplicationTaskStartDate",
            .cdc_start_position = "CdcStartPosition",
            .cdc_stop_position = "CdcStopPosition",
            .recovery_checkpoint = "RecoveryCheckpoint",
            .replication_task_arn = "ReplicationTaskArn",
            .replication_task_stats = "ReplicationTaskStats",
            .task_data = "TaskData",
            .target_replication_instance_arn = "TargetReplicationInstanceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTaskStats = struct {
    full_load_progress_percent: ?i64 = null,
    elapsed_time_millis: ?i64 = null,
    tables_loaded: ?i64 = null,
    tables_loading: ?i64 = null,
    tables_queued: ?i64 = null,
    tables_errored: ?i64 = null,
    fresh_start_date: ?i64 = null,
    start_date: ?i64 = null,
    stop_date: ?i64 = null,
    full_load_start_date: ?i64 = null,
    full_load_finish_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .full_load_progress_percent = "FullLoadProgressPercent",
            .elapsed_time_millis = "ElapsedTimeMillis",
            .tables_loaded = "TablesLoaded",
            .tables_loading = "TablesLoading",
            .tables_queued = "TablesQueued",
            .tables_errored = "TablesErrored",
            .fresh_start_date = "FreshStartDate",
            .start_date = "StartDate",
            .stop_date = "StopDate",
            .full_load_start_date = "FullLoadStartDate",
            .full_load_finish_date = "FullLoadFinishDate",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTaskAssessmentRun = struct {
    replication_task_assessment_run_arn: ?[]const u8 = null,
    replication_task_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    replication_task_assessment_run_creation_date: ?i64 = null,
    assessment_progress: ?ReplicationTaskAssessmentRunProgress = null,
    last_failure_message: ?[]const u8 = null,
    service_access_role_arn: ?[]const u8 = null,
    result_location_bucket: ?[]const u8 = null,
    result_location_folder: ?[]const u8 = null,
    result_encryption_mode: ?[]const u8 = null,
    result_kms_key_arn: ?[]const u8 = null,
    assessment_run_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_task_assessment_run_arn = "ReplicationTaskAssessmentRunArn",
            .replication_task_arn = "ReplicationTaskArn",
            .status = "Status",
            .replication_task_assessment_run_creation_date = "ReplicationTaskAssessmentRunCreationDate",
            .assessment_progress = "AssessmentProgress",
            .last_failure_message = "LastFailureMessage",
            .service_access_role_arn = "ServiceAccessRoleArn",
            .result_location_bucket = "ResultLocationBucket",
            .result_location_folder = "ResultLocationFolder",
            .result_encryption_mode = "ResultEncryptionMode",
            .result_kms_key_arn = "ResultKmsKeyArn",
            .assessment_run_name = "AssessmentRunName",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationTaskAssessmentRunProgress = struct {
    individual_assessment_count: ?i64 = null,
    individual_assessment_completed_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .individual_assessment_count = "IndividualAssessmentCount",
            .individual_assessment_completed_count = "IndividualAssessmentCompletedCount",
        };
        return @field(mappings, field_name);
    }
};

pub const RefreshSchemasStatus = struct {
    endpoint_arn: ?[]const u8 = null,
    replication_instance_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    last_refresh_date: ?i64 = null,
    last_failure_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_arn = "EndpointArn",
            .replication_instance_arn = "ReplicationInstanceArn",
            .status = "Status",
            .last_refresh_date = "LastRefreshDate",
            .last_failure_message = "LastFailureMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationInstance = struct {
    replication_instance_identifier: ?[]const u8 = null,
    replication_instance_class: ?[]const u8 = null,
    replication_instance_status: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    instance_create_time: ?i64 = null,
    vpc_security_groups: ?[]VpcSecurityGroupMembership = null,
    availability_zone: ?[]const u8 = null,
    replication_subnet_group: ?ReplicationSubnetGroup = null,
    preferred_maintenance_window: ?[]const u8 = null,
    pending_modified_values: ?ReplicationPendingModifiedValues = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,
    auto_minor_version_upgrade: ?bool = null,
    kms_key_id: ?[]const u8 = null,
    replication_instance_arn: ?[]const u8 = null,
    replication_instance_public_ip_address: ?[]const u8 = null,
    replication_instance_private_ip_address: ?[]const u8 = null,
    replication_instance_public_ip_addresses: ?[][]const u8 = null,
    replication_instance_private_ip_addresses: ?[][]const u8 = null,
    publicly_accessible: ?bool = null,
    secondary_availability_zone: ?[]const u8 = null,
    free_until: ?i64 = null,
    dns_name_servers: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_instance_identifier = "ReplicationInstanceIdentifier",
            .replication_instance_class = "ReplicationInstanceClass",
            .replication_instance_status = "ReplicationInstanceStatus",
            .allocated_storage = "AllocatedStorage",
            .instance_create_time = "InstanceCreateTime",
            .vpc_security_groups = "VpcSecurityGroups",
            .availability_zone = "AvailabilityZone",
            .replication_subnet_group = "ReplicationSubnetGroup",
            .preferred_maintenance_window = "PreferredMaintenanceWindow",
            .pending_modified_values = "PendingModifiedValues",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
            .auto_minor_version_upgrade = "AutoMinorVersionUpgrade",
            .kms_key_id = "KmsKeyId",
            .replication_instance_arn = "ReplicationInstanceArn",
            .replication_instance_public_ip_address = "ReplicationInstancePublicIpAddress",
            .replication_instance_private_ip_address = "ReplicationInstancePrivateIpAddress",
            .replication_instance_public_ip_addresses = "ReplicationInstancePublicIpAddresses",
            .replication_instance_private_ip_addresses = "ReplicationInstancePrivateIpAddresses",
            .publicly_accessible = "PubliclyAccessible",
            .secondary_availability_zone = "SecondaryAvailabilityZone",
            .free_until = "FreeUntil",
            .dns_name_servers = "DnsNameServers",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationPendingModifiedValues = struct {
    replication_instance_class: ?[]const u8 = null,
    allocated_storage: ?i64 = null,
    multi_az: ?bool = null,
    engine_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_instance_class = "ReplicationInstanceClass",
            .allocated_storage = "AllocatedStorage",
            .multi_az = "MultiAZ",
            .engine_version = "EngineVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationSubnetGroup = struct {
    replication_subnet_group_identifier: ?[]const u8 = null,
    replication_subnet_group_description: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    subnet_group_status: ?[]const u8 = null,
    subnets: ?[]Subnet = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .replication_subnet_group_identifier = "ReplicationSubnetGroupIdentifier",
            .replication_subnet_group_description = "ReplicationSubnetGroupDescription",
            .vpc_id = "VpcId",
            .subnet_group_status = "SubnetGroupStatus",
            .subnets = "Subnets",
        };
        return @field(mappings, field_name);
    }
};

pub const Subnet = struct {
    subnet_identifier: ?[]const u8 = null,
    subnet_availability_zone: ?AvailabilityZone = null,
    subnet_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_identifier = "SubnetIdentifier",
            .subnet_availability_zone = "SubnetAvailabilityZone",
            .subnet_status = "SubnetStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailabilityZone = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcSecurityGroupMembership = struct {
    vpc_security_group_id: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_security_group_id = "VpcSecurityGroupId",
            .status = "Status",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSubscription = struct {
    customer_aws_id: ?[]const u8 = null,
    cust_subscription_id: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    status: ?[]const u8 = null,
    subscription_creation_time: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    source_ids_list: ?[][]const u8 = null,
    event_categories_list: ?[][]const u8 = null,
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .customer_aws_id = "CustomerAwsId",
            .cust_subscription_id = "CustSubscriptionId",
            .sns_topic_arn = "SnsTopicArn",
            .status = "Status",
            .subscription_creation_time = "SubscriptionCreationTime",
            .source_type = "SourceType",
            .source_ids_list = "SourceIdsList",
            .event_categories_list = "EventCategoriesList",
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Endpoint = struct {
    endpoint_identifier: ?[]const u8 = null,
    endpoint_type: ?[]const u8 = null,
    engine_name: ?[]const u8 = null,
    engine_display_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    extra_connection_attributes: ?[]const u8 = null,
    status: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    endpoint_arn: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    ssl_mode: ?[]const u8 = null,
    service_access_role_arn: ?[]const u8 = null,
    external_table_definition: ?[]const u8 = null,
    external_id: ?[]const u8 = null,
    dynamo_db_settings: ?DynamoDbSettings = null,
    s3_settings: ?S3Settings = null,
    dms_transfer_settings: ?DmsTransferSettings = null,
    mongo_db_settings: ?MongoDbSettings = null,
    kinesis_settings: ?KinesisSettings = null,
    kafka_settings: ?KafkaSettings = null,
    elasticsearch_settings: ?ElasticsearchSettings = null,
    neptune_settings: ?NeptuneSettings = null,
    redshift_settings: ?RedshiftSettings = null,
    postgre_sql_settings: ?PostgreSQLSettings = null,
    my_sql_settings: ?MySQLSettings = null,
    oracle_settings: ?OracleSettings = null,
    sybase_settings: ?SybaseSettings = null,
    microsoft_sql_server_settings: ?MicrosoftSQLServerSettings = null,
    ibm_db2_settings: ?IBMDb2Settings = null,
    doc_db_settings: ?DocDbSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_identifier = "EndpointIdentifier",
            .endpoint_type = "EndpointType",
            .engine_name = "EngineName",
            .engine_display_name = "EngineDisplayName",
            .username = "Username",
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .extra_connection_attributes = "ExtraConnectionAttributes",
            .status = "Status",
            .kms_key_id = "KmsKeyId",
            .endpoint_arn = "EndpointArn",
            .certificate_arn = "CertificateArn",
            .ssl_mode = "SslMode",
            .service_access_role_arn = "ServiceAccessRoleArn",
            .external_table_definition = "ExternalTableDefinition",
            .external_id = "ExternalId",
            .dynamo_db_settings = "DynamoDbSettings",
            .s3_settings = "S3Settings",
            .dms_transfer_settings = "DmsTransferSettings",
            .mongo_db_settings = "MongoDbSettings",
            .kinesis_settings = "KinesisSettings",
            .kafka_settings = "KafkaSettings",
            .elasticsearch_settings = "ElasticsearchSettings",
            .neptune_settings = "NeptuneSettings",
            .redshift_settings = "RedshiftSettings",
            .postgre_sql_settings = "PostgreSQLSettings",
            .my_sql_settings = "MySQLSettings",
            .oracle_settings = "OracleSettings",
            .sybase_settings = "SybaseSettings",
            .microsoft_sql_server_settings = "MicrosoftSQLServerSettings",
            .ibm_db2_settings = "IBMDb2Settings",
            .doc_db_settings = "DocDbSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const DocDbSettings = struct {
    username: ?[]const u8 = null,
    password: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    nesting_level: ?[]const u8 = null,
    extract_doc_id: ?bool = null,
    docs_to_investigate: ?i64 = null,
    kms_key_id: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .password = "Password",
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .nesting_level = "NestingLevel",
            .extract_doc_id = "ExtractDocId",
            .docs_to_investigate = "DocsToInvestigate",
            .kms_key_id = "KmsKeyId",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const IBMDb2Settings = struct {
    database_name: ?[]const u8 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    set_data_capture_changes: ?bool = null,
    current_lsn: ?[]const u8 = null,
    max_k_bytes_per_read: ?i64 = null,
    username: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .set_data_capture_changes = "SetDataCaptureChanges",
            .current_lsn = "CurrentLsn",
            .max_k_bytes_per_read = "MaxKBytesPerRead",
            .username = "Username",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const MicrosoftSQLServerSettings = struct {
    port: ?i64 = null,
    bcp_packet_size: ?i64 = null,
    database_name: ?[]const u8 = null,
    control_tables_file_group: ?[]const u8 = null,
    password: ?[]const u8 = null,
    query_single_always_on_node: ?bool = null,
    read_backup_only: ?bool = null,
    safeguard_policy: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    use_bcp_full_load: ?bool = null,
    use_third_party_backup_device: ?bool = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .port = "Port",
            .bcp_packet_size = "BcpPacketSize",
            .database_name = "DatabaseName",
            .control_tables_file_group = "ControlTablesFileGroup",
            .password = "Password",
            .query_single_always_on_node = "QuerySingleAlwaysOnNode",
            .read_backup_only = "ReadBackupOnly",
            .safeguard_policy = "SafeguardPolicy",
            .server_name = "ServerName",
            .username = "Username",
            .use_bcp_full_load = "UseBcpFullLoad",
            .use_third_party_backup_device = "UseThirdPartyBackupDevice",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const SybaseSettings = struct {
    database_name: ?[]const u8 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .username = "Username",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const OracleSettings = struct {
    add_supplemental_logging: ?bool = null,
    archived_log_dest_id: ?i64 = null,
    additional_archived_log_dest_id: ?i64 = null,
    allow_select_nested_tables: ?bool = null,
    parallel_asm_read_threads: ?i64 = null,
    read_ahead_blocks: ?i64 = null,
    access_alternate_directly: ?bool = null,
    use_alternate_folder_for_online: ?bool = null,
    oracle_path_prefix: ?[]const u8 = null,
    use_path_prefix: ?[]const u8 = null,
    replace_path_prefix: ?bool = null,
    enable_homogenous_tablespace: ?bool = null,
    direct_path_no_log: ?bool = null,
    archived_logs_only: ?bool = null,
    asm_password: ?[]const u8 = null,
    asm_server: ?[]const u8 = null,
    asm_user: ?[]const u8 = null,
    char_length_semantics: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    direct_path_parallel_load: ?bool = null,
    fail_tasks_on_lob_truncation: ?bool = null,
    number_datatype_scale: ?i64 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    read_table_space_name: ?bool = null,
    retry_interval: ?i64 = null,
    security_db_encryption: ?[]const u8 = null,
    security_db_encryption_name: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    spatial_data_option_to_geo_json_function_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,
    secrets_manager_oracle_asm_access_role_arn: ?[]const u8 = null,
    secrets_manager_oracle_asm_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .add_supplemental_logging = "AddSupplementalLogging",
            .archived_log_dest_id = "ArchivedLogDestId",
            .additional_archived_log_dest_id = "AdditionalArchivedLogDestId",
            .allow_select_nested_tables = "AllowSelectNestedTables",
            .parallel_asm_read_threads = "ParallelAsmReadThreads",
            .read_ahead_blocks = "ReadAheadBlocks",
            .access_alternate_directly = "AccessAlternateDirectly",
            .use_alternate_folder_for_online = "UseAlternateFolderForOnline",
            .oracle_path_prefix = "OraclePathPrefix",
            .use_path_prefix = "UsePathPrefix",
            .replace_path_prefix = "ReplacePathPrefix",
            .enable_homogenous_tablespace = "EnableHomogenousTablespace",
            .direct_path_no_log = "DirectPathNoLog",
            .archived_logs_only = "ArchivedLogsOnly",
            .asm_password = "AsmPassword",
            .asm_server = "AsmServer",
            .asm_user = "AsmUser",
            .char_length_semantics = "CharLengthSemantics",
            .database_name = "DatabaseName",
            .direct_path_parallel_load = "DirectPathParallelLoad",
            .fail_tasks_on_lob_truncation = "FailTasksOnLobTruncation",
            .number_datatype_scale = "NumberDatatypeScale",
            .password = "Password",
            .port = "Port",
            .read_table_space_name = "ReadTableSpaceName",
            .retry_interval = "RetryInterval",
            .security_db_encryption = "SecurityDbEncryption",
            .security_db_encryption_name = "SecurityDbEncryptionName",
            .server_name = "ServerName",
            .spatial_data_option_to_geo_json_function_name = "SpatialDataOptionToGeoJsonFunctionName",
            .username = "Username",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
            .secrets_manager_oracle_asm_access_role_arn = "SecretsManagerOracleAsmAccessRoleArn",
            .secrets_manager_oracle_asm_secret_id = "SecretsManagerOracleAsmSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const MySQLSettings = struct {
    after_connect_script: ?[]const u8 = null,
    clean_source_metadata_on_mismatch: ?bool = null,
    database_name: ?[]const u8 = null,
    events_poll_interval: ?i64 = null,
    target_db_type: ?[]const u8 = null,
    max_file_size: ?i64 = null,
    parallel_load_threads: ?i64 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    server_timezone: ?[]const u8 = null,
    username: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .after_connect_script = "AfterConnectScript",
            .clean_source_metadata_on_mismatch = "CleanSourceMetadataOnMismatch",
            .database_name = "DatabaseName",
            .events_poll_interval = "EventsPollInterval",
            .target_db_type = "TargetDbType",
            .max_file_size = "MaxFileSize",
            .parallel_load_threads = "ParallelLoadThreads",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .server_timezone = "ServerTimezone",
            .username = "Username",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const PostgreSQLSettings = struct {
    after_connect_script: ?[]const u8 = null,
    capture_ddls: ?bool = null,
    max_file_size: ?i64 = null,
    database_name: ?[]const u8 = null,
    ddl_artifacts_schema: ?[]const u8 = null,
    execute_timeout: ?i64 = null,
    fail_tasks_on_lob_truncation: ?bool = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    server_name: ?[]const u8 = null,
    username: ?[]const u8 = null,
    slot_name: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .after_connect_script = "AfterConnectScript",
            .capture_ddls = "CaptureDdls",
            .max_file_size = "MaxFileSize",
            .database_name = "DatabaseName",
            .ddl_artifacts_schema = "DdlArtifactsSchema",
            .execute_timeout = "ExecuteTimeout",
            .fail_tasks_on_lob_truncation = "FailTasksOnLobTruncation",
            .password = "Password",
            .port = "Port",
            .server_name = "ServerName",
            .username = "Username",
            .slot_name = "SlotName",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftSettings = struct {
    accept_any_date: ?bool = null,
    after_connect_script: ?[]const u8 = null,
    bucket_folder: ?[]const u8 = null,
    bucket_name: ?[]const u8 = null,
    case_sensitive_names: ?bool = null,
    comp_update: ?bool = null,
    connection_timeout: ?i64 = null,
    database_name: ?[]const u8 = null,
    date_format: ?[]const u8 = null,
    empty_as_null: ?bool = null,
    encryption_mode: ?[]const u8 = null,
    explicit_ids: ?bool = null,
    file_transfer_upload_streams: ?i64 = null,
    load_timeout: ?i64 = null,
    max_file_size: ?i64 = null,
    password: ?[]const u8 = null,
    port: ?i64 = null,
    remove_quotes: ?bool = null,
    replace_invalid_chars: ?[]const u8 = null,
    replace_chars: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    service_access_role_arn: ?[]const u8 = null,
    server_side_encryption_kms_key_id: ?[]const u8 = null,
    time_format: ?[]const u8 = null,
    trim_blanks: ?bool = null,
    truncate_columns: ?bool = null,
    username: ?[]const u8 = null,
    write_buffer_size: ?i64 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accept_any_date = "AcceptAnyDate",
            .after_connect_script = "AfterConnectScript",
            .bucket_folder = "BucketFolder",
            .bucket_name = "BucketName",
            .case_sensitive_names = "CaseSensitiveNames",
            .comp_update = "CompUpdate",
            .connection_timeout = "ConnectionTimeout",
            .database_name = "DatabaseName",
            .date_format = "DateFormat",
            .empty_as_null = "EmptyAsNull",
            .encryption_mode = "EncryptionMode",
            .explicit_ids = "ExplicitIds",
            .file_transfer_upload_streams = "FileTransferUploadStreams",
            .load_timeout = "LoadTimeout",
            .max_file_size = "MaxFileSize",
            .password = "Password",
            .port = "Port",
            .remove_quotes = "RemoveQuotes",
            .replace_invalid_chars = "ReplaceInvalidChars",
            .replace_chars = "ReplaceChars",
            .server_name = "ServerName",
            .service_access_role_arn = "ServiceAccessRoleArn",
            .server_side_encryption_kms_key_id = "ServerSideEncryptionKmsKeyId",
            .time_format = "TimeFormat",
            .trim_blanks = "TrimBlanks",
            .truncate_columns = "TruncateColumns",
            .username = "Username",
            .write_buffer_size = "WriteBufferSize",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const NeptuneSettings = struct {
    service_access_role_arn: ?[]const u8 = null,
    s3_bucket_name: []const u8,
    s3_bucket_folder: []const u8,
    error_retry_duration: ?i64 = null,
    max_file_size: ?i64 = null,
    max_retry_count: ?i64 = null,
    iam_auth_enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
            .s3_bucket_name = "S3BucketName",
            .s3_bucket_folder = "S3BucketFolder",
            .error_retry_duration = "ErrorRetryDuration",
            .max_file_size = "MaxFileSize",
            .max_retry_count = "MaxRetryCount",
            .iam_auth_enabled = "IamAuthEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchSettings = struct {
    service_access_role_arn: []const u8,
    endpoint_uri: []const u8,
    full_load_error_percentage: ?i64 = null,
    error_retry_duration: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
            .endpoint_uri = "EndpointUri",
            .full_load_error_percentage = "FullLoadErrorPercentage",
            .error_retry_duration = "ErrorRetryDuration",
        };
        return @field(mappings, field_name);
    }
};

pub const KafkaSettings = struct {
    broker: ?[]const u8 = null,
    topic: ?[]const u8 = null,
    message_format: ?[]const u8 = null,
    include_transaction_details: ?bool = null,
    include_partition_value: ?bool = null,
    partition_include_schema_table: ?bool = null,
    include_table_alter_operations: ?bool = null,
    include_control_details: ?bool = null,
    message_max_bytes: ?i64 = null,
    include_null_and_empty: ?bool = null,
    security_protocol: ?[]const u8 = null,
    ssl_client_certificate_arn: ?[]const u8 = null,
    ssl_client_key_arn: ?[]const u8 = null,
    ssl_client_key_password: ?[]const u8 = null,
    ssl_ca_certificate_arn: ?[]const u8 = null,
    sasl_username: ?[]const u8 = null,
    sasl_password: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .broker = "Broker",
            .topic = "Topic",
            .message_format = "MessageFormat",
            .include_transaction_details = "IncludeTransactionDetails",
            .include_partition_value = "IncludePartitionValue",
            .partition_include_schema_table = "PartitionIncludeSchemaTable",
            .include_table_alter_operations = "IncludeTableAlterOperations",
            .include_control_details = "IncludeControlDetails",
            .message_max_bytes = "MessageMaxBytes",
            .include_null_and_empty = "IncludeNullAndEmpty",
            .security_protocol = "SecurityProtocol",
            .ssl_client_certificate_arn = "SslClientCertificateArn",
            .ssl_client_key_arn = "SslClientKeyArn",
            .ssl_client_key_password = "SslClientKeyPassword",
            .ssl_ca_certificate_arn = "SslCaCertificateArn",
            .sasl_username = "SaslUsername",
            .sasl_password = "SaslPassword",
        };
        return @field(mappings, field_name);
    }
};

pub const KinesisSettings = struct {
    stream_arn: ?[]const u8 = null,
    message_format: ?[]const u8 = null,
    service_access_role_arn: ?[]const u8 = null,
    include_transaction_details: ?bool = null,
    include_partition_value: ?bool = null,
    partition_include_schema_table: ?bool = null,
    include_table_alter_operations: ?bool = null,
    include_control_details: ?bool = null,
    include_null_and_empty: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .stream_arn = "StreamArn",
            .message_format = "MessageFormat",
            .service_access_role_arn = "ServiceAccessRoleArn",
            .include_transaction_details = "IncludeTransactionDetails",
            .include_partition_value = "IncludePartitionValue",
            .partition_include_schema_table = "PartitionIncludeSchemaTable",
            .include_table_alter_operations = "IncludeTableAlterOperations",
            .include_control_details = "IncludeControlDetails",
            .include_null_and_empty = "IncludeNullAndEmpty",
        };
        return @field(mappings, field_name);
    }
};

pub const MongoDbSettings = struct {
    username: ?[]const u8 = null,
    password: ?[]const u8 = null,
    server_name: ?[]const u8 = null,
    port: ?i64 = null,
    database_name: ?[]const u8 = null,
    auth_type: ?[]const u8 = null,
    auth_mechanism: ?[]const u8 = null,
    nesting_level: ?[]const u8 = null,
    extract_doc_id: ?[]const u8 = null,
    docs_to_investigate: ?[]const u8 = null,
    auth_source: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    secrets_manager_access_role_arn: ?[]const u8 = null,
    secrets_manager_secret_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .password = "Password",
            .server_name = "ServerName",
            .port = "Port",
            .database_name = "DatabaseName",
            .auth_type = "AuthType",
            .auth_mechanism = "AuthMechanism",
            .nesting_level = "NestingLevel",
            .extract_doc_id = "ExtractDocId",
            .docs_to_investigate = "DocsToInvestigate",
            .auth_source = "AuthSource",
            .kms_key_id = "KmsKeyId",
            .secrets_manager_access_role_arn = "SecretsManagerAccessRoleArn",
            .secrets_manager_secret_id = "SecretsManagerSecretId",
        };
        return @field(mappings, field_name);
    }
};

pub const DmsTransferSettings = struct {
    service_access_role_arn: ?[]const u8 = null,
    bucket_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
            .bucket_name = "BucketName",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Settings = struct {
    service_access_role_arn: ?[]const u8 = null,
    external_table_definition: ?[]const u8 = null,
    csv_row_delimiter: ?[]const u8 = null,
    csv_delimiter: ?[]const u8 = null,
    bucket_folder: ?[]const u8 = null,
    bucket_name: ?[]const u8 = null,
    compression_type: ?[]const u8 = null,
    encryption_mode: ?[]const u8 = null,
    server_side_encryption_kms_key_id: ?[]const u8 = null,
    data_format: ?[]const u8 = null,
    encoding_type: ?[]const u8 = null,
    dict_page_size_limit: ?i64 = null,
    row_group_length: ?i64 = null,
    data_page_size: ?i64 = null,
    parquet_version: ?[]const u8 = null,
    enable_statistics: ?bool = null,
    include_op_for_full_load: ?bool = null,
    cdc_inserts_only: ?bool = null,
    timestamp_column_name: ?[]const u8 = null,
    parquet_timestamp_in_millisecond: ?bool = null,
    cdc_inserts_and_updates: ?bool = null,
    date_partition_enabled: ?bool = null,
    date_partition_sequence: ?[]const u8 = null,
    date_partition_delimiter: ?[]const u8 = null,
    use_csv_no_sup_value: ?bool = null,
    csv_no_sup_value: ?[]const u8 = null,
    preserve_transactions: ?bool = null,
    cdc_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
            .external_table_definition = "ExternalTableDefinition",
            .csv_row_delimiter = "CsvRowDelimiter",
            .csv_delimiter = "CsvDelimiter",
            .bucket_folder = "BucketFolder",
            .bucket_name = "BucketName",
            .compression_type = "CompressionType",
            .encryption_mode = "EncryptionMode",
            .server_side_encryption_kms_key_id = "ServerSideEncryptionKmsKeyId",
            .data_format = "DataFormat",
            .encoding_type = "EncodingType",
            .dict_page_size_limit = "DictPageSizeLimit",
            .row_group_length = "RowGroupLength",
            .data_page_size = "DataPageSize",
            .parquet_version = "ParquetVersion",
            .enable_statistics = "EnableStatistics",
            .include_op_for_full_load = "IncludeOpForFullLoad",
            .cdc_inserts_only = "CdcInsertsOnly",
            .timestamp_column_name = "TimestampColumnName",
            .parquet_timestamp_in_millisecond = "ParquetTimestampInMillisecond",
            .cdc_inserts_and_updates = "CdcInsertsAndUpdates",
            .date_partition_enabled = "DatePartitionEnabled",
            .date_partition_sequence = "DatePartitionSequence",
            .date_partition_delimiter = "DatePartitionDelimiter",
            .use_csv_no_sup_value = "UseCsvNoSupValue",
            .csv_no_sup_value = "CsvNoSupValue",
            .preserve_transactions = "PreserveTransactions",
            .cdc_path = "CdcPath",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamoDbSettings = struct {
    service_access_role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service_access_role_arn = "ServiceAccessRoleArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Certificate = struct {
    certificate_identifier: ?[]const u8 = null,
    certificate_creation_date: ?i64 = null,
    certificate_pem: ?[]const u8 = null,
    certificate_wallet: ?[]const u8 = null,
    certificate_arn: ?[]const u8 = null,
    certificate_owner: ?[]const u8 = null,
    valid_from_date: ?i64 = null,
    valid_to_date: ?i64 = null,
    signing_algorithm: ?[]const u8 = null,
    key_length: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_identifier = "CertificateIdentifier",
            .certificate_creation_date = "CertificateCreationDate",
            .certificate_pem = "CertificatePem",
            .certificate_wallet = "CertificateWallet",
            .certificate_arn = "CertificateArn",
            .certificate_owner = "CertificateOwner",
            .valid_from_date = "ValidFromDate",
            .valid_to_date = "ValidToDate",
            .signing_algorithm = "SigningAlgorithm",
            .key_length = "KeyLength",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePendingMaintenanceActions = struct {
    resource_identifier: ?[]const u8 = null,
    pending_maintenance_action_details: ?[]PendingMaintenanceAction = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_identifier = "ResourceIdentifier",
            .pending_maintenance_action_details = "PendingMaintenanceActionDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const PendingMaintenanceAction = struct {
    action: ?[]const u8 = null,
    auto_applied_after_date: ?i64 = null,
    forced_apply_date: ?i64 = null,
    opt_in_status: ?[]const u8 = null,
    current_apply_date: ?i64 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action = "Action",
            .auto_applied_after_date = "AutoAppliedAfterDate",
            .forced_apply_date = "ForcedApplyDate",
            .opt_in_status = "OptInStatus",
            .current_apply_date = "CurrentApplyDate",
            .description = "Description",
        };
        return @field(mappings, field_name);
    }
};
