const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-09-21";
pub const sdk_id: []const u8 = "ECR";
pub const arn_namespace: []const u8 = "ecr";
pub const endpoint_prefix: []const u8 = "api.ecr";
pub const sigv4_name: []const u8 = "ecr";
pub const name: []const u8 = "AmazonEC2ContainerRegistry_V20150921";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-09-21",
    sdk_id: []const u8 = "ECR",
    arn_namespace: []const u8 = "ecr",
    endpoint_prefix: []const u8 = "api.ecr",
    sigv4_name: []const u8 = "ecr",
    name: []const u8 = "AmazonEC2ContainerRegistry_V20150921",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_check_layer_availability: struct {
    action_name: []const u8 = "BatchCheckLayerAvailability",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        layer_digests: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .layer_digests = "layerDigests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_check_layer_availability) } {
            return .{ .service_metadata = service_metadata, .action = batch_check_layer_availability };
        }
    },
    Response: type = struct {
        layers: ?[]struct {
            layer_digest: ?[]const u8 = null,
            layer_availability: ?[]const u8 = null,
            layer_size: ?i64 = null,
            media_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .layer_digest = "layerDigest",
                    .layer_availability = "layerAvailability",
                    .layer_size = "layerSize",
                    .media_type = "mediaType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        failures: ?[]struct {
            layer_digest: ?[]const u8 = null,
            failure_code: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .layer_digest = "layerDigest",
                    .failure_code = "failureCode",
                    .failure_reason = "failureReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .layers = "layers",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const batch_delete_image: struct {
    action_name: []const u8 = "BatchDeleteImage",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_ids: []ImageIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_ids = "imageIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_image) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_image };
        }
    },
    Response: type = struct {
        image_ids: ?[]ImageIdentifier = null,
        failures: ?[]ImageFailure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_ids = "imageIds",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const batch_get_image: struct {
    action_name: []const u8 = "BatchGetImage",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_ids: []ImageIdentifier,
        accepted_media_types: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_ids = "imageIds",
                .accepted_media_types = "acceptedMediaTypes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_image) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_image };
        }
    },
    Response: type = struct {
        images: ?[]Image = null,
        failures: ?[]ImageFailure = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .images = "images",
                .failures = "failures",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const complete_layer_upload: struct {
    action_name: []const u8 = "CompleteLayerUpload",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        upload_id: []const u8,
        layer_digests: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .upload_id = "uploadId",
                .layer_digests = "layerDigests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(complete_layer_upload) } {
            return .{ .service_metadata = service_metadata, .action = complete_layer_upload };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        upload_id: ?[]const u8 = null,
        layer_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .upload_id = "uploadId",
                .layer_digest = "layerDigest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EmptyUpload,
        InvalidLayer,
        InvalidParameter,
        Kms,
        LayerAlreadyExists,
        LayerPartTooSmall,
        RepositoryNotFound,
        Server,
        UploadNotFound,
    },
} = .{};
pub const create_repository: struct {
    action_name: []const u8 = "CreateRepository",
    Request: type = struct {
        repository_name: []const u8,
        tags: ?[]Tag = null,
        image_tag_mutability: ?[]const u8 = null,
        image_scanning_configuration: ?ImageScanningConfiguration = null,
        encryption_configuration: ?EncryptionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository_name = "repositoryName",
                .tags = "tags",
                .image_tag_mutability = "imageTagMutability",
                .image_scanning_configuration = "imageScanningConfiguration",
                .encryption_configuration = "encryptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_repository) } {
            return .{ .service_metadata = service_metadata, .action = create_repository };
        }
    },
    Response: type = struct {
        repository: ?Repository = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidTagParameter,
        Kms,
        LimitExceeded,
        RepositoryAlreadyExists,
        Server,
        TooManyTags,
    },
} = .{};
pub const delete_lifecycle_policy: struct {
    action_name: []const u8 = "DeleteLifecyclePolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_lifecycle_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        lifecycle_policy_text: ?[]const u8 = null,
        last_evaluated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .lifecycle_policy_text = "lifecyclePolicyText",
                .last_evaluated_at = "lastEvaluatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LifecyclePolicyNotFound,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const delete_registry_policy: struct {
    action_name: []const u8 = "DeleteRegistryPolicy",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_registry_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_registry_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RegistryPolicyNotFound,
        Server,
    },
} = .{};
pub const delete_repository: struct {
    action_name: []const u8 = "DeleteRepository",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_repository) } {
            return .{ .service_metadata = service_metadata, .action = delete_repository };
        }
    },
    Response: type = struct {
        repository: ?Repository = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repository = "repository",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Kms,
        RepositoryNotEmpty,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const delete_repository_policy: struct {
    action_name: []const u8 = "DeleteRepositoryPolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_repository_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_repository_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        RepositoryPolicyNotFound,
        Server,
    },
} = .{};
pub const describe_images: struct {
    action_name: []const u8 = "DescribeImages",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_ids: ?[]ImageIdentifier = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?struct {
            tag_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_status = "tagStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_ids = "imageIds",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filter = "filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_images) } {
            return .{ .service_metadata = service_metadata, .action = describe_images };
        }
    },
    Response: type = struct {
        image_details: ?[]struct {
            registry_id: ?[]const u8 = null,
            repository_name: ?[]const u8 = null,
            image_digest: ?[]const u8 = null,
            image_tags: ?[][]const u8 = null,
            image_size_in_bytes: ?i64 = null,
            image_pushed_at: ?i64 = null,
            image_scan_status: ?ImageScanStatus = null,
            image_scan_findings_summary: ?struct {
                image_scan_completed_at: ?i64 = null,
                vulnerability_source_updated_at: ?i64 = null,
                finding_severity_counts: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .image_scan_completed_at = "imageScanCompletedAt",
                        .vulnerability_source_updated_at = "vulnerabilitySourceUpdatedAt",
                        .finding_severity_counts = "findingSeverityCounts",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "finding_severity_counts", field_name))
                        return try serializeMap(self.finding_severity_counts, self.fieldNameFor("finding_severity_counts"), options, out_stream);
                    return false;
                }
            } = null,
            image_manifest_media_type: ?[]const u8 = null,
            artifact_media_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_id = "registryId",
                    .repository_name = "repositoryName",
                    .image_digest = "imageDigest",
                    .image_tags = "imageTags",
                    .image_size_in_bytes = "imageSizeInBytes",
                    .image_pushed_at = "imagePushedAt",
                    .image_scan_status = "imageScanStatus",
                    .image_scan_findings_summary = "imageScanFindingsSummary",
                    .image_manifest_media_type = "imageManifestMediaType",
                    .artifact_media_type = "artifactMediaType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_details = "imageDetails",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImageNotFound,
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const describe_image_scan_findings: struct {
    action_name: []const u8 = "DescribeImageScanFindings",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_id: ImageIdentifier,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_id = "imageId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_image_scan_findings) } {
            return .{ .service_metadata = service_metadata, .action = describe_image_scan_findings };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        image_id: ?ImageIdentifier = null,
        image_scan_status: ?ImageScanStatus = null,
        image_scan_findings: ?struct {
            image_scan_completed_at: ?i64 = null,
            vulnerability_source_updated_at: ?i64 = null,
            findings: ?[]struct {
                name: ?[]const u8 = null,
                description: ?[]const u8 = null,
                uri: ?[]const u8 = null,
                severity: ?[]const u8 = null,
                attributes: ?[]struct {
                    key: []const u8,
                    value: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .key = "key",
                            .value = "value",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .description = "description",
                        .uri = "uri",
                        .severity = "severity",
                        .attributes = "attributes",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            finding_severity_counts: ?[]struct {
                key: ?[]const u8 = null,
                value: ?i64 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_scan_completed_at = "imageScanCompletedAt",
                    .vulnerability_source_updated_at = "vulnerabilitySourceUpdatedAt",
                    .findings = "findings",
                    .finding_severity_counts = "findingSeverityCounts",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "finding_severity_counts", field_name))
                    return try serializeMap(self.finding_severity_counts, self.fieldNameFor("finding_severity_counts"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_id = "imageId",
                .image_scan_status = "imageScanStatus",
                .image_scan_findings = "imageScanFindings",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImageNotFound,
        InvalidParameter,
        RepositoryNotFound,
        ScanNotFound,
        Server,
    },
} = .{};
pub const describe_registry: struct {
    action_name: []const u8 = "DescribeRegistry",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_registry) } {
            return .{ .service_metadata = service_metadata, .action = describe_registry };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        replication_configuration: ?ReplicationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .replication_configuration = "replicationConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Server,
        Validation,
    },
} = .{};
pub const describe_repositories: struct {
    action_name: []const u8 = "DescribeRepositories",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_names = "repositoryNames",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_repositories) } {
            return .{ .service_metadata = service_metadata, .action = describe_repositories };
        }
    },
    Response: type = struct {
        repositories: ?[]Repository = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .repositories = "repositories",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const get_authorization_token: struct {
    action_name: []const u8 = "GetAuthorizationToken",
    Request: type = struct {
        registry_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_ids = "registryIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_authorization_token) } {
            return .{ .service_metadata = service_metadata, .action = get_authorization_token };
        }
    },
    Response: type = struct {
        authorization_data: ?[]struct {
            authorization_token: ?[]const u8 = null,
            expires_at: ?i64 = null,
            proxy_endpoint: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .authorization_token = "authorizationToken",
                    .expires_at = "expiresAt",
                    .proxy_endpoint = "proxyEndpoint",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorization_data = "authorizationData",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Server,
    },
} = .{};
pub const get_download_url_for_layer: struct {
    action_name: []const u8 = "GetDownloadUrlForLayer",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        layer_digest: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .layer_digest = "layerDigest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_download_url_for_layer) } {
            return .{ .service_metadata = service_metadata, .action = get_download_url_for_layer };
        }
    },
    Response: type = struct {
        download_url: ?[]const u8 = null,
        layer_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .download_url = "downloadUrl",
                .layer_digest = "layerDigest",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LayerInaccessible,
        LayersNotFound,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const get_lifecycle_policy: struct {
    action_name: []const u8 = "GetLifecyclePolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_lifecycle_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        lifecycle_policy_text: ?[]const u8 = null,
        last_evaluated_at: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .lifecycle_policy_text = "lifecyclePolicyText",
                .last_evaluated_at = "lastEvaluatedAt",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LifecyclePolicyNotFound,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const get_lifecycle_policy_preview: struct {
    action_name: []const u8 = "GetLifecyclePolicyPreview",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_ids: ?[]ImageIdentifier = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?struct {
            tag_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_status = "tagStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_ids = "imageIds",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filter = "filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_lifecycle_policy_preview) } {
            return .{ .service_metadata = service_metadata, .action = get_lifecycle_policy_preview };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        lifecycle_policy_text: ?[]const u8 = null,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        preview_results: ?[]struct {
            image_tags: ?[][]const u8 = null,
            image_digest: ?[]const u8 = null,
            image_pushed_at: ?i64 = null,
            action: ?struct {
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            applied_rule_priority: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_tags = "imageTags",
                    .image_digest = "imageDigest",
                    .image_pushed_at = "imagePushedAt",
                    .action = "action",
                    .applied_rule_priority = "appliedRulePriority",
                };
                return @field(mappings, field_name);
            }
        } = null,
        summary: ?struct {
            expiring_image_total_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .expiring_image_total_count = "expiringImageTotalCount",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .lifecycle_policy_text = "lifecyclePolicyText",
                .status = "status",
                .next_token = "nextToken",
                .preview_results = "previewResults",
                .summary = "summary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LifecyclePolicyPreviewNotFound,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const get_registry_policy: struct {
    action_name: []const u8 = "GetRegistryPolicy",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_registry_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_registry_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RegistryPolicyNotFound,
        Server,
    },
} = .{};
pub const get_repository_policy: struct {
    action_name: []const u8 = "GetRepositoryPolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_repository_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_repository_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        RepositoryPolicyNotFound,
        Server,
    },
} = .{};
pub const initiate_layer_upload: struct {
    action_name: []const u8 = "InitiateLayerUpload",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(initiate_layer_upload) } {
            return .{ .service_metadata = service_metadata, .action = initiate_layer_upload };
        }
    },
    Response: type = struct {
        upload_id: ?[]const u8 = null,
        part_size: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .upload_id = "uploadId",
                .part_size = "partSize",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Kms,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const list_images: struct {
    action_name: []const u8 = "ListImages",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?struct {
            tag_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .tag_status = "tagStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .next_token = "nextToken",
                .max_results = "maxResults",
                .filter = "filter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_images) } {
            return .{ .service_metadata = service_metadata, .action = list_images };
        }
    },
    Response: type = struct {
        image_ids: ?[]ImageIdentifier = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_ids = "imageIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const put_image: struct {
    action_name: []const u8 = "PutImage",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_manifest: []const u8,
        image_manifest_media_type: ?[]const u8 = null,
        image_tag: ?[]const u8 = null,
        image_digest: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_manifest = "imageManifest",
                .image_manifest_media_type = "imageManifestMediaType",
                .image_tag = "imageTag",
                .image_digest = "imageDigest",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_image) } {
            return .{ .service_metadata = service_metadata, .action = put_image };
        }
    },
    Response: type = struct {
        image: ?Image = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image = "image",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImageAlreadyExists,
        ImageDigestDoesNotMatch,
        ImageTagAlreadyExists,
        InvalidParameter,
        Kms,
        LayersNotFound,
        LimitExceeded,
        ReferencedImagesNotFound,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const put_image_scanning_configuration: struct {
    action_name: []const u8 = "PutImageScanningConfiguration",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_scanning_configuration: ImageScanningConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_scanning_configuration = "imageScanningConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_image_scanning_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_image_scanning_configuration };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        image_scanning_configuration: ?ImageScanningConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_scanning_configuration = "imageScanningConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const put_image_tag_mutability: struct {
    action_name: []const u8 = "PutImageTagMutability",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_tag_mutability: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_tag_mutability = "imageTagMutability",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_image_tag_mutability) } {
            return .{ .service_metadata = service_metadata, .action = put_image_tag_mutability };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        image_tag_mutability: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_tag_mutability = "imageTagMutability",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const put_lifecycle_policy: struct {
    action_name: []const u8 = "PutLifecyclePolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        lifecycle_policy_text: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .lifecycle_policy_text = "lifecyclePolicyText",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_lifecycle_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_lifecycle_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        lifecycle_policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .lifecycle_policy_text = "lifecyclePolicyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const put_registry_policy: struct {
    action_name: []const u8 = "PutRegistryPolicy",
    Request: type = struct {
        policy_text: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_registry_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_registry_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Server,
    },
} = .{};
pub const put_replication_configuration: struct {
    action_name: []const u8 = "PutReplicationConfiguration",
    Request: type = struct {
        replication_configuration: ReplicationConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_configuration = "replicationConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_replication_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_replication_configuration };
        }
    },
    Response: type = struct {
        replication_configuration: ?ReplicationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .replication_configuration = "replicationConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        Server,
        Validation,
    },
} = .{};
pub const set_repository_policy: struct {
    action_name: []const u8 = "SetRepositoryPolicy",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        policy_text: []const u8,
        force: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .policy_text = "policyText",
                .force = "force",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(set_repository_policy) } {
            return .{ .service_metadata = service_metadata, .action = set_repository_policy };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .policy_text = "policyText",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const start_image_scan: struct {
    action_name: []const u8 = "StartImageScan",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        image_id: ImageIdentifier,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_id = "imageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_image_scan) } {
            return .{ .service_metadata = service_metadata, .action = start_image_scan };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        image_id: ?ImageIdentifier = null,
        image_scan_status: ?ImageScanStatus = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .image_id = "imageId",
                .image_scan_status = "imageScanStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ImageNotFound,
        InvalidParameter,
        LimitExceeded,
        RepositoryNotFound,
        Server,
        UnsupportedImageType,
    },
} = .{};
pub const start_lifecycle_policy_preview: struct {
    action_name: []const u8 = "StartLifecyclePolicyPreview",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        lifecycle_policy_text: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .lifecycle_policy_text = "lifecyclePolicyText",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_lifecycle_policy_preview) } {
            return .{ .service_metadata = service_metadata, .action = start_lifecycle_policy_preview };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        lifecycle_policy_text: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .lifecycle_policy_text = "lifecyclePolicyText",
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        LifecyclePolicyNotFound,
        LifecyclePolicyPreviewInProgress,
        RepositoryNotFound,
        Server,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidTagParameter,
        RepositoryNotFound,
        Server,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        InvalidTagParameter,
        RepositoryNotFound,
        Server,
        TooManyTags,
    },
} = .{};
pub const upload_layer_part: struct {
    action_name: []const u8 = "UploadLayerPart",
    Request: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: []const u8,
        upload_id: []const u8,
        part_first_byte: i64,
        part_last_byte: i64,
        layer_part_blob: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .upload_id = "uploadId",
                .part_first_byte = "partFirstByte",
                .part_last_byte = "partLastByte",
                .layer_part_blob = "layerPartBlob",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(upload_layer_part) } {
            return .{ .service_metadata = service_metadata, .action = upload_layer_part };
        }
    },
    Response: type = struct {
        registry_id: ?[]const u8 = null,
        repository_name: ?[]const u8 = null,
        upload_id: ?[]const u8 = null,
        last_byte_received: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "registryId",
                .repository_name = "repositoryName",
                .upload_id = "uploadId",
                .last_byte_received = "lastByteReceived",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidLayerPart,
        InvalidParameter,
        Kms,
        LimitExceeded,
        RepositoryNotFound,
        Server,
        UploadNotFound,
    },
} = .{};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageScanStatus = struct {
    status: ?[]const u8 = null,
    description: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .description = "description",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageIdentifier = struct {
    image_digest: ?[]const u8 = null,
    image_tag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_digest = "imageDigest",
            .image_tag = "imageTag",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationConfiguration = struct {
    rules: []ReplicationRule,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rules = "rules",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationRule = struct {
    destinations: []ReplicationDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destinations = "destinations",
        };
        return @field(mappings, field_name);
    }
};

pub const ReplicationDestination = struct {
    region: []const u8,
    registry_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "region",
            .registry_id = "registryId",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageScanningConfiguration = struct {
    scan_on_push: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scan_on_push = "scanOnPush",
        };
        return @field(mappings, field_name);
    }
};

pub const Image = struct {
    registry_id: ?[]const u8 = null,
    repository_name: ?[]const u8 = null,
    image_id: ?ImageIdentifier = null,
    image_manifest: ?[]const u8 = null,
    image_manifest_media_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .registry_id = "registryId",
            .repository_name = "repositoryName",
            .image_id = "imageId",
            .image_manifest = "imageManifest",
            .image_manifest_media_type = "imageManifestMediaType",
        };
        return @field(mappings, field_name);
    }
};

pub const Repository = struct {
    repository_arn: ?[]const u8 = null,
    registry_id: ?[]const u8 = null,
    repository_name: ?[]const u8 = null,
    repository_uri: ?[]const u8 = null,
    created_at: ?i64 = null,
    image_tag_mutability: ?[]const u8 = null,
    image_scanning_configuration: ?ImageScanningConfiguration = null,
    encryption_configuration: ?EncryptionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_arn = "repositoryArn",
            .registry_id = "registryId",
            .repository_name = "repositoryName",
            .repository_uri = "repositoryUri",
            .created_at = "createdAt",
            .image_tag_mutability = "imageTagMutability",
            .image_scanning_configuration = "imageScanningConfiguration",
            .encryption_configuration = "encryptionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    encryption_type: []const u8,
    kms_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_type = "encryptionType",
            .kms_key = "kmsKey",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageFailure = struct {
    image_id: ?ImageIdentifier = null,
    failure_code: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_id = "imageId",
            .failure_code = "failureCode",
            .failure_reason = "failureReason",
        };
        return @field(mappings, field_name);
    }
};
