const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-12-01";
pub const sdk_id: []const u8 = "fis";
pub const arn_namespace: []const u8 = "fis";
pub const endpoint_prefix: []const u8 = "fis";
pub const sigv4_name: []const u8 = "fis";
pub const name: []const u8 = "FaultInjectionSimulator";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-12-01",
    sdk_id: []const u8 = "fis",
    arn_namespace: []const u8 = "fis",
    endpoint_prefix: []const u8 = "fis",
    sigv4_name: []const u8 = "fis",
    name: []const u8 = "FaultInjectionSimulator",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_experiment_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/experimentTemplates",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateExperimentTemplate",
    Request: type = struct {
        client_token: []const u8,
        description: []const u8,
        stop_conditions: []struct {
            source: []const u8,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source = "source",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        },
        targets: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                resource_type: []const u8,
                resource_arns: ?[][]const u8 = null,
                resource_tags: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                filters: ?[]ExperimentTemplateTargetInputFilter = null,
                selection_mode: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource_arns = "resourceArns",
                        .resource_tags = "resourceTags",
                        .filters = "filters",
                        .selection_mode = "selectionMode",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "resource_tags", field_name))
                        return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        actions: []struct {
            key: ?[]const u8 = null,
            value: ?struct {
                action_id: []const u8,
                description: ?[]const u8 = null,
                parameters: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                targets: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                start_after: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action_id = "actionId",
                        .description = "description",
                        .parameters = "parameters",
                        .targets = "targets",
                        .start_after = "startAfter",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "parameters", field_name))
                        return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                    if (std.mem.eql(u8, "targets", field_name))
                        return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
                    return false;
                }
            } = null,
        },
        role_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .description = "description",
                .stop_conditions = "stopConditions",
                .targets = "targets",
                .actions = "actions",
                .role_arn = "roleArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "targets", field_name))
                return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
            if (std.mem.eql(u8, "actions", field_name))
                return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_experiment_template) } {
            return .{ .service_metadata = service_metadata, .action = create_experiment_template };
        }
    },
    Response: type = struct {
        experiment_template: ?ExperimentTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_template = "experimentTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const delete_experiment_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/experimentTemplates/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteExperimentTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_experiment_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_experiment_template };
        }
    },
    Response: type = struct {
        experiment_template: ?ExperimentTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_template = "experimentTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_action: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/actions/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetAction",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_action) } {
            return .{ .service_metadata = service_metadata, .action = get_action };
        }
    },
    Response: type = struct {
        action: ?struct {
            id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?struct {
                    description: ?[]const u8 = null,
                    required: ?bool = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .description = "description",
                            .required = "required",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
            } = null,
            targets: ?[]struct {
                key: ?[]const u8 = null,
                value: ?ActionTarget = null,
            } = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .description = "description",
                    .parameters = "parameters",
                    .targets = "targets",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                if (std.mem.eql(u8, "targets", field_name))
                    return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action = "action",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_experiment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/experiments/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExperiment",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_experiment) } {
            return .{ .service_metadata = service_metadata, .action = get_experiment };
        }
    },
    Response: type = struct {
        experiment: ?Experiment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment = "experiment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const get_experiment_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/experimentTemplates/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetExperimentTemplate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_experiment_template) } {
            return .{ .service_metadata = service_metadata, .action = get_experiment_template };
        }
    },
    Response: type = struct {
        experiment_template: ?ExperimentTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_template = "experimentTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const list_actions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/actions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListActions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_actions };
        }
    },
    Response: type = struct {
        actions: ?[]struct {
            id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            targets: ?[]struct {
                key: ?[]const u8 = null,
                value: ?ActionTarget = null,
            } = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .description = "description",
                    .targets = "targets",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "targets", field_name))
                    return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .actions = "actions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_experiments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/experiments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListExperiments",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_experiments) } {
            return .{ .service_metadata = service_metadata, .action = list_experiments };
        }
    },
    Response: type = struct {
        experiments: ?[]struct {
            id: ?[]const u8 = null,
            experiment_template_id: ?[]const u8 = null,
            state: ?ExperimentState = null,
            creation_time: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .experiment_template_id = "experimentTemplateId",
                    .state = "state",
                    .creation_time = "creationTime",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiments = "experiments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_experiment_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/experimentTemplates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListExperimentTemplates",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_experiment_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_experiment_templates };
        }
    },
    Response: type = struct {
        experiment_templates: ?[]struct {
            id: ?[]const u8 = null,
            description: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_update_time: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "id",
                    .description = "description",
                    .creation_time = "creationTime",
                    .last_update_time = "lastUpdateTime",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_templates = "experimentTemplates",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const start_experiment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/experiments",
        .success_code = 200,
    };

    action_name: []const u8 = "StartExperiment",
    Request: type = struct {
        client_token: []const u8,
        experiment_template_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .experiment_template_id = "experimentTemplateId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_experiment) } {
            return .{ .service_metadata = service_metadata, .action = start_experiment };
        }
    },
    Response: type = struct {
        experiment: ?Experiment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment = "experiment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};
pub const stop_experiment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/experiments/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "StopExperiment",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_experiment) } {
            return .{ .service_metadata = service_metadata, .action = stop_experiment };
        }
    },
    Response: type = struct {
        experiment: ?Experiment = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment = "experiment",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: ?[][]const u8 = null,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_experiment_template: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/experimentTemplates/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateExperimentTemplate",
    Request: type = struct {
        id: []const u8,
        description: ?[]const u8 = null,
        stop_conditions: ?[]struct {
            source: []const u8,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source = "source",
                    .value = "value",
                };
                return @field(mappings, field_name);
            }
        } = null,
        targets: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                resource_type: []const u8,
                resource_arns: ?[][]const u8 = null,
                resource_tags: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                filters: ?[]ExperimentTemplateTargetInputFilter = null,
                selection_mode: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource_arns = "resourceArns",
                        .resource_tags = "resourceTags",
                        .filters = "filters",
                        .selection_mode = "selectionMode",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "resource_tags", field_name))
                        return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        actions: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                action_id: ?[]const u8 = null,
                description: ?[]const u8 = null,
                parameters: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                targets: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                start_after: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .action_id = "actionId",
                        .description = "description",
                        .parameters = "parameters",
                        .targets = "targets",
                        .start_after = "startAfter",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "parameters", field_name))
                        return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                    if (std.mem.eql(u8, "targets", field_name))
                        return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
                    return false;
                }
            } = null,
        } = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "id",
                .description = "description",
                .stop_conditions = "stopConditions",
                .targets = "targets",
                .actions = "actions",
                .role_arn = "roleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "targets", field_name))
                return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
            if (std.mem.eql(u8, "actions", field_name))
                return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_experiment_template) } {
            return .{ .service_metadata = service_metadata, .action = update_experiment_template };
        }
    },
    Response: type = struct {
        experiment_template: ?ExperimentTemplate = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_template = "experimentTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ServiceQuotaExceeded,
        Validation,
    },
} = .{};

pub const ExperimentTemplate = struct {
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    targets: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ExperimentTemplateTarget = null,
    } = null,
    actions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ExperimentTemplateAction = null,
    } = null,
    stop_conditions: ?[]ExperimentTemplateStopCondition = null,
    creation_time: ?i64 = null,
    last_update_time: ?i64 = null,
    role_arn: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .description = "description",
            .targets = "targets",
            .actions = "actions",
            .stop_conditions = "stopConditions",
            .creation_time = "creationTime",
            .last_update_time = "lastUpdateTime",
            .role_arn = "roleArn",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "targets", field_name))
            return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
        if (std.mem.eql(u8, "actions", field_name))
            return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ExperimentTemplateStopCondition = struct {
    source: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperimentTemplateAction = struct {
    action_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    targets: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    start_after: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_id = "actionId",
            .description = "description",
            .parameters = "parameters",
            .targets = "targets",
            .start_after = "startAfter",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        if (std.mem.eql(u8, "targets", field_name))
            return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
        return false;
    }
};

pub const ExperimentTemplateTarget = struct {
    resource_type: ?[]const u8 = null,
    resource_arns: ?[][]const u8 = null,
    resource_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    filters: ?[]ExperimentTemplateTargetFilter = null,
    selection_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .resource_arns = "resourceArns",
            .resource_tags = "resourceTags",
            .filters = "filters",
            .selection_mode = "selectionMode",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "resource_tags", field_name))
            return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
        return false;
    }
};

pub const ExperimentTemplateTargetFilter = struct {
    path: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "path",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperimentTemplateTargetInputFilter = struct {
    path: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "path",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const Experiment = struct {
    id: ?[]const u8 = null,
    experiment_template_id: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    state: ?ExperimentState = null,
    targets: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ExperimentTarget = null,
    } = null,
    actions: ?[]struct {
        key: ?[]const u8 = null,
        value: ?ExperimentAction = null,
    } = null,
    stop_conditions: ?[]ExperimentStopCondition = null,
    creation_time: ?i64 = null,
    start_time: ?i64 = null,
    end_time: ?i64 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .experiment_template_id = "experimentTemplateId",
            .role_arn = "roleArn",
            .state = "state",
            .targets = "targets",
            .actions = "actions",
            .stop_conditions = "stopConditions",
            .creation_time = "creationTime",
            .start_time = "startTime",
            .end_time = "endTime",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "targets", field_name))
            return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
        if (std.mem.eql(u8, "actions", field_name))
            return try serializeMap(self.actions, self.fieldNameFor("actions"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ExperimentStopCondition = struct {
    source: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "source",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperimentAction = struct {
    action_id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    targets: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    start_after: ?[][]const u8 = null,
    state: ?ExperimentActionState = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .action_id = "actionId",
            .description = "description",
            .parameters = "parameters",
            .targets = "targets",
            .start_after = "startAfter",
            .state = "state",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        if (std.mem.eql(u8, "targets", field_name))
            return try serializeMap(self.targets, self.fieldNameFor("targets"), options, out_stream);
        return false;
    }
};

pub const ExperimentActionState = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperimentTarget = struct {
    resource_type: ?[]const u8 = null,
    resource_arns: ?[][]const u8 = null,
    resource_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    filters: ?[]ExperimentTargetFilter = null,
    selection_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
            .resource_arns = "resourceArns",
            .resource_tags = "resourceTags",
            .filters = "filters",
            .selection_mode = "selectionMode",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "resource_tags", field_name))
            return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
        return false;
    }
};

pub const ExperimentTargetFilter = struct {
    path: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "path",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperimentState = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionTarget = struct {
    resource_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "resourceType",
        };
        return @field(mappings, field_name);
    }
};
