const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-06-26";
pub const sdk_id: []const u8 = "forecast";
pub const arn_namespace: []const u8 = "forecast";
pub const endpoint_prefix: []const u8 = "forecast";
pub const sigv4_name: []const u8 = "forecast";
pub const name: []const u8 = "AmazonForecast";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-06-26",
    sdk_id: []const u8 = "forecast",
    arn_namespace: []const u8 = "forecast",
    endpoint_prefix: []const u8 = "forecast",
    sigv4_name: []const u8 = "forecast",
    name: []const u8 = "AmazonForecast",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_dataset: struct {
    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        dataset_name: []const u8,
        domain: []const u8,
        dataset_type: []const u8,
        data_frequency: ?[]const u8 = null,
        schema: Schema,
        encryption_config: ?EncryptionConfig = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .domain = "Domain",
                .dataset_type = "DatasetType",
                .data_frequency = "DataFrequency",
                .schema = "Schema",
                .encryption_config = "EncryptionConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        dataset_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
    },
} = .{};
pub const create_dataset_group: struct {
    action_name: []const u8 = "CreateDatasetGroup",
    Request: type = struct {
        dataset_group_name: []const u8,
        domain: []const u8,
        dataset_arns: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_name = "DatasetGroupName",
                .domain = "Domain",
                .dataset_arns = "DatasetArns",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset_group) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset_group };
        }
    },
    Response: type = struct {
        dataset_group_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "DatasetGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const create_dataset_import_job: struct {
    action_name: []const u8 = "CreateDatasetImportJob",
    Request: type = struct {
        dataset_import_job_name: []const u8,
        dataset_arn: []const u8,
        data_source: DataSource,
        timestamp_format: ?[]const u8 = null,
        time_zone: ?[]const u8 = null,
        use_geolocation_for_time_zone: ?bool = null,
        geolocation_format: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_job_name = "DatasetImportJobName",
                .dataset_arn = "DatasetArn",
                .data_source = "DataSource",
                .timestamp_format = "TimestampFormat",
                .time_zone = "TimeZone",
                .use_geolocation_for_time_zone = "UseGeolocationForTimeZone",
                .geolocation_format = "GeolocationFormat",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset_import_job) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset_import_job };
        }
    },
    Response: type = struct {
        dataset_import_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_job_arn = "DatasetImportJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const create_forecast: struct {
    action_name: []const u8 = "CreateForecast",
    Request: type = struct {
        forecast_name: []const u8,
        predictor_arn: []const u8,
        forecast_types: ?[][]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_name = "ForecastName",
                .predictor_arn = "PredictorArn",
                .forecast_types = "ForecastTypes",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_forecast) } {
            return .{ .service_metadata = service_metadata, .action = create_forecast };
        }
    },
    Response: type = struct {
        forecast_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_arn = "ForecastArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const create_forecast_export_job: struct {
    action_name: []const u8 = "CreateForecastExportJob",
    Request: type = struct {
        forecast_export_job_name: []const u8,
        forecast_arn: []const u8,
        destination: DataDestination,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_export_job_name = "ForecastExportJobName",
                .forecast_arn = "ForecastArn",
                .destination = "Destination",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_forecast_export_job) } {
            return .{ .service_metadata = service_metadata, .action = create_forecast_export_job };
        }
    },
    Response: type = struct {
        forecast_export_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_export_job_arn = "ForecastExportJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const create_predictor: struct {
    action_name: []const u8 = "CreatePredictor",
    Request: type = struct {
        predictor_name: []const u8,
        algorithm_arn: ?[]const u8 = null,
        forecast_horizon: i64,
        forecast_types: ?[][]const u8 = null,
        perform_auto_ml: ?bool = null,
        perform_hpo: ?bool = null,
        training_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        evaluation_parameters: ?EvaluationParameters = null,
        hpo_config: ?HyperParameterTuningJobConfig = null,
        input_data_config: InputDataConfig,
        featurization_config: FeaturizationConfig,
        encryption_config: ?EncryptionConfig = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_name = "PredictorName",
                .algorithm_arn = "AlgorithmArn",
                .forecast_horizon = "ForecastHorizon",
                .forecast_types = "ForecastTypes",
                .perform_auto_ml = "PerformAutoML",
                .perform_hpo = "PerformHPO",
                .training_parameters = "TrainingParameters",
                .evaluation_parameters = "EvaluationParameters",
                .hpo_config = "HPOConfig",
                .input_data_config = "InputDataConfig",
                .featurization_config = "FeaturizationConfig",
                .encryption_config = "EncryptionConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "training_parameters", field_name))
                return try serializeMap(self.training_parameters, self.fieldNameFor("training_parameters"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_predictor) } {
            return .{ .service_metadata = service_metadata, .action = create_predictor };
        }
    },
    Response: type = struct {
        predictor_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_arn = "PredictorArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const create_predictor_backtest_export_job: struct {
    action_name: []const u8 = "CreatePredictorBacktestExportJob",
    Request: type = struct {
        predictor_backtest_export_job_name: []const u8,
        predictor_arn: []const u8,
        destination: DataDestination,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_backtest_export_job_name = "PredictorBacktestExportJobName",
                .predictor_arn = "PredictorArn",
                .destination = "Destination",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_predictor_backtest_export_job) } {
            return .{ .service_metadata = service_metadata, .action = create_predictor_backtest_export_job };
        }
    },
    Response: type = struct {
        predictor_backtest_export_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_backtest_export_job_arn = "PredictorBacktestExportJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceAlreadyExists,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_dataset: struct {
    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        dataset_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_dataset_group: struct {
    action_name: []const u8 = "DeleteDatasetGroup",
    Request: type = struct {
        dataset_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "DatasetGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_dataset_import_job: struct {
    action_name: []const u8 = "DeleteDatasetImportJob",
    Request: type = struct {
        dataset_import_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_job_arn = "DatasetImportJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset_import_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset_import_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_forecast: struct {
    action_name: []const u8 = "DeleteForecast",
    Request: type = struct {
        forecast_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_arn = "ForecastArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_forecast) } {
            return .{ .service_metadata = service_metadata, .action = delete_forecast };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_forecast_export_job: struct {
    action_name: []const u8 = "DeleteForecastExportJob",
    Request: type = struct {
        forecast_export_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_export_job_arn = "ForecastExportJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_forecast_export_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_forecast_export_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_predictor: struct {
    action_name: []const u8 = "DeletePredictor",
    Request: type = struct {
        predictor_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_arn = "PredictorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_predictor) } {
            return .{ .service_metadata = service_metadata, .action = delete_predictor };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_predictor_backtest_export_job: struct {
    action_name: []const u8 = "DeletePredictorBacktestExportJob",
    Request: type = struct {
        predictor_backtest_export_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_backtest_export_job_arn = "PredictorBacktestExportJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_predictor_backtest_export_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_predictor_backtest_export_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_resource_tree: struct {
    action_name: []const u8 = "DeleteResourceTree",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_tree) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_tree };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const describe_dataset: struct {
    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        dataset_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        dataset_arn: ?[]const u8 = null,
        dataset_name: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        dataset_type: ?[]const u8 = null,
        data_frequency: ?[]const u8 = null,
        schema: ?Schema = null,
        encryption_config: ?EncryptionConfig = null,
        status: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_arn = "DatasetArn",
                .dataset_name = "DatasetName",
                .domain = "Domain",
                .dataset_type = "DatasetType",
                .data_frequency = "DataFrequency",
                .schema = "Schema",
                .encryption_config = "EncryptionConfig",
                .status = "Status",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_dataset_group: struct {
    action_name: []const u8 = "DescribeDatasetGroup",
    Request: type = struct {
        dataset_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "DatasetGroupArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset_group };
        }
    },
    Response: type = struct {
        dataset_group_name: ?[]const u8 = null,
        dataset_group_arn: ?[]const u8 = null,
        dataset_arns: ?[][]const u8 = null,
        domain: ?[]const u8 = null,
        status: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_name = "DatasetGroupName",
                .dataset_group_arn = "DatasetGroupArn",
                .dataset_arns = "DatasetArns",
                .domain = "Domain",
                .status = "Status",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_dataset_import_job: struct {
    action_name: []const u8 = "DescribeDatasetImportJob",
    Request: type = struct {
        dataset_import_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_job_arn = "DatasetImportJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset_import_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset_import_job };
        }
    },
    Response: type = struct {
        dataset_import_job_name: ?[]const u8 = null,
        dataset_import_job_arn: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        timestamp_format: ?[]const u8 = null,
        time_zone: ?[]const u8 = null,
        use_geolocation_for_time_zone: ?bool = null,
        geolocation_format: ?[]const u8 = null,
        data_source: ?DataSource = null,
        estimated_time_remaining_in_minutes: ?i64 = null,
        field_statistics: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                count: ?i64 = null,
                count_distinct: ?i64 = null,
                count_null: ?i64 = null,
                count_nan: ?i64 = null,
                min: ?[]const u8 = null,
                max: ?[]const u8 = null,
                avg: ?f64 = null,
                stddev: ?f64 = null,
                count_long: ?i64 = null,
                count_distinct_long: ?i64 = null,
                count_null_long: ?i64 = null,
                count_nan_long: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .count = "Count",
                        .count_distinct = "CountDistinct",
                        .count_null = "CountNull",
                        .count_nan = "CountNan",
                        .min = "Min",
                        .max = "Max",
                        .avg = "Avg",
                        .stddev = "Stddev",
                        .count_long = "CountLong",
                        .count_distinct_long = "CountDistinctLong",
                        .count_null_long = "CountNullLong",
                        .count_nan_long = "CountNanLong",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        data_size: ?f64 = null,
        status: ?[]const u8 = null,
        message: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_job_name = "DatasetImportJobName",
                .dataset_import_job_arn = "DatasetImportJobArn",
                .dataset_arn = "DatasetArn",
                .timestamp_format = "TimestampFormat",
                .time_zone = "TimeZone",
                .use_geolocation_for_time_zone = "UseGeolocationForTimeZone",
                .geolocation_format = "GeolocationFormat",
                .data_source = "DataSource",
                .estimated_time_remaining_in_minutes = "EstimatedTimeRemainingInMinutes",
                .field_statistics = "FieldStatistics",
                .data_size = "DataSize",
                .status = "Status",
                .message = "Message",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "field_statistics", field_name))
                return try serializeMap(self.field_statistics, self.fieldNameFor("field_statistics"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_forecast: struct {
    action_name: []const u8 = "DescribeForecast",
    Request: type = struct {
        forecast_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_arn = "ForecastArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_forecast) } {
            return .{ .service_metadata = service_metadata, .action = describe_forecast };
        }
    },
    Response: type = struct {
        forecast_arn: ?[]const u8 = null,
        forecast_name: ?[]const u8 = null,
        forecast_types: ?[][]const u8 = null,
        predictor_arn: ?[]const u8 = null,
        dataset_group_arn: ?[]const u8 = null,
        estimated_time_remaining_in_minutes: ?i64 = null,
        status: ?[]const u8 = null,
        message: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_arn = "ForecastArn",
                .forecast_name = "ForecastName",
                .forecast_types = "ForecastTypes",
                .predictor_arn = "PredictorArn",
                .dataset_group_arn = "DatasetGroupArn",
                .estimated_time_remaining_in_minutes = "EstimatedTimeRemainingInMinutes",
                .status = "Status",
                .message = "Message",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_forecast_export_job: struct {
    action_name: []const u8 = "DescribeForecastExportJob",
    Request: type = struct {
        forecast_export_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_export_job_arn = "ForecastExportJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_forecast_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_forecast_export_job };
        }
    },
    Response: type = struct {
        forecast_export_job_arn: ?[]const u8 = null,
        forecast_export_job_name: ?[]const u8 = null,
        forecast_arn: ?[]const u8 = null,
        destination: ?DataDestination = null,
        message: ?[]const u8 = null,
        status: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_export_job_arn = "ForecastExportJobArn",
                .forecast_export_job_name = "ForecastExportJobName",
                .forecast_arn = "ForecastArn",
                .destination = "Destination",
                .message = "Message",
                .status = "Status",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_predictor: struct {
    action_name: []const u8 = "DescribePredictor",
    Request: type = struct {
        predictor_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_arn = "PredictorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_predictor) } {
            return .{ .service_metadata = service_metadata, .action = describe_predictor };
        }
    },
    Response: type = struct {
        predictor_arn: ?[]const u8 = null,
        predictor_name: ?[]const u8 = null,
        algorithm_arn: ?[]const u8 = null,
        forecast_horizon: ?i64 = null,
        forecast_types: ?[][]const u8 = null,
        perform_auto_ml: ?bool = null,
        perform_hpo: ?bool = null,
        training_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        evaluation_parameters: ?EvaluationParameters = null,
        hpo_config: ?HyperParameterTuningJobConfig = null,
        input_data_config: ?InputDataConfig = null,
        featurization_config: ?FeaturizationConfig = null,
        encryption_config: ?EncryptionConfig = null,
        predictor_execution_details: ?struct {
            predictor_executions: ?[]struct {
                algorithm_arn: ?[]const u8 = null,
                test_windows: ?[]struct {
                    test_window_start: ?i64 = null,
                    test_window_end: ?i64 = null,
                    status: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .test_window_start = "TestWindowStart",
                            .test_window_end = "TestWindowEnd",
                            .status = "Status",
                            .message = "Message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .algorithm_arn = "AlgorithmArn",
                        .test_windows = "TestWindows",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .predictor_executions = "PredictorExecutions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        estimated_time_remaining_in_minutes: ?i64 = null,
        dataset_import_job_arns: ?[][]const u8 = null,
        auto_ml_algorithm_arns: ?[][]const u8 = null,
        status: ?[]const u8 = null,
        message: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_arn = "PredictorArn",
                .predictor_name = "PredictorName",
                .algorithm_arn = "AlgorithmArn",
                .forecast_horizon = "ForecastHorizon",
                .forecast_types = "ForecastTypes",
                .perform_auto_ml = "PerformAutoML",
                .perform_hpo = "PerformHPO",
                .training_parameters = "TrainingParameters",
                .evaluation_parameters = "EvaluationParameters",
                .hpo_config = "HPOConfig",
                .input_data_config = "InputDataConfig",
                .featurization_config = "FeaturizationConfig",
                .encryption_config = "EncryptionConfig",
                .predictor_execution_details = "PredictorExecutionDetails",
                .estimated_time_remaining_in_minutes = "EstimatedTimeRemainingInMinutes",
                .dataset_import_job_arns = "DatasetImportJobArns",
                .auto_ml_algorithm_arns = "AutoMLAlgorithmArns",
                .status = "Status",
                .message = "Message",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "training_parameters", field_name))
                return try serializeMap(self.training_parameters, self.fieldNameFor("training_parameters"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const describe_predictor_backtest_export_job: struct {
    action_name: []const u8 = "DescribePredictorBacktestExportJob",
    Request: type = struct {
        predictor_backtest_export_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_backtest_export_job_arn = "PredictorBacktestExportJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_predictor_backtest_export_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_predictor_backtest_export_job };
        }
    },
    Response: type = struct {
        predictor_backtest_export_job_arn: ?[]const u8 = null,
        predictor_backtest_export_job_name: ?[]const u8 = null,
        predictor_arn: ?[]const u8 = null,
        destination: ?DataDestination = null,
        message: ?[]const u8 = null,
        status: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modification_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_backtest_export_job_arn = "PredictorBacktestExportJobArn",
                .predictor_backtest_export_job_name = "PredictorBacktestExportJobName",
                .predictor_arn = "PredictorArn",
                .destination = "Destination",
                .message = "Message",
                .status = "Status",
                .creation_time = "CreationTime",
                .last_modification_time = "LastModificationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const get_accuracy_metrics: struct {
    action_name: []const u8 = "GetAccuracyMetrics",
    Request: type = struct {
        predictor_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_arn = "PredictorArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_accuracy_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_accuracy_metrics };
        }
    },
    Response: type = struct {
        predictor_evaluation_results: ?[]struct {
            algorithm_arn: ?[]const u8 = null,
            test_windows: ?[]struct {
                test_window_start: ?i64 = null,
                test_window_end: ?i64 = null,
                item_count: ?i64 = null,
                evaluation_type: ?[]const u8 = null,
                metrics: ?struct {
                    rmse: ?f64 = null,
                    weighted_quantile_losses: ?[]struct {
                        quantile: ?f64 = null,
                        loss_value: ?f64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .quantile = "Quantile",
                                .loss_value = "LossValue",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    error_metrics: ?[]struct {
                        forecast_type: ?[]const u8 = null,
                        wape: ?f64 = null,
                        rmse: ?f64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .forecast_type = "ForecastType",
                                .wape = "WAPE",
                                .rmse = "RMSE",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .rmse = "RMSE",
                            .weighted_quantile_losses = "WeightedQuantileLosses",
                            .error_metrics = "ErrorMetrics",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .test_window_start = "TestWindowStart",
                        .test_window_end = "TestWindowEnd",
                        .item_count = "ItemCount",
                        .evaluation_type = "EvaluationType",
                        .metrics = "Metrics",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .algorithm_arn = "AlgorithmArn",
                    .test_windows = "TestWindows",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_evaluation_results = "PredictorEvaluationResults",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const list_dataset_groups: struct {
    action_name: []const u8 = "ListDatasetGroups",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_groups };
        }
    },
    Response: type = struct {
        dataset_groups: ?[]struct {
            dataset_group_arn: ?[]const u8 = null,
            dataset_group_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_group_arn = "DatasetGroupArn",
                    .dataset_group_name = "DatasetGroupName",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_groups = "DatasetGroups",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
    },
} = .{};
pub const list_dataset_import_jobs: struct {
    action_name: []const u8 = "ListDatasetImportJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dataset_import_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_dataset_import_jobs };
        }
    },
    Response: type = struct {
        dataset_import_jobs: ?[]struct {
            dataset_import_job_arn: ?[]const u8 = null,
            dataset_import_job_name: ?[]const u8 = null,
            data_source: ?DataSource = null,
            status: ?[]const u8 = null,
            message: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_import_job_arn = "DatasetImportJobArn",
                    .dataset_import_job_name = "DatasetImportJobName",
                    .data_source = "DataSource",
                    .status = "Status",
                    .message = "Message",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_import_jobs = "DatasetImportJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_datasets: struct {
    action_name: []const u8 = "ListDatasets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasets) } {
            return .{ .service_metadata = service_metadata, .action = list_datasets };
        }
    },
    Response: type = struct {
        datasets: ?[]struct {
            dataset_arn: ?[]const u8 = null,
            dataset_name: ?[]const u8 = null,
            dataset_type: ?[]const u8 = null,
            domain: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_arn = "DatasetArn",
                    .dataset_name = "DatasetName",
                    .dataset_type = "DatasetType",
                    .domain = "Domain",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .datasets = "Datasets",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidNextToken,
    },
} = .{};
pub const list_forecast_export_jobs: struct {
    action_name: []const u8 = "ListForecastExportJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_forecast_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_forecast_export_jobs };
        }
    },
    Response: type = struct {
        forecast_export_jobs: ?[]struct {
            forecast_export_job_arn: ?[]const u8 = null,
            forecast_export_job_name: ?[]const u8 = null,
            destination: ?DataDestination = null,
            status: ?[]const u8 = null,
            message: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .forecast_export_job_arn = "ForecastExportJobArn",
                    .forecast_export_job_name = "ForecastExportJobName",
                    .destination = "Destination",
                    .status = "Status",
                    .message = "Message",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecast_export_jobs = "ForecastExportJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_forecasts: struct {
    action_name: []const u8 = "ListForecasts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_forecasts) } {
            return .{ .service_metadata = service_metadata, .action = list_forecasts };
        }
    },
    Response: type = struct {
        forecasts: ?[]struct {
            forecast_arn: ?[]const u8 = null,
            forecast_name: ?[]const u8 = null,
            predictor_arn: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            message: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .forecast_arn = "ForecastArn",
                    .forecast_name = "ForecastName",
                    .predictor_arn = "PredictorArn",
                    .dataset_group_arn = "DatasetGroupArn",
                    .status = "Status",
                    .message = "Message",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .forecasts = "Forecasts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_predictor_backtest_export_jobs: struct {
    action_name: []const u8 = "ListPredictorBacktestExportJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_predictor_backtest_export_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_predictor_backtest_export_jobs };
        }
    },
    Response: type = struct {
        predictor_backtest_export_jobs: ?[]struct {
            predictor_backtest_export_job_arn: ?[]const u8 = null,
            predictor_backtest_export_job_name: ?[]const u8 = null,
            destination: ?DataDestination = null,
            status: ?[]const u8 = null,
            message: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .predictor_backtest_export_job_arn = "PredictorBacktestExportJobArn",
                    .predictor_backtest_export_job_name = "PredictorBacktestExportJobName",
                    .destination = "Destination",
                    .status = "Status",
                    .message = "Message",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictor_backtest_export_jobs = "PredictorBacktestExportJobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_predictors: struct {
    action_name: []const u8 = "ListPredictors",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filters: ?[]Filter = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_predictors) } {
            return .{ .service_metadata = service_metadata, .action = list_predictors };
        }
    },
    Response: type = struct {
        predictors: ?[]struct {
            predictor_arn: ?[]const u8 = null,
            predictor_name: ?[]const u8 = null,
            dataset_group_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            message: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modification_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .predictor_arn = "PredictorArn",
                    .predictor_name = "PredictorName",
                    .dataset_group_arn = "DatasetGroupArn",
                    .status = "Status",
                    .message = "Message",
                    .creation_time = "CreationTime",
                    .last_modification_time = "LastModificationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .predictors = "Predictors",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        InvalidNextToken,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const stop_resource: struct {
    action_name: []const u8 = "StopResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_resource) } {
            return .{ .service_metadata = service_metadata, .action = stop_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceNotFound,
    },
} = .{};
pub const update_dataset_group: struct {
    action_name: []const u8 = "UpdateDatasetGroup",
    Request: type = struct {
        dataset_group_arn: []const u8,
        dataset_arns: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_group_arn = "DatasetGroupArn",
                .dataset_arns = "DatasetArns",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dataset_group) } {
            return .{ .service_metadata = service_metadata, .action = update_dataset_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    key: []const u8,
    value: []const u8,
    condition: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
            .condition = "Condition",
        };
        return @field(mappings, field_name);
    }
};

pub const DataDestination = struct {
    s3_config: S3Config,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_config = "S3Config",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Config = struct {
    path: []const u8,
    role_arn: []const u8,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .role_arn = "RoleArn",
            .kms_key_arn = "KMSKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSource = struct {
    s3_config: S3Config,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_config = "S3Config",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfig = struct {
    role_arn: []const u8,
    kms_key_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .role_arn = "RoleArn",
            .kms_key_arn = "KMSKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const FeaturizationConfig = struct {
    forecast_frequency: []const u8,
    forecast_dimensions: ?[][]const u8 = null,
    featurizations: ?[]Featurization = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .forecast_frequency = "ForecastFrequency",
            .forecast_dimensions = "ForecastDimensions",
            .featurizations = "Featurizations",
        };
        return @field(mappings, field_name);
    }
};

pub const Featurization = struct {
    attribute_name: []const u8,
    featurization_pipeline: ?[]FeaturizationMethod = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .featurization_pipeline = "FeaturizationPipeline",
        };
        return @field(mappings, field_name);
    }
};

pub const FeaturizationMethod = struct {
    featurization_method_name: []const u8,
    featurization_method_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .featurization_method_name = "FeaturizationMethodName",
            .featurization_method_parameters = "FeaturizationMethodParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "featurization_method_parameters", field_name))
            return try serializeMap(self.featurization_method_parameters, self.fieldNameFor("featurization_method_parameters"), options, out_stream);
        return false;
    }
};

pub const InputDataConfig = struct {
    dataset_group_arn: []const u8,
    supplementary_features: ?[]SupplementaryFeature = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dataset_group_arn = "DatasetGroupArn",
            .supplementary_features = "SupplementaryFeatures",
        };
        return @field(mappings, field_name);
    }
};

pub const SupplementaryFeature = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const HyperParameterTuningJobConfig = struct {
    parameter_ranges: ?ParameterRanges = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parameter_ranges = "ParameterRanges",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterRanges = struct {
    categorical_parameter_ranges: ?[]CategoricalParameterRange = null,
    continuous_parameter_ranges: ?[]ContinuousParameterRange = null,
    integer_parameter_ranges: ?[]IntegerParameterRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .categorical_parameter_ranges = "CategoricalParameterRanges",
            .continuous_parameter_ranges = "ContinuousParameterRanges",
            .integer_parameter_ranges = "IntegerParameterRanges",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerParameterRange = struct {
    name: []const u8,
    max_value: i64,
    min_value: i64,
    scaling_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .max_value = "MaxValue",
            .min_value = "MinValue",
            .scaling_type = "ScalingType",
        };
        return @field(mappings, field_name);
    }
};

pub const ContinuousParameterRange = struct {
    name: []const u8,
    max_value: f64,
    min_value: f64,
    scaling_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .max_value = "MaxValue",
            .min_value = "MinValue",
            .scaling_type = "ScalingType",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoricalParameterRange = struct {
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationParameters = struct {
    number_of_backtest_windows: ?i64 = null,
    back_test_window_offset: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_backtest_windows = "NumberOfBacktestWindows",
            .back_test_window_offset = "BackTestWindowOffset",
        };
        return @field(mappings, field_name);
    }
};

pub const Schema = struct {
    attributes: ?[]SchemaAttribute = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attributes = "Attributes",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaAttribute = struct {
    attribute_name: ?[]const u8 = null,
    attribute_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attribute_name = "AttributeName",
            .attribute_type = "AttributeType",
        };
        return @field(mappings, field_name);
    }
};
