const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-14";
pub const sdk_id: []const u8 = "Kafka";
pub const arn_namespace: []const u8 = "kafka";
pub const endpoint_prefix: []const u8 = "kafka";
pub const sigv4_name: []const u8 = "kafka";
pub const name: []const u8 = "Kafka";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-14",
    sdk_id: []const u8 = "Kafka",
    arn_namespace: []const u8 = "kafka",
    endpoint_prefix: []const u8 = "kafka",
    sigv4_name: []const u8 = "kafka",
    name: []const u8 = "Kafka",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const batch_associate_scram_secret: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/clusters/{ClusterArn}/scram-secrets",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchAssociateScramSecret",
    Request: type = struct {
        cluster_arn: []const u8,
        secret_arn_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .secret_arn_list = "secretArnList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_associate_scram_secret) } {
            return .{ .service_metadata = service_metadata, .action = batch_associate_scram_secret };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        unprocessed_scram_secrets: ?[]UnprocessedScramSecret = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .unprocessed_scram_secrets = "unprocessedScramSecrets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const batch_disassociate_scram_secret: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/v1/clusters/{ClusterArn}/scram-secrets",
        .success_code = 200,
    };

    action_name: []const u8 = "BatchDisassociateScramSecret",
    Request: type = struct {
        cluster_arn: []const u8,
        secret_arn_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .secret_arn_list = "secretArnList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_disassociate_scram_secret) } {
            return .{ .service_metadata = service_metadata, .action = batch_disassociate_scram_secret };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        unprocessed_scram_secrets: ?[]UnprocessedScramSecret = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .unprocessed_scram_secrets = "unprocessedScramSecrets",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_cluster: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/clusters",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateCluster",
    Request: type = struct {
        broker_node_group_info: BrokerNodeGroupInfo,
        client_authentication: ?ClientAuthentication = null,
        cluster_name: []const u8,
        configuration_info: ?ConfigurationInfo = null,
        encryption_info: ?EncryptionInfo = null,
        enhanced_monitoring: ?[]const u8 = null,
        open_monitoring: ?OpenMonitoringInfo = null,
        kafka_version: []const u8,
        logging_info: ?LoggingInfo = null,
        number_of_broker_nodes: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_node_group_info = "brokerNodeGroupInfo",
                .client_authentication = "clientAuthentication",
                .cluster_name = "clusterName",
                .configuration_info = "configurationInfo",
                .encryption_info = "encryptionInfo",
                .enhanced_monitoring = "enhancedMonitoring",
                .open_monitoring = "openMonitoring",
                .kafka_version = "kafkaVersion",
                .logging_info = "loggingInfo",
                .number_of_broker_nodes = "numberOfBrokerNodes",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_cluster) } {
            return .{ .service_metadata = service_metadata, .action = create_cluster };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        cluster_name: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .cluster_name = "clusterName",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const create_configuration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateConfiguration",
    Request: type = struct {
        description: ?[]const u8 = null,
        kafka_versions: ?[][]const u8 = null,
        name: []const u8,
        server_properties: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "description",
                .kafka_versions = "kafkaVersions",
                .name = "name",
                .server_properties = "serverProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        latest_revision: ?ConfigurationRevision = null,
        name: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .creation_time = "creationTime",
                .latest_revision = "latestRevision",
                .name = "name",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const delete_cluster: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/clusters/{ClusterArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteCluster",
    Request: type = struct {
        cluster_arn: []const u8,
        current_version: ?[]const u8 = null,

        pub const http_query = .{
            .current_version = "currentVersion",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .current_version = "CurrentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_cluster) } {
            return .{ .service_metadata = service_metadata, .action = delete_cluster };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const delete_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/configurations/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const describe_cluster: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/clusters/{ClusterArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeCluster",
    Request: type = struct {
        cluster_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster };
        }
    },
    Response: type = struct {
        cluster_info: ?ClusterInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_info = "clusterInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_cluster_operation: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/operations/{ClusterOperationArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeClusterOperation",
    Request: type = struct {
        cluster_operation_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_operation_arn = "ClusterOperationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_cluster_operation) } {
            return .{ .service_metadata = service_metadata, .action = describe_cluster_operation };
        }
    },
    Response: type = struct {
        cluster_operation_info: ?ClusterOperationInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_operation_info = "clusterOperationInfo",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const describe_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/configurations/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConfiguration",
    Request: type = struct {
        arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        description: ?[]const u8 = null,
        kafka_versions: ?[][]const u8 = null,
        latest_revision: ?ConfigurationRevision = null,
        name: ?[]const u8 = null,
        state: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .creation_time = "creationTime",
                .description = "description",
                .kafka_versions = "kafkaVersions",
                .latest_revision = "latestRevision",
                .name = "name",
                .state = "state",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const describe_configuration_revision: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/configurations/{Arn}/revisions/{Revision}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeConfigurationRevision",
    Request: type = struct {
        arn: []const u8,
        revision: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .revision = "Revision",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_configuration_revision) } {
            return .{ .service_metadata = service_metadata, .action = describe_configuration_revision };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        description: ?[]const u8 = null,
        revision: ?i64 = null,
        server_properties: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .creation_time = "creationTime",
                .description = "description",
                .revision = "revision",
                .server_properties = "serverProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const get_bootstrap_brokers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/clusters/{ClusterArn}/bootstrap-brokers",
        .success_code = 200,
    };

    action_name: []const u8 = "GetBootstrapBrokers",
    Request: type = struct {
        cluster_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_bootstrap_brokers) } {
            return .{ .service_metadata = service_metadata, .action = get_bootstrap_brokers };
        }
    },
    Response: type = struct {
        bootstrap_broker_string: ?[]const u8 = null,
        bootstrap_broker_string_tls: ?[]const u8 = null,
        bootstrap_broker_string_sasl_scram: ?[]const u8 = null,
        bootstrap_broker_string_sasl_iam: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bootstrap_broker_string = "bootstrapBrokerString",
                .bootstrap_broker_string_tls = "bootstrapBrokerStringTls",
                .bootstrap_broker_string_sasl_scram = "bootstrapBrokerStringSaslScram",
                .bootstrap_broker_string_sasl_iam = "bootstrapBrokerStringSaslIam",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Conflict,
        Forbidden,
        InternalServerError,
        Unauthorized,
    },
} = .{};
pub const get_compatible_kafka_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/compatible-kafka-versions",
        .success_code = 200,
    };

    action_name: []const u8 = "GetCompatibleKafkaVersions",
    Request: type = struct {
        cluster_arn: ?[]const u8 = null,

        pub const http_query = .{
            .cluster_arn = "clusterArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_compatible_kafka_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_compatible_kafka_versions };
        }
    },
    Response: type = struct {
        compatible_kafka_versions: ?[]struct {
            source_version: ?[]const u8 = null,
            target_versions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_version = "sourceVersion",
                    .target_versions = "targetVersions",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compatible_kafka_versions = "compatibleKafkaVersions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_cluster_operations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/clusters/{ClusterArn}/operations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListClusterOperations",
    Request: type = struct {
        cluster_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_cluster_operations) } {
            return .{ .service_metadata = service_metadata, .action = list_cluster_operations };
        }
    },
    Response: type = struct {
        cluster_operation_info_list: ?[]ClusterOperationInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_operation_info_list = "clusterOperationInfoList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        Unauthorized,
    },
} = .{};
pub const list_clusters: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/clusters",
        .success_code = 200,
    };

    action_name: []const u8 = "ListClusters",
    Request: type = struct {
        cluster_name_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .cluster_name_filter = "clusterNameFilter",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_name_filter = "ClusterNameFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_clusters) } {
            return .{ .service_metadata = service_metadata, .action = list_clusters };
        }
    },
    Response: type = struct {
        cluster_info_list: ?[]ClusterInfo = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_info_list = "clusterInfoList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        Unauthorized,
    },
} = .{};
pub const list_configuration_revisions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/configurations/{Arn}/revisions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurationRevisions",
    Request: type = struct {
        arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configuration_revisions) } {
            return .{ .service_metadata = service_metadata, .action = list_configuration_revisions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        revisions: ?[]ConfigurationRevision = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .revisions = "revisions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const list_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/configurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_configurations };
        }
    },
    Response: type = struct {
        configurations: ?[]struct {
            arn: []const u8,
            creation_time: i64,
            description: []const u8,
            kafka_versions: [][]const u8,
            latest_revision: ConfigurationRevision,
            name: []const u8,
            state: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .creation_time = "creationTime",
                    .description = "description",
                    .kafka_versions = "kafkaVersions",
                    .latest_revision = "latestRevision",
                    .name = "name",
                    .state = "state",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .configurations = "configurations",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const list_kafka_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/kafka-versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListKafkaVersions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_kafka_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_kafka_versions };
        }
    },
    Response: type = struct {
        kafka_versions: ?[]struct {
            version: ?[]const u8 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "version",
                    .status = "status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .kafka_versions = "kafkaVersions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        Unauthorized,
    },
} = .{};
pub const list_nodes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/clusters/{ClusterArn}/nodes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNodes",
    Request: type = struct {
        cluster_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_nodes) } {
            return .{ .service_metadata = service_metadata, .action = list_nodes };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        node_info_list: ?[]struct {
            added_to_cluster_time: ?[]const u8 = null,
            broker_node_info: ?struct {
                attached_eni_id: ?[]const u8 = null,
                broker_id: ?f64 = null,
                client_subnet: ?[]const u8 = null,
                client_vpc_ip_address: ?[]const u8 = null,
                current_broker_software_info: ?BrokerSoftwareInfo = null,
                endpoints: ?[][]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attached_eni_id = "attachedENIId",
                        .broker_id = "brokerId",
                        .client_subnet = "clientSubnet",
                        .client_vpc_ip_address = "clientVpcIpAddress",
                        .current_broker_software_info = "currentBrokerSoftwareInfo",
                        .endpoints = "endpoints",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            instance_type: ?[]const u8 = null,
            node_arn: ?[]const u8 = null,
            node_type: ?[]const u8 = null,
            zookeeper_node_info: ?struct {
                attached_eni_id: ?[]const u8 = null,
                client_vpc_ip_address: ?[]const u8 = null,
                endpoints: ?[][]const u8 = null,
                zookeeper_id: ?f64 = null,
                zookeeper_version: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .attached_eni_id = "attachedENIId",
                        .client_vpc_ip_address = "clientVpcIpAddress",
                        .endpoints = "endpoints",
                        .zookeeper_id = "zookeeperId",
                        .zookeeper_version = "zookeeperVersion",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .added_to_cluster_time = "addedToClusterTime",
                    .broker_node_info = "brokerNodeInfo",
                    .instance_type = "instanceType",
                    .node_arn = "nodeARN",
                    .node_type = "nodeType",
                    .zookeeper_node_info = "zookeeperNodeInfo",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .node_info_list = "nodeInfoList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const list_scram_secrets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/clusters/{ClusterArn}/scram-secrets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListScramSecrets",
    Request: type = struct {
        cluster_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_scram_secrets) } {
            return .{ .service_metadata = service_metadata, .action = list_scram_secrets };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        secret_arn_list: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .secret_arn_list = "secretArnList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const reboot_broker: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/clusters/{ClusterArn}/reboot-broker",
        .success_code = 200,
    };

    action_name: []const u8 = "RebootBroker",
    Request: type = struct {
        broker_ids: [][]const u8,
        cluster_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .broker_ids = "brokerIds",
                .cluster_arn = "ClusterArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_broker) } {
            return .{ .service_metadata = service_metadata, .action = reboot_broker };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        cluster_operation_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .cluster_operation_arn = "clusterOperationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
        InternalServerError,
        NotFound,
    },
} = .{};
pub const update_broker_count: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/clusters/{ClusterArn}/nodes/count",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBrokerCount",
    Request: type = struct {
        cluster_arn: []const u8,
        current_version: []const u8,
        target_number_of_broker_nodes: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .current_version = "currentVersion",
                .target_number_of_broker_nodes = "targetNumberOfBrokerNodes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_broker_count) } {
            return .{ .service_metadata = service_metadata, .action = update_broker_count };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        cluster_operation_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .cluster_operation_arn = "clusterOperationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const update_broker_storage: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/clusters/{ClusterArn}/nodes/storage",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBrokerStorage",
    Request: type = struct {
        cluster_arn: []const u8,
        current_version: []const u8,
        target_broker_ebs_volume_info: []BrokerEBSVolumeInfo,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .current_version = "currentVersion",
                .target_broker_ebs_volume_info = "targetBrokerEBSVolumeInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_broker_storage) } {
            return .{ .service_metadata = service_metadata, .action = update_broker_storage };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        cluster_operation_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .cluster_operation_arn = "clusterOperationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const update_broker_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/clusters/{ClusterArn}/nodes/type",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateBrokerType",
    Request: type = struct {
        cluster_arn: []const u8,
        current_version: []const u8,
        target_instance_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .current_version = "currentVersion",
                .target_instance_type = "targetInstanceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_broker_type) } {
            return .{ .service_metadata = service_metadata, .action = update_broker_type };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        cluster_operation_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .cluster_operation_arn = "clusterOperationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_cluster_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/clusters/{ClusterArn}/configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateClusterConfiguration",
    Request: type = struct {
        cluster_arn: []const u8,
        configuration_info: ConfigurationInfo,
        current_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .configuration_info = "configurationInfo",
                .current_version = "currentVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster_configuration };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        cluster_operation_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .cluster_operation_arn = "clusterOperationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const update_cluster_kafka_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/clusters/{ClusterArn}/version",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateClusterKafkaVersion",
    Request: type = struct {
        cluster_arn: []const u8,
        configuration_info: ?ConfigurationInfo = null,
        current_version: []const u8,
        target_kafka_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .configuration_info = "configurationInfo",
                .current_version = "currentVersion",
                .target_kafka_version = "targetKafkaVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_cluster_kafka_version) } {
            return .{ .service_metadata = service_metadata, .action = update_cluster_kafka_version };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        cluster_operation_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .cluster_operation_arn = "clusterOperationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        TooManyRequests,
        Unauthorized,
    },
} = .{};
pub const update_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/configurations/{Arn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateConfiguration",
    Request: type = struct {
        arn: []const u8,
        description: ?[]const u8 = null,
        server_properties: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .description = "description",
                .server_properties = "serverProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_configuration };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        latest_revision: ?ConfigurationRevision = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "arn",
                .latest_revision = "latestRevision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        NotFound,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};
pub const update_monitoring: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/v1/clusters/{ClusterArn}/monitoring",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateMonitoring",
    Request: type = struct {
        cluster_arn: []const u8,
        current_version: []const u8,
        enhanced_monitoring: ?[]const u8 = null,
        open_monitoring: ?OpenMonitoringInfo = null,
        logging_info: ?LoggingInfo = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "ClusterArn",
                .current_version = "currentVersion",
                .enhanced_monitoring = "enhancedMonitoring",
                .open_monitoring = "openMonitoring",
                .logging_info = "loggingInfo",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_monitoring) } {
            return .{ .service_metadata = service_metadata, .action = update_monitoring };
        }
    },
    Response: type = struct {
        cluster_arn: ?[]const u8 = null,
        cluster_operation_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cluster_arn = "clusterArn",
                .cluster_operation_arn = "clusterOperationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        Forbidden,
        InternalServerError,
        ServiceUnavailable,
        Unauthorized,
    },
} = .{};

pub const LoggingInfo = struct {
    broker_logs: BrokerLogs,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .broker_logs = "brokerLogs",
        };
        return @field(mappings, field_name);
    }
};

pub const BrokerLogs = struct {
    cloud_watch_logs: ?CloudWatchLogs = null,
    firehose: ?Firehose = null,
    s3: ?S3 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs = "cloudWatchLogs",
            .firehose = "firehose",
            .s3 = "s3",
        };
        return @field(mappings, field_name);
    }
};

pub const S3 = struct {
    bucket: ?[]const u8 = null,
    enabled: bool,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "bucket",
            .enabled = "enabled",
            .prefix = "prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Firehose = struct {
    delivery_stream: ?[]const u8 = null,
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .delivery_stream = "deliveryStream",
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogs = struct {
    enabled: bool,
    log_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .log_group = "logGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenMonitoringInfo = struct {
    prometheus: PrometheusInfo,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prometheus = "prometheus",
        };
        return @field(mappings, field_name);
    }
};

pub const PrometheusInfo = struct {
    jmx_exporter: ?JmxExporterInfo = null,
    node_exporter: ?NodeExporterInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .jmx_exporter = "jmxExporter",
            .node_exporter = "nodeExporter",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeExporterInfo = struct {
    enabled_in_broker: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled_in_broker = "enabledInBroker",
        };
        return @field(mappings, field_name);
    }
};

pub const JmxExporterInfo = struct {
    enabled_in_broker: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled_in_broker = "enabledInBroker",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationRevision = struct {
    creation_time: i64,
    description: ?[]const u8 = null,
    revision: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .creation_time = "creationTime",
            .description = "description",
            .revision = "revision",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfigurationInfo = struct {
    arn: []const u8,
    revision: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .revision = "revision",
        };
        return @field(mappings, field_name);
    }
};

pub const BrokerEBSVolumeInfo = struct {
    kafka_broker_node_id: []const u8,
    volume_size_gb: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kafka_broker_node_id = "kafkaBrokerNodeId",
            .volume_size_gb = "volumeSizeGB",
        };
        return @field(mappings, field_name);
    }
};

pub const BrokerSoftwareInfo = struct {
    configuration_arn: ?[]const u8 = null,
    configuration_revision: ?i64 = null,
    kafka_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .configuration_arn = "configurationArn",
            .configuration_revision = "configurationRevision",
            .kafka_version = "kafkaVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterInfo = struct {
    active_operation_arn: ?[]const u8 = null,
    broker_node_group_info: ?BrokerNodeGroupInfo = null,
    client_authentication: ?ClientAuthentication = null,
    cluster_arn: ?[]const u8 = null,
    cluster_name: ?[]const u8 = null,
    creation_time: ?i64 = null,
    current_broker_software_info: ?BrokerSoftwareInfo = null,
    current_version: ?[]const u8 = null,
    encryption_info: ?EncryptionInfo = null,
    enhanced_monitoring: ?[]const u8 = null,
    open_monitoring: ?OpenMonitoring = null,
    logging_info: ?LoggingInfo = null,
    number_of_broker_nodes: ?i64 = null,
    state: ?[]const u8 = null,
    state_info: ?StateInfo = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    zookeeper_connect_string: ?[]const u8 = null,
    zookeeper_connect_string_tls: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_operation_arn = "activeOperationArn",
            .broker_node_group_info = "brokerNodeGroupInfo",
            .client_authentication = "clientAuthentication",
            .cluster_arn = "clusterArn",
            .cluster_name = "clusterName",
            .creation_time = "creationTime",
            .current_broker_software_info = "currentBrokerSoftwareInfo",
            .current_version = "currentVersion",
            .encryption_info = "encryptionInfo",
            .enhanced_monitoring = "enhancedMonitoring",
            .open_monitoring = "openMonitoring",
            .logging_info = "loggingInfo",
            .number_of_broker_nodes = "numberOfBrokerNodes",
            .state = "state",
            .state_info = "stateInfo",
            .tags = "tags",
            .zookeeper_connect_string = "zookeeperConnectString",
            .zookeeper_connect_string_tls = "zookeeperConnectStringTls",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const StateInfo = struct {
    code: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .code = "code",
            .message = "message",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenMonitoring = struct {
    prometheus: Prometheus,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prometheus = "prometheus",
        };
        return @field(mappings, field_name);
    }
};

pub const Prometheus = struct {
    jmx_exporter: ?JmxExporter = null,
    node_exporter: ?NodeExporter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .jmx_exporter = "jmxExporter",
            .node_exporter = "nodeExporter",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeExporter = struct {
    enabled_in_broker: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled_in_broker = "enabledInBroker",
        };
        return @field(mappings, field_name);
    }
};

pub const JmxExporter = struct {
    enabled_in_broker: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled_in_broker = "enabledInBroker",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionInfo = struct {
    encryption_at_rest: ?EncryptionAtRest = null,
    encryption_in_transit: ?EncryptionInTransit = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_at_rest = "encryptionAtRest",
            .encryption_in_transit = "encryptionInTransit",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionInTransit = struct {
    client_broker: ?[]const u8 = null,
    in_cluster: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_broker = "clientBroker",
            .in_cluster = "inCluster",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAtRest = struct {
    data_volume_kms_key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_volume_kms_key_id = "dataVolumeKMSKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientAuthentication = struct {
    sasl: ?Sasl = null,
    tls: ?Tls = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sasl = "sasl",
            .tls = "tls",
        };
        return @field(mappings, field_name);
    }
};

pub const Tls = struct {
    certificate_authority_arn_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .certificate_authority_arn_list = "certificateAuthorityArnList",
        };
        return @field(mappings, field_name);
    }
};

pub const Sasl = struct {
    scram: ?Scram = null,
    iam: ?Iam = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .scram = "scram",
            .iam = "iam",
        };
        return @field(mappings, field_name);
    }
};

pub const Iam = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Scram = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const BrokerNodeGroupInfo = struct {
    broker_az_distribution: ?[]const u8 = null,
    client_subnets: [][]const u8,
    instance_type: []const u8,
    security_groups: ?[][]const u8 = null,
    storage_info: ?StorageInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .broker_az_distribution = "brokerAZDistribution",
            .client_subnets = "clientSubnets",
            .instance_type = "instanceType",
            .security_groups = "securityGroups",
            .storage_info = "storageInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const StorageInfo = struct {
    ebs_storage_info: ?EBSStorageInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ebs_storage_info = "ebsStorageInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const EBSStorageInfo = struct {
    volume_size: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_size = "volumeSize",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterOperationInfo = struct {
    client_request_id: ?[]const u8 = null,
    cluster_arn: ?[]const u8 = null,
    creation_time: ?i64 = null,
    end_time: ?i64 = null,
    error_info: ?ErrorInfo = null,
    operation_arn: ?[]const u8 = null,
    operation_state: ?[]const u8 = null,
    operation_steps: ?[]ClusterOperationStep = null,
    operation_type: ?[]const u8 = null,
    source_cluster_info: ?MutableClusterInfo = null,
    target_cluster_info: ?MutableClusterInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_request_id = "clientRequestId",
            .cluster_arn = "clusterArn",
            .creation_time = "creationTime",
            .end_time = "endTime",
            .error_info = "errorInfo",
            .operation_arn = "operationArn",
            .operation_state = "operationState",
            .operation_steps = "operationSteps",
            .operation_type = "operationType",
            .source_cluster_info = "sourceClusterInfo",
            .target_cluster_info = "targetClusterInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const MutableClusterInfo = struct {
    broker_ebs_volume_info: ?[]BrokerEBSVolumeInfo = null,
    configuration_info: ?ConfigurationInfo = null,
    number_of_broker_nodes: ?i64 = null,
    enhanced_monitoring: ?[]const u8 = null,
    open_monitoring: ?OpenMonitoring = null,
    kafka_version: ?[]const u8 = null,
    logging_info: ?LoggingInfo = null,
    instance_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .broker_ebs_volume_info = "brokerEBSVolumeInfo",
            .configuration_info = "configurationInfo",
            .number_of_broker_nodes = "numberOfBrokerNodes",
            .enhanced_monitoring = "enhancedMonitoring",
            .open_monitoring = "openMonitoring",
            .kafka_version = "kafkaVersion",
            .logging_info = "loggingInfo",
            .instance_type = "instanceType",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterOperationStep = struct {
    step_info: ?ClusterOperationStepInfo = null,
    step_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .step_info = "stepInfo",
            .step_name = "stepName",
        };
        return @field(mappings, field_name);
    }
};

pub const ClusterOperationStepInfo = struct {
    step_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .step_status = "stepStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorInfo = struct {
    error_code: ?[]const u8 = null,
    error_string: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "errorCode",
            .error_string = "errorString",
        };
        return @field(mappings, field_name);
    }
};

pub const UnprocessedScramSecret = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    secret_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "errorCode",
            .error_message = "errorMessage",
            .secret_arn = "secretArn",
        };
        return @field(mappings, field_name);
    }
};
