const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-09-17";
pub const sdk_id: []const u8 = "Marketplace Catalog";
pub const arn_namespace: []const u8 = "aws-marketplace";
pub const endpoint_prefix: []const u8 = "catalog.marketplace";
pub const sigv4_name: []const u8 = "aws-marketplace";
pub const name: []const u8 = "AWSMPSeymour";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-09-17",
    sdk_id: []const u8 = "Marketplace Catalog",
    arn_namespace: []const u8 = "aws-marketplace",
    endpoint_prefix: []const u8 = "catalog.marketplace",
    sigv4_name: []const u8 = "aws-marketplace",
    name: []const u8 = "AWSMPSeymour",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_change_set: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/CancelChangeSet",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelChangeSet",
    Request: type = struct {
        catalog: []const u8,
        change_set_id: []const u8,

        pub const http_query = .{
            .catalog = "catalog",
            .change_set_id = "changeSetId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .change_set_id = "ChangeSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_change_set) } {
            return .{ .service_metadata = service_metadata, .action = cancel_change_set };
        }
    },
    Response: type = struct {
        change_set_id: ?[]const u8 = null,
        change_set_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_set_id = "ChangeSetId",
                .change_set_arn = "ChangeSetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_change_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/DescribeChangeSet",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChangeSet",
    Request: type = struct {
        catalog: []const u8,
        change_set_id: []const u8,

        pub const http_query = .{
            .catalog = "catalog",
            .change_set_id = "changeSetId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .change_set_id = "ChangeSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_change_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_change_set };
        }
    },
    Response: type = struct {
        change_set_id: ?[]const u8 = null,
        change_set_arn: ?[]const u8 = null,
        change_set_name: ?[]const u8 = null,
        start_time: ?[]const u8 = null,
        end_time: ?[]const u8 = null,
        status: ?[]const u8 = null,
        failure_code: ?[]const u8 = null,
        failure_description: ?[]const u8 = null,
        change_set: ?[]struct {
            change_type: ?[]const u8 = null,
            entity: ?Entity = null,
            details: ?[]const u8 = null,
            error_detail_list: ?[]struct {
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_message = "ErrorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            change_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .change_type = "ChangeType",
                    .entity = "Entity",
                    .details = "Details",
                    .error_detail_list = "ErrorDetailList",
                    .change_name = "ChangeName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_set_id = "ChangeSetId",
                .change_set_arn = "ChangeSetArn",
                .change_set_name = "ChangeSetName",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .status = "Status",
                .failure_code = "FailureCode",
                .failure_description = "FailureDescription",
                .change_set = "ChangeSet",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_entity: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/DescribeEntity",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeEntity",
    Request: type = struct {
        catalog: []const u8,
        entity_id: []const u8,

        pub const http_query = .{
            .catalog = "catalog",
            .entity_id = "entityId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .entity_id = "EntityId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_entity) } {
            return .{ .service_metadata = service_metadata, .action = describe_entity };
        }
    },
    Response: type = struct {
        entity_type: ?[]const u8 = null,
        entity_identifier: ?[]const u8 = null,
        entity_arn: ?[]const u8 = null,
        last_modified_date: ?[]const u8 = null,
        details: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_type = "EntityType",
                .entity_identifier = "EntityIdentifier",
                .entity_arn = "EntityArn",
                .last_modified_date = "LastModifiedDate",
                .details = "Details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        ResourceNotSupported,
        Throttling,
        Validation,
    },
} = .{};
pub const list_change_sets: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListChangeSets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChangeSets",
    Request: type = struct {
        catalog: []const u8,
        filter_list: ?[]Filter = null,
        sort: ?Sort = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .filter_list = "FilterList",
                .sort = "Sort",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_change_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_change_sets };
        }
    },
    Response: type = struct {
        change_set_summary_list: ?[]struct {
            change_set_id: ?[]const u8 = null,
            change_set_arn: ?[]const u8 = null,
            change_set_name: ?[]const u8 = null,
            start_time: ?[]const u8 = null,
            end_time: ?[]const u8 = null,
            status: ?[]const u8 = null,
            entity_id_list: ?[][]const u8 = null,
            failure_code: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .change_set_id = "ChangeSetId",
                    .change_set_arn = "ChangeSetArn",
                    .change_set_name = "ChangeSetName",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .status = "Status",
                    .entity_id_list = "EntityIdList",
                    .failure_code = "FailureCode",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_set_summary_list = "ChangeSetSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        Throttling,
        Validation,
    },
} = .{};
pub const list_entities: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListEntities",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEntities",
    Request: type = struct {
        catalog: []const u8,
        entity_type: []const u8,
        filter_list: ?[]Filter = null,
        sort: ?Sort = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .entity_type = "EntityType",
                .filter_list = "FilterList",
                .sort = "Sort",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_entities) } {
            return .{ .service_metadata = service_metadata, .action = list_entities };
        }
    },
    Response: type = struct {
        entity_summary_list: ?[]struct {
            name: ?[]const u8 = null,
            entity_type: ?[]const u8 = null,
            entity_id: ?[]const u8 = null,
            entity_arn: ?[]const u8 = null,
            last_modified_date: ?[]const u8 = null,
            visibility: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .entity_type = "EntityType",
                    .entity_id = "EntityId",
                    .entity_arn = "EntityArn",
                    .last_modified_date = "LastModifiedDate",
                    .visibility = "Visibility",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .entity_summary_list = "EntitySummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_change_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/StartChangeSet",
        .success_code = 200,
    };

    action_name: []const u8 = "StartChangeSet",
    Request: type = struct {
        catalog: []const u8,
        change_set: []struct {
            change_type: []const u8,
            entity: Entity,
            details: []const u8,
            change_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .change_type = "ChangeType",
                    .entity = "Entity",
                    .details = "Details",
                    .change_name = "ChangeName",
                };
                return @field(mappings, field_name);
            }
        },
        change_set_name: ?[]const u8 = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog = "Catalog",
                .change_set = "ChangeSet",
                .change_set_name = "ChangeSetName",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_change_set) } {
            return .{ .service_metadata = service_metadata, .action = start_change_set };
        }
    },
    Response: type = struct {
        change_set_id: ?[]const u8 = null,
        change_set_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .change_set_id = "ChangeSetId",
                .change_set_arn = "ChangeSetArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        ResourceInUse,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const Entity = struct {
    type: []const u8,
    identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .identifier = "Identifier",
        };
        return @field(mappings, field_name);
    }
};

pub const Sort = struct {
    sort_by: ?[]const u8 = null,
    sort_order: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sort_by = "SortBy",
            .sort_order = "SortOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    value_list: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value_list = "ValueList",
        };
        return @field(mappings, field_name);
    }
};
