const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-04-23";
pub const sdk_id: []const u8 = "MediaTailor";
pub const arn_namespace: []const u8 = "mediatailor";
pub const endpoint_prefix: []const u8 = "api.mediatailor";
pub const sigv4_name: []const u8 = "mediatailor";
pub const name: []const u8 = "MediaTailor";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-04-23",
    sdk_id: []const u8 = "MediaTailor",
    arn_namespace: []const u8 = "mediatailor",
    endpoint_prefix: []const u8 = "api.mediatailor",
    sigv4_name: []const u8 = "mediatailor",
    name: []const u8 = "MediaTailor",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_channel: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channel/{ChannelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateChannel",
    Request: type = struct {
        channel_name: []const u8,
        outputs: []RequestOutputItem,
        playback_mode: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
                .outputs = "Outputs",
                .playback_mode = "PlaybackMode",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_channel) } {
            return .{ .service_metadata = service_metadata, .action = create_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        channel_name: ?[]const u8 = null,
        channel_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        outputs: ?[]ResponseOutputItem = null,
        playback_mode: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .channel_name = "ChannelName",
                .channel_state = "ChannelState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .outputs = "Outputs",
                .playback_mode = "PlaybackMode",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const create_program: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/channel/{ChannelName}/program/{ProgramName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProgram",
    Request: type = struct {
        ad_breaks: ?[]AdBreak = null,
        channel_name: []const u8,
        program_name: []const u8,
        schedule_configuration: struct {
            transition: struct {
                relative_position: []const u8,
                relative_program: ?[]const u8 = null,
                type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .relative_position = "RelativePosition",
                        .relative_program = "RelativeProgram",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transition = "Transition",
                };
                return @field(mappings, field_name);
            }
        },
        source_location_name: []const u8,
        vod_source_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ad_breaks = "AdBreaks",
                .channel_name = "ChannelName",
                .program_name = "ProgramName",
                .schedule_configuration = "ScheduleConfiguration",
                .source_location_name = "SourceLocationName",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_program) } {
            return .{ .service_metadata = service_metadata, .action = create_program };
        }
    },
    Response: type = struct {
        ad_breaks: ?[]AdBreak = null,
        arn: ?[]const u8 = null,
        channel_name: ?[]const u8 = null,
        creation_time: ?i64 = null,
        program_name: ?[]const u8 = null,
        source_location_name: ?[]const u8 = null,
        vod_source_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ad_breaks = "AdBreaks",
                .arn = "Arn",
                .channel_name = "ChannelName",
                .creation_time = "CreationTime",
                .program_name = "ProgramName",
                .source_location_name = "SourceLocationName",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_source_location: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sourceLocation/{SourceLocationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSourceLocation",
    Request: type = struct {
        access_configuration: ?AccessConfiguration = null,
        default_segment_delivery_configuration: ?DefaultSegmentDeliveryConfiguration = null,
        http_configuration: HttpConfiguration,
        source_location_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_configuration = "AccessConfiguration",
                .default_segment_delivery_configuration = "DefaultSegmentDeliveryConfiguration",
                .http_configuration = "HttpConfiguration",
                .source_location_name = "SourceLocationName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_source_location) } {
            return .{ .service_metadata = service_metadata, .action = create_source_location };
        }
    },
    Response: type = struct {
        access_configuration: ?AccessConfiguration = null,
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        default_segment_delivery_configuration: ?DefaultSegmentDeliveryConfiguration = null,
        http_configuration: ?HttpConfiguration = null,
        last_modified_time: ?i64 = null,
        source_location_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_configuration = "AccessConfiguration",
                .arn = "Arn",
                .creation_time = "CreationTime",
                .default_segment_delivery_configuration = "DefaultSegmentDeliveryConfiguration",
                .http_configuration = "HttpConfiguration",
                .last_modified_time = "LastModifiedTime",
                .source_location_name = "SourceLocationName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const create_vod_source: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/sourceLocation/{SourceLocationName}/vodSource/{VodSourceName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateVodSource",
    Request: type = struct {
        http_package_configurations: []HttpPackageConfiguration,
        source_location_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vod_source_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .http_package_configurations = "HttpPackageConfigurations",
                .source_location_name = "SourceLocationName",
                .tags = "tags",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_vod_source) } {
            return .{ .service_metadata = service_metadata, .action = create_vod_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        http_package_configurations: ?[]HttpPackageConfiguration = null,
        last_modified_time: ?i64 = null,
        source_location_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vod_source_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_time = "CreationTime",
                .http_package_configurations = "HttpPackageConfigurations",
                .last_modified_time = "LastModifiedTime",
                .source_location_name = "SourceLocationName",
                .tags = "tags",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const delete_channel: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channel/{ChannelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteChannel",
    Request: type = struct {
        channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_channel_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channel/{ChannelName}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteChannelPolicy",
    Request: type = struct {
        channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_channel_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_channel_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_playback_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/playbackConfiguration/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeletePlaybackConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_playback_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_playback_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_program: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/channel/{ChannelName}/program/{ProgramName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProgram",
    Request: type = struct {
        channel_name: []const u8,
        program_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
                .program_name = "ProgramName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_program) } {
            return .{ .service_metadata = service_metadata, .action = delete_program };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_source_location: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sourceLocation/{SourceLocationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteSourceLocation",
    Request: type = struct {
        source_location_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_location_name = "SourceLocationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_source_location) } {
            return .{ .service_metadata = service_metadata, .action = delete_source_location };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_vod_source: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/sourceLocation/{SourceLocationName}/vodSource/{VodSourceName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteVodSource",
    Request: type = struct {
        source_location_name: []const u8,
        vod_source_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_location_name = "SourceLocationName",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_vod_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_vod_source };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_channel: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channel/{ChannelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeChannel",
    Request: type = struct {
        channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_channel) } {
            return .{ .service_metadata = service_metadata, .action = describe_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        channel_name: ?[]const u8 = null,
        channel_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        outputs: ?[]ResponseOutputItem = null,
        playback_mode: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .channel_name = "ChannelName",
                .channel_state = "ChannelState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .outputs = "Outputs",
                .playback_mode = "PlaybackMode",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const describe_program: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channel/{ChannelName}/program/{ProgramName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeProgram",
    Request: type = struct {
        channel_name: []const u8,
        program_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
                .program_name = "ProgramName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_program) } {
            return .{ .service_metadata = service_metadata, .action = describe_program };
        }
    },
    Response: type = struct {
        ad_breaks: ?[]AdBreak = null,
        arn: ?[]const u8 = null,
        channel_name: ?[]const u8 = null,
        creation_time: ?i64 = null,
        program_name: ?[]const u8 = null,
        source_location_name: ?[]const u8 = null,
        vod_source_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ad_breaks = "AdBreaks",
                .arn = "Arn",
                .channel_name = "ChannelName",
                .creation_time = "CreationTime",
                .program_name = "ProgramName",
                .source_location_name = "SourceLocationName",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_source_location: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sourceLocation/{SourceLocationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSourceLocation",
    Request: type = struct {
        source_location_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_location_name = "SourceLocationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_source_location) } {
            return .{ .service_metadata = service_metadata, .action = describe_source_location };
        }
    },
    Response: type = struct {
        access_configuration: ?AccessConfiguration = null,
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        default_segment_delivery_configuration: ?DefaultSegmentDeliveryConfiguration = null,
        http_configuration: ?HttpConfiguration = null,
        last_modified_time: ?i64 = null,
        source_location_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_configuration = "AccessConfiguration",
                .arn = "Arn",
                .creation_time = "CreationTime",
                .default_segment_delivery_configuration = "DefaultSegmentDeliveryConfiguration",
                .http_configuration = "HttpConfiguration",
                .last_modified_time = "LastModifiedTime",
                .source_location_name = "SourceLocationName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const describe_vod_source: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sourceLocation/{SourceLocationName}/vodSource/{VodSourceName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeVodSource",
    Request: type = struct {
        source_location_name: []const u8,
        vod_source_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_location_name = "SourceLocationName",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_vod_source) } {
            return .{ .service_metadata = service_metadata, .action = describe_vod_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        http_package_configurations: ?[]HttpPackageConfiguration = null,
        last_modified_time: ?i64 = null,
        source_location_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vod_source_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_time = "CreationTime",
                .http_package_configurations = "HttpPackageConfigurations",
                .last_modified_time = "LastModifiedTime",
                .source_location_name = "SourceLocationName",
                .tags = "tags",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const get_channel_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channel/{ChannelName}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChannelPolicy",
    Request: type = struct {
        channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channel_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_channel_policy };
        }
    },
    Response: type = struct {
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_channel_schedule: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channel/{ChannelName}/schedule",
        .success_code = 200,
    };

    action_name: []const u8 = "GetChannelSchedule",
    Request: type = struct {
        channel_name: []const u8,
        duration_minutes: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .duration_minutes = "durationMinutes",
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
                .duration_minutes = "DurationMinutes",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_channel_schedule) } {
            return .{ .service_metadata = service_metadata, .action = get_channel_schedule };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            approximate_duration_seconds: ?i64 = null,
            approximate_start_time: ?i64 = null,
            arn: []const u8,
            channel_name: []const u8,
            program_name: []const u8,
            source_location_name: []const u8,
            vod_source_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .approximate_duration_seconds = "ApproximateDurationSeconds",
                    .approximate_start_time = "ApproximateStartTime",
                    .arn = "Arn",
                    .channel_name = "ChannelName",
                    .program_name = "ProgramName",
                    .source_location_name = "SourceLocationName",
                    .vod_source_name = "VodSourceName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_playback_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/playbackConfiguration/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPlaybackConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_playback_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_playback_configuration };
        }
    },
    Response: type = struct {
        ad_decision_server_url: ?[]const u8 = null,
        avail_suppression: ?AvailSuppression = null,
        bumper: ?Bumper = null,
        cdn_configuration: ?CdnConfiguration = null,
        configuration_aliases: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        dash_configuration: ?DashConfiguration = null,
        hls_configuration: ?HlsConfiguration = null,
        live_pre_roll_configuration: ?LivePreRollConfiguration = null,
        manifest_processing_rules: ?ManifestProcessingRules = null,
        name: ?[]const u8 = null,
        personalization_threshold_seconds: ?i64 = null,
        playback_configuration_arn: ?[]const u8 = null,
        playback_endpoint_prefix: ?[]const u8 = null,
        session_initialization_endpoint_prefix: ?[]const u8 = null,
        slate_ad_url: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        transcode_profile_name: ?[]const u8 = null,
        video_content_source_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ad_decision_server_url = "AdDecisionServerUrl",
                .avail_suppression = "AvailSuppression",
                .bumper = "Bumper",
                .cdn_configuration = "CdnConfiguration",
                .configuration_aliases = "ConfigurationAliases",
                .dash_configuration = "DashConfiguration",
                .hls_configuration = "HlsConfiguration",
                .live_pre_roll_configuration = "LivePreRollConfiguration",
                .manifest_processing_rules = "ManifestProcessingRules",
                .name = "Name",
                .personalization_threshold_seconds = "PersonalizationThresholdSeconds",
                .playback_configuration_arn = "PlaybackConfigurationArn",
                .playback_endpoint_prefix = "PlaybackEndpointPrefix",
                .session_initialization_endpoint_prefix = "SessionInitializationEndpointPrefix",
                .slate_ad_url = "SlateAdUrl",
                .tags = "tags",
                .transcode_profile_name = "TranscodeProfileName",
                .video_content_source_url = "VideoContentSourceUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "configuration_aliases", field_name))
                return try serializeMap(self.configuration_aliases, self.fieldNameFor("configuration_aliases"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const list_channels: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/channels",
        .success_code = 200,
    };

    action_name: []const u8 = "ListChannels",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_channels) } {
            return .{ .service_metadata = service_metadata, .action = list_channels };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            arn: []const u8,
            channel_name: []const u8,
            channel_state: []const u8,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            outputs: []ResponseOutputItem,
            playback_mode: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .channel_name = "ChannelName",
                    .channel_state = "ChannelState",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .outputs = "Outputs",
                    .playback_mode = "PlaybackMode",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_playback_configurations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/playbackConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPlaybackConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "MaxResults",
            .next_token = "NextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_playback_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_playback_configurations };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            ad_decision_server_url: ?[]const u8 = null,
            avail_suppression: ?AvailSuppression = null,
            bumper: ?Bumper = null,
            cdn_configuration: ?CdnConfiguration = null,
            configuration_aliases: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,


            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "value", field_name))
                    return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
                return false;
            }
            } = null,
            dash_configuration: ?DashConfiguration = null,
            hls_configuration: ?HlsConfiguration = null,
            live_pre_roll_configuration: ?LivePreRollConfiguration = null,
            manifest_processing_rules: ?ManifestProcessingRules = null,
            name: ?[]const u8 = null,
            personalization_threshold_seconds: ?i64 = null,
            playback_configuration_arn: ?[]const u8 = null,
            playback_endpoint_prefix: ?[]const u8 = null,
            session_initialization_endpoint_prefix: ?[]const u8 = null,
            slate_ad_url: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            transcode_profile_name: ?[]const u8 = null,
            video_content_source_url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ad_decision_server_url = "AdDecisionServerUrl",
                    .avail_suppression = "AvailSuppression",
                    .bumper = "Bumper",
                    .cdn_configuration = "CdnConfiguration",
                    .configuration_aliases = "ConfigurationAliases",
                    .dash_configuration = "DashConfiguration",
                    .hls_configuration = "HlsConfiguration",
                    .live_pre_roll_configuration = "LivePreRollConfiguration",
                    .manifest_processing_rules = "ManifestProcessingRules",
                    .name = "Name",
                    .personalization_threshold_seconds = "PersonalizationThresholdSeconds",
                    .playback_configuration_arn = "PlaybackConfigurationArn",
                    .playback_endpoint_prefix = "PlaybackEndpointPrefix",
                    .session_initialization_endpoint_prefix = "SessionInitializationEndpointPrefix",
                    .slate_ad_url = "SlateAdUrl",
                    .tags = "tags",
                    .transcode_profile_name = "TranscodeProfileName",
                    .video_content_source_url = "VideoContentSourceUrl",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "configuration_aliases", field_name))
                    return try serializeMap(self.configuration_aliases, self.fieldNameFor("configuration_aliases"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_source_locations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sourceLocations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSourceLocations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_source_locations) } {
            return .{ .service_metadata = service_metadata, .action = list_source_locations };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            access_configuration: ?AccessConfiguration = null,
            arn: []const u8,
            creation_time: ?i64 = null,
            default_segment_delivery_configuration: ?DefaultSegmentDeliveryConfiguration = null,
            http_configuration: HttpConfiguration,
            last_modified_time: ?i64 = null,
            source_location_name: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .access_configuration = "AccessConfiguration",
                    .arn = "Arn",
                    .creation_time = "CreationTime",
                    .default_segment_delivery_configuration = "DefaultSegmentDeliveryConfiguration",
                    .http_configuration = "HttpConfiguration",
                    .last_modified_time = "LastModifiedTime",
                    .source_location_name = "SourceLocationName",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{ResourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const list_vod_sources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/sourceLocation/{SourceLocationName}/vodSources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListVodSources",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        source_location_name: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .source_location_name = "SourceLocationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_vod_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_vod_sources };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            arn: []const u8,
            creation_time: ?i64 = null,
            http_package_configurations: []HttpPackageConfiguration,
            last_modified_time: ?i64 = null,
            source_location_name: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            vod_source_name: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .creation_time = "CreationTime",
                    .http_package_configurations = "HttpPackageConfigurations",
                    .last_modified_time = "LastModifiedTime",
                    .source_location_name = "SourceLocationName",
                    .tags = "tags",
                    .vod_source_name = "VodSourceName",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_channel_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channel/{ChannelName}/policy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutChannelPolicy",
    Request: type = struct {
        channel_name: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
                .policy = "Policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_channel_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_channel_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_playback_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/playbackConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "PutPlaybackConfiguration",
    Request: type = struct {
        ad_decision_server_url: ?[]const u8 = null,
        avail_suppression: ?AvailSuppression = null,
        bumper: ?Bumper = null,
        cdn_configuration: ?CdnConfiguration = null,
        configuration_aliases: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        dash_configuration: ?struct {
            mpd_location: ?[]const u8 = null,
            origin_manifest_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .mpd_location = "MpdLocation",
                    .origin_manifest_type = "OriginManifestType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        live_pre_roll_configuration: ?LivePreRollConfiguration = null,
        manifest_processing_rules: ?ManifestProcessingRules = null,
        name: ?[]const u8 = null,
        personalization_threshold_seconds: ?i64 = null,
        slate_ad_url: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        transcode_profile_name: ?[]const u8 = null,
        video_content_source_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ad_decision_server_url = "AdDecisionServerUrl",
                .avail_suppression = "AvailSuppression",
                .bumper = "Bumper",
                .cdn_configuration = "CdnConfiguration",
                .configuration_aliases = "ConfigurationAliases",
                .dash_configuration = "DashConfiguration",
                .live_pre_roll_configuration = "LivePreRollConfiguration",
                .manifest_processing_rules = "ManifestProcessingRules",
                .name = "Name",
                .personalization_threshold_seconds = "PersonalizationThresholdSeconds",
                .slate_ad_url = "SlateAdUrl",
                .tags = "tags",
                .transcode_profile_name = "TranscodeProfileName",
                .video_content_source_url = "VideoContentSourceUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "configuration_aliases", field_name))
                return try serializeMap(self.configuration_aliases, self.fieldNameFor("configuration_aliases"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_playback_configuration) } {
            return .{ .service_metadata = service_metadata, .action = put_playback_configuration };
        }
    },
    Response: type = struct {
        ad_decision_server_url: ?[]const u8 = null,
        avail_suppression: ?AvailSuppression = null,
        bumper: ?Bumper = null,
        cdn_configuration: ?CdnConfiguration = null,
        configuration_aliases: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        dash_configuration: ?DashConfiguration = null,
        hls_configuration: ?HlsConfiguration = null,
        live_pre_roll_configuration: ?LivePreRollConfiguration = null,
        manifest_processing_rules: ?ManifestProcessingRules = null,
        name: ?[]const u8 = null,
        personalization_threshold_seconds: ?i64 = null,
        playback_configuration_arn: ?[]const u8 = null,
        playback_endpoint_prefix: ?[]const u8 = null,
        session_initialization_endpoint_prefix: ?[]const u8 = null,
        slate_ad_url: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        transcode_profile_name: ?[]const u8 = null,
        video_content_source_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ad_decision_server_url = "AdDecisionServerUrl",
                .avail_suppression = "AvailSuppression",
                .bumper = "Bumper",
                .cdn_configuration = "CdnConfiguration",
                .configuration_aliases = "ConfigurationAliases",
                .dash_configuration = "DashConfiguration",
                .hls_configuration = "HlsConfiguration",
                .live_pre_roll_configuration = "LivePreRollConfiguration",
                .manifest_processing_rules = "ManifestProcessingRules",
                .name = "Name",
                .personalization_threshold_seconds = "PersonalizationThresholdSeconds",
                .playback_configuration_arn = "PlaybackConfigurationArn",
                .playback_endpoint_prefix = "PlaybackEndpointPrefix",
                .session_initialization_endpoint_prefix = "SessionInitializationEndpointPrefix",
                .slate_ad_url = "SlateAdUrl",
                .tags = "tags",
                .transcode_profile_name = "TranscodeProfileName",
                .video_content_source_url = "VideoContentSourceUrl",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "configuration_aliases", field_name))
                return try serializeMap(self.configuration_aliases, self.fieldNameFor("configuration_aliases"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const start_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channel/{ChannelName}/start",
        .success_code = 200,
    };

    action_name: []const u8 = "StartChannel",
    Request: type = struct {
        channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_channel) } {
            return .{ .service_metadata = service_metadata, .action = start_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const stop_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channel/{ChannelName}/stop",
        .success_code = 200,
    };

    action_name: []const u8 = "StopChannel",
    Request: type = struct {
        channel_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_channel) } {
            return .{ .service_metadata = service_metadata, .action = stop_channel };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{ResourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        BadRequest,
    },
} = .{};
pub const update_channel: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/channel/{ChannelName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateChannel",
    Request: type = struct {
        channel_name: []const u8,
        outputs: []RequestOutputItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .channel_name = "ChannelName",
                .outputs = "Outputs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_channel) } {
            return .{ .service_metadata = service_metadata, .action = update_channel };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        channel_name: ?[]const u8 = null,
        channel_state: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        outputs: ?[]ResponseOutputItem = null,
        playback_mode: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .channel_name = "ChannelName",
                .channel_state = "ChannelState",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .outputs = "Outputs",
                .playback_mode = "PlaybackMode",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const update_source_location: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sourceLocation/{SourceLocationName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSourceLocation",
    Request: type = struct {
        access_configuration: ?AccessConfiguration = null,
        default_segment_delivery_configuration: ?DefaultSegmentDeliveryConfiguration = null,
        http_configuration: HttpConfiguration,
        source_location_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_configuration = "AccessConfiguration",
                .default_segment_delivery_configuration = "DefaultSegmentDeliveryConfiguration",
                .http_configuration = "HttpConfiguration",
                .source_location_name = "SourceLocationName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_source_location) } {
            return .{ .service_metadata = service_metadata, .action = update_source_location };
        }
    },
    Response: type = struct {
        access_configuration: ?AccessConfiguration = null,
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        default_segment_delivery_configuration: ?DefaultSegmentDeliveryConfiguration = null,
        http_configuration: ?HttpConfiguration = null,
        last_modified_time: ?i64 = null,
        source_location_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .access_configuration = "AccessConfiguration",
                .arn = "Arn",
                .creation_time = "CreationTime",
                .default_segment_delivery_configuration = "DefaultSegmentDeliveryConfiguration",
                .http_configuration = "HttpConfiguration",
                .last_modified_time = "LastModifiedTime",
                .source_location_name = "SourceLocationName",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};
pub const update_vod_source: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/sourceLocation/{SourceLocationName}/vodSource/{VodSourceName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateVodSource",
    Request: type = struct {
        http_package_configurations: []HttpPackageConfiguration,
        source_location_name: []const u8,
        vod_source_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .http_package_configurations = "HttpPackageConfigurations",
                .source_location_name = "SourceLocationName",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_vod_source) } {
            return .{ .service_metadata = service_metadata, .action = update_vod_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        creation_time: ?i64 = null,
        http_package_configurations: ?[]HttpPackageConfiguration = null,
        last_modified_time: ?i64 = null,
        source_location_name: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        vod_source_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .creation_time = "CreationTime",
                .http_package_configurations = "HttpPackageConfigurations",
                .last_modified_time = "LastModifiedTime",
                .source_location_name = "SourceLocationName",
                .tags = "tags",
                .vod_source_name = "VodSourceName",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
} = .{};

pub const HttpPackageConfiguration = struct {
    path: []const u8,
    source_group: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .source_group = "SourceGroup",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpConfiguration = struct {
    base_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base_url = "BaseUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const DefaultSegmentDeliveryConfiguration = struct {
    base_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base_url = "BaseUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const AccessConfiguration = struct {
    access_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_type = "AccessType",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseOutputItem = struct {
    dash_playlist_settings: ?DashPlaylistSettings = null,
    hls_playlist_settings: ?HlsPlaylistSettings = null,
    manifest_name: []const u8,
    playback_url: []const u8,
    source_group: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dash_playlist_settings = "DashPlaylistSettings",
            .hls_playlist_settings = "HlsPlaylistSettings",
            .manifest_name = "ManifestName",
            .playback_url = "PlaybackUrl",
            .source_group = "SourceGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsPlaylistSettings = struct {
    manifest_window_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_window_seconds = "ManifestWindowSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const DashPlaylistSettings = struct {
    manifest_window_seconds: ?i64 = null,
    min_buffer_time_seconds: ?i64 = null,
    min_update_period_seconds: ?i64 = null,
    suggested_presentation_delay_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_window_seconds = "ManifestWindowSeconds",
            .min_buffer_time_seconds = "MinBufferTimeSeconds",
            .min_update_period_seconds = "MinUpdatePeriodSeconds",
            .suggested_presentation_delay_seconds = "SuggestedPresentationDelaySeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const RequestOutputItem = struct {
    dash_playlist_settings: ?DashPlaylistSettings = null,
    hls_playlist_settings: ?HlsPlaylistSettings = null,
    manifest_name: []const u8,
    source_group: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dash_playlist_settings = "DashPlaylistSettings",
            .hls_playlist_settings = "HlsPlaylistSettings",
            .manifest_name = "ManifestName",
            .source_group = "SourceGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const ManifestProcessingRules = struct {
    ad_marker_passthrough: ?AdMarkerPassthrough = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_marker_passthrough = "AdMarkerPassthrough",
        };
        return @field(mappings, field_name);
    }
};

pub const AdMarkerPassthrough = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const LivePreRollConfiguration = struct {
    ad_decision_server_url: ?[]const u8 = null,
    max_duration_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_decision_server_url = "AdDecisionServerUrl",
            .max_duration_seconds = "MaxDurationSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const HlsConfiguration = struct {
    manifest_endpoint_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_endpoint_prefix = "ManifestEndpointPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const DashConfiguration = struct {
    manifest_endpoint_prefix: ?[]const u8 = null,
    mpd_location: ?[]const u8 = null,
    origin_manifest_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_endpoint_prefix = "ManifestEndpointPrefix",
            .mpd_location = "MpdLocation",
            .origin_manifest_type = "OriginManifestType",
        };
        return @field(mappings, field_name);
    }
};

pub const CdnConfiguration = struct {
    ad_segment_url_prefix: ?[]const u8 = null,
    content_segment_url_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_segment_url_prefix = "AdSegmentUrlPrefix",
            .content_segment_url_prefix = "ContentSegmentUrlPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Bumper = struct {
    end_url: ?[]const u8 = null,
    start_url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .end_url = "EndUrl",
            .start_url = "StartUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const AvailSuppression = struct {
    mode: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AdBreak = struct {
    message_type: ?[]const u8 = null,
    offset_millis: ?i64 = null,
    slate: ?SlateSource = null,
    splice_insert_message: ?SpliceInsertMessage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_type = "MessageType",
            .offset_millis = "OffsetMillis",
            .slate = "Slate",
            .splice_insert_message = "SpliceInsertMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const SpliceInsertMessage = struct {
    avail_num: ?i64 = null,
    avails_expected: ?i64 = null,
    splice_event_id: ?i64 = null,
    unique_program_id: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .avail_num = "AvailNum",
            .avails_expected = "AvailsExpected",
            .splice_event_id = "SpliceEventId",
            .unique_program_id = "UniqueProgramId",
        };
        return @field(mappings, field_name);
    }
};

pub const SlateSource = struct {
    source_location_name: ?[]const u8 = null,
    vod_source_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_location_name = "SourceLocationName",
            .vod_source_name = "VodSourceName",
        };
        return @field(mappings, field_name);
    }
};
