const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-02-27";
pub const sdk_id: []const u8 = "PI";
pub const arn_namespace: []const u8 = "pi";
pub const endpoint_prefix: []const u8 = "pi";
pub const sigv4_name: []const u8 = "pi";
pub const name: []const u8 = "PerformanceInsightsv20180227";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-02-27",
    sdk_id: []const u8 = "PI",
    arn_namespace: []const u8 = "pi",
    endpoint_prefix: []const u8 = "pi",
    sigv4_name: []const u8 = "pi",
    name: []const u8 = "PerformanceInsightsv20180227",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const describe_dimension_keys: struct {
    action_name: []const u8 = "DescribeDimensionKeys",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        start_time: i64,
        end_time: i64,
        metric: []const u8,
        period_in_seconds: ?i64 = null,
        group_by: DimensionGroup,
        partition_by: ?DimensionGroup = null,
        filter: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .metric = "Metric",
                .period_in_seconds = "PeriodInSeconds",
                .group_by = "GroupBy",
                .partition_by = "PartitionBy",
                .filter = "Filter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "filter", field_name))
                return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dimension_keys) } {
            return .{ .service_metadata = service_metadata, .action = describe_dimension_keys };
        }
    },
    Response: type = struct {
        aligned_start_time: ?i64 = null,
        aligned_end_time: ?i64 = null,
        partition_keys: ?[]struct {
            dimensions: []struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "dimensions", field_name))
                    return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
                return false;
            }
        } = null,
        keys: ?[]struct {
            dimensions: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            total: ?f64 = null,
            partitions: ?[]f64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dimensions = "Dimensions",
                    .total = "Total",
                    .partitions = "Partitions",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "dimensions", field_name))
                    return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aligned_start_time = "AlignedStartTime",
                .aligned_end_time = "AlignedEndTime",
                .partition_keys = "PartitionKeys",
                .keys = "Keys",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};
pub const get_resource_metrics: struct {
    action_name: []const u8 = "GetResourceMetrics",
    Request: type = struct {
        service_type: []const u8,
        identifier: []const u8,
        metric_queries: []struct {
            metric: []const u8,
            group_by: ?DimensionGroup = null,
            filter: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .metric = "Metric",
                    .group_by = "GroupBy",
                    .filter = "Filter",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "filter", field_name))
                    return try serializeMap(self.filter, self.fieldNameFor("filter"), options, out_stream);
                return false;
            }
        },
        start_time: i64,
        end_time: i64,
        period_in_seconds: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .identifier = "Identifier",
                .metric_queries = "MetricQueries",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .period_in_seconds = "PeriodInSeconds",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_metrics };
        }
    },
    Response: type = struct {
        aligned_start_time: ?i64 = null,
        aligned_end_time: ?i64 = null,
        identifier: ?[]const u8 = null,
        metric_list: ?[]struct {
            key: ?struct {
                metric: []const u8,
                dimensions: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metric = "Metric",
                        .dimensions = "Dimensions",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "dimensions", field_name))
                        return try serializeMap(self.dimensions, self.fieldNameFor("dimensions"), options, out_stream);
                    return false;
                }
            } = null,
            data_points: ?[]struct {
                timestamp: i64,
                value: f64,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .timestamp = "Timestamp",
                        .value = "Value",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .data_points = "DataPoints",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aligned_start_time = "AlignedStartTime",
                .aligned_end_time = "AlignedEndTime",
                .identifier = "Identifier",
                .metric_list = "MetricList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidArgument,
        NotAuthorized,
    },
} = .{};

pub const DimensionGroup = struct {
    group: []const u8,
    dimensions: ?[][]const u8 = null,
    limit: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .group = "Group",
            .dimensions = "Dimensions",
            .limit = "Limit",
        };
        return @field(mappings, field_name);
    }
};
