const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-11-23";
pub const sdk_id: []const u8 = "SFN";
pub const arn_namespace: []const u8 = "states";
pub const endpoint_prefix: []const u8 = "states";
pub const sigv4_name: []const u8 = "states";
pub const name: []const u8 = "AWSStepFunctions";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2016-11-23",
    sdk_id: []const u8 = "SFN",
    arn_namespace: []const u8 = "states",
    endpoint_prefix: []const u8 = "states",
    sigv4_name: []const u8 = "states",
    name: []const u8 = "AWSStepFunctions",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_activity: struct {
    action_name: []const u8 = "CreateActivity",
    Request: type = struct {
        name: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_activity) } {
            return .{ .service_metadata = service_metadata, .action = create_activity };
        }
    },
    Response: type = struct {
        activity_arn: []const u8,
        creation_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activity_arn = "activityArn",
                .creation_date = "creationDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActivityLimitExceeded,
        InvalidName,
        TooManyTags,
    },
} = .{};
pub const create_state_machine: struct {
    action_name: []const u8 = "CreateStateMachine",
    Request: type = struct {
        name: []const u8,
        definition: []const u8,
        role_arn: []const u8,
        type: ?[]const u8 = null,
        logging_configuration: ?LoggingConfiguration = null,
        tags: ?[]Tag = null,
        tracing_configuration: ?TracingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .definition = "definition",
                .role_arn = "roleArn",
                .type = "type",
                .logging_configuration = "loggingConfiguration",
                .tags = "tags",
                .tracing_configuration = "tracingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_state_machine) } {
            return .{ .service_metadata = service_metadata, .action = create_state_machine };
        }
    },
    Response: type = struct {
        state_machine_arn: []const u8,
        creation_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
                .creation_date = "creationDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidDefinition,
        InvalidLoggingConfiguration,
        InvalidName,
        InvalidTracingConfiguration,
        StateMachineAlreadyExists,
        StateMachineDeleting,
        StateMachineLimitExceeded,
        StateMachineTypeNotSupported,
        TooManyTags,
    },
} = .{};
pub const delete_activity: struct {
    action_name: []const u8 = "DeleteActivity",
    Request: type = struct {
        activity_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activity_arn = "activityArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_activity) } {
            return .{ .service_metadata = service_metadata, .action = delete_activity };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
    },
} = .{};
pub const delete_state_machine: struct {
    action_name: []const u8 = "DeleteStateMachine",
    Request: type = struct {
        state_machine_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_state_machine) } {
            return .{ .service_metadata = service_metadata, .action = delete_state_machine };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
    },
} = .{};
pub const describe_activity: struct {
    action_name: []const u8 = "DescribeActivity",
    Request: type = struct {
        activity_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activity_arn = "activityArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_activity) } {
            return .{ .service_metadata = service_metadata, .action = describe_activity };
        }
    },
    Response: type = struct {
        activity_arn: []const u8,
        name: []const u8,
        creation_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activity_arn = "activityArn",
                .name = "name",
                .creation_date = "creationDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActivityDoesNotExist,
        InvalidArn,
    },
} = .{};
pub const describe_execution: struct {
    action_name: []const u8 = "DescribeExecution",
    Request: type = struct {
        execution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_arn = "executionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_execution };
        }
    },
    Response: type = struct {
        execution_arn: []const u8,
        state_machine_arn: []const u8,
        name: ?[]const u8 = null,
        status: []const u8,
        start_date: i64,
        stop_date: ?i64 = null,
        input: ?[]const u8 = null,
        input_details: ?CloudWatchEventsExecutionDataDetails = null,
        output: ?[]const u8 = null,
        output_details: ?CloudWatchEventsExecutionDataDetails = null,
        trace_header: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_arn = "executionArn",
                .state_machine_arn = "stateMachineArn",
                .name = "name",
                .status = "status",
                .start_date = "startDate",
                .stop_date = "stopDate",
                .input = "input",
                .input_details = "inputDetails",
                .output = "output",
                .output_details = "outputDetails",
                .trace_header = "traceHeader",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExecutionDoesNotExist,
        InvalidArn,
    },
} = .{};
pub const describe_state_machine: struct {
    action_name: []const u8 = "DescribeStateMachine",
    Request: type = struct {
        state_machine_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_state_machine) } {
            return .{ .service_metadata = service_metadata, .action = describe_state_machine };
        }
    },
    Response: type = struct {
        state_machine_arn: []const u8,
        name: []const u8,
        status: ?[]const u8 = null,
        definition: []const u8,
        role_arn: []const u8,
        type: []const u8,
        creation_date: i64,
        logging_configuration: ?LoggingConfiguration = null,
        tracing_configuration: ?TracingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
                .name = "name",
                .status = "status",
                .definition = "definition",
                .role_arn = "roleArn",
                .type = "type",
                .creation_date = "creationDate",
                .logging_configuration = "loggingConfiguration",
                .tracing_configuration = "tracingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        StateMachineDoesNotExist,
    },
} = .{};
pub const describe_state_machine_for_execution: struct {
    action_name: []const u8 = "DescribeStateMachineForExecution",
    Request: type = struct {
        execution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_arn = "executionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_state_machine_for_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_state_machine_for_execution };
        }
    },
    Response: type = struct {
        state_machine_arn: []const u8,
        name: []const u8,
        definition: []const u8,
        role_arn: []const u8,
        update_date: i64,
        logging_configuration: ?LoggingConfiguration = null,
        tracing_configuration: ?TracingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
                .name = "name",
                .definition = "definition",
                .role_arn = "roleArn",
                .update_date = "updateDate",
                .logging_configuration = "loggingConfiguration",
                .tracing_configuration = "tracingConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExecutionDoesNotExist,
        InvalidArn,
    },
} = .{};
pub const get_activity_task: struct {
    action_name: []const u8 = "GetActivityTask",
    Request: type = struct {
        activity_arn: []const u8,
        worker_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activity_arn = "activityArn",
                .worker_name = "workerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_activity_task) } {
            return .{ .service_metadata = service_metadata, .action = get_activity_task };
        }
    },
    Response: type = struct {
        task_token: ?[]const u8 = null,
        input: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .input = "input",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ActivityDoesNotExist,
        ActivityWorkerLimitExceeded,
        InvalidArn,
    },
} = .{};
pub const get_execution_history: struct {
    action_name: []const u8 = "GetExecutionHistory",
    Request: type = struct {
        execution_arn: []const u8,
        max_results: ?i64 = null,
        reverse_order: ?bool = null,
        next_token: ?[]const u8 = null,
        include_execution_data: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_arn = "executionArn",
                .max_results = "maxResults",
                .reverse_order = "reverseOrder",
                .next_token = "nextToken",
                .include_execution_data = "includeExecutionData",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_execution_history) } {
            return .{ .service_metadata = service_metadata, .action = get_execution_history };
        }
    },
    Response: type = struct {
        events: []struct {
            timestamp: i64,
            type: []const u8,
            id: i64,
            previous_event_id: ?i64 = null,
            activity_failed_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            activity_schedule_failed_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            activity_scheduled_event_details: ?struct {
                resource: []const u8,
                input: ?[]const u8 = null,
                input_details: ?HistoryEventExecutionDataDetails = null,
                timeout_in_seconds: ?i64 = null,
                heartbeat_in_seconds: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource = "resource",
                        .input = "input",
                        .input_details = "inputDetails",
                        .timeout_in_seconds = "timeoutInSeconds",
                        .heartbeat_in_seconds = "heartbeatInSeconds",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            activity_started_event_details: ?struct {
                worker_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .worker_name = "workerName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            activity_succeeded_event_details: ?struct {
                output: ?[]const u8 = null,
                output_details: ?HistoryEventExecutionDataDetails = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .output = "output",
                        .output_details = "outputDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            activity_timed_out_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_failed_event_details: ?struct {
                resource_type: []const u8,
                resource: []const u8,
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource = "resource",
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_scheduled_event_details: ?struct {
                resource_type: []const u8,
                resource: []const u8,
                region: []const u8,
                parameters: []const u8,
                timeout_in_seconds: ?i64 = null,
                heartbeat_in_seconds: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource = "resource",
                        .region = "region",
                        .parameters = "parameters",
                        .timeout_in_seconds = "timeoutInSeconds",
                        .heartbeat_in_seconds = "heartbeatInSeconds",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_start_failed_event_details: ?struct {
                resource_type: []const u8,
                resource: []const u8,
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource = "resource",
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_started_event_details: ?struct {
                resource_type: []const u8,
                resource: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource = "resource",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_submit_failed_event_details: ?struct {
                resource_type: []const u8,
                resource: []const u8,
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource = "resource",
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_submitted_event_details: ?struct {
                resource_type: []const u8,
                resource: []const u8,
                output: ?[]const u8 = null,
                output_details: ?HistoryEventExecutionDataDetails = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource = "resource",
                        .output = "output",
                        .output_details = "outputDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_succeeded_event_details: ?struct {
                resource_type: []const u8,
                resource: []const u8,
                output: ?[]const u8 = null,
                output_details: ?HistoryEventExecutionDataDetails = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource = "resource",
                        .output = "output",
                        .output_details = "outputDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            task_timed_out_event_details: ?struct {
                resource_type: []const u8,
                resource: []const u8,
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "resourceType",
                        .resource = "resource",
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            execution_failed_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            execution_started_event_details: ?struct {
                input: ?[]const u8 = null,
                input_details: ?HistoryEventExecutionDataDetails = null,
                role_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .input = "input",
                        .input_details = "inputDetails",
                        .role_arn = "roleArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            execution_succeeded_event_details: ?struct {
                output: ?[]const u8 = null,
                output_details: ?HistoryEventExecutionDataDetails = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .output = "output",
                        .output_details = "outputDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            execution_aborted_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            execution_timed_out_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            map_state_started_event_details: ?struct {
                length: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .length = "length",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            map_iteration_started_event_details: ?MapIterationEventDetails = null,
            map_iteration_succeeded_event_details: ?MapIterationEventDetails = null,
            map_iteration_failed_event_details: ?MapIterationEventDetails = null,
            map_iteration_aborted_event_details: ?MapIterationEventDetails = null,
            lambda_function_failed_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lambda_function_schedule_failed_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lambda_function_scheduled_event_details: ?struct {
                resource: []const u8,
                input: ?[]const u8 = null,
                input_details: ?HistoryEventExecutionDataDetails = null,
                timeout_in_seconds: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource = "resource",
                        .input = "input",
                        .input_details = "inputDetails",
                        .timeout_in_seconds = "timeoutInSeconds",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lambda_function_start_failed_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lambda_function_succeeded_event_details: ?struct {
                output: ?[]const u8 = null,
                output_details: ?HistoryEventExecutionDataDetails = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .output = "output",
                        .output_details = "outputDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            lambda_function_timed_out_event_details: ?struct {
                @"error": ?[]const u8 = null,
                cause: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .@"error" = "error",
                        .cause = "cause",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            state_entered_event_details: ?struct {
                name: []const u8,
                input: ?[]const u8 = null,
                input_details: ?HistoryEventExecutionDataDetails = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .input = "input",
                        .input_details = "inputDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            state_exited_event_details: ?struct {
                name: []const u8,
                output: ?[]const u8 = null,
                output_details: ?HistoryEventExecutionDataDetails = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "name",
                        .output = "output",
                        .output_details = "outputDetails",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .timestamp = "timestamp",
                    .type = "type",
                    .id = "id",
                    .previous_event_id = "previousEventId",
                    .activity_failed_event_details = "activityFailedEventDetails",
                    .activity_schedule_failed_event_details = "activityScheduleFailedEventDetails",
                    .activity_scheduled_event_details = "activityScheduledEventDetails",
                    .activity_started_event_details = "activityStartedEventDetails",
                    .activity_succeeded_event_details = "activitySucceededEventDetails",
                    .activity_timed_out_event_details = "activityTimedOutEventDetails",
                    .task_failed_event_details = "taskFailedEventDetails",
                    .task_scheduled_event_details = "taskScheduledEventDetails",
                    .task_start_failed_event_details = "taskStartFailedEventDetails",
                    .task_started_event_details = "taskStartedEventDetails",
                    .task_submit_failed_event_details = "taskSubmitFailedEventDetails",
                    .task_submitted_event_details = "taskSubmittedEventDetails",
                    .task_succeeded_event_details = "taskSucceededEventDetails",
                    .task_timed_out_event_details = "taskTimedOutEventDetails",
                    .execution_failed_event_details = "executionFailedEventDetails",
                    .execution_started_event_details = "executionStartedEventDetails",
                    .execution_succeeded_event_details = "executionSucceededEventDetails",
                    .execution_aborted_event_details = "executionAbortedEventDetails",
                    .execution_timed_out_event_details = "executionTimedOutEventDetails",
                    .map_state_started_event_details = "mapStateStartedEventDetails",
                    .map_iteration_started_event_details = "mapIterationStartedEventDetails",
                    .map_iteration_succeeded_event_details = "mapIterationSucceededEventDetails",
                    .map_iteration_failed_event_details = "mapIterationFailedEventDetails",
                    .map_iteration_aborted_event_details = "mapIterationAbortedEventDetails",
                    .lambda_function_failed_event_details = "lambdaFunctionFailedEventDetails",
                    .lambda_function_schedule_failed_event_details = "lambdaFunctionScheduleFailedEventDetails",
                    .lambda_function_scheduled_event_details = "lambdaFunctionScheduledEventDetails",
                    .lambda_function_start_failed_event_details = "lambdaFunctionStartFailedEventDetails",
                    .lambda_function_succeeded_event_details = "lambdaFunctionSucceededEventDetails",
                    .lambda_function_timed_out_event_details = "lambdaFunctionTimedOutEventDetails",
                    .state_entered_event_details = "stateEnteredEventDetails",
                    .state_exited_event_details = "stateExitedEventDetails",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "events",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExecutionDoesNotExist,
        InvalidArn,
        InvalidToken,
    },
} = .{};
pub const list_activities: struct {
    action_name: []const u8 = "ListActivities",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_activities) } {
            return .{ .service_metadata = service_metadata, .action = list_activities };
        }
    },
    Response: type = struct {
        activities: []struct {
            activity_arn: []const u8,
            name: []const u8,
            creation_date: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .activity_arn = "activityArn",
                    .name = "name",
                    .creation_date = "creationDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .activities = "activities",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidToken,
    },
} = .{};
pub const list_executions: struct {
    action_name: []const u8 = "ListExecutions",
    Request: type = struct {
        state_machine_arn: []const u8,
        status_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
                .status_filter = "statusFilter",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_executions };
        }
    },
    Response: type = struct {
        executions: []struct {
            execution_arn: []const u8,
            state_machine_arn: []const u8,
            name: []const u8,
            status: []const u8,
            start_date: i64,
            stop_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .execution_arn = "executionArn",
                    .state_machine_arn = "stateMachineArn",
                    .name = "name",
                    .status = "status",
                    .start_date = "startDate",
                    .stop_date = "stopDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .executions = "executions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidToken,
        StateMachineDoesNotExist,
        StateMachineTypeNotSupported,
    },
} = .{};
pub const list_state_machines: struct {
    action_name: []const u8 = "ListStateMachines",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_state_machines) } {
            return .{ .service_metadata = service_metadata, .action = list_state_machines };
        }
    },
    Response: type = struct {
        state_machines: []struct {
            state_machine_arn: []const u8,
            name: []const u8,
            type: []const u8,
            creation_date: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .state_machine_arn = "stateMachineArn",
                    .name = "name",
                    .type = "type",
                    .creation_date = "creationDate",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machines = "stateMachines",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidToken,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        ResourceNotFound,
    },
} = .{};
pub const send_task_failure: struct {
    action_name: []const u8 = "SendTaskFailure",
    Request: type = struct {
        task_token: []const u8,
        @"error": ?[]const u8 = null,
        cause: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .@"error" = "error",
                .cause = "cause",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_task_failure) } {
            return .{ .service_metadata = service_metadata, .action = send_task_failure };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidToken,
        TaskDoesNotExist,
        TaskTimedOut,
    },
} = .{};
pub const send_task_heartbeat: struct {
    action_name: []const u8 = "SendTaskHeartbeat",
    Request: type = struct {
        task_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_task_heartbeat) } {
            return .{ .service_metadata = service_metadata, .action = send_task_heartbeat };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidToken,
        TaskDoesNotExist,
        TaskTimedOut,
    },
} = .{};
pub const send_task_success: struct {
    action_name: []const u8 = "SendTaskSuccess",
    Request: type = struct {
        task_token: []const u8,
        output: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_token = "taskToken",
                .output = "output",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_task_success) } {
            return .{ .service_metadata = service_metadata, .action = send_task_success };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidOutput,
        InvalidToken,
        TaskDoesNotExist,
        TaskTimedOut,
    },
} = .{};
pub const start_execution: struct {
    action_name: []const u8 = "StartExecution",
    Request: type = struct {
        state_machine_arn: []const u8,
        name: ?[]const u8 = null,
        input: ?[]const u8 = null,
        trace_header: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
                .name = "name",
                .input = "input",
                .trace_header = "traceHeader",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_execution };
        }
    },
    Response: type = struct {
        execution_arn: []const u8,
        start_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_arn = "executionArn",
                .start_date = "startDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExecutionAlreadyExists,
        ExecutionLimitExceeded,
        InvalidArn,
        InvalidExecutionInput,
        InvalidName,
        StateMachineDeleting,
        StateMachineDoesNotExist,
    },
} = .{};
pub const start_sync_execution: struct {
    action_name: []const u8 = "StartSyncExecution",
    Request: type = struct {
        state_machine_arn: []const u8,
        name: ?[]const u8 = null,
        input: ?[]const u8 = null,
        trace_header: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
                .name = "name",
                .input = "input",
                .trace_header = "traceHeader",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_sync_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_sync_execution };
        }
    },
    Response: type = struct {
        execution_arn: []const u8,
        state_machine_arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        start_date: i64,
        stop_date: i64,
        status: []const u8,
        @"error": ?[]const u8 = null,
        cause: ?[]const u8 = null,
        input: ?[]const u8 = null,
        input_details: ?CloudWatchEventsExecutionDataDetails = null,
        output: ?[]const u8 = null,
        output_details: ?CloudWatchEventsExecutionDataDetails = null,
        trace_header: ?[]const u8 = null,
        billing_details: ?struct {
            billed_memory_used_in_mb: ?i64 = null,
            billed_duration_in_milliseconds: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .billed_memory_used_in_mb = "billedMemoryUsedInMB",
                    .billed_duration_in_milliseconds = "billedDurationInMilliseconds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_arn = "executionArn",
                .state_machine_arn = "stateMachineArn",
                .name = "name",
                .start_date = "startDate",
                .stop_date = "stopDate",
                .status = "status",
                .@"error" = "error",
                .cause = "cause",
                .input = "input",
                .input_details = "inputDetails",
                .output = "output",
                .output_details = "outputDetails",
                .trace_header = "traceHeader",
                .billing_details = "billingDetails",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidExecutionInput,
        InvalidName,
        StateMachineDeleting,
        StateMachineDoesNotExist,
        StateMachineTypeNotSupported,
    },
} = .{};
pub const stop_execution: struct {
    action_name: []const u8 = "StopExecution",
    Request: type = struct {
        execution_arn: []const u8,
        @"error": ?[]const u8 = null,
        cause: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .execution_arn = "executionArn",
                .@"error" = "error",
                .cause = "cause",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_execution) } {
            return .{ .service_metadata = service_metadata, .action = stop_execution };
        }
    },
    Response: type = struct {
        stop_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stop_date = "stopDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ExecutionDoesNotExist,
        InvalidArn,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        ResourceNotFound,
        TooManyTags,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        ResourceNotFound,
    },
} = .{};
pub const update_state_machine: struct {
    action_name: []const u8 = "UpdateStateMachine",
    Request: type = struct {
        state_machine_arn: []const u8,
        definition: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        logging_configuration: ?LoggingConfiguration = null,
        tracing_configuration: ?TracingConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .state_machine_arn = "stateMachineArn",
                .definition = "definition",
                .role_arn = "roleArn",
                .logging_configuration = "loggingConfiguration",
                .tracing_configuration = "tracingConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_state_machine) } {
            return .{ .service_metadata = service_metadata, .action = update_state_machine };
        }
    },
    Response: type = struct {
        update_date: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .update_date = "updateDate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidArn,
        InvalidDefinition,
        InvalidLoggingConfiguration,
        InvalidTracingConfiguration,
        MissingRequiredParameter,
        StateMachineDeleting,
        StateMachineDoesNotExist,
    },
} = .{};

pub const TracingConfiguration = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const LoggingConfiguration = struct {
    level: ?[]const u8 = null,
    include_execution_data: ?bool = null,
    destinations: ?[]LogDestination = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .level = "level",
            .include_execution_data = "includeExecutionData",
            .destinations = "destinations",
        };
        return @field(mappings, field_name);
    }
};

pub const LogDestination = struct {
    cloud_watch_logs_log_group: ?CloudWatchLogsLogGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_logs_log_group = "cloudWatchLogsLogGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogsLogGroup = struct {
    log_group_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_group_arn = "logGroupArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchEventsExecutionDataDetails = struct {
    included: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .included = "included",
        };
        return @field(mappings, field_name);
    }
};

pub const HistoryEventExecutionDataDetails = struct {
    truncated: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .truncated = "truncated",
        };
        return @field(mappings, field_name);
    }
};

pub const MapIterationEventDetails = struct {
    name: ?[]const u8 = null,
    index: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .index = "index",
        };
        return @field(mappings, field_name);
    }
};
