const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-03-31";
pub const sdk_id: []const u8 = "Glue";
pub const arn_namespace: []const u8 = "glue";
pub const endpoint_prefix: []const u8 = "glue";
pub const sigv4_name: []const u8 = "glue";
pub const name: []const u8 = "AWSGlue";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-03-31",
    sdk_id: []const u8 = "Glue",
    arn_namespace: []const u8 = "glue",
    endpoint_prefix: []const u8 = "glue",
    sigv4_name: []const u8 = "glue",
    name: []const u8 = "AWSGlue",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const batch_create_partition: struct {
    action_name: []const u8 = "BatchCreatePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_input_list: []PartitionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_input_list = "PartitionInputList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_create_partition) } {
            return .{ .service_metadata = service_metadata, .action = batch_create_partition };
        }
    },
    Response: type = struct {
        errors: ?[]PartitionError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const batch_delete_connection: struct {
    action_name: []const u8 = "BatchDeleteConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        connection_name_list: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .connection_name_list = "ConnectionNameList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_connection };
        }
    },
    Response: type = struct {
        succeeded: ?[][]const u8 = null,
        errors: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ErrorDetail = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .succeeded = "Succeeded",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "errors", field_name))
                return try serializeMap(self.errors, self.fieldNameFor("errors"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalService,
        OperationTimeout,
    },
} = .{};
pub const batch_delete_partition: struct {
    action_name: []const u8 = "BatchDeletePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partitions_to_delete: []PartitionValueList,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partitions_to_delete = "PartitionsToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_partition) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_partition };
        }
    },
    Response: type = struct {
        errors: ?[]PartitionError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_delete_table: struct {
    action_name: []const u8 = "BatchDeleteTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        tables_to_delete: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .tables_to_delete = "TablesToDelete",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_table) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_table };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            table_name: ?[]const u8 = null,
            error_detail: ?ErrorDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_name = "TableName",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_delete_table_version: struct {
    action_name: []const u8 = "BatchDeleteTableVersion",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        version_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .version_ids = "VersionIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_delete_table_version) } {
            return .{ .service_metadata = service_metadata, .action = batch_delete_table_version };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            table_name: ?[]const u8 = null,
            version_id: ?[]const u8 = null,
            error_detail: ?ErrorDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .table_name = "TableName",
                    .version_id = "VersionId",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_crawlers: struct {
    action_name: []const u8 = "BatchGetCrawlers",
    Request: type = struct {
        crawler_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_names = "CrawlerNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_crawlers) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_crawlers };
        }
    },
    Response: type = struct {
        crawlers: ?[]Crawler = null,
        crawlers_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawlers = "Crawlers",
                .crawlers_not_found = "CrawlersNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_dev_endpoints: struct {
    action_name: []const u8 = "BatchGetDevEndpoints",
    Request: type = struct {
        dev_endpoint_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoint_names = "DevEndpointNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_dev_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_dev_endpoints };
        }
    },
    Response: type = struct {
        dev_endpoints: ?[]DevEndpoint = null,
        dev_endpoints_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoints = "DevEndpoints",
                .dev_endpoints_not_found = "DevEndpointsNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_jobs: struct {
    action_name: []const u8 = "BatchGetJobs",
    Request: type = struct {
        job_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_names = "JobNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_jobs) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]Job = null,
        jobs_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .jobs_not_found = "JobsNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_partition: struct {
    action_name: []const u8 = "BatchGetPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partitions_to_get: []PartitionValueList,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partitions_to_get = "PartitionsToGet",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_partition) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_partition };
        }
    },
    Response: type = struct {
        partitions: ?[]Partition = null,
        unprocessed_keys: ?[]PartitionValueList = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partitions = "Partitions",
                .unprocessed_keys = "UnprocessedKeys",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_triggers: struct {
    action_name: []const u8 = "BatchGetTriggers",
    Request: type = struct {
        trigger_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trigger_names = "TriggerNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_triggers) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_triggers };
        }
    },
    Response: type = struct {
        triggers: ?[]Trigger = null,
        triggers_not_found: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .triggers = "Triggers",
                .triggers_not_found = "TriggersNotFound",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_get_workflows: struct {
    action_name: []const u8 = "BatchGetWorkflows",
    Request: type = struct {
        names: [][]const u8,
        include_graph: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .names = "Names",
                .include_graph = "IncludeGraph",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_get_workflows) } {
            return .{ .service_metadata = service_metadata, .action = batch_get_workflows };
        }
    },
    Response: type = struct {
        workflows: ?[]Workflow = null,
        missing_workflows: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflows = "Workflows",
                .missing_workflows = "MissingWorkflows",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_stop_job_run: struct {
    action_name: []const u8 = "BatchStopJobRun",
    Request: type = struct {
        job_name: []const u8,
        job_run_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .job_run_ids = "JobRunIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_stop_job_run) } {
            return .{ .service_metadata = service_metadata, .action = batch_stop_job_run };
        }
    },
    Response: type = struct {
        successful_submissions: ?[]struct {
            job_name: ?[]const u8 = null,
            job_run_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "JobName",
                    .job_run_id = "JobRunId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        errors: ?[]struct {
            job_name: ?[]const u8 = null,
            job_run_id: ?[]const u8 = null,
            error_detail: ?ErrorDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_name = "JobName",
                    .job_run_id = "JobRunId",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .successful_submissions = "SuccessfulSubmissions",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const batch_update_partition: struct {
    action_name: []const u8 = "BatchUpdatePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        entries: []struct {
            partition_value_list: [][]const u8,
            partition_input: PartitionInput,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .partition_value_list = "PartitionValueList",
                    .partition_input = "PartitionInput",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .entries = "Entries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(batch_update_partition) } {
            return .{ .service_metadata = service_metadata, .action = batch_update_partition };
        }
    },
    Response: type = struct {
        errors: ?[]struct {
            partition_value_list: ?[][]const u8 = null,
            error_detail: ?ErrorDetail = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .partition_value_list = "PartitionValueList",
                    .error_detail = "ErrorDetail",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const cancel_ml_task_run: struct {
    action_name: []const u8 = "CancelMLTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        task_run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_ml_task_run) } {
            return .{ .service_metadata = service_metadata, .action = cancel_ml_task_run };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,
        task_run_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .task_run_id = "TaskRunId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const check_schema_version_validity: struct {
    action_name: []const u8 = "CheckSchemaVersionValidity",
    Request: type = struct {
        data_format: []const u8,
        schema_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_format = "DataFormat",
                .schema_definition = "SchemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(check_schema_version_validity) } {
            return .{ .service_metadata = service_metadata, .action = check_schema_version_validity };
        }
    },
    Response: type = struct {
        valid: ?bool = null,
        @"error": ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .valid = "Valid",
                .@"error" = "Error",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const create_classifier: struct {
    action_name: []const u8 = "CreateClassifier",
    Request: type = struct {
        grok_classifier: ?struct {
            classification: []const u8,
            name: []const u8,
            grok_pattern: []const u8,
            custom_patterns: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .classification = "Classification",
                    .name = "Name",
                    .grok_pattern = "GrokPattern",
                    .custom_patterns = "CustomPatterns",
                };
                return @field(mappings, field_name);
            }
        } = null,
        xml_classifier: ?struct {
            classification: []const u8,
            name: []const u8,
            row_tag: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .classification = "Classification",
                    .name = "Name",
                    .row_tag = "RowTag",
                };
                return @field(mappings, field_name);
            }
        } = null,
        json_classifier: ?struct {
            name: []const u8,
            json_path: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .json_path = "JsonPath",
                };
                return @field(mappings, field_name);
            }
        } = null,
        csv_classifier: ?struct {
            name: []const u8,
            delimiter: ?[]const u8 = null,
            quote_symbol: ?[]const u8 = null,
            contains_header: ?[]const u8 = null,
            header: ?[][]const u8 = null,
            disable_value_trimming: ?bool = null,
            allow_single_column: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .delimiter = "Delimiter",
                    .quote_symbol = "QuoteSymbol",
                    .contains_header = "ContainsHeader",
                    .header = "Header",
                    .disable_value_trimming = "DisableValueTrimming",
                    .allow_single_column = "AllowSingleColumn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grok_classifier = "GrokClassifier",
                .xml_classifier = "XMLClassifier",
                .json_classifier = "JsonClassifier",
                .csv_classifier = "CsvClassifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_classifier) } {
            return .{ .service_metadata = service_metadata, .action = create_classifier };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const create_connection: struct {
    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        connection_input: ConnectionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .connection_input = "ConnectionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        GlueEncryption,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_crawler: struct {
    action_name: []const u8 = "CreateCrawler",
    Request: type = struct {
        name: []const u8,
        role: []const u8,
        database_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        targets: CrawlerTargets,
        schedule: ?[]const u8 = null,
        classifiers: ?[][]const u8 = null,
        table_prefix: ?[]const u8 = null,
        schema_change_policy: ?SchemaChangePolicy = null,
        recrawl_policy: ?RecrawlPolicy = null,
        lineage_configuration: ?LineageConfiguration = null,
        configuration: ?[]const u8 = null,
        crawler_security_configuration: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .role = "Role",
                .database_name = "DatabaseName",
                .description = "Description",
                .targets = "Targets",
                .schedule = "Schedule",
                .classifiers = "Classifiers",
                .table_prefix = "TablePrefix",
                .schema_change_policy = "SchemaChangePolicy",
                .recrawl_policy = "RecrawlPolicy",
                .lineage_configuration = "LineageConfiguration",
                .configuration = "Configuration",
                .crawler_security_configuration = "CrawlerSecurityConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_crawler) } {
            return .{ .service_metadata = service_metadata, .action = create_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_database: struct {
    action_name: []const u8 = "CreateDatabase",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_input: DatabaseInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_input = "DatabaseInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_database) } {
            return .{ .service_metadata = service_metadata, .action = create_database };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_dev_endpoint: struct {
    action_name: []const u8 = "CreateDevEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,
        role_arn: []const u8,
        security_group_ids: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        public_key: ?[]const u8 = null,
        public_keys: ?[][]const u8 = null,
        number_of_nodes: ?i64 = null,
        worker_type: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        extra_python_libs_s3_path: ?[]const u8 = null,
        extra_jars_s3_path: ?[]const u8 = null,
        security_configuration: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .role_arn = "RoleArn",
                .security_group_ids = "SecurityGroupIds",
                .subnet_id = "SubnetId",
                .public_key = "PublicKey",
                .public_keys = "PublicKeys",
                .number_of_nodes = "NumberOfNodes",
                .worker_type = "WorkerType",
                .glue_version = "GlueVersion",
                .number_of_workers = "NumberOfWorkers",
                .extra_python_libs_s3_path = "ExtraPythonLibsS3Path",
                .extra_jars_s3_path = "ExtraJarsS3Path",
                .security_configuration = "SecurityConfiguration",
                .tags = "Tags",
                .arguments = "Arguments",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            if (std.mem.eql(u8, "arguments", field_name))
                return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dev_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_dev_endpoint };
        }
    },
    Response: type = struct {
        endpoint_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        yarn_endpoint_address: ?[]const u8 = null,
        zeppelin_remote_spark_interpreter_port: ?i64 = null,
        number_of_nodes: ?i64 = null,
        worker_type: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        availability_zone: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        extra_python_libs_s3_path: ?[]const u8 = null,
        extra_jars_s3_path: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        security_configuration: ?[]const u8 = null,
        created_timestamp: ?i64 = null,
        arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .status = "Status",
                .security_group_ids = "SecurityGroupIds",
                .subnet_id = "SubnetId",
                .role_arn = "RoleArn",
                .yarn_endpoint_address = "YarnEndpointAddress",
                .zeppelin_remote_spark_interpreter_port = "ZeppelinRemoteSparkInterpreterPort",
                .number_of_nodes = "NumberOfNodes",
                .worker_type = "WorkerType",
                .glue_version = "GlueVersion",
                .number_of_workers = "NumberOfWorkers",
                .availability_zone = "AvailabilityZone",
                .vpc_id = "VpcId",
                .extra_python_libs_s3_path = "ExtraPythonLibsS3Path",
                .extra_jars_s3_path = "ExtraJarsS3Path",
                .failure_reason = "FailureReason",
                .security_configuration = "SecurityConfiguration",
                .created_timestamp = "CreatedTimestamp",
                .arguments = "Arguments",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "arguments", field_name))
                return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
        Validation,
    },
} = .{};
pub const create_job: struct {
    action_name: []const u8 = "CreateJob",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        log_uri: ?[]const u8 = null,
        role: []const u8,
        execution_property: ?ExecutionProperty = null,
        command: JobCommand,
        default_arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        non_overridable_arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        connections: ?ConnectionsList = null,
        max_retries: ?i64 = null,
        allocated_capacity: ?i64 = null,
        timeout: ?i64 = null,
        max_capacity: ?f64 = null,
        security_configuration: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        notification_property: ?NotificationProperty = null,
        glue_version: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        worker_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .log_uri = "LogUri",
                .role = "Role",
                .execution_property = "ExecutionProperty",
                .command = "Command",
                .default_arguments = "DefaultArguments",
                .non_overridable_arguments = "NonOverridableArguments",
                .connections = "Connections",
                .max_retries = "MaxRetries",
                .allocated_capacity = "AllocatedCapacity",
                .timeout = "Timeout",
                .max_capacity = "MaxCapacity",
                .security_configuration = "SecurityConfiguration",
                .tags = "Tags",
                .notification_property = "NotificationProperty",
                .glue_version = "GlueVersion",
                .number_of_workers = "NumberOfWorkers",
                .worker_type = "WorkerType",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "default_arguments", field_name))
                return try serializeMap(self.default_arguments, self.fieldNameFor("default_arguments"), options, out_stream);
            if (std.mem.eql(u8, "non_overridable_arguments", field_name))
                return try serializeMap(self.non_overridable_arguments, self.fieldNameFor("non_overridable_arguments"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job) } {
            return .{ .service_metadata = service_metadata, .action = create_job };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_ml_transform: struct {
    action_name: []const u8 = "CreateMLTransform",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        input_record_tables: []GlueTable,
        parameters: TransformParameters,
        role: []const u8,
        glue_version: ?[]const u8 = null,
        max_capacity: ?f64 = null,
        worker_type: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        max_retries: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        transform_encryption: ?TransformEncryption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .input_record_tables = "InputRecordTables",
                .parameters = "Parameters",
                .role = "Role",
                .glue_version = "GlueVersion",
                .max_capacity = "MaxCapacity",
                .worker_type = "WorkerType",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .max_retries = "MaxRetries",
                .tags = "Tags",
                .transform_encryption = "TransformEncryption",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ml_transform) } {
            return .{ .service_metadata = service_metadata, .action = create_ml_transform };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_partition: struct {
    action_name: []const u8 = "CreatePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_input: PartitionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_input = "PartitionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_partition) } {
            return .{ .service_metadata = service_metadata, .action = create_partition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_partition_index: struct {
    action_name: []const u8 = "CreatePartitionIndex",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_index: PartitionIndex,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_index = "PartitionIndex",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_partition_index) } {
            return .{ .service_metadata = service_metadata, .action = create_partition_index };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_registry: struct {
    action_name: []const u8 = "CreateRegistry",
    Request: type = struct {
        registry_name: []const u8,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_registry) } {
            return .{ .service_metadata = service_metadata, .action = create_registry };
        }
    },
    Response: type = struct {
        registry_arn: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_arn = "RegistryArn",
                .registry_name = "RegistryName",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        InternalService,
        InvalidInput,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_schema: struct {
    action_name: []const u8 = "CreateSchema",
    Request: type = struct {
        registry_id: ?RegistryId = null,
        schema_name: []const u8,
        data_format: []const u8,
        compatibility: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        schema_definition: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
                .schema_name = "SchemaName",
                .data_format = "DataFormat",
                .compatibility = "Compatibility",
                .description = "Description",
                .tags = "Tags",
                .schema_definition = "SchemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_schema) } {
            return .{ .service_metadata = service_metadata, .action = create_schema };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        data_format: ?[]const u8 = null,
        compatibility: ?[]const u8 = null,
        schema_checkpoint: ?i64 = null,
        latest_schema_version: ?i64 = null,
        next_schema_version: ?i64 = null,
        schema_status: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        schema_version_id: ?[]const u8 = null,
        schema_version_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
                .schema_name = "SchemaName",
                .schema_arn = "SchemaArn",
                .description = "Description",
                .data_format = "DataFormat",
                .compatibility = "Compatibility",
                .schema_checkpoint = "SchemaCheckpoint",
                .latest_schema_version = "LatestSchemaVersion",
                .next_schema_version = "NextSchemaVersion",
                .schema_status = "SchemaStatus",
                .tags = "Tags",
                .schema_version_id = "SchemaVersionId",
                .schema_version_status = "SchemaVersionStatus",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        EntityNotFound,
        InternalService,
        InvalidInput,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_script: struct {
    action_name: []const u8 = "CreateScript",
    Request: type = struct {
        dag_nodes: ?[]CodeGenNode = null,
        dag_edges: ?[]CodeGenEdge = null,
        language: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dag_nodes = "DagNodes",
                .dag_edges = "DagEdges",
                .language = "Language",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_script) } {
            return .{ .service_metadata = service_metadata, .action = create_script };
        }
    },
    Response: type = struct {
        python_script: ?[]const u8 = null,
        scala_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .python_script = "PythonScript",
                .scala_code = "ScalaCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const create_security_configuration: struct {
    action_name: []const u8 = "CreateSecurityConfiguration",
    Request: type = struct {
        name: []const u8,
        encryption_configuration: EncryptionConfiguration,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .encryption_configuration = "EncryptionConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_security_configuration };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        created_timestamp: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .created_timestamp = "CreatedTimestamp",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_table: struct {
    action_name: []const u8 = "CreateTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_input: TableInput,
        partition_indexes: ?[]PartitionIndex = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_input = "TableInput",
                .partition_indexes = "PartitionIndexes",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_table) } {
            return .{ .service_metadata = service_metadata, .action = create_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_trigger: struct {
    action_name: []const u8 = "CreateTrigger",
    Request: type = struct {
        name: []const u8,
        workflow_name: ?[]const u8 = null,
        type: []const u8,
        schedule: ?[]const u8 = null,
        predicate: ?Predicate = null,
        actions: []Action,
        description: ?[]const u8 = null,
        start_on_creation: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .workflow_name = "WorkflowName",
                .type = "Type",
                .schedule = "Schedule",
                .predicate = "Predicate",
                .actions = "Actions",
                .description = "Description",
                .start_on_creation = "StartOnCreation",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trigger) } {
            return .{ .service_metadata = service_metadata, .action = create_trigger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        EntityNotFound,
        IdempotentParameterMismatch,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_user_defined_function: struct {
    action_name: []const u8 = "CreateUserDefinedFunction",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        function_input: UserDefinedFunctionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .function_input = "FunctionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_defined_function) } {
            return .{ .service_metadata = service_metadata, .action = create_user_defined_function };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const create_workflow: struct {
    action_name: []const u8 = "CreateWorkflow",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        default_run_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        max_concurrent_runs: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .default_run_properties = "DefaultRunProperties",
                .tags = "Tags",
                .max_concurrent_runs = "MaxConcurrentRuns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "default_run_properties", field_name))
                return try serializeMap(self.default_run_properties, self.fieldNameFor("default_run_properties"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workflow) } {
            return .{ .service_metadata = service_metadata, .action = create_workflow };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const delete_classifier: struct {
    action_name: []const u8 = "DeleteClassifier",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_classifier) } {
            return .{ .service_metadata = service_metadata, .action = delete_classifier };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const delete_column_statistics_for_partition: struct {
    action_name: []const u8 = "DeleteColumnStatisticsForPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,
        column_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
                .column_name = "ColumnName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_column_statistics_for_partition) } {
            return .{ .service_metadata = service_metadata, .action = delete_column_statistics_for_partition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_column_statistics_for_table: struct {
    action_name: []const u8 = "DeleteColumnStatisticsForTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        column_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .column_name = "ColumnName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_column_statistics_for_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_column_statistics_for_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        connection_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .connection_name = "ConnectionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const delete_crawler: struct {
    action_name: []const u8 = "DeleteCrawler",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_crawler) } {
            return .{ .service_metadata = service_metadata, .action = delete_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CrawlerRunning,
        EntityNotFound,
        OperationTimeout,
        SchedulerTransitioning,
    },
} = .{};
pub const delete_database: struct {
    action_name: []const u8 = "DeleteDatabase",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_database) } {
            return .{ .service_metadata = service_metadata, .action = delete_database };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_dev_endpoint: struct {
    action_name: []const u8 = "DeleteDevEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dev_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_dev_endpoint };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_job: struct {
    action_name: []const u8 = "DeleteJob",
    Request: type = struct {
        job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job) } {
            return .{ .service_metadata = service_metadata, .action = delete_job };
        }
    },
    Response: type = struct {
        job_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_ml_transform: struct {
    action_name: []const u8 = "DeleteMLTransform",
    Request: type = struct {
        transform_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ml_transform) } {
            return .{ .service_metadata = service_metadata, .action = delete_ml_transform };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_partition: struct {
    action_name: []const u8 = "DeletePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_partition) } {
            return .{ .service_metadata = service_metadata, .action = delete_partition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_partition_index: struct {
    action_name: []const u8 = "DeletePartitionIndex",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        index_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .index_name = "IndexName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_partition_index) } {
            return .{ .service_metadata = service_metadata, .action = delete_partition_index };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_registry: struct {
    action_name: []const u8 = "DeleteRegistry",
    Request: type = struct {
        registry_id: RegistryId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_registry) } {
            return .{ .service_metadata = service_metadata, .action = delete_registry };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const delete_resource_policy: struct {
    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        policy_hash_condition: ?[]const u8 = null,
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_hash_condition = "PolicyHashCondition",
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConditionCheckFailure,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_schema: struct {
    action_name: []const u8 = "DeleteSchema",
    Request: type = struct {
        schema_id: SchemaId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const delete_schema_versions: struct {
    action_name: []const u8 = "DeleteSchemaVersions",
    Request: type = struct {
        schema_id: SchemaId,
        versions: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .versions = "Versions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_schema_versions) } {
            return .{ .service_metadata = service_metadata, .action = delete_schema_versions };
        }
    },
    Response: type = struct {
        schema_version_errors: ?[]struct {
            version_number: ?i64 = null,
            error_details: ?struct {
                error_code: ?[]const u8 = null,
                error_message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .error_code = "ErrorCode",
                        .error_message = "ErrorMessage",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_number = "VersionNumber",
                    .error_details = "ErrorDetails",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_version_errors = "SchemaVersionErrors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const delete_security_configuration: struct {
    action_name: []const u8 = "DeleteSecurityConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_security_configuration };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_table: struct {
    action_name: []const u8 = "DeleteTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_table) } {
            return .{ .service_metadata = service_metadata, .action = delete_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_table_version: struct {
    action_name: []const u8 = "DeleteTableVersion",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        version_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_table_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_table_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_trigger: struct {
    action_name: []const u8 = "DeleteTrigger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trigger) } {
            return .{ .service_metadata = service_metadata, .action = delete_trigger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_user_defined_function: struct {
    action_name: []const u8 = "DeleteUserDefinedFunction",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_defined_function) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_defined_function };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const delete_workflow: struct {
    action_name: []const u8 = "DeleteWorkflow",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workflow) } {
            return .{ .service_metadata = service_metadata, .action = delete_workflow };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_catalog_import_status: struct {
    action_name: []const u8 = "GetCatalogImportStatus",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_catalog_import_status) } {
            return .{ .service_metadata = service_metadata, .action = get_catalog_import_status };
        }
    },
    Response: type = struct {
        import_status: ?struct {
            import_completed: ?bool = null,
            import_time: ?i64 = null,
            imported_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .import_completed = "ImportCompleted",
                    .import_time = "ImportTime",
                    .imported_by = "ImportedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_status = "ImportStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        OperationTimeout,
    },
} = .{};
pub const get_classifier: struct {
    action_name: []const u8 = "GetClassifier",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_classifier) } {
            return .{ .service_metadata = service_metadata, .action = get_classifier };
        }
    },
    Response: type = struct {
        classifier: ?Classifier = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .classifier = "Classifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const get_classifiers: struct {
    action_name: []const u8 = "GetClassifiers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_classifiers) } {
            return .{ .service_metadata = service_metadata, .action = get_classifiers };
        }
    },
    Response: type = struct {
        classifiers: ?[]Classifier = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .classifiers = "Classifiers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const get_column_statistics_for_partition: struct {
    action_name: []const u8 = "GetColumnStatisticsForPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,
        column_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
                .column_names = "ColumnNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_column_statistics_for_partition) } {
            return .{ .service_metadata = service_metadata, .action = get_column_statistics_for_partition };
        }
    },
    Response: type = struct {
        column_statistics_list: ?[]ColumnStatistics = null,
        errors: ?[]ColumnError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_list = "ColumnStatisticsList",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_column_statistics_for_table: struct {
    action_name: []const u8 = "GetColumnStatisticsForTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        column_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .column_names = "ColumnNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_column_statistics_for_table) } {
            return .{ .service_metadata = service_metadata, .action = get_column_statistics_for_table };
        }
    },
    Response: type = struct {
        column_statistics_list: ?[]ColumnStatistics = null,
        errors: ?[]ColumnError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .column_statistics_list = "ColumnStatisticsList",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_connection: struct {
    action_name: []const u8 = "GetConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,
        hide_password: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
                .hide_password = "HidePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connection) } {
            return .{ .service_metadata = service_metadata, .action = get_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_connections: struct {
    action_name: []const u8 = "GetConnections",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        filter: ?struct {
            match_criteria: ?[][]const u8 = null,
            connection_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .match_criteria = "MatchCriteria",
                    .connection_type = "ConnectionType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        hide_password: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .filter = "Filter",
                .hide_password = "HidePassword",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connections) } {
            return .{ .service_metadata = service_metadata, .action = get_connections };
        }
    },
    Response: type = struct {
        connection_list: ?[]Connection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_list = "ConnectionList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_crawler: struct {
    action_name: []const u8 = "GetCrawler",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_crawler) } {
            return .{ .service_metadata = service_metadata, .action = get_crawler };
        }
    },
    Response: type = struct {
        crawler: ?Crawler = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler = "Crawler",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const get_crawler_metrics: struct {
    action_name: []const u8 = "GetCrawlerMetrics",
    Request: type = struct {
        crawler_name_list: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name_list = "CrawlerNameList",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_crawler_metrics) } {
            return .{ .service_metadata = service_metadata, .action = get_crawler_metrics };
        }
    },
    Response: type = struct {
        crawler_metrics_list: ?[]struct {
            crawler_name: ?[]const u8 = null,
            time_left_seconds: ?f64 = null,
            still_estimating: ?bool = null,
            last_runtime_seconds: ?f64 = null,
            median_runtime_seconds: ?f64 = null,
            tables_created: ?i64 = null,
            tables_updated: ?i64 = null,
            tables_deleted: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .crawler_name = "CrawlerName",
                    .time_left_seconds = "TimeLeftSeconds",
                    .still_estimating = "StillEstimating",
                    .last_runtime_seconds = "LastRuntimeSeconds",
                    .median_runtime_seconds = "MedianRuntimeSeconds",
                    .tables_created = "TablesCreated",
                    .tables_updated = "TablesUpdated",
                    .tables_deleted = "TablesDeleted",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_metrics_list = "CrawlerMetricsList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const get_crawlers: struct {
    action_name: []const u8 = "GetCrawlers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_crawlers) } {
            return .{ .service_metadata = service_metadata, .action = get_crawlers };
        }
    },
    Response: type = struct {
        crawlers: ?[]Crawler = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawlers = "Crawlers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const get_database: struct {
    action_name: []const u8 = "GetDatabase",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_database) } {
            return .{ .service_metadata = service_metadata, .action = get_database };
        }
    },
    Response: type = struct {
        database: ?Database = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database = "Database",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_databases: struct {
    action_name: []const u8 = "GetDatabases",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        resource_share_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .resource_share_type = "ResourceShareType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_databases) } {
            return .{ .service_metadata = service_metadata, .action = get_databases };
        }
    },
    Response: type = struct {
        database_list: []Database,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .database_list = "DatabaseList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_data_catalog_encryption_settings: struct {
    action_name: []const u8 = "GetDataCatalogEncryptionSettings",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_catalog_encryption_settings) } {
            return .{ .service_metadata = service_metadata, .action = get_data_catalog_encryption_settings };
        }
    },
    Response: type = struct {
        data_catalog_encryption_settings: ?DataCatalogEncryptionSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_catalog_encryption_settings = "DataCatalogEncryptionSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_dataflow_graph: struct {
    action_name: []const u8 = "GetDataflowGraph",
    Request: type = struct {
        python_script: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .python_script = "PythonScript",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dataflow_graph) } {
            return .{ .service_metadata = service_metadata, .action = get_dataflow_graph };
        }
    },
    Response: type = struct {
        dag_nodes: ?[]CodeGenNode = null,
        dag_edges: ?[]CodeGenEdge = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dag_nodes = "DagNodes",
                .dag_edges = "DagEdges",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_dev_endpoint: struct {
    action_name: []const u8 = "GetDevEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dev_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_dev_endpoint };
        }
    },
    Response: type = struct {
        dev_endpoint: ?DevEndpoint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoint = "DevEndpoint",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_dev_endpoints: struct {
    action_name: []const u8 = "GetDevEndpoints",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dev_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = get_dev_endpoints };
        }
    },
    Response: type = struct {
        dev_endpoints: ?[]DevEndpoint = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoints = "DevEndpoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_job: struct {
    action_name: []const u8 = "GetJob",
    Request: type = struct {
        job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job) } {
            return .{ .service_metadata = service_metadata, .action = get_job };
        }
    },
    Response: type = struct {
        job: ?Job = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job = "Job",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_job_bookmark: struct {
    action_name: []const u8 = "GetJobBookmark",
    Request: type = struct {
        job_name: []const u8,
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_bookmark) } {
            return .{ .service_metadata = service_metadata, .action = get_job_bookmark };
        }
    },
    Response: type = struct {
        job_bookmark_entry: ?JobBookmarkEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_bookmark_entry = "JobBookmarkEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        Validation,
    },
} = .{};
pub const get_job_run: struct {
    action_name: []const u8 = "GetJobRun",
    Request: type = struct {
        job_name: []const u8,
        run_id: []const u8,
        predecessors_included: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .run_id = "RunId",
                .predecessors_included = "PredecessorsIncluded",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_run) } {
            return .{ .service_metadata = service_metadata, .action = get_job_run };
        }
    },
    Response: type = struct {
        job_run: ?JobRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_run = "JobRun",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_job_runs: struct {
    action_name: []const u8 = "GetJobRuns",
    Request: type = struct {
        job_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_job_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_job_runs };
        }
    },
    Response: type = struct {
        job_runs: ?[]JobRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_runs = "JobRuns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_jobs: struct {
    action_name: []const u8 = "GetJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_jobs) } {
            return .{ .service_metadata = service_metadata, .action = get_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]Job = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "Jobs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_mapping: struct {
    action_name: []const u8 = "GetMapping",
    Request: type = struct {
        source: CatalogEntry,
        sinks: ?[]CatalogEntry = null,
        location: ?Location = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source = "Source",
                .sinks = "Sinks",
                .location = "Location",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_mapping) } {
            return .{ .service_metadata = service_metadata, .action = get_mapping };
        }
    },
    Response: type = struct {
        mapping: []MappingEntry,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mapping = "Mapping",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_ml_task_run: struct {
    action_name: []const u8 = "GetMLTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        task_run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_task_run) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_task_run };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,
        task_run_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        log_group_name: ?[]const u8 = null,
        properties: ?TaskRunProperties = null,
        error_string: ?[]const u8 = null,
        started_on: ?i64 = null,
        last_modified_on: ?i64 = null,
        completed_on: ?i64 = null,
        execution_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .task_run_id = "TaskRunId",
                .status = "Status",
                .log_group_name = "LogGroupName",
                .properties = "Properties",
                .error_string = "ErrorString",
                .started_on = "StartedOn",
                .last_modified_on = "LastModifiedOn",
                .completed_on = "CompletedOn",
                .execution_time = "ExecutionTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_ml_task_runs: struct {
    action_name: []const u8 = "GetMLTaskRuns",
    Request: type = struct {
        transform_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?struct {
            task_run_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            started_before: ?i64 = null,
            started_after: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .task_run_type = "TaskRunType",
                    .status = "Status",
                    .started_before = "StartedBefore",
                    .started_after = "StartedAfter",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sort: ?struct {
            column: []const u8,
            sort_direction: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .column = "Column",
                    .sort_direction = "SortDirection",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filter = "Filter",
                .sort = "Sort",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_task_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_task_runs };
        }
    },
    Response: type = struct {
        task_runs: ?[]struct {
            transform_id: ?[]const u8 = null,
            task_run_id: ?[]const u8 = null,
            status: ?[]const u8 = null,
            log_group_name: ?[]const u8 = null,
            properties: ?TaskRunProperties = null,
            error_string: ?[]const u8 = null,
            started_on: ?i64 = null,
            last_modified_on: ?i64 = null,
            completed_on: ?i64 = null,
            execution_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transform_id = "TransformId",
                    .task_run_id = "TaskRunId",
                    .status = "Status",
                    .log_group_name = "LogGroupName",
                    .properties = "Properties",
                    .error_string = "ErrorString",
                    .started_on = "StartedOn",
                    .last_modified_on = "LastModifiedOn",
                    .completed_on = "CompletedOn",
                    .execution_time = "ExecutionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_runs = "TaskRuns",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_ml_transform: struct {
    action_name: []const u8 = "GetMLTransform",
    Request: type = struct {
        transform_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_transform) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_transform };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_on: ?i64 = null,
        last_modified_on: ?i64 = null,
        input_record_tables: ?[]GlueTable = null,
        parameters: ?TransformParameters = null,
        evaluation_metrics: ?EvaluationMetrics = null,
        label_count: ?i64 = null,
        schema: ?[]SchemaColumn = null,
        role: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        max_capacity: ?f64 = null,
        worker_type: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        max_retries: ?i64 = null,
        transform_encryption: ?TransformEncryption = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .name = "Name",
                .description = "Description",
                .status = "Status",
                .created_on = "CreatedOn",
                .last_modified_on = "LastModifiedOn",
                .input_record_tables = "InputRecordTables",
                .parameters = "Parameters",
                .evaluation_metrics = "EvaluationMetrics",
                .label_count = "LabelCount",
                .schema = "Schema",
                .role = "Role",
                .glue_version = "GlueVersion",
                .max_capacity = "MaxCapacity",
                .worker_type = "WorkerType",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .max_retries = "MaxRetries",
                .transform_encryption = "TransformEncryption",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_ml_transforms: struct {
    action_name: []const u8 = "GetMLTransforms",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?TransformFilterCriteria = null,
        sort: ?TransformSortCriteria = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filter = "Filter",
                .sort = "Sort",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_ml_transforms) } {
            return .{ .service_metadata = service_metadata, .action = get_ml_transforms };
        }
    },
    Response: type = struct {
        transforms: []struct {
            transform_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_on: ?i64 = null,
            last_modified_on: ?i64 = null,
            input_record_tables: ?[]GlueTable = null,
            parameters: ?TransformParameters = null,
            evaluation_metrics: ?EvaluationMetrics = null,
            label_count: ?i64 = null,
            schema: ?[]SchemaColumn = null,
            role: ?[]const u8 = null,
            glue_version: ?[]const u8 = null,
            max_capacity: ?f64 = null,
            worker_type: ?[]const u8 = null,
            number_of_workers: ?i64 = null,
            timeout: ?i64 = null,
            max_retries: ?i64 = null,
            transform_encryption: ?TransformEncryption = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transform_id = "TransformId",
                    .name = "Name",
                    .description = "Description",
                    .status = "Status",
                    .created_on = "CreatedOn",
                    .last_modified_on = "LastModifiedOn",
                    .input_record_tables = "InputRecordTables",
                    .parameters = "Parameters",
                    .evaluation_metrics = "EvaluationMetrics",
                    .label_count = "LabelCount",
                    .schema = "Schema",
                    .role = "Role",
                    .glue_version = "GlueVersion",
                    .max_capacity = "MaxCapacity",
                    .worker_type = "WorkerType",
                    .number_of_workers = "NumberOfWorkers",
                    .timeout = "Timeout",
                    .max_retries = "MaxRetries",
                    .transform_encryption = "TransformEncryption",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transforms = "Transforms",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_partition: struct {
    action_name: []const u8 = "GetPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_partition) } {
            return .{ .service_metadata = service_metadata, .action = get_partition };
        }
    },
    Response: type = struct {
        partition: ?Partition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partition = "Partition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_partition_indexes: struct {
    action_name: []const u8 = "GetPartitionIndexes",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_partition_indexes) } {
            return .{ .service_metadata = service_metadata, .action = get_partition_indexes };
        }
    },
    Response: type = struct {
        partition_index_descriptor_list: ?[]struct {
            index_name: []const u8,
            keys: []struct {
                name: []const u8,
                type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            },
            index_status: []const u8,
            backfill_errors: ?[]struct {
                code: ?[]const u8 = null,
                partitions: ?[]PartitionValueList = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .code = "Code",
                        .partitions = "Partitions",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .index_name = "IndexName",
                    .keys = "Keys",
                    .index_status = "IndexStatus",
                    .backfill_errors = "BackfillErrors",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partition_index_descriptor_list = "PartitionIndexDescriptorList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_partitions: struct {
    action_name: []const u8 = "GetPartitions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        expression: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        segment: ?struct {
            segment_number: i64,
            total_segments: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .segment_number = "SegmentNumber",
                    .total_segments = "TotalSegments",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        exclude_column_schema: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .expression = "Expression",
                .next_token = "NextToken",
                .segment = "Segment",
                .max_results = "MaxResults",
                .exclude_column_schema = "ExcludeColumnSchema",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_partitions) } {
            return .{ .service_metadata = service_metadata, .action = get_partitions };
        }
    },
    Response: type = struct {
        partitions: ?[]Partition = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partitions = "Partitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_plan: struct {
    action_name: []const u8 = "GetPlan",
    Request: type = struct {
        mapping: []MappingEntry,
        source: CatalogEntry,
        sinks: ?[]CatalogEntry = null,
        location: ?Location = null,
        language: ?[]const u8 = null,
        additional_plan_options_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .mapping = "Mapping",
                .source = "Source",
                .sinks = "Sinks",
                .location = "Location",
                .language = "Language",
                .additional_plan_options_map = "AdditionalPlanOptionsMap",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "additional_plan_options_map", field_name))
                return try serializeMap(self.additional_plan_options_map, self.fieldNameFor("additional_plan_options_map"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_plan) } {
            return .{ .service_metadata = service_metadata, .action = get_plan };
        }
    },
    Response: type = struct {
        python_script: ?[]const u8 = null,
        scala_code: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .python_script = "PythonScript",
                .scala_code = "ScalaCode",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_registry: struct {
    action_name: []const u8 = "GetRegistry",
    Request: type = struct {
        registry_id: RegistryId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_registry) } {
            return .{ .service_metadata = service_metadata, .action = get_registry };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_time: ?[]const u8 = null,
        updated_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
                .description = "Description",
                .status = "Status",
                .created_time = "CreatedTime",
                .updated_time = "UpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_resource_policies: struct {
    action_name: []const u8 = "GetResourcePolicies",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policies) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policies };
        }
    },
    Response: type = struct {
        get_resource_policies_response_list: ?[]struct {
            policy_in_json: ?[]const u8 = null,
            policy_hash: ?[]const u8 = null,
            create_time: ?i64 = null,
            update_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .policy_in_json = "PolicyInJson",
                    .policy_hash = "PolicyHash",
                    .create_time = "CreateTime",
                    .update_time = "UpdateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .get_resource_policies_response_list = "GetResourcePoliciesResponseList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_resource_policy: struct {
    action_name: []const u8 = "GetResourcePolicy",
    Request: type = struct {
        resource_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_resource_policy };
        }
    },
    Response: type = struct {
        policy_in_json: ?[]const u8 = null,
        policy_hash: ?[]const u8 = null,
        create_time: ?i64 = null,
        update_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_in_json = "PolicyInJson",
                .policy_hash = "PolicyHash",
                .create_time = "CreateTime",
                .update_time = "UpdateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_schema: struct {
    action_name: []const u8 = "GetSchema",
    Request: type = struct {
        schema_id: SchemaId,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema) } {
            return .{ .service_metadata = service_metadata, .action = get_schema };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        data_format: ?[]const u8 = null,
        compatibility: ?[]const u8 = null,
        schema_checkpoint: ?i64 = null,
        latest_schema_version: ?i64 = null,
        next_schema_version: ?i64 = null,
        schema_status: ?[]const u8 = null,
        created_time: ?[]const u8 = null,
        updated_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
                .schema_name = "SchemaName",
                .schema_arn = "SchemaArn",
                .description = "Description",
                .data_format = "DataFormat",
                .compatibility = "Compatibility",
                .schema_checkpoint = "SchemaCheckpoint",
                .latest_schema_version = "LatestSchemaVersion",
                .next_schema_version = "NextSchemaVersion",
                .schema_status = "SchemaStatus",
                .created_time = "CreatedTime",
                .updated_time = "UpdatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_schema_by_definition: struct {
    action_name: []const u8 = "GetSchemaByDefinition",
    Request: type = struct {
        schema_id: SchemaId,
        schema_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_definition = "SchemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_by_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_by_definition };
        }
    },
    Response: type = struct {
        schema_version_id: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        data_format: ?[]const u8 = null,
        status: ?[]const u8 = null,
        created_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_version_id = "SchemaVersionId",
                .schema_arn = "SchemaArn",
                .data_format = "DataFormat",
                .status = "Status",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_schema_version: struct {
    action_name: []const u8 = "GetSchemaVersion",
    Request: type = struct {
        schema_id: ?SchemaId = null,
        schema_version_id: ?[]const u8 = null,
        schema_version_number: ?SchemaVersionNumber = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_id = "SchemaVersionId",
                .schema_version_number = "SchemaVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_version) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_version };
        }
    },
    Response: type = struct {
        schema_version_id: ?[]const u8 = null,
        schema_definition: ?[]const u8 = null,
        data_format: ?[]const u8 = null,
        schema_arn: ?[]const u8 = null,
        version_number: ?i64 = null,
        status: ?[]const u8 = null,
        created_time: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_version_id = "SchemaVersionId",
                .schema_definition = "SchemaDefinition",
                .data_format = "DataFormat",
                .schema_arn = "SchemaArn",
                .version_number = "VersionNumber",
                .status = "Status",
                .created_time = "CreatedTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_schema_versions_diff: struct {
    action_name: []const u8 = "GetSchemaVersionsDiff",
    Request: type = struct {
        schema_id: SchemaId,
        first_schema_version_number: SchemaVersionNumber,
        second_schema_version_number: SchemaVersionNumber,
        schema_diff_type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .first_schema_version_number = "FirstSchemaVersionNumber",
                .second_schema_version_number = "SecondSchemaVersionNumber",
                .schema_diff_type = "SchemaDiffType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_versions_diff) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_versions_diff };
        }
    },
    Response: type = struct {
        diff: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .diff = "Diff",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const get_security_configuration: struct {
    action_name: []const u8 = "GetSecurityConfiguration",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_security_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_security_configuration };
        }
    },
    Response: type = struct {
        security_configuration: ?SecurityConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_configuration = "SecurityConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_security_configurations: struct {
    action_name: []const u8 = "GetSecurityConfigurations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_security_configurations) } {
            return .{ .service_metadata = service_metadata, .action = get_security_configurations };
        }
    },
    Response: type = struct {
        security_configurations: ?[]SecurityConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_configurations = "SecurityConfigurations",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_table: struct {
    action_name: []const u8 = "GetTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table) } {
            return .{ .service_metadata = service_metadata, .action = get_table };
        }
    },
    Response: type = struct {
        table: ?Table = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table = "Table",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_tables: struct {
    action_name: []const u8 = "GetTables",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        expression: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .expression = "Expression",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_tables) } {
            return .{ .service_metadata = service_metadata, .action = get_tables };
        }
    },
    Response: type = struct {
        table_list: ?[]Table = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_list = "TableList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_table_version: struct {
    action_name: []const u8 = "GetTableVersion",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        version_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .version_id = "VersionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_version) } {
            return .{ .service_metadata = service_metadata, .action = get_table_version };
        }
    },
    Response: type = struct {
        table_version: ?TableVersion = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_version = "TableVersion",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_table_versions: struct {
    action_name: []const u8 = "GetTableVersions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_table_versions) } {
            return .{ .service_metadata = service_metadata, .action = get_table_versions };
        }
    },
    Response: type = struct {
        table_versions: ?[]TableVersion = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .table_versions = "TableVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_tags: struct {
    action_name: []const u8 = "GetTags",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_tags) } {
            return .{ .service_metadata = service_metadata, .action = get_tags };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_trigger: struct {
    action_name: []const u8 = "GetTrigger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trigger) } {
            return .{ .service_metadata = service_metadata, .action = get_trigger };
        }
    },
    Response: type = struct {
        trigger: ?Trigger = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trigger = "Trigger",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_triggers: struct {
    action_name: []const u8 = "GetTriggers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        dependent_job_name: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .dependent_job_name = "DependentJobName",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_triggers) } {
            return .{ .service_metadata = service_metadata, .action = get_triggers };
        }
    },
    Response: type = struct {
        triggers: ?[]Trigger = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .triggers = "Triggers",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_user_defined_function: struct {
    action_name: []const u8 = "GetUserDefinedFunction",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        function_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .function_name = "FunctionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_defined_function) } {
            return .{ .service_metadata = service_metadata, .action = get_user_defined_function };
        }
    },
    Response: type = struct {
        user_defined_function: ?UserDefinedFunction = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_defined_function = "UserDefinedFunction",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_user_defined_functions: struct {
    action_name: []const u8 = "GetUserDefinedFunctions",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        pattern: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .pattern = "Pattern",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_user_defined_functions) } {
            return .{ .service_metadata = service_metadata, .action = get_user_defined_functions };
        }
    },
    Response: type = struct {
        user_defined_functions: ?[]UserDefinedFunction = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_defined_functions = "UserDefinedFunctions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_workflow: struct {
    action_name: []const u8 = "GetWorkflow",
    Request: type = struct {
        name: []const u8,
        include_graph: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .include_graph = "IncludeGraph",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow };
        }
    },
    Response: type = struct {
        workflow: ?Workflow = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflow = "Workflow",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_workflow_run: struct {
    action_name: []const u8 = "GetWorkflowRun",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,
        include_graph: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
                .include_graph = "IncludeGraph",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_run) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_run };
        }
    },
    Response: type = struct {
        run: ?WorkflowRun = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run = "Run",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_workflow_run_properties: struct {
    action_name: []const u8 = "GetWorkflowRunProperties",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_run_properties) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_run_properties };
        }
    },
    Response: type = struct {
        run_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_properties = "RunProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "run_properties", field_name))
                return try serializeMap(self.run_properties, self.fieldNameFor("run_properties"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const get_workflow_runs: struct {
    action_name: []const u8 = "GetWorkflowRuns",
    Request: type = struct {
        name: []const u8,
        include_graph: ?bool = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .include_graph = "IncludeGraph",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_workflow_runs) } {
            return .{ .service_metadata = service_metadata, .action = get_workflow_runs };
        }
    },
    Response: type = struct {
        runs: ?[]WorkflowRun = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .runs = "Runs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const import_catalog_to_glue: struct {
    action_name: []const u8 = "ImportCatalogToGlue",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_catalog_to_glue) } {
            return .{ .service_metadata = service_metadata, .action = import_catalog_to_glue };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        OperationTimeout,
    },
} = .{};
pub const list_crawlers: struct {
    action_name: []const u8 = "ListCrawlers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_crawlers) } {
            return .{ .service_metadata = service_metadata, .action = list_crawlers };
        }
    },
    Response: type = struct {
        crawler_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_names = "CrawlerNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationTimeout,
    },
} = .{};
pub const list_dev_endpoints: struct {
    action_name: []const u8 = "ListDevEndpoints",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dev_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_dev_endpoints };
        }
    },
    Response: type = struct {
        dev_endpoint_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dev_endpoint_names = "DevEndpointNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_jobs: struct {
    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        job_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_names = "JobNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_ml_transforms: struct {
    action_name: []const u8 = "ListMLTransforms",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        filter: ?TransformFilterCriteria = null,
        sort: ?TransformSortCriteria = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .filter = "Filter",
                .sort = "Sort",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ml_transforms) } {
            return .{ .service_metadata = service_metadata, .action = list_ml_transforms };
        }
    },
    Response: type = struct {
        transform_ids: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_ids = "TransformIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_registries: struct {
    action_name: []const u8 = "ListRegistries",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_registries) } {
            return .{ .service_metadata = service_metadata, .action = list_registries };
        }
    },
    Response: type = struct {
        registries: ?[]struct {
            registry_name: ?[]const u8 = null,
            registry_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_time: ?[]const u8 = null,
            updated_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_name = "RegistryName",
                    .registry_arn = "RegistryArn",
                    .description = "Description",
                    .status = "Status",
                    .created_time = "CreatedTime",
                    .updated_time = "UpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registries = "Registries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const list_schemas: struct {
    action_name: []const u8 = "ListSchemas",
    Request: type = struct {
        registry_id: ?RegistryId = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schemas) } {
            return .{ .service_metadata = service_metadata, .action = list_schemas };
        }
    },
    Response: type = struct {
        schemas: ?[]struct {
            registry_name: ?[]const u8 = null,
            schema_name: ?[]const u8 = null,
            schema_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            schema_status: ?[]const u8 = null,
            created_time: ?[]const u8 = null,
            updated_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .registry_name = "RegistryName",
                    .schema_name = "SchemaName",
                    .schema_arn = "SchemaArn",
                    .description = "Description",
                    .schema_status = "SchemaStatus",
                    .created_time = "CreatedTime",
                    .updated_time = "UpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schemas = "Schemas",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const list_schema_versions: struct {
    action_name: []const u8 = "ListSchemaVersions",
    Request: type = struct {
        schema_id: SchemaId,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_schema_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_schema_versions };
        }
    },
    Response: type = struct {
        schemas: ?[]struct {
            schema_arn: ?[]const u8 = null,
            schema_version_id: ?[]const u8 = null,
            version_number: ?i64 = null,
            status: ?[]const u8 = null,
            created_time: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .schema_arn = "SchemaArn",
                    .schema_version_id = "SchemaVersionId",
                    .version_number = "VersionNumber",
                    .status = "Status",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schemas = "Schemas",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const list_triggers: struct {
    action_name: []const u8 = "ListTriggers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        dependent_job_name: ?[]const u8 = null,
        max_results: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .dependent_job_name = "DependentJobName",
                .max_results = "MaxResults",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_triggers) } {
            return .{ .service_metadata = service_metadata, .action = list_triggers };
        }
    },
    Response: type = struct {
        trigger_names: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trigger_names = "TriggerNames",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const list_workflows: struct {
    action_name: []const u8 = "ListWorkflows",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workflows) } {
            return .{ .service_metadata = service_metadata, .action = list_workflows };
        }
    },
    Response: type = struct {
        workflows: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workflows = "Workflows",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const put_data_catalog_encryption_settings: struct {
    action_name: []const u8 = "PutDataCatalogEncryptionSettings",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        data_catalog_encryption_settings: DataCatalogEncryptionSettings,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .data_catalog_encryption_settings = "DataCatalogEncryptionSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_data_catalog_encryption_settings) } {
            return .{ .service_metadata = service_metadata, .action = put_data_catalog_encryption_settings };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const put_resource_policy: struct {
    action_name: []const u8 = "PutResourcePolicy",
    Request: type = struct {
        policy_in_json: []const u8,
        resource_arn: ?[]const u8 = null,
        policy_hash_condition: ?[]const u8 = null,
        policy_exists_condition: ?[]const u8 = null,
        enable_hybrid: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_in_json = "PolicyInJson",
                .resource_arn = "ResourceArn",
                .policy_hash_condition = "PolicyHashCondition",
                .policy_exists_condition = "PolicyExistsCondition",
                .enable_hybrid = "EnableHybrid",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_resource_policy };
        }
    },
    Response: type = struct {
        policy_hash: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .policy_hash = "PolicyHash",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConditionCheckFailure,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const put_schema_version_metadata: struct {
    action_name: []const u8 = "PutSchemaVersionMetadata",
    Request: type = struct {
        schema_id: ?SchemaId = null,
        schema_version_number: ?SchemaVersionNumber = null,
        schema_version_id: ?[]const u8 = null,
        metadata_key_value: MetadataKeyValuePair,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_number = "SchemaVersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_key_value = "MetadataKeyValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_schema_version_metadata) } {
            return .{ .service_metadata = service_metadata, .action = put_schema_version_metadata };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        latest_version: ?bool = null,
        version_number: ?i64 = null,
        schema_version_id: ?[]const u8 = null,
        metadata_key: ?[]const u8 = null,
        metadata_value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .registry_name = "RegistryName",
                .latest_version = "LatestVersion",
                .version_number = "VersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_key = "MetadataKey",
                .metadata_value = "MetadataValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        AlreadyExists,
        EntityNotFound,
        InvalidInput,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const put_workflow_run_properties: struct {
    action_name: []const u8 = "PutWorkflowRunProperties",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,
        run_properties: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
                .run_properties = "RunProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "run_properties", field_name))
                return try serializeMap(self.run_properties, self.fieldNameFor("run_properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_workflow_run_properties) } {
            return .{ .service_metadata = service_metadata, .action = put_workflow_run_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AlreadyExists,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const query_schema_version_metadata: struct {
    action_name: []const u8 = "QuerySchemaVersionMetadata",
    Request: type = struct {
        schema_id: ?SchemaId = null,
        schema_version_number: ?SchemaVersionNumber = null,
        schema_version_id: ?[]const u8 = null,
        metadata_list: ?[]MetadataKeyValuePair = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_number = "SchemaVersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_list = "MetadataList",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(query_schema_version_metadata) } {
            return .{ .service_metadata = service_metadata, .action = query_schema_version_metadata };
        }
    },
    Response: type = struct {
        metadata_info_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?struct {
                metadata_value: ?[]const u8 = null,
                created_time: ?[]const u8 = null,
                other_metadata_value_list: ?[]struct {
                    metadata_value: ?[]const u8 = null,
                    created_time: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .metadata_value = "MetadataValue",
                            .created_time = "CreatedTime",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .metadata_value = "MetadataValue",
                        .created_time = "CreatedTime",
                        .other_metadata_value_list = "OtherMetadataValueList",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
        } = null,
        schema_version_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .metadata_info_map = "MetadataInfoMap",
                .schema_version_id = "SchemaVersionId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "metadata_info_map", field_name))
                return try serializeMap(self.metadata_info_map, self.fieldNameFor("metadata_info_map"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const register_schema_version: struct {
    action_name: []const u8 = "RegisterSchemaVersion",
    Request: type = struct {
        schema_id: SchemaId,
        schema_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_definition = "SchemaDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_schema_version) } {
            return .{ .service_metadata = service_metadata, .action = register_schema_version };
        }
    },
    Response: type = struct {
        schema_version_id: ?[]const u8 = null,
        version_number: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_version_id = "SchemaVersionId",
                .version_number = "VersionNumber",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const remove_schema_version_metadata: struct {
    action_name: []const u8 = "RemoveSchemaVersionMetadata",
    Request: type = struct {
        schema_id: ?SchemaId = null,
        schema_version_number: ?SchemaVersionNumber = null,
        schema_version_id: ?[]const u8 = null,
        metadata_key_value: MetadataKeyValuePair,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_number = "SchemaVersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_key_value = "MetadataKeyValue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_schema_version_metadata) } {
            return .{ .service_metadata = service_metadata, .action = remove_schema_version_metadata };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,
        latest_version: ?bool = null,
        version_number: ?i64 = null,
        schema_version_id: ?[]const u8 = null,
        metadata_key: ?[]const u8 = null,
        metadata_value: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .registry_name = "RegistryName",
                .latest_version = "LatestVersion",
                .version_number = "VersionNumber",
                .schema_version_id = "SchemaVersionId",
                .metadata_key = "MetadataKey",
                .metadata_value = "MetadataValue",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InvalidInput,
    },
} = .{};
pub const reset_job_bookmark: struct {
    action_name: []const u8 = "ResetJobBookmark",
    Request: type = struct {
        job_name: []const u8,
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reset_job_bookmark) } {
            return .{ .service_metadata = service_metadata, .action = reset_job_bookmark };
        }
    },
    Response: type = struct {
        job_bookmark_entry: ?JobBookmarkEntry = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_bookmark_entry = "JobBookmarkEntry",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const resume_workflow_run: struct {
    action_name: []const u8 = "ResumeWorkflowRun",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,
        node_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
                .node_ids = "NodeIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(resume_workflow_run) } {
            return .{ .service_metadata = service_metadata, .action = resume_workflow_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,
        node_ids: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
                .node_ids = "NodeIds",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        IllegalWorkflowState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const search_tables: struct {
    action_name: []const u8 = "SearchTables",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        filters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
            comparator: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .key = "Key",
                    .value = "Value",
                    .comparator = "Comparator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        search_text: ?[]const u8 = null,
        sort_criteria: ?[]struct {
            field_name: ?[]const u8 = null,
            sort: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .field_name = "FieldName",
                    .sort = "Sort",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        resource_share_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .next_token = "NextToken",
                .filters = "Filters",
                .search_text = "SearchText",
                .sort_criteria = "SortCriteria",
                .max_results = "MaxResults",
                .resource_share_type = "ResourceShareType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_tables) } {
            return .{ .service_metadata = service_metadata, .action = search_tables };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        table_list: ?[]Table = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .table_list = "TableList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_crawler: struct {
    action_name: []const u8 = "StartCrawler",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_crawler) } {
            return .{ .service_metadata = service_metadata, .action = start_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CrawlerRunning,
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const start_crawler_schedule: struct {
    action_name: []const u8 = "StartCrawlerSchedule",
    Request: type = struct {
        crawler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name = "CrawlerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_crawler_schedule) } {
            return .{ .service_metadata = service_metadata, .action = start_crawler_schedule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        NoSchedule,
        OperationTimeout,
        SchedulerRunning,
        SchedulerTransitioning,
    },
} = .{};
pub const start_export_labels_task_run: struct {
    action_name: []const u8 = "StartExportLabelsTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        output_s3_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .output_s3_path = "OutputS3Path",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_export_labels_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_export_labels_task_run };
        }
    },
    Response: type = struct {
        task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_import_labels_task_run: struct {
    action_name: []const u8 = "StartImportLabelsTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        input_s3_path: []const u8,
        replace_all_labels: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .input_s3_path = "InputS3Path",
                .replace_all_labels = "ReplaceAllLabels",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_import_labels_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_import_labels_task_run };
        }
    },
    Response: type = struct {
        task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const start_job_run: struct {
    action_name: []const u8 = "StartJobRun",
    Request: type = struct {
        job_name: []const u8,
        job_run_id: ?[]const u8 = null,
        arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        allocated_capacity: ?i64 = null,
        timeout: ?i64 = null,
        max_capacity: ?f64 = null,
        security_configuration: ?[]const u8 = null,
        notification_property: ?NotificationProperty = null,
        worker_type: ?[]const u8 = null,
        number_of_workers: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .job_run_id = "JobRunId",
                .arguments = "Arguments",
                .allocated_capacity = "AllocatedCapacity",
                .timeout = "Timeout",
                .max_capacity = "MaxCapacity",
                .security_configuration = "SecurityConfiguration",
                .notification_property = "NotificationProperty",
                .worker_type = "WorkerType",
                .number_of_workers = "NumberOfWorkers",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "arguments", field_name))
                return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_job_run) } {
            return .{ .service_metadata = service_metadata, .action = start_job_run };
        }
    },
    Response: type = struct {
        job_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_run_id = "JobRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const start_ml_evaluation_task_run: struct {
    action_name: []const u8 = "StartMLEvaluationTaskRun",
    Request: type = struct {
        transform_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_ml_evaluation_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_ml_evaluation_task_run };
        }
    },
    Response: type = struct {
        task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        MLTransformNotReady,
        OperationTimeout,
    },
} = .{};
pub const start_ml_labeling_set_generation_task_run: struct {
    action_name: []const u8 = "StartMLLabelingSetGenerationTaskRun",
    Request: type = struct {
        transform_id: []const u8,
        output_s3_path: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .output_s3_path = "OutputS3Path",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_ml_labeling_set_generation_task_run) } {
            return .{ .service_metadata = service_metadata, .action = start_ml_labeling_set_generation_task_run };
        }
    },
    Response: type = struct {
        task_run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .task_run_id = "TaskRunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const start_trigger: struct {
    action_name: []const u8 = "StartTrigger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_trigger) } {
            return .{ .service_metadata = service_metadata, .action = start_trigger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const start_workflow_run: struct {
    action_name: []const u8 = "StartWorkflowRun",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_workflow_run) } {
            return .{ .service_metadata = service_metadata, .action = start_workflow_run };
        }
    },
    Response: type = struct {
        run_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentRunsExceeded,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const stop_crawler: struct {
    action_name: []const u8 = "StopCrawler",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_crawler) } {
            return .{ .service_metadata = service_metadata, .action = stop_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CrawlerNotRunning,
        CrawlerStopping,
        EntityNotFound,
        OperationTimeout,
    },
} = .{};
pub const stop_crawler_schedule: struct {
    action_name: []const u8 = "StopCrawlerSchedule",
    Request: type = struct {
        crawler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name = "CrawlerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_crawler_schedule) } {
            return .{ .service_metadata = service_metadata, .action = stop_crawler_schedule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        OperationTimeout,
        SchedulerNotRunning,
        SchedulerTransitioning,
    },
} = .{};
pub const stop_trigger: struct {
    action_name: []const u8 = "StopTrigger",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_trigger) } {
            return .{ .service_metadata = service_metadata, .action = stop_trigger };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const stop_workflow_run: struct {
    action_name: []const u8 = "StopWorkflowRun",
    Request: type = struct {
        name: []const u8,
        run_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .run_id = "RunId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_workflow_run) } {
            return .{ .service_metadata = service_metadata, .action = stop_workflow_run };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        IllegalWorkflowState,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags_to_add: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags_to_add = "TagsToAdd",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags_to_add", field_name))
                return try serializeMap(self.tags_to_add, self.fieldNameFor("tags_to_add"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags_to_remove: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags_to_remove = "TagsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_classifier: struct {
    action_name: []const u8 = "UpdateClassifier",
    Request: type = struct {
        grok_classifier: ?struct {
            name: []const u8,
            classification: ?[]const u8 = null,
            grok_pattern: ?[]const u8 = null,
            custom_patterns: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .classification = "Classification",
                    .grok_pattern = "GrokPattern",
                    .custom_patterns = "CustomPatterns",
                };
                return @field(mappings, field_name);
            }
        } = null,
        xml_classifier: ?struct {
            name: []const u8,
            classification: ?[]const u8 = null,
            row_tag: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .classification = "Classification",
                    .row_tag = "RowTag",
                };
                return @field(mappings, field_name);
            }
        } = null,
        json_classifier: ?struct {
            name: []const u8,
            json_path: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .json_path = "JsonPath",
                };
                return @field(mappings, field_name);
            }
        } = null,
        csv_classifier: ?struct {
            name: []const u8,
            delimiter: ?[]const u8 = null,
            quote_symbol: ?[]const u8 = null,
            contains_header: ?[]const u8 = null,
            header: ?[][]const u8 = null,
            disable_value_trimming: ?bool = null,
            allow_single_column: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .delimiter = "Delimiter",
                    .quote_symbol = "QuoteSymbol",
                    .contains_header = "ContainsHeader",
                    .header = "Header",
                    .disable_value_trimming = "DisableValueTrimming",
                    .allow_single_column = "AllowSingleColumn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .grok_classifier = "GrokClassifier",
                .xml_classifier = "XMLClassifier",
                .json_classifier = "JsonClassifier",
                .csv_classifier = "CsvClassifier",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_classifier) } {
            return .{ .service_metadata = service_metadata, .action = update_classifier };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
        VersionMismatch,
    },
} = .{};
pub const update_column_statistics_for_partition: struct {
    action_name: []const u8 = "UpdateColumnStatisticsForPartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_values: [][]const u8,
        column_statistics_list: []ColumnStatistics,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_values = "PartitionValues",
                .column_statistics_list = "ColumnStatisticsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_column_statistics_for_partition) } {
            return .{ .service_metadata = service_metadata, .action = update_column_statistics_for_partition };
        }
    },
    Response: type = struct {
        errors: ?[]ColumnStatisticsError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_column_statistics_for_table: struct {
    action_name: []const u8 = "UpdateColumnStatisticsForTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        column_statistics_list: []ColumnStatistics,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .column_statistics_list = "ColumnStatisticsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_column_statistics_for_table) } {
            return .{ .service_metadata = service_metadata, .action = update_column_statistics_for_table };
        }
    },
    Response: type = struct {
        errors: ?[]ColumnStatisticsError = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_connection: struct {
    action_name: []const u8 = "UpdateConnection",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,
        connection_input: ConnectionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
                .connection_input = "ConnectionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connection) } {
            return .{ .service_metadata = service_metadata, .action = update_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_crawler: struct {
    action_name: []const u8 = "UpdateCrawler",
    Request: type = struct {
        name: []const u8,
        role: ?[]const u8 = null,
        database_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        targets: ?CrawlerTargets = null,
        schedule: ?[]const u8 = null,
        classifiers: ?[][]const u8 = null,
        table_prefix: ?[]const u8 = null,
        schema_change_policy: ?SchemaChangePolicy = null,
        recrawl_policy: ?RecrawlPolicy = null,
        lineage_configuration: ?LineageConfiguration = null,
        configuration: ?[]const u8 = null,
        crawler_security_configuration: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .role = "Role",
                .database_name = "DatabaseName",
                .description = "Description",
                .targets = "Targets",
                .schedule = "Schedule",
                .classifiers = "Classifiers",
                .table_prefix = "TablePrefix",
                .schema_change_policy = "SchemaChangePolicy",
                .recrawl_policy = "RecrawlPolicy",
                .lineage_configuration = "LineageConfiguration",
                .configuration = "Configuration",
                .crawler_security_configuration = "CrawlerSecurityConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_crawler) } {
            return .{ .service_metadata = service_metadata, .action = update_crawler };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CrawlerRunning,
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
        VersionMismatch,
    },
} = .{};
pub const update_crawler_schedule: struct {
    action_name: []const u8 = "UpdateCrawlerSchedule",
    Request: type = struct {
        crawler_name: []const u8,
        schedule: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .crawler_name = "CrawlerName",
                .schedule = "Schedule",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_crawler_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_crawler_schedule };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InvalidInput,
        OperationTimeout,
        SchedulerTransitioning,
        VersionMismatch,
    },
} = .{};
pub const update_database: struct {
    action_name: []const u8 = "UpdateDatabase",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        name: []const u8,
        database_input: DatabaseInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .name = "Name",
                .database_input = "DatabaseInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_database) } {
            return .{ .service_metadata = service_metadata, .action = update_database };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_dev_endpoint: struct {
    action_name: []const u8 = "UpdateDevEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,
        public_key: ?[]const u8 = null,
        add_public_keys: ?[][]const u8 = null,
        delete_public_keys: ?[][]const u8 = null,
        custom_libraries: ?struct {
            extra_python_libs_s3_path: ?[]const u8 = null,
            extra_jars_s3_path: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .extra_python_libs_s3_path = "ExtraPythonLibsS3Path",
                    .extra_jars_s3_path = "ExtraJarsS3Path",
                };
                return @field(mappings, field_name);
            }
        } = null,
        update_etl_libraries: ?bool = null,
        delete_arguments: ?[][]const u8 = null,
        add_arguments: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .public_key = "PublicKey",
                .add_public_keys = "AddPublicKeys",
                .delete_public_keys = "DeletePublicKeys",
                .custom_libraries = "CustomLibraries",
                .update_etl_libraries = "UpdateEtlLibraries",
                .delete_arguments = "DeleteArguments",
                .add_arguments = "AddArguments",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "add_arguments", field_name))
                return try serializeMap(self.add_arguments, self.fieldNameFor("add_arguments"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dev_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_dev_endpoint };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
        Validation,
    },
} = .{};
pub const update_job: struct {
    action_name: []const u8 = "UpdateJob",
    Request: type = struct {
        job_name: []const u8,
        job_update: struct {
            description: ?[]const u8 = null,
            log_uri: ?[]const u8 = null,
            role: ?[]const u8 = null,
            execution_property: ?ExecutionProperty = null,
            command: ?JobCommand = null,
            default_arguments: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            non_overridable_arguments: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            connections: ?ConnectionsList = null,
            max_retries: ?i64 = null,
            allocated_capacity: ?i64 = null,
            timeout: ?i64 = null,
            max_capacity: ?f64 = null,
            worker_type: ?[]const u8 = null,
            number_of_workers: ?i64 = null,
            security_configuration: ?[]const u8 = null,
            notification_property: ?NotificationProperty = null,
            glue_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .log_uri = "LogUri",
                    .role = "Role",
                    .execution_property = "ExecutionProperty",
                    .command = "Command",
                    .default_arguments = "DefaultArguments",
                    .non_overridable_arguments = "NonOverridableArguments",
                    .connections = "Connections",
                    .max_retries = "MaxRetries",
                    .allocated_capacity = "AllocatedCapacity",
                    .timeout = "Timeout",
                    .max_capacity = "MaxCapacity",
                    .worker_type = "WorkerType",
                    .number_of_workers = "NumberOfWorkers",
                    .security_configuration = "SecurityConfiguration",
                    .notification_property = "NotificationProperty",
                    .glue_version = "GlueVersion",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "default_arguments", field_name))
                    return try serializeMap(self.default_arguments, self.fieldNameFor("default_arguments"), options, out_stream);
                if (std.mem.eql(u8, "non_overridable_arguments", field_name))
                    return try serializeMap(self.non_overridable_arguments, self.fieldNameFor("non_overridable_arguments"), options, out_stream);
                return false;
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
                .job_update = "JobUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job) } {
            return .{ .service_metadata = service_metadata, .action = update_job };
        }
    },
    Response: type = struct {
        job_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "JobName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_ml_transform: struct {
    action_name: []const u8 = "UpdateMLTransform",
    Request: type = struct {
        transform_id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        parameters: ?TransformParameters = null,
        role: ?[]const u8 = null,
        glue_version: ?[]const u8 = null,
        max_capacity: ?f64 = null,
        worker_type: ?[]const u8 = null,
        number_of_workers: ?i64 = null,
        timeout: ?i64 = null,
        max_retries: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
                .name = "Name",
                .description = "Description",
                .parameters = "Parameters",
                .role = "Role",
                .glue_version = "GlueVersion",
                .max_capacity = "MaxCapacity",
                .worker_type = "WorkerType",
                .number_of_workers = "NumberOfWorkers",
                .timeout = "Timeout",
                .max_retries = "MaxRetries",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_ml_transform) } {
            return .{ .service_metadata = service_metadata, .action = update_ml_transform };
        }
    },
    Response: type = struct {
        transform_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_id = "TransformId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_partition: struct {
    action_name: []const u8 = "UpdatePartition",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_name: []const u8,
        partition_value_list: [][]const u8,
        partition_input: PartitionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_name = "TableName",
                .partition_value_list = "PartitionValueList",
                .partition_input = "PartitionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_partition) } {
            return .{ .service_metadata = service_metadata, .action = update_partition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_registry: struct {
    action_name: []const u8 = "UpdateRegistry",
    Request: type = struct {
        registry_id: RegistryId,
        description: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_id = "RegistryId",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_registry) } {
            return .{ .service_metadata = service_metadata, .action = update_registry };
        }
    },
    Response: type = struct {
        registry_name: ?[]const u8 = null,
        registry_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .registry_name = "RegistryName",
                .registry_arn = "RegistryArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const update_schema: struct {
    action_name: []const u8 = "UpdateSchema",
    Request: type = struct {
        schema_id: SchemaId,
        schema_version_number: ?SchemaVersionNumber = null,
        compatibility: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_id = "SchemaId",
                .schema_version_number = "SchemaVersionNumber",
                .compatibility = "Compatibility",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_schema) } {
            return .{ .service_metadata = service_metadata, .action = update_schema };
        }
    },
    Response: type = struct {
        schema_arn: ?[]const u8 = null,
        schema_name: ?[]const u8 = null,
        registry_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema_arn = "SchemaArn",
                .schema_name = "SchemaName",
                .registry_name = "RegistryName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
    },
} = .{};
pub const update_table: struct {
    action_name: []const u8 = "UpdateTable",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        table_input: TableInput,
        skip_archive: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .table_input = "TableInput",
                .skip_archive = "SkipArchive",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_table) } {
            return .{ .service_metadata = service_metadata, .action = update_table };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
        ResourceNumberLimitExceeded,
    },
} = .{};
pub const update_trigger: struct {
    action_name: []const u8 = "UpdateTrigger",
    Request: type = struct {
        name: []const u8,
        trigger_update: struct {
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            schedule: ?[]const u8 = null,
            actions: ?[]Action = null,
            predicate: ?Predicate = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .description = "Description",
                    .schedule = "Schedule",
                    .actions = "Actions",
                    .predicate = "Predicate",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .trigger_update = "TriggerUpdate",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_trigger) } {
            return .{ .service_metadata = service_metadata, .action = update_trigger };
        }
    },
    Response: type = struct {
        trigger: ?Trigger = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trigger = "Trigger",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_user_defined_function: struct {
    action_name: []const u8 = "UpdateUserDefinedFunction",
    Request: type = struct {
        catalog_id: ?[]const u8 = null,
        database_name: []const u8,
        function_name: []const u8,
        function_input: UserDefinedFunctionInput,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .catalog_id = "CatalogId",
                .database_name = "DatabaseName",
                .function_name = "FunctionName",
                .function_input = "FunctionInput",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_defined_function) } {
            return .{ .service_metadata = service_metadata, .action = update_user_defined_function };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        EntityNotFound,
        GlueEncryption,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};
pub const update_workflow: struct {
    action_name: []const u8 = "UpdateWorkflow",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        default_run_properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        max_concurrent_runs: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .default_run_properties = "DefaultRunProperties",
                .max_concurrent_runs = "MaxConcurrentRuns",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "default_run_properties", field_name))
                return try serializeMap(self.default_run_properties, self.fieldNameFor("default_run_properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workflow) } {
            return .{ .service_metadata = service_metadata, .action = update_workflow };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        EntityNotFound,
        InternalService,
        InvalidInput,
        OperationTimeout,
    },
} = .{};

pub const UserDefinedFunctionInput = struct {
    function_name: ?[]const u8 = null,
    class_name: ?[]const u8 = null,
    owner_name: ?[]const u8 = null,
    owner_type: ?[]const u8 = null,
    resource_uris: ?[]ResourceUri = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_name = "FunctionName",
            .class_name = "ClassName",
            .owner_name = "OwnerName",
            .owner_type = "OwnerType",
            .resource_uris = "ResourceUris",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceUri = struct {
    resource_type: ?[]const u8 = null,
    uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource_type = "ResourceType",
            .uri = "Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const Trigger = struct {
    name: ?[]const u8 = null,
    workflow_name: ?[]const u8 = null,
    id: ?[]const u8 = null,
    type: ?[]const u8 = null,
    state: ?[]const u8 = null,
    description: ?[]const u8 = null,
    schedule: ?[]const u8 = null,
    actions: ?[]Action = null,
    predicate: ?Predicate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .workflow_name = "WorkflowName",
            .id = "Id",
            .type = "Type",
            .state = "State",
            .description = "Description",
            .schedule = "Schedule",
            .actions = "Actions",
            .predicate = "Predicate",
        };
        return @field(mappings, field_name);
    }
};

pub const Predicate = struct {
    logical: ?[]const u8 = null,
    conditions: ?[]Condition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .logical = "Logical",
            .conditions = "Conditions",
        };
        return @field(mappings, field_name);
    }
};

pub const Condition = struct {
    logical_operator: ?[]const u8 = null,
    job_name: ?[]const u8 = null,
    state: ?[]const u8 = null,
    crawler_name: ?[]const u8 = null,
    crawl_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .logical_operator = "LogicalOperator",
            .job_name = "JobName",
            .state = "State",
            .crawler_name = "CrawlerName",
            .crawl_state = "CrawlState",
        };
        return @field(mappings, field_name);
    }
};

pub const Action = struct {
    job_name: ?[]const u8 = null,
    arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    timeout: ?i64 = null,
    security_configuration: ?[]const u8 = null,
    notification_property: ?NotificationProperty = null,
    crawler_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .arguments = "Arguments",
            .timeout = "Timeout",
            .security_configuration = "SecurityConfiguration",
            .notification_property = "NotificationProperty",
            .crawler_name = "CrawlerName",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "arguments", field_name))
            return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
        return false;
    }
};

pub const NotificationProperty = struct {
    notify_delay_after: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notify_delay_after = "NotifyDelayAfter",
        };
        return @field(mappings, field_name);
    }
};

pub const TableInput = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    last_access_time: ?i64 = null,
    last_analyzed_time: ?i64 = null,
    retention: ?i64 = null,
    storage_descriptor: ?StorageDescriptor = null,
    partition_keys: ?[]Column = null,
    view_original_text: ?[]const u8 = null,
    view_expanded_text: ?[]const u8 = null,
    table_type: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    target_table: ?TableIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .owner = "Owner",
            .last_access_time = "LastAccessTime",
            .last_analyzed_time = "LastAnalyzedTime",
            .retention = "Retention",
            .storage_descriptor = "StorageDescriptor",
            .partition_keys = "PartitionKeys",
            .view_original_text = "ViewOriginalText",
            .view_expanded_text = "ViewExpandedText",
            .table_type = "TableType",
            .parameters = "Parameters",
            .target_table = "TargetTable",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const TableIdentifier = struct {
    catalog_id: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const Column = struct {
    name: []const u8,
    type: ?[]const u8 = null,
    comment: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
            .comment = "Comment",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const StorageDescriptor = struct {
    columns: ?[]Column = null,
    location: ?[]const u8 = null,
    input_format: ?[]const u8 = null,
    output_format: ?[]const u8 = null,
    compressed: ?bool = null,
    number_of_buckets: ?i64 = null,
    serde_info: ?SerDeInfo = null,
    bucket_columns: ?[][]const u8 = null,
    sort_columns: ?[]Order = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    skewed_info: ?SkewedInfo = null,
    stored_as_sub_directories: ?bool = null,
    schema_reference: ?SchemaReference = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .columns = "Columns",
            .location = "Location",
            .input_format = "InputFormat",
            .output_format = "OutputFormat",
            .compressed = "Compressed",
            .number_of_buckets = "NumberOfBuckets",
            .serde_info = "SerdeInfo",
            .bucket_columns = "BucketColumns",
            .sort_columns = "SortColumns",
            .parameters = "Parameters",
            .skewed_info = "SkewedInfo",
            .stored_as_sub_directories = "StoredAsSubDirectories",
            .schema_reference = "SchemaReference",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const SchemaReference = struct {
    schema_id: ?SchemaId = null,
    schema_version_id: ?[]const u8 = null,
    schema_version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_id = "SchemaId",
            .schema_version_id = "SchemaVersionId",
            .schema_version_number = "SchemaVersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaId = struct {
    schema_arn: ?[]const u8 = null,
    schema_name: ?[]const u8 = null,
    registry_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schema_arn = "SchemaArn",
            .schema_name = "SchemaName",
            .registry_name = "RegistryName",
        };
        return @field(mappings, field_name);
    }
};

pub const SkewedInfo = struct {
    skewed_column_names: ?[][]const u8 = null,
    skewed_column_values: ?[][]const u8 = null,
    skewed_column_value_location_maps: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .skewed_column_names = "SkewedColumnNames",
            .skewed_column_values = "SkewedColumnValues",
            .skewed_column_value_location_maps = "SkewedColumnValueLocationMaps",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "skewed_column_value_location_maps", field_name))
            return try serializeMap(self.skewed_column_value_location_maps, self.fieldNameFor("skewed_column_value_location_maps"), options, out_stream);
        return false;
    }
};

pub const Order = struct {
    column: []const u8,
    sort_order: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .sort_order = "SortOrder",
        };
        return @field(mappings, field_name);
    }
};

pub const SerDeInfo = struct {
    name: ?[]const u8 = null,
    serialization_library: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .serialization_library = "SerializationLibrary",
            .parameters = "Parameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const SchemaVersionNumber = struct {
    latest_version: ?bool = null,
    version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .latest_version = "LatestVersion",
            .version_number = "VersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const RegistryId = struct {
    registry_name: ?[]const u8 = null,
    registry_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .registry_name = "RegistryName",
            .registry_arn = "RegistryArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionInput = struct {
    values: ?[][]const u8 = null,
    last_access_time: ?i64 = null,
    storage_descriptor: ?StorageDescriptor = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    last_analyzed_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
            .last_access_time = "LastAccessTime",
            .storage_descriptor = "StorageDescriptor",
            .parameters = "Parameters",
            .last_analyzed_time = "LastAnalyzedTime",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const TransformParameters = struct {
    transform_type: []const u8,
    find_matches_parameters: ?FindMatchesParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transform_type = "TransformType",
            .find_matches_parameters = "FindMatchesParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const FindMatchesParameters = struct {
    primary_key_column_name: ?[]const u8 = null,
    precision_recall_tradeoff: ?f64 = null,
    accuracy_cost_tradeoff: ?f64 = null,
    enforce_provided_labels: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_key_column_name = "PrimaryKeyColumnName",
            .precision_recall_tradeoff = "PrecisionRecallTradeoff",
            .accuracy_cost_tradeoff = "AccuracyCostTradeoff",
            .enforce_provided_labels = "EnforceProvidedLabels",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionsList = struct {
    connections: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connections = "Connections",
        };
        return @field(mappings, field_name);
    }
};

pub const JobCommand = struct {
    name: ?[]const u8 = null,
    script_location: ?[]const u8 = null,
    python_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .script_location = "ScriptLocation",
            .python_version = "PythonVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ExecutionProperty = struct {
    max_concurrent_runs: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_concurrent_runs = "MaxConcurrentRuns",
        };
        return @field(mappings, field_name);
    }
};

pub const DatabaseInput = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    location_uri: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    create_table_default_permissions: ?[]PrincipalPermissions = null,
    target_database: ?DatabaseIdentifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .location_uri = "LocationUri",
            .parameters = "Parameters",
            .create_table_default_permissions = "CreateTableDefaultPermissions",
            .target_database = "TargetDatabase",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const DatabaseIdentifier = struct {
    catalog_id: ?[]const u8 = null,
    database_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_id = "CatalogId",
            .database_name = "DatabaseName",
        };
        return @field(mappings, field_name);
    }
};

pub const PrincipalPermissions = struct {
    principal: ?DataLakePrincipal = null,
    permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
            .permissions = "Permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const DataLakePrincipal = struct {
    data_lake_principal_identifier: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_lake_principal_identifier = "DataLakePrincipalIdentifier",
        };
        return @field(mappings, field_name);
    }
};

pub const LineageConfiguration = struct {
    crawler_lineage_settings: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawler_lineage_settings = "CrawlerLineageSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const RecrawlPolicy = struct {
    recrawl_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .recrawl_behavior = "RecrawlBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaChangePolicy = struct {
    update_behavior: ?[]const u8 = null,
    delete_behavior: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .update_behavior = "UpdateBehavior",
            .delete_behavior = "DeleteBehavior",
        };
        return @field(mappings, field_name);
    }
};

pub const CrawlerTargets = struct {
    s3_targets: ?[]S3Target = null,
    jdbc_targets: ?[]JdbcTarget = null,
    mongo_db_targets: ?[]MongoDBTarget = null,
    dynamo_db_targets: ?[]DynamoDBTarget = null,
    catalog_targets: ?[]CatalogTarget = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_targets = "S3Targets",
            .jdbc_targets = "JdbcTargets",
            .mongo_db_targets = "MongoDBTargets",
            .dynamo_db_targets = "DynamoDBTargets",
            .catalog_targets = "CatalogTargets",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogTarget = struct {
    database_name: []const u8,
    tables: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .tables = "Tables",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamoDBTarget = struct {
    path: ?[]const u8 = null,
    scan_all: ?bool = null,
    scan_rate: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .scan_all = "scanAll",
            .scan_rate = "scanRate",
        };
        return @field(mappings, field_name);
    }
};

pub const MongoDBTarget = struct {
    connection_name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    scan_all: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_name = "ConnectionName",
            .path = "Path",
            .scan_all = "ScanAll",
        };
        return @field(mappings, field_name);
    }
};

pub const JdbcTarget = struct {
    connection_name: ?[]const u8 = null,
    path: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_name = "ConnectionName",
            .path = "Path",
            .exclusions = "Exclusions",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Target = struct {
    path: ?[]const u8 = null,
    exclusions: ?[][]const u8 = null,
    connection_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .path = "Path",
            .exclusions = "Exclusions",
            .connection_name = "ConnectionName",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionInput = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    connection_type: []const u8,
    match_criteria: ?[][]const u8 = null,
    connection_properties: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    physical_connection_requirements: ?PhysicalConnectionRequirements = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .connection_type = "ConnectionType",
            .match_criteria = "MatchCriteria",
            .connection_properties = "ConnectionProperties",
            .physical_connection_requirements = "PhysicalConnectionRequirements",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "connection_properties", field_name))
            return try serializeMap(self.connection_properties, self.fieldNameFor("connection_properties"), options, out_stream);
        return false;
    }
};

pub const PhysicalConnectionRequirements = struct {
    subnet_id: ?[]const u8 = null,
    security_group_id_list: ?[][]const u8 = null,
    availability_zone: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .subnet_id = "SubnetId",
            .security_group_id_list = "SecurityGroupIdList",
            .availability_zone = "AvailabilityZone",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnStatisticsError = struct {
    column_statistics: ?ColumnStatistics = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_statistics = "ColumnStatistics",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorDetail = struct {
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnStatistics = struct {
    column_name: []const u8,
    column_type: []const u8,
    analyzed_time: i64,
    statistics_data: ColumnStatisticsData,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .column_type = "ColumnType",
            .analyzed_time = "AnalyzedTime",
            .statistics_data = "StatisticsData",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnStatisticsData = struct {
    type: []const u8,
    boolean_column_statistics_data: ?BooleanColumnStatisticsData = null,
    date_column_statistics_data: ?DateColumnStatisticsData = null,
    decimal_column_statistics_data: ?DecimalColumnStatisticsData = null,
    double_column_statistics_data: ?DoubleColumnStatisticsData = null,
    long_column_statistics_data: ?LongColumnStatisticsData = null,
    string_column_statistics_data: ?StringColumnStatisticsData = null,
    binary_column_statistics_data: ?BinaryColumnStatisticsData = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .boolean_column_statistics_data = "BooleanColumnStatisticsData",
            .date_column_statistics_data = "DateColumnStatisticsData",
            .decimal_column_statistics_data = "DecimalColumnStatisticsData",
            .double_column_statistics_data = "DoubleColumnStatisticsData",
            .long_column_statistics_data = "LongColumnStatisticsData",
            .string_column_statistics_data = "StringColumnStatisticsData",
            .binary_column_statistics_data = "BinaryColumnStatisticsData",
        };
        return @field(mappings, field_name);
    }
};

pub const BinaryColumnStatisticsData = struct {
    maximum_length: i64,
    average_length: f64,
    number_of_nulls: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_length = "MaximumLength",
            .average_length = "AverageLength",
            .number_of_nulls = "NumberOfNulls",
        };
        return @field(mappings, field_name);
    }
};

pub const StringColumnStatisticsData = struct {
    maximum_length: i64,
    average_length: f64,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_length = "MaximumLength",
            .average_length = "AverageLength",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const LongColumnStatisticsData = struct {
    minimum_value: ?i64 = null,
    maximum_value: ?i64 = null,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_value = "MinimumValue",
            .maximum_value = "MaximumValue",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DoubleColumnStatisticsData = struct {
    minimum_value: ?f64 = null,
    maximum_value: ?f64 = null,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_value = "MinimumValue",
            .maximum_value = "MaximumValue",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalColumnStatisticsData = struct {
    minimum_value: ?DecimalNumber = null,
    maximum_value: ?DecimalNumber = null,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_value = "MinimumValue",
            .maximum_value = "MaximumValue",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalNumber = struct {
    unscaled_value: []const u8,
    scale: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unscaled_value = "UnscaledValue",
            .scale = "Scale",
        };
        return @field(mappings, field_name);
    }
};

pub const DateColumnStatisticsData = struct {
    minimum_value: ?i64 = null,
    maximum_value: ?i64 = null,
    number_of_nulls: i64,
    number_of_distinct_values: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .minimum_value = "MinimumValue",
            .maximum_value = "MaximumValue",
            .number_of_nulls = "NumberOfNulls",
            .number_of_distinct_values = "NumberOfDistinctValues",
        };
        return @field(mappings, field_name);
    }
};

pub const BooleanColumnStatisticsData = struct {
    number_of_trues: i64,
    number_of_falses: i64,
    number_of_nulls: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .number_of_trues = "NumberOfTrues",
            .number_of_falses = "NumberOfFalses",
            .number_of_nulls = "NumberOfNulls",
        };
        return @field(mappings, field_name);
    }
};

pub const Table = struct {
    name: []const u8,
    database_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    create_time: ?i64 = null,
    update_time: ?i64 = null,
    last_access_time: ?i64 = null,
    last_analyzed_time: ?i64 = null,
    retention: ?i64 = null,
    storage_descriptor: ?StorageDescriptor = null,
    partition_keys: ?[]Column = null,
    view_original_text: ?[]const u8 = null,
    view_expanded_text: ?[]const u8 = null,
    table_type: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    created_by: ?[]const u8 = null,
    is_registered_with_lake_formation: ?bool = null,
    target_table: ?TableIdentifier = null,
    catalog_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .database_name = "DatabaseName",
            .description = "Description",
            .owner = "Owner",
            .create_time = "CreateTime",
            .update_time = "UpdateTime",
            .last_access_time = "LastAccessTime",
            .last_analyzed_time = "LastAnalyzedTime",
            .retention = "Retention",
            .storage_descriptor = "StorageDescriptor",
            .partition_keys = "PartitionKeys",
            .view_original_text = "ViewOriginalText",
            .view_expanded_text = "ViewExpandedText",
            .table_type = "TableType",
            .parameters = "Parameters",
            .created_by = "CreatedBy",
            .is_registered_with_lake_formation = "IsRegisteredWithLakeFormation",
            .target_table = "TargetTable",
            .catalog_id = "CatalogId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const JobBookmarkEntry = struct {
    job_name: ?[]const u8 = null,
    version: ?i64 = null,
    run: ?i64 = null,
    attempt: ?i64 = null,
    previous_run_id: ?[]const u8 = null,
    run_id: ?[]const u8 = null,
    job_bookmark: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .version = "Version",
            .run = "Run",
            .attempt = "Attempt",
            .previous_run_id = "PreviousRunId",
            .run_id = "RunId",
            .job_bookmark = "JobBookmark",
        };
        return @field(mappings, field_name);
    }
};

pub const MetadataKeyValuePair = struct {
    metadata_key: ?[]const u8 = null,
    metadata_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metadata_key = "MetadataKey",
            .metadata_value = "MetadataValue",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCatalogEncryptionSettings = struct {
    encryption_at_rest: ?EncryptionAtRest = null,
    connection_password_encryption: ?ConnectionPasswordEncryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encryption_at_rest = "EncryptionAtRest",
            .connection_password_encryption = "ConnectionPasswordEncryption",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionPasswordEncryption = struct {
    return_connection_password_encrypted: bool,
    aws_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .return_connection_password_encrypted = "ReturnConnectionPasswordEncrypted",
            .aws_kms_key_id = "AwsKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionAtRest = struct {
    catalog_encryption_mode: []const u8,
    sse_aws_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog_encryption_mode = "CatalogEncryptionMode",
            .sse_aws_kms_key_id = "SseAwsKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformSortCriteria = struct {
    column: []const u8,
    sort_direction: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column = "Column",
            .sort_direction = "SortDirection",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformFilterCriteria = struct {
    name: ?[]const u8 = null,
    transform_type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    glue_version: ?[]const u8 = null,
    created_before: ?i64 = null,
    created_after: ?i64 = null,
    last_modified_before: ?i64 = null,
    last_modified_after: ?i64 = null,
    schema: ?[]SchemaColumn = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .transform_type = "TransformType",
            .status = "Status",
            .glue_version = "GlueVersion",
            .created_before = "CreatedBefore",
            .created_after = "CreatedAfter",
            .last_modified_before = "LastModifiedBefore",
            .last_modified_after = "LastModifiedAfter",
            .schema = "Schema",
        };
        return @field(mappings, field_name);
    }
};

pub const SchemaColumn = struct {
    name: ?[]const u8 = null,
    data_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .data_type = "DataType",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowRun = struct {
    name: ?[]const u8 = null,
    workflow_run_id: ?[]const u8 = null,
    previous_run_id: ?[]const u8 = null,
    workflow_run_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    started_on: ?i64 = null,
    completed_on: ?i64 = null,
    status: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    statistics: ?WorkflowRunStatistics = null,
    graph: ?WorkflowGraph = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .workflow_run_id = "WorkflowRunId",
            .previous_run_id = "PreviousRunId",
            .workflow_run_properties = "WorkflowRunProperties",
            .started_on = "StartedOn",
            .completed_on = "CompletedOn",
            .status = "Status",
            .error_message = "ErrorMessage",
            .statistics = "Statistics",
            .graph = "Graph",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "workflow_run_properties", field_name))
            return try serializeMap(self.workflow_run_properties, self.fieldNameFor("workflow_run_properties"), options, out_stream);
        return false;
    }
};

pub const WorkflowGraph = struct {
    nodes: ?[]Node = null,
    edges: ?[]Edge = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nodes = "Nodes",
            .edges = "Edges",
        };
        return @field(mappings, field_name);
    }
};

pub const Edge = struct {
    source_id: ?[]const u8 = null,
    destination_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_id = "SourceId",
            .destination_id = "DestinationId",
        };
        return @field(mappings, field_name);
    }
};

pub const Node = struct {
    type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    unique_id: ?[]const u8 = null,
    trigger_details: ?TriggerNodeDetails = null,
    job_details: ?JobNodeDetails = null,
    crawler_details: ?CrawlerNodeDetails = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .name = "Name",
            .unique_id = "UniqueId",
            .trigger_details = "TriggerDetails",
            .job_details = "JobDetails",
            .crawler_details = "CrawlerDetails",
        };
        return @field(mappings, field_name);
    }
};

pub const CrawlerNodeDetails = struct {
    crawls: ?[]Crawl = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .crawls = "Crawls",
        };
        return @field(mappings, field_name);
    }
};

pub const Crawl = struct {
    state: ?[]const u8 = null,
    started_on: ?i64 = null,
    completed_on: ?i64 = null,
    error_message: ?[]const u8 = null,
    log_group: ?[]const u8 = null,
    log_stream: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .state = "State",
            .started_on = "StartedOn",
            .completed_on = "CompletedOn",
            .error_message = "ErrorMessage",
            .log_group = "LogGroup",
            .log_stream = "LogStream",
        };
        return @field(mappings, field_name);
    }
};

pub const JobNodeDetails = struct {
    job_runs: ?[]JobRun = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_runs = "JobRuns",
        };
        return @field(mappings, field_name);
    }
};

pub const JobRun = struct {
    id: ?[]const u8 = null,
    attempt: ?i64 = null,
    previous_run_id: ?[]const u8 = null,
    trigger_name: ?[]const u8 = null,
    job_name: ?[]const u8 = null,
    started_on: ?i64 = null,
    last_modified_on: ?i64 = null,
    completed_on: ?i64 = null,
    job_run_state: ?[]const u8 = null,
    arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    error_message: ?[]const u8 = null,
    predecessor_runs: ?[]Predecessor = null,
    allocated_capacity: ?i64 = null,
    execution_time: ?i64 = null,
    timeout: ?i64 = null,
    max_capacity: ?f64 = null,
    worker_type: ?[]const u8 = null,
    number_of_workers: ?i64 = null,
    security_configuration: ?[]const u8 = null,
    log_group_name: ?[]const u8 = null,
    notification_property: ?NotificationProperty = null,
    glue_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .attempt = "Attempt",
            .previous_run_id = "PreviousRunId",
            .trigger_name = "TriggerName",
            .job_name = "JobName",
            .started_on = "StartedOn",
            .last_modified_on = "LastModifiedOn",
            .completed_on = "CompletedOn",
            .job_run_state = "JobRunState",
            .arguments = "Arguments",
            .error_message = "ErrorMessage",
            .predecessor_runs = "PredecessorRuns",
            .allocated_capacity = "AllocatedCapacity",
            .execution_time = "ExecutionTime",
            .timeout = "Timeout",
            .max_capacity = "MaxCapacity",
            .worker_type = "WorkerType",
            .number_of_workers = "NumberOfWorkers",
            .security_configuration = "SecurityConfiguration",
            .log_group_name = "LogGroupName",
            .notification_property = "NotificationProperty",
            .glue_version = "GlueVersion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "arguments", field_name))
            return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
        return false;
    }
};

pub const Predecessor = struct {
    job_name: ?[]const u8 = null,
    run_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_name = "JobName",
            .run_id = "RunId",
        };
        return @field(mappings, field_name);
    }
};

pub const TriggerNodeDetails = struct {
    trigger: ?Trigger = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .trigger = "Trigger",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkflowRunStatistics = struct {
    total_actions: ?i64 = null,
    timeout_actions: ?i64 = null,
    failed_actions: ?i64 = null,
    stopped_actions: ?i64 = null,
    succeeded_actions: ?i64 = null,
    running_actions: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_actions = "TotalActions",
            .timeout_actions = "TimeoutActions",
            .failed_actions = "FailedActions",
            .stopped_actions = "StoppedActions",
            .succeeded_actions = "SucceededActions",
            .running_actions = "RunningActions",
        };
        return @field(mappings, field_name);
    }
};

pub const Workflow = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    default_run_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    created_on: ?i64 = null,
    last_modified_on: ?i64 = null,
    last_run: ?WorkflowRun = null,
    graph: ?WorkflowGraph = null,
    max_concurrent_runs: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .default_run_properties = "DefaultRunProperties",
            .created_on = "CreatedOn",
            .last_modified_on = "LastModifiedOn",
            .last_run = "LastRun",
            .graph = "Graph",
            .max_concurrent_runs = "MaxConcurrentRuns",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "default_run_properties", field_name))
            return try serializeMap(self.default_run_properties, self.fieldNameFor("default_run_properties"), options, out_stream);
        return false;
    }
};

pub const UserDefinedFunction = struct {
    function_name: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    class_name: ?[]const u8 = null,
    owner_name: ?[]const u8 = null,
    owner_type: ?[]const u8 = null,
    create_time: ?i64 = null,
    resource_uris: ?[]ResourceUri = null,
    catalog_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_name = "FunctionName",
            .database_name = "DatabaseName",
            .class_name = "ClassName",
            .owner_name = "OwnerName",
            .owner_type = "OwnerType",
            .create_time = "CreateTime",
            .resource_uris = "ResourceUris",
            .catalog_id = "CatalogId",
        };
        return @field(mappings, field_name);
    }
};

pub const TableVersion = struct {
    table: ?Table = null,
    version_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table = "Table",
            .version_id = "VersionId",
        };
        return @field(mappings, field_name);
    }
};

pub const SecurityConfiguration = struct {
    name: ?[]const u8 = null,
    created_time_stamp: ?i64 = null,
    encryption_configuration: ?EncryptionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .created_time_stamp = "CreatedTimeStamp",
            .encryption_configuration = "EncryptionConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const EncryptionConfiguration = struct {
    s3_encryption: ?[]S3Encryption = null,
    cloud_watch_encryption: ?CloudWatchEncryption = null,
    job_bookmarks_encryption: ?JobBookmarksEncryption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_encryption = "S3Encryption",
            .cloud_watch_encryption = "CloudWatchEncryption",
            .job_bookmarks_encryption = "JobBookmarksEncryption",
        };
        return @field(mappings, field_name);
    }
};

pub const JobBookmarksEncryption = struct {
    job_bookmarks_encryption_mode: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_bookmarks_encryption_mode = "JobBookmarksEncryptionMode",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchEncryption = struct {
    cloud_watch_encryption_mode: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_encryption_mode = "CloudWatchEncryptionMode",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Encryption = struct {
    s3_encryption_mode: ?[]const u8 = null,
    kms_key_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_encryption_mode = "S3EncryptionMode",
            .kms_key_arn = "KmsKeyArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Location = struct {
    jdbc: ?[]CodeGenNodeArg = null,
    s3: ?[]CodeGenNodeArg = null,
    dynamo_db: ?[]CodeGenNodeArg = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .jdbc = "Jdbc",
            .s3 = "S3",
            .dynamo_db = "DynamoDB",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeGenNodeArg = struct {
    name: []const u8,
    value: []const u8,
    param: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
            .param = "Param",
        };
        return @field(mappings, field_name);
    }
};

pub const CatalogEntry = struct {
    database_name: []const u8,
    table_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .table_name = "TableName",
        };
        return @field(mappings, field_name);
    }
};

pub const MappingEntry = struct {
    source_table: ?[]const u8 = null,
    source_path: ?[]const u8 = null,
    source_type: ?[]const u8 = null,
    target_table: ?[]const u8 = null,
    target_path: ?[]const u8 = null,
    target_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_table = "SourceTable",
            .source_path = "SourcePath",
            .source_type = "SourceType",
            .target_table = "TargetTable",
            .target_path = "TargetPath",
            .target_type = "TargetType",
        };
        return @field(mappings, field_name);
    }
};

pub const Partition = struct {
    values: ?[][]const u8 = null,
    database_name: ?[]const u8 = null,
    table_name: ?[]const u8 = null,
    creation_time: ?i64 = null,
    last_access_time: ?i64 = null,
    storage_descriptor: ?StorageDescriptor = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    last_analyzed_time: ?i64 = null,
    catalog_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .creation_time = "CreationTime",
            .last_access_time = "LastAccessTime",
            .storage_descriptor = "StorageDescriptor",
            .parameters = "Parameters",
            .last_analyzed_time = "LastAnalyzedTime",
            .catalog_id = "CatalogId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const PartitionValueList = struct {
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformEncryption = struct {
    ml_user_data_encryption: ?MLUserDataEncryption = null,
    task_run_security_configuration_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ml_user_data_encryption = "MlUserDataEncryption",
            .task_run_security_configuration_name = "TaskRunSecurityConfigurationName",
        };
        return @field(mappings, field_name);
    }
};

pub const MLUserDataEncryption = struct {
    ml_user_data_encryption_mode: []const u8,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ml_user_data_encryption_mode = "MlUserDataEncryptionMode",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluationMetrics = struct {
    transform_type: []const u8,
    find_matches_metrics: ?FindMatchesMetrics = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .transform_type = "TransformType",
            .find_matches_metrics = "FindMatchesMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const FindMatchesMetrics = struct {
    area_under_pr_curve: ?f64 = null,
    precision: ?f64 = null,
    recall: ?f64 = null,
    f1: ?f64 = null,
    confusion_matrix: ?ConfusionMatrix = null,
    column_importances: ?[]ColumnImportance = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .area_under_pr_curve = "AreaUnderPRCurve",
            .precision = "Precision",
            .recall = "Recall",
            .f1 = "F1",
            .confusion_matrix = "ConfusionMatrix",
            .column_importances = "ColumnImportances",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnImportance = struct {
    column_name: ?[]const u8 = null,
    importance: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .importance = "Importance",
        };
        return @field(mappings, field_name);
    }
};

pub const ConfusionMatrix = struct {
    num_true_positives: ?i64 = null,
    num_false_positives: ?i64 = null,
    num_true_negatives: ?i64 = null,
    num_false_negatives: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .num_true_positives = "NumTruePositives",
            .num_false_positives = "NumFalsePositives",
            .num_true_negatives = "NumTrueNegatives",
            .num_false_negatives = "NumFalseNegatives",
        };
        return @field(mappings, field_name);
    }
};

pub const GlueTable = struct {
    database_name: []const u8,
    table_name: []const u8,
    catalog_id: ?[]const u8 = null,
    connection_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .database_name = "DatabaseName",
            .table_name = "TableName",
            .catalog_id = "CatalogId",
            .connection_name = "ConnectionName",
        };
        return @field(mappings, field_name);
    }
};

pub const TaskRunProperties = struct {
    task_type: ?[]const u8 = null,
    import_labels_task_run_properties: ?ImportLabelsTaskRunProperties = null,
    export_labels_task_run_properties: ?ExportLabelsTaskRunProperties = null,
    labeling_set_generation_task_run_properties: ?LabelingSetGenerationTaskRunProperties = null,
    find_matches_task_run_properties: ?FindMatchesTaskRunProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .task_type = "TaskType",
            .import_labels_task_run_properties = "ImportLabelsTaskRunProperties",
            .export_labels_task_run_properties = "ExportLabelsTaskRunProperties",
            .labeling_set_generation_task_run_properties = "LabelingSetGenerationTaskRunProperties",
            .find_matches_task_run_properties = "FindMatchesTaskRunProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const FindMatchesTaskRunProperties = struct {
    job_id: ?[]const u8 = null,
    job_name: ?[]const u8 = null,
    job_run_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "JobId",
            .job_name = "JobName",
            .job_run_id = "JobRunId",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingSetGenerationTaskRunProperties = struct {
    output_s3_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_s3_path = "OutputS3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportLabelsTaskRunProperties = struct {
    output_s3_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_s3_path = "OutputS3Path",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportLabelsTaskRunProperties = struct {
    input_s3_path: ?[]const u8 = null,
    replace: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_s3_path = "InputS3Path",
            .replace = "Replace",
        };
        return @field(mappings, field_name);
    }
};

pub const Job = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    log_uri: ?[]const u8 = null,
    role: ?[]const u8 = null,
    created_on: ?i64 = null,
    last_modified_on: ?i64 = null,
    execution_property: ?ExecutionProperty = null,
    command: ?JobCommand = null,
    default_arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    non_overridable_arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    connections: ?ConnectionsList = null,
    max_retries: ?i64 = null,
    allocated_capacity: ?i64 = null,
    timeout: ?i64 = null,
    max_capacity: ?f64 = null,
    worker_type: ?[]const u8 = null,
    number_of_workers: ?i64 = null,
    security_configuration: ?[]const u8 = null,
    notification_property: ?NotificationProperty = null,
    glue_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .log_uri = "LogUri",
            .role = "Role",
            .created_on = "CreatedOn",
            .last_modified_on = "LastModifiedOn",
            .execution_property = "ExecutionProperty",
            .command = "Command",
            .default_arguments = "DefaultArguments",
            .non_overridable_arguments = "NonOverridableArguments",
            .connections = "Connections",
            .max_retries = "MaxRetries",
            .allocated_capacity = "AllocatedCapacity",
            .timeout = "Timeout",
            .max_capacity = "MaxCapacity",
            .worker_type = "WorkerType",
            .number_of_workers = "NumberOfWorkers",
            .security_configuration = "SecurityConfiguration",
            .notification_property = "NotificationProperty",
            .glue_version = "GlueVersion",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "default_arguments", field_name))
            return try serializeMap(self.default_arguments, self.fieldNameFor("default_arguments"), options, out_stream);
        if (std.mem.eql(u8, "non_overridable_arguments", field_name))
            return try serializeMap(self.non_overridable_arguments, self.fieldNameFor("non_overridable_arguments"), options, out_stream);
        return false;
    }
};

pub const DevEndpoint = struct {
    endpoint_name: ?[]const u8 = null,
    role_arn: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    subnet_id: ?[]const u8 = null,
    yarn_endpoint_address: ?[]const u8 = null,
    private_address: ?[]const u8 = null,
    zeppelin_remote_spark_interpreter_port: ?i64 = null,
    public_address: ?[]const u8 = null,
    status: ?[]const u8 = null,
    worker_type: ?[]const u8 = null,
    glue_version: ?[]const u8 = null,
    number_of_workers: ?i64 = null,
    number_of_nodes: ?i64 = null,
    availability_zone: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    extra_python_libs_s3_path: ?[]const u8 = null,
    extra_jars_s3_path: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    last_update_status: ?[]const u8 = null,
    created_timestamp: ?i64 = null,
    last_modified_timestamp: ?i64 = null,
    public_key: ?[]const u8 = null,
    public_keys: ?[][]const u8 = null,
    security_configuration: ?[]const u8 = null,
    arguments: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_name = "EndpointName",
            .role_arn = "RoleArn",
            .security_group_ids = "SecurityGroupIds",
            .subnet_id = "SubnetId",
            .yarn_endpoint_address = "YarnEndpointAddress",
            .private_address = "PrivateAddress",
            .zeppelin_remote_spark_interpreter_port = "ZeppelinRemoteSparkInterpreterPort",
            .public_address = "PublicAddress",
            .status = "Status",
            .worker_type = "WorkerType",
            .glue_version = "GlueVersion",
            .number_of_workers = "NumberOfWorkers",
            .number_of_nodes = "NumberOfNodes",
            .availability_zone = "AvailabilityZone",
            .vpc_id = "VpcId",
            .extra_python_libs_s3_path = "ExtraPythonLibsS3Path",
            .extra_jars_s3_path = "ExtraJarsS3Path",
            .failure_reason = "FailureReason",
            .last_update_status = "LastUpdateStatus",
            .created_timestamp = "CreatedTimestamp",
            .last_modified_timestamp = "LastModifiedTimestamp",
            .public_key = "PublicKey",
            .public_keys = "PublicKeys",
            .security_configuration = "SecurityConfiguration",
            .arguments = "Arguments",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "arguments", field_name))
            return try serializeMap(self.arguments, self.fieldNameFor("arguments"), options, out_stream);
        return false;
    }
};

pub const CodeGenEdge = struct {
    source: []const u8,
    target: []const u8,
    target_parameter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
            .target = "Target",
            .target_parameter = "TargetParameter",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeGenNode = struct {
    id: []const u8,
    node_type: []const u8,
    args: []CodeGenNodeArg,
    line_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "Id",
            .node_type = "NodeType",
            .args = "Args",
            .line_number = "LineNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const Database = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    location_uri: ?[]const u8 = null,
    parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    create_time: ?i64 = null,
    create_table_default_permissions: ?[]PrincipalPermissions = null,
    target_database: ?DatabaseIdentifier = null,
    catalog_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .location_uri = "LocationUri",
            .parameters = "Parameters",
            .create_time = "CreateTime",
            .create_table_default_permissions = "CreateTableDefaultPermissions",
            .target_database = "TargetDatabase",
            .catalog_id = "CatalogId",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "parameters", field_name))
            return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
        return false;
    }
};

pub const Crawler = struct {
    name: ?[]const u8 = null,
    role: ?[]const u8 = null,
    targets: ?CrawlerTargets = null,
    database_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    classifiers: ?[][]const u8 = null,
    recrawl_policy: ?RecrawlPolicy = null,
    schema_change_policy: ?SchemaChangePolicy = null,
    lineage_configuration: ?LineageConfiguration = null,
    state: ?[]const u8 = null,
    table_prefix: ?[]const u8 = null,
    schedule: ?Schedule = null,
    crawl_elapsed_time: ?i64 = null,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    last_crawl: ?LastCrawlInfo = null,
    version: ?i64 = null,
    configuration: ?[]const u8 = null,
    crawler_security_configuration: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .role = "Role",
            .targets = "Targets",
            .database_name = "DatabaseName",
            .description = "Description",
            .classifiers = "Classifiers",
            .recrawl_policy = "RecrawlPolicy",
            .schema_change_policy = "SchemaChangePolicy",
            .lineage_configuration = "LineageConfiguration",
            .state = "State",
            .table_prefix = "TablePrefix",
            .schedule = "Schedule",
            .crawl_elapsed_time = "CrawlElapsedTime",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .last_crawl = "LastCrawl",
            .version = "Version",
            .configuration = "Configuration",
            .crawler_security_configuration = "CrawlerSecurityConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LastCrawlInfo = struct {
    status: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    log_group: ?[]const u8 = null,
    log_stream: ?[]const u8 = null,
    message_prefix: ?[]const u8 = null,
    start_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .error_message = "ErrorMessage",
            .log_group = "LogGroup",
            .log_stream = "LogStream",
            .message_prefix = "MessagePrefix",
            .start_time = "StartTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Schedule = struct {
    schedule_expression: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "ScheduleExpression",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const Connection = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    connection_type: ?[]const u8 = null,
    match_criteria: ?[][]const u8 = null,
    connection_properties: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    physical_connection_requirements: ?PhysicalConnectionRequirements = null,
    creation_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    last_updated_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .connection_type = "ConnectionType",
            .match_criteria = "MatchCriteria",
            .connection_properties = "ConnectionProperties",
            .physical_connection_requirements = "PhysicalConnectionRequirements",
            .creation_time = "CreationTime",
            .last_updated_time = "LastUpdatedTime",
            .last_updated_by = "LastUpdatedBy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "connection_properties", field_name))
            return try serializeMap(self.connection_properties, self.fieldNameFor("connection_properties"), options, out_stream);
        return false;
    }
};

pub const ColumnError = struct {
    column_name: ?[]const u8 = null,
    @"error": ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .@"error" = "Error",
        };
        return @field(mappings, field_name);
    }
};

pub const Classifier = struct {
    grok_classifier: ?GrokClassifier = null,
    xml_classifier: ?XMLClassifier = null,
    json_classifier: ?JsonClassifier = null,
    csv_classifier: ?CsvClassifier = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .grok_classifier = "GrokClassifier",
            .xml_classifier = "XMLClassifier",
            .json_classifier = "JsonClassifier",
            .csv_classifier = "CsvClassifier",
        };
        return @field(mappings, field_name);
    }
};

pub const CsvClassifier = struct {
    name: []const u8,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    version: ?i64 = null,
    delimiter: ?[]const u8 = null,
    quote_symbol: ?[]const u8 = null,
    contains_header: ?[]const u8 = null,
    header: ?[][]const u8 = null,
    disable_value_trimming: ?bool = null,
    allow_single_column: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .version = "Version",
            .delimiter = "Delimiter",
            .quote_symbol = "QuoteSymbol",
            .contains_header = "ContainsHeader",
            .header = "Header",
            .disable_value_trimming = "DisableValueTrimming",
            .allow_single_column = "AllowSingleColumn",
        };
        return @field(mappings, field_name);
    }
};

pub const JsonClassifier = struct {
    name: []const u8,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    version: ?i64 = null,
    json_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .version = "Version",
            .json_path = "JsonPath",
        };
        return @field(mappings, field_name);
    }
};

pub const XMLClassifier = struct {
    name: []const u8,
    classification: []const u8,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    version: ?i64 = null,
    row_tag: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .classification = "Classification",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .version = "Version",
            .row_tag = "RowTag",
        };
        return @field(mappings, field_name);
    }
};

pub const GrokClassifier = struct {
    name: []const u8,
    classification: []const u8,
    creation_time: ?i64 = null,
    last_updated: ?i64 = null,
    version: ?i64 = null,
    grok_pattern: []const u8,
    custom_patterns: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .classification = "Classification",
            .creation_time = "CreationTime",
            .last_updated = "LastUpdated",
            .version = "Version",
            .grok_pattern = "GrokPattern",
            .custom_patterns = "CustomPatterns",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionIndex = struct {
    keys: [][]const u8,
    index_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .keys = "Keys",
            .index_name = "IndexName",
        };
        return @field(mappings, field_name);
    }
};

pub const PartitionError = struct {
    partition_values: ?[][]const u8 = null,
    error_detail: ?ErrorDetail = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .partition_values = "PartitionValues",
            .error_detail = "ErrorDetail",
        };
        return @field(mappings, field_name);
    }
};
