const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-24";
pub const sdk_id: []const u8 = "SageMaker";
pub const arn_namespace: []const u8 = "sagemaker";
pub const endpoint_prefix: []const u8 = "api.sagemaker";
pub const sigv4_name: []const u8 = "sagemaker";
pub const name: []const u8 = "SageMaker";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-24",
    sdk_id: []const u8 = "SageMaker",
    arn_namespace: []const u8 = "sagemaker",
    endpoint_prefix: []const u8 = "api.sagemaker",
    sigv4_name: []const u8 = "sagemaker",
    name: []const u8 = "SageMaker",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_association: struct {
    action_name: []const u8 = "AddAssociation",
    Request: type = struct {
        source_arn: []const u8,
        destination_arn: []const u8,
        association_type: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_arn = "SourceArn",
                .destination_arn = "DestinationArn",
                .association_type = "AssociationType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_association) } {
            return .{ .service_metadata = service_metadata, .action = add_association };
        }
    },
    Response: type = struct {
        source_arn: ?[]const u8 = null,
        destination_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_arn = "SourceArn",
                .destination_arn = "DestinationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const add_tags: struct {
    action_name: []const u8 = "AddTags",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const associate_trial_component: struct {
    action_name: []const u8 = "AssociateTrialComponent",
    Request: type = struct {
        trial_component_name: []const u8,
        trial_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_name = "TrialComponentName",
                .trial_name = "TrialName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_trial_component) } {
            return .{ .service_metadata = service_metadata, .action = associate_trial_component };
        }
    },
    Response: type = struct {
        trial_component_arn: ?[]const u8 = null,
        trial_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_arn = "TrialComponentArn",
                .trial_arn = "TrialArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_action: struct {
    action_name: []const u8 = "CreateAction",
    Request: type = struct {
        action_name: []const u8,
        source: ActionSource,
        action_type: []const u8,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        metadata_properties: ?MetadataProperties = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "ActionName",
                .source = "Source",
                .action_type = "ActionType",
                .description = "Description",
                .status = "Status",
                .properties = "Properties",
                .metadata_properties = "MetadataProperties",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_action) } {
            return .{ .service_metadata = service_metadata, .action = create_action };
        }
    },
    Response: type = struct {
        action_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_arn = "ActionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_algorithm: struct {
    action_name: []const u8 = "CreateAlgorithm",
    Request: type = struct {
        algorithm_name: []const u8,
        algorithm_description: ?[]const u8 = null,
        training_specification: TrainingSpecification,
        inference_specification: ?InferenceSpecification = null,
        validation_specification: ?AlgorithmValidationSpecification = null,
        certify_for_marketplace: ?bool = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .algorithm_name = "AlgorithmName",
                .algorithm_description = "AlgorithmDescription",
                .training_specification = "TrainingSpecification",
                .inference_specification = "InferenceSpecification",
                .validation_specification = "ValidationSpecification",
                .certify_for_marketplace = "CertifyForMarketplace",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_algorithm) } {
            return .{ .service_metadata = service_metadata, .action = create_algorithm };
        }
    },
    Response: type = struct {
        algorithm_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .algorithm_arn = "AlgorithmArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_app: struct {
    action_name: []const u8 = "CreateApp",
    Request: type = struct {
        domain_id: []const u8,
        user_profile_name: []const u8,
        app_type: []const u8,
        app_name: []const u8,
        tags: ?[]Tag = null,
        resource_spec: ?ResourceSpec = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
                .app_type = "AppType",
                .app_name = "AppName",
                .tags = "Tags",
                .resource_spec = "ResourceSpec",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app) } {
            return .{ .service_metadata = service_metadata, .action = create_app };
        }
    },
    Response: type = struct {
        app_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "AppArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_app_image_config: struct {
    action_name: []const u8 = "CreateAppImageConfig",
    Request: type = struct {
        app_image_config_name: []const u8,
        tags: ?[]Tag = null,
        kernel_gateway_image_config: ?KernelGatewayImageConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_image_config_name = "AppImageConfigName",
                .tags = "Tags",
                .kernel_gateway_image_config = "KernelGatewayImageConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_app_image_config) } {
            return .{ .service_metadata = service_metadata, .action = create_app_image_config };
        }
    },
    Response: type = struct {
        app_image_config_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_image_config_arn = "AppImageConfigArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
    },
} = .{};
pub const create_artifact: struct {
    action_name: []const u8 = "CreateArtifact",
    Request: type = struct {
        artifact_name: ?[]const u8 = null,
        source: ArtifactSource,
        artifact_type: []const u8,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        metadata_properties: ?MetadataProperties = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_name = "ArtifactName",
                .source = "Source",
                .artifact_type = "ArtifactType",
                .properties = "Properties",
                .metadata_properties = "MetadataProperties",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_artifact) } {
            return .{ .service_metadata = service_metadata, .action = create_artifact };
        }
    },
    Response: type = struct {
        artifact_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_arn = "ArtifactArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_auto_ml_job: struct {
    action_name: []const u8 = "CreateAutoMLJob",
    Request: type = struct {
        auto_ml_job_name: []const u8,
        input_data_config: []AutoMLChannel,
        output_data_config: AutoMLOutputDataConfig,
        problem_type: ?[]const u8 = null,
        auto_ml_job_objective: ?AutoMLJobObjective = null,
        auto_ml_job_config: ?AutoMLJobConfig = null,
        role_arn: []const u8,
        generate_candidate_definitions_only: ?bool = null,
        tags: ?[]Tag = null,
        model_deploy_config: ?ModelDeployConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_ml_job_name = "AutoMLJobName",
                .input_data_config = "InputDataConfig",
                .output_data_config = "OutputDataConfig",
                .problem_type = "ProblemType",
                .auto_ml_job_objective = "AutoMLJobObjective",
                .auto_ml_job_config = "AutoMLJobConfig",
                .role_arn = "RoleArn",
                .generate_candidate_definitions_only = "GenerateCandidateDefinitionsOnly",
                .tags = "Tags",
                .model_deploy_config = "ModelDeployConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_auto_ml_job) } {
            return .{ .service_metadata = service_metadata, .action = create_auto_ml_job };
        }
    },
    Response: type = struct {
        auto_ml_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_ml_job_arn = "AutoMLJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_code_repository: struct {
    action_name: []const u8 = "CreateCodeRepository",
    Request: type = struct {
        code_repository_name: []const u8,
        git_config: GitConfig,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_repository_name = "CodeRepositoryName",
                .git_config = "GitConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_code_repository) } {
            return .{ .service_metadata = service_metadata, .action = create_code_repository };
        }
    },
    Response: type = struct {
        code_repository_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_repository_arn = "CodeRepositoryArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_compilation_job: struct {
    action_name: []const u8 = "CreateCompilationJob",
    Request: type = struct {
        compilation_job_name: []const u8,
        role_arn: []const u8,
        input_config: InputConfig,
        output_config: OutputConfig,
        stopping_condition: StoppingCondition,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compilation_job_name = "CompilationJobName",
                .role_arn = "RoleArn",
                .input_config = "InputConfig",
                .output_config = "OutputConfig",
                .stopping_condition = "StoppingCondition",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_compilation_job) } {
            return .{ .service_metadata = service_metadata, .action = create_compilation_job };
        }
    },
    Response: type = struct {
        compilation_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compilation_job_arn = "CompilationJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_context: struct {
    action_name: []const u8 = "CreateContext",
    Request: type = struct {
        context_name: []const u8,
        source: ContextSource,
        context_type: []const u8,
        description: ?[]const u8 = null,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_name = "ContextName",
                .source = "Source",
                .context_type = "ContextType",
                .description = "Description",
                .properties = "Properties",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_context) } {
            return .{ .service_metadata = service_metadata, .action = create_context };
        }
    },
    Response: type = struct {
        context_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_arn = "ContextArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_data_quality_job_definition: struct {
    action_name: []const u8 = "CreateDataQualityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,
        data_quality_baseline_config: ?DataQualityBaselineConfig = null,
        data_quality_app_specification: DataQualityAppSpecification,
        data_quality_job_input: DataQualityJobInput,
        data_quality_job_output_config: MonitoringOutputConfig,
        job_resources: MonitoringResources,
        network_config: ?MonitoringNetworkConfig = null,
        role_arn: []const u8,
        stopping_condition: ?MonitoringStoppingCondition = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
                .data_quality_baseline_config = "DataQualityBaselineConfig",
                .data_quality_app_specification = "DataQualityAppSpecification",
                .data_quality_job_input = "DataQualityJobInput",
                .data_quality_job_output_config = "DataQualityJobOutputConfig",
                .job_resources = "JobResources",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .stopping_condition = "StoppingCondition",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_quality_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_data_quality_job_definition };
        }
    },
    Response: type = struct {
        job_definition_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_arn = "JobDefinitionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_device_fleet: struct {
    action_name: []const u8 = "CreateDeviceFleet",
    Request: type = struct {
        device_fleet_name: []const u8,
        role_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        output_config: EdgeOutputConfig,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
                .role_arn = "RoleArn",
                .description = "Description",
                .output_config = "OutputConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_device_fleet) } {
            return .{ .service_metadata = service_metadata, .action = create_device_fleet };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_domain: struct {
    action_name: []const u8 = "CreateDomain",
    Request: type = struct {
        domain_name: []const u8,
        auth_mode: []const u8,
        default_user_settings: UserSettings,
        subnet_ids: [][]const u8,
        vpc_id: []const u8,
        tags: ?[]Tag = null,
        app_network_access_type: ?[]const u8 = null,
        home_efs_file_system_kms_key_id: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .auth_mode = "AuthMode",
                .default_user_settings = "DefaultUserSettings",
                .subnet_ids = "SubnetIds",
                .vpc_id = "VpcId",
                .tags = "Tags",
                .app_network_access_type = "AppNetworkAccessType",
                .home_efs_file_system_kms_key_id = "HomeEfsFileSystemKmsKeyId",
                .kms_key_id = "KmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_domain };
        }
    },
    Response: type = struct {
        domain_arn: ?[]const u8 = null,
        url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_arn = "DomainArn",
                .url = "Url",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_edge_packaging_job: struct {
    action_name: []const u8 = "CreateEdgePackagingJob",
    Request: type = struct {
        edge_packaging_job_name: []const u8,
        compilation_job_name: []const u8,
        model_name: []const u8,
        model_version: []const u8,
        role_arn: []const u8,
        output_config: EdgeOutputConfig,
        resource_key: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .edge_packaging_job_name = "EdgePackagingJobName",
                .compilation_job_name = "CompilationJobName",
                .model_name = "ModelName",
                .model_version = "ModelVersion",
                .role_arn = "RoleArn",
                .output_config = "OutputConfig",
                .resource_key = "ResourceKey",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_edge_packaging_job) } {
            return .{ .service_metadata = service_metadata, .action = create_edge_packaging_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_endpoint: struct {
    action_name: []const u8 = "CreateEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,
        endpoint_config_name: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .endpoint_config_name = "EndpointConfigName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = create_endpoint };
        }
    },
    Response: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_endpoint_config: struct {
    action_name: []const u8 = "CreateEndpointConfig",
    Request: type = struct {
        endpoint_config_name: []const u8,
        production_variants: []ProductionVariant,
        data_capture_config: ?DataCaptureConfig = null,
        tags: ?[]Tag = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_config_name = "EndpointConfigName",
                .production_variants = "ProductionVariants",
                .data_capture_config = "DataCaptureConfig",
                .tags = "Tags",
                .kms_key_id = "KmsKeyId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_endpoint_config) } {
            return .{ .service_metadata = service_metadata, .action = create_endpoint_config };
        }
    },
    Response: type = struct {
        endpoint_config_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_config_arn = "EndpointConfigArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_experiment: struct {
    action_name: []const u8 = "CreateExperiment",
    Request: type = struct {
        experiment_name: []const u8,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_name = "ExperimentName",
                .display_name = "DisplayName",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_experiment) } {
            return .{ .service_metadata = service_metadata, .action = create_experiment };
        }
    },
    Response: type = struct {
        experiment_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_arn = "ExperimentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_feature_group: struct {
    action_name: []const u8 = "CreateFeatureGroup",
    Request: type = struct {
        feature_group_name: []const u8,
        record_identifier_feature_name: []const u8,
        event_time_feature_name: []const u8,
        feature_definitions: []FeatureDefinition,
        online_store_config: ?OnlineStoreConfig = null,
        offline_store_config: ?OfflineStoreConfig = null,
        role_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
                .record_identifier_feature_name = "RecordIdentifierFeatureName",
                .event_time_feature_name = "EventTimeFeatureName",
                .feature_definitions = "FeatureDefinitions",
                .online_store_config = "OnlineStoreConfig",
                .offline_store_config = "OfflineStoreConfig",
                .role_arn = "RoleArn",
                .description = "Description",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_feature_group) } {
            return .{ .service_metadata = service_metadata, .action = create_feature_group };
        }
    },
    Response: type = struct {
        feature_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_arn = "FeatureGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_flow_definition: struct {
    action_name: []const u8 = "CreateFlowDefinition",
    Request: type = struct {
        flow_definition_name: []const u8,
        human_loop_request_source: ?HumanLoopRequestSource = null,
        human_loop_activation_config: ?HumanLoopActivationConfig = null,
        human_loop_config: HumanLoopConfig,
        output_config: FlowDefinitionOutputConfig,
        role_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_definition_name = "FlowDefinitionName",
                .human_loop_request_source = "HumanLoopRequestSource",
                .human_loop_activation_config = "HumanLoopActivationConfig",
                .human_loop_config = "HumanLoopConfig",
                .output_config = "OutputConfig",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_flow_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_flow_definition };
        }
    },
    Response: type = struct {
        flow_definition_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_definition_arn = "FlowDefinitionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_human_task_ui: struct {
    action_name: []const u8 = "CreateHumanTaskUi",
    Request: type = struct {
        human_task_ui_name: []const u8,
        ui_template: UiTemplate,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_task_ui_name = "HumanTaskUiName",
                .ui_template = "UiTemplate",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_human_task_ui) } {
            return .{ .service_metadata = service_metadata, .action = create_human_task_ui };
        }
    },
    Response: type = struct {
        human_task_ui_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_task_ui_arn = "HumanTaskUiArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_hyper_parameter_tuning_job: struct {
    action_name: []const u8 = "CreateHyperParameterTuningJob",
    Request: type = struct {
        hyper_parameter_tuning_job_name: []const u8,
        hyper_parameter_tuning_job_config: HyperParameterTuningJobConfig,
        training_job_definition: ?HyperParameterTrainingJobDefinition = null,
        training_job_definitions: ?[]HyperParameterTrainingJobDefinition = null,
        warm_start_config: ?HyperParameterTuningJobWarmStartConfig = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hyper_parameter_tuning_job_name = "HyperParameterTuningJobName",
                .hyper_parameter_tuning_job_config = "HyperParameterTuningJobConfig",
                .training_job_definition = "TrainingJobDefinition",
                .training_job_definitions = "TrainingJobDefinitions",
                .warm_start_config = "WarmStartConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_hyper_parameter_tuning_job) } {
            return .{ .service_metadata = service_metadata, .action = create_hyper_parameter_tuning_job };
        }
    },
    Response: type = struct {
        hyper_parameter_tuning_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hyper_parameter_tuning_job_arn = "HyperParameterTuningJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_image: struct {
    action_name: []const u8 = "CreateImage",
    Request: type = struct {
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        image_name: []const u8,
        role_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .description = "Description",
                .display_name = "DisplayName",
                .image_name = "ImageName",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image) } {
            return .{ .service_metadata = service_metadata, .action = create_image };
        }
    },
    Response: type = struct {
        image_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_arn = "ImageArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_image_version: struct {
    action_name: []const u8 = "CreateImageVersion",
    Request: type = struct {
        base_image: []const u8,
        client_token: []const u8,
        image_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .base_image = "BaseImage",
                .client_token = "ClientToken",
                .image_name = "ImageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image_version) } {
            return .{ .service_metadata = service_metadata, .action = create_image_version };
        }
    },
    Response: type = struct {
        image_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_version_arn = "ImageVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_labeling_job: struct {
    action_name: []const u8 = "CreateLabelingJob",
    Request: type = struct {
        labeling_job_name: []const u8,
        label_attribute_name: []const u8,
        input_config: LabelingJobInputConfig,
        output_config: LabelingJobOutputConfig,
        role_arn: []const u8,
        label_category_config_s3_uri: ?[]const u8 = null,
        stopping_conditions: ?LabelingJobStoppingConditions = null,
        labeling_job_algorithms_config: ?LabelingJobAlgorithmsConfig = null,
        human_task_config: HumanTaskConfig,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labeling_job_name = "LabelingJobName",
                .label_attribute_name = "LabelAttributeName",
                .input_config = "InputConfig",
                .output_config = "OutputConfig",
                .role_arn = "RoleArn",
                .label_category_config_s3_uri = "LabelCategoryConfigS3Uri",
                .stopping_conditions = "StoppingConditions",
                .labeling_job_algorithms_config = "LabelingJobAlgorithmsConfig",
                .human_task_config = "HumanTaskConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_labeling_job) } {
            return .{ .service_metadata = service_metadata, .action = create_labeling_job };
        }
    },
    Response: type = struct {
        labeling_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labeling_job_arn = "LabelingJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_model: struct {
    action_name: []const u8 = "CreateModel",
    Request: type = struct {
        model_name: []const u8,
        primary_container: ?ContainerDefinition = null,
        containers: ?[]ContainerDefinition = null,
        inference_execution_config: ?InferenceExecutionConfig = null,
        execution_role_arn: []const u8,
        tags: ?[]Tag = null,
        vpc_config: ?VpcConfig = null,
        enable_network_isolation: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .primary_container = "PrimaryContainer",
                .containers = "Containers",
                .inference_execution_config = "InferenceExecutionConfig",
                .execution_role_arn = "ExecutionRoleArn",
                .tags = "Tags",
                .vpc_config = "VpcConfig",
                .enable_network_isolation = "EnableNetworkIsolation",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model) } {
            return .{ .service_metadata = service_metadata, .action = create_model };
        }
    },
    Response: type = struct {
        model_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_model_bias_job_definition: struct {
    action_name: []const u8 = "CreateModelBiasJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,
        model_bias_baseline_config: ?ModelBiasBaselineConfig = null,
        model_bias_app_specification: ModelBiasAppSpecification,
        model_bias_job_input: ModelBiasJobInput,
        model_bias_job_output_config: MonitoringOutputConfig,
        job_resources: MonitoringResources,
        network_config: ?MonitoringNetworkConfig = null,
        role_arn: []const u8,
        stopping_condition: ?MonitoringStoppingCondition = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
                .model_bias_baseline_config = "ModelBiasBaselineConfig",
                .model_bias_app_specification = "ModelBiasAppSpecification",
                .model_bias_job_input = "ModelBiasJobInput",
                .model_bias_job_output_config = "ModelBiasJobOutputConfig",
                .job_resources = "JobResources",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .stopping_condition = "StoppingCondition",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model_bias_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_model_bias_job_definition };
        }
    },
    Response: type = struct {
        job_definition_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_arn = "JobDefinitionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_model_explainability_job_definition: struct {
    action_name: []const u8 = "CreateModelExplainabilityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,
        model_explainability_baseline_config: ?ModelExplainabilityBaselineConfig = null,
        model_explainability_app_specification: ModelExplainabilityAppSpecification,
        model_explainability_job_input: ModelExplainabilityJobInput,
        model_explainability_job_output_config: MonitoringOutputConfig,
        job_resources: MonitoringResources,
        network_config: ?MonitoringNetworkConfig = null,
        role_arn: []const u8,
        stopping_condition: ?MonitoringStoppingCondition = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
                .model_explainability_baseline_config = "ModelExplainabilityBaselineConfig",
                .model_explainability_app_specification = "ModelExplainabilityAppSpecification",
                .model_explainability_job_input = "ModelExplainabilityJobInput",
                .model_explainability_job_output_config = "ModelExplainabilityJobOutputConfig",
                .job_resources = "JobResources",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .stopping_condition = "StoppingCondition",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model_explainability_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_model_explainability_job_definition };
        }
    },
    Response: type = struct {
        job_definition_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_arn = "JobDefinitionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_model_package: struct {
    action_name: []const u8 = "CreateModelPackage",
    Request: type = struct {
        model_package_name: ?[]const u8 = null,
        model_package_group_name: ?[]const u8 = null,
        model_package_description: ?[]const u8 = null,
        inference_specification: ?InferenceSpecification = null,
        validation_specification: ?ModelPackageValidationSpecification = null,
        source_algorithm_specification: ?SourceAlgorithmSpecification = null,
        certify_for_marketplace: ?bool = null,
        tags: ?[]Tag = null,
        model_approval_status: ?[]const u8 = null,
        metadata_properties: ?MetadataProperties = null,
        model_metrics: ?ModelMetrics = null,
        client_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_name = "ModelPackageName",
                .model_package_group_name = "ModelPackageGroupName",
                .model_package_description = "ModelPackageDescription",
                .inference_specification = "InferenceSpecification",
                .validation_specification = "ValidationSpecification",
                .source_algorithm_specification = "SourceAlgorithmSpecification",
                .certify_for_marketplace = "CertifyForMarketplace",
                .tags = "Tags",
                .model_approval_status = "ModelApprovalStatus",
                .metadata_properties = "MetadataProperties",
                .model_metrics = "ModelMetrics",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model_package) } {
            return .{ .service_metadata = service_metadata, .action = create_model_package };
        }
    },
    Response: type = struct {
        model_package_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_arn = "ModelPackageArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_model_package_group: struct {
    action_name: []const u8 = "CreateModelPackageGroup",
    Request: type = struct {
        model_package_group_name: []const u8,
        model_package_group_description: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_name = "ModelPackageGroupName",
                .model_package_group_description = "ModelPackageGroupDescription",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model_package_group) } {
            return .{ .service_metadata = service_metadata, .action = create_model_package_group };
        }
    },
    Response: type = struct {
        model_package_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_arn = "ModelPackageGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_model_quality_job_definition: struct {
    action_name: []const u8 = "CreateModelQualityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,
        model_quality_baseline_config: ?ModelQualityBaselineConfig = null,
        model_quality_app_specification: ModelQualityAppSpecification,
        model_quality_job_input: ModelQualityJobInput,
        model_quality_job_output_config: MonitoringOutputConfig,
        job_resources: MonitoringResources,
        network_config: ?MonitoringNetworkConfig = null,
        role_arn: []const u8,
        stopping_condition: ?MonitoringStoppingCondition = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
                .model_quality_baseline_config = "ModelQualityBaselineConfig",
                .model_quality_app_specification = "ModelQualityAppSpecification",
                .model_quality_job_input = "ModelQualityJobInput",
                .model_quality_job_output_config = "ModelQualityJobOutputConfig",
                .job_resources = "JobResources",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .stopping_condition = "StoppingCondition",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model_quality_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_model_quality_job_definition };
        }
    },
    Response: type = struct {
        job_definition_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_arn = "JobDefinitionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_monitoring_schedule: struct {
    action_name: []const u8 = "CreateMonitoringSchedule",
    Request: type = struct {
        monitoring_schedule_name: []const u8,
        monitoring_schedule_config: MonitoringScheduleConfig,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_name = "MonitoringScheduleName",
                .monitoring_schedule_config = "MonitoringScheduleConfig",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_monitoring_schedule) } {
            return .{ .service_metadata = service_metadata, .action = create_monitoring_schedule };
        }
    },
    Response: type = struct {
        monitoring_schedule_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_arn = "MonitoringScheduleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_notebook_instance: struct {
    action_name: []const u8 = "CreateNotebookInstance",
    Request: type = struct {
        notebook_instance_name: []const u8,
        instance_type: []const u8,
        subnet_id: ?[]const u8 = null,
        security_group_ids: ?[][]const u8 = null,
        role_arn: []const u8,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,
        lifecycle_config_name: ?[]const u8 = null,
        direct_internet_access: ?[]const u8 = null,
        volume_size_in_gb: ?i64 = null,
        accelerator_types: ?[][]const u8 = null,
        default_code_repository: ?[]const u8 = null,
        additional_code_repositories: ?[][]const u8 = null,
        root_access: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_name = "NotebookInstanceName",
                .instance_type = "InstanceType",
                .subnet_id = "SubnetId",
                .security_group_ids = "SecurityGroupIds",
                .role_arn = "RoleArn",
                .kms_key_id = "KmsKeyId",
                .tags = "Tags",
                .lifecycle_config_name = "LifecycleConfigName",
                .direct_internet_access = "DirectInternetAccess",
                .volume_size_in_gb = "VolumeSizeInGB",
                .accelerator_types = "AcceleratorTypes",
                .default_code_repository = "DefaultCodeRepository",
                .additional_code_repositories = "AdditionalCodeRepositories",
                .root_access = "RootAccess",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_notebook_instance) } {
            return .{ .service_metadata = service_metadata, .action = create_notebook_instance };
        }
    },
    Response: type = struct {
        notebook_instance_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_arn = "NotebookInstanceArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_notebook_instance_lifecycle_config: struct {
    action_name: []const u8 = "CreateNotebookInstanceLifecycleConfig",
    Request: type = struct {
        notebook_instance_lifecycle_config_name: []const u8,
        on_create: ?[]NotebookInstanceLifecycleHook = null,
        on_start: ?[]NotebookInstanceLifecycleHook = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
                .on_create = "OnCreate",
                .on_start = "OnStart",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_notebook_instance_lifecycle_config) } {
            return .{ .service_metadata = service_metadata, .action = create_notebook_instance_lifecycle_config };
        }
    },
    Response: type = struct {
        notebook_instance_lifecycle_config_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_lifecycle_config_arn = "NotebookInstanceLifecycleConfigArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_pipeline: struct {
    action_name: []const u8 = "CreatePipeline",
    Request: type = struct {
        pipeline_name: []const u8,
        pipeline_display_name: ?[]const u8 = null,
        pipeline_definition: []const u8,
        pipeline_description: ?[]const u8 = null,
        client_request_token: []const u8,
        role_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
                .pipeline_display_name = "PipelineDisplayName",
                .pipeline_definition = "PipelineDefinition",
                .pipeline_description = "PipelineDescription",
                .client_request_token = "ClientRequestToken",
                .role_arn = "RoleArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_pipeline };
        }
    },
    Response: type = struct {
        pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_arn = "PipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_presigned_domain_url: struct {
    action_name: []const u8 = "CreatePresignedDomainUrl",
    Request: type = struct {
        domain_id: []const u8,
        user_profile_name: []const u8,
        session_expiration_duration_in_seconds: ?i64 = null,
        expires_in_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
                .session_expiration_duration_in_seconds = "SessionExpirationDurationInSeconds",
                .expires_in_seconds = "ExpiresInSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_presigned_domain_url) } {
            return .{ .service_metadata = service_metadata, .action = create_presigned_domain_url };
        }
    },
    Response: type = struct {
        authorized_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorized_url = "AuthorizedUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const create_presigned_notebook_instance_url: struct {
    action_name: []const u8 = "CreatePresignedNotebookInstanceUrl",
    Request: type = struct {
        notebook_instance_name: []const u8,
        session_expiration_duration_in_seconds: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_name = "NotebookInstanceName",
                .session_expiration_duration_in_seconds = "SessionExpirationDurationInSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_presigned_notebook_instance_url) } {
            return .{ .service_metadata = service_metadata, .action = create_presigned_notebook_instance_url };
        }
    },
    Response: type = struct {
        authorized_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .authorized_url = "AuthorizedUrl",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_processing_job: struct {
    action_name: []const u8 = "CreateProcessingJob",
    Request: type = struct {
        processing_inputs: ?[]ProcessingInput = null,
        processing_output_config: ?ProcessingOutputConfig = null,
        processing_job_name: []const u8,
        processing_resources: ProcessingResources,
        stopping_condition: ?ProcessingStoppingCondition = null,
        app_specification: AppSpecification,
        environment: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        network_config: ?NetworkConfig = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        experiment_config: ?ExperimentConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processing_inputs = "ProcessingInputs",
                .processing_output_config = "ProcessingOutputConfig",
                .processing_job_name = "ProcessingJobName",
                .processing_resources = "ProcessingResources",
                .stopping_condition = "StoppingCondition",
                .app_specification = "AppSpecification",
                .environment = "Environment",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .experiment_config = "ExperimentConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment", field_name))
                return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_processing_job) } {
            return .{ .service_metadata = service_metadata, .action = create_processing_job };
        }
    },
    Response: type = struct {
        processing_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processing_job_arn = "ProcessingJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_project: struct {
    action_name: []const u8 = "CreateProject",
    Request: type = struct {
        project_name: []const u8,
        project_description: ?[]const u8 = null,
        service_catalog_provisioning_details: ServiceCatalogProvisioningDetails,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
                .project_description = "ProjectDescription",
                .service_catalog_provisioning_details = "ServiceCatalogProvisioningDetails",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_project) } {
            return .{ .service_metadata = service_metadata, .action = create_project };
        }
    },
    Response: type = struct {
        project_arn: []const u8,
        project_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .project_id = "ProjectId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_training_job: struct {
    action_name: []const u8 = "CreateTrainingJob",
    Request: type = struct {
        training_job_name: []const u8,
        hyper_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        algorithm_specification: AlgorithmSpecification,
        role_arn: []const u8,
        input_data_config: ?[]Channel = null,
        output_data_config: OutputDataConfig,
        resource_config: ResourceConfig,
        vpc_config: ?VpcConfig = null,
        stopping_condition: StoppingCondition,
        tags: ?[]Tag = null,
        enable_network_isolation: ?bool = null,
        enable_inter_container_traffic_encryption: ?bool = null,
        enable_managed_spot_training: ?bool = null,
        checkpoint_config: ?CheckpointConfig = null,
        debug_hook_config: ?DebugHookConfig = null,
        debug_rule_configurations: ?[]DebugRuleConfiguration = null,
        tensor_board_output_config: ?TensorBoardOutputConfig = null,
        experiment_config: ?ExperimentConfig = null,
        profiler_config: ?ProfilerConfig = null,
        profiler_rule_configurations: ?[]ProfilerRuleConfiguration = null,
        environment: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        retry_strategy: ?RetryStrategy = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_name = "TrainingJobName",
                .hyper_parameters = "HyperParameters",
                .algorithm_specification = "AlgorithmSpecification",
                .role_arn = "RoleArn",
                .input_data_config = "InputDataConfig",
                .output_data_config = "OutputDataConfig",
                .resource_config = "ResourceConfig",
                .vpc_config = "VpcConfig",
                .stopping_condition = "StoppingCondition",
                .tags = "Tags",
                .enable_network_isolation = "EnableNetworkIsolation",
                .enable_inter_container_traffic_encryption = "EnableInterContainerTrafficEncryption",
                .enable_managed_spot_training = "EnableManagedSpotTraining",
                .checkpoint_config = "CheckpointConfig",
                .debug_hook_config = "DebugHookConfig",
                .debug_rule_configurations = "DebugRuleConfigurations",
                .tensor_board_output_config = "TensorBoardOutputConfig",
                .experiment_config = "ExperimentConfig",
                .profiler_config = "ProfilerConfig",
                .profiler_rule_configurations = "ProfilerRuleConfigurations",
                .environment = "Environment",
                .retry_strategy = "RetryStrategy",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "hyper_parameters", field_name))
                return try serializeMap(self.hyper_parameters, self.fieldNameFor("hyper_parameters"), options, out_stream);
            if (std.mem.eql(u8, "environment", field_name))
                return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_training_job) } {
            return .{ .service_metadata = service_metadata, .action = create_training_job };
        }
    },
    Response: type = struct {
        training_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_arn = "TrainingJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_transform_job: struct {
    action_name: []const u8 = "CreateTransformJob",
    Request: type = struct {
        transform_job_name: []const u8,
        model_name: []const u8,
        max_concurrent_transforms: ?i64 = null,
        model_client_config: ?ModelClientConfig = null,
        max_payload_in_mb: ?i64 = null,
        batch_strategy: ?[]const u8 = null,
        environment: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        transform_input: TransformInput,
        transform_output: TransformOutput,
        transform_resources: TransformResources,
        data_processing: ?DataProcessing = null,
        tags: ?[]Tag = null,
        experiment_config: ?ExperimentConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_job_name = "TransformJobName",
                .model_name = "ModelName",
                .max_concurrent_transforms = "MaxConcurrentTransforms",
                .model_client_config = "ModelClientConfig",
                .max_payload_in_mb = "MaxPayloadInMB",
                .batch_strategy = "BatchStrategy",
                .environment = "Environment",
                .transform_input = "TransformInput",
                .transform_output = "TransformOutput",
                .transform_resources = "TransformResources",
                .data_processing = "DataProcessing",
                .tags = "Tags",
                .experiment_config = "ExperimentConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment", field_name))
                return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_transform_job) } {
            return .{ .service_metadata = service_metadata, .action = create_transform_job };
        }
    },
    Response: type = struct {
        transform_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_job_arn = "TransformJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_trial: struct {
    action_name: []const u8 = "CreateTrial",
    Request: type = struct {
        trial_name: []const u8,
        display_name: ?[]const u8 = null,
        experiment_name: []const u8,
        metadata_properties: ?MetadataProperties = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_name = "TrialName",
                .display_name = "DisplayName",
                .experiment_name = "ExperimentName",
                .metadata_properties = "MetadataProperties",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trial) } {
            return .{ .service_metadata = service_metadata, .action = create_trial };
        }
    },
    Response: type = struct {
        trial_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_arn = "TrialArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_trial_component: struct {
    action_name: []const u8 = "CreateTrialComponent",
    Request: type = struct {
        trial_component_name: []const u8,
        display_name: ?[]const u8 = null,
        status: ?TrialComponentStatus = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentParameterValue = null,
        } = null,
        input_artifacts: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentArtifact = null,
        } = null,
        output_artifacts: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentArtifact = null,
        } = null,
        metadata_properties: ?MetadataProperties = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_name = "TrialComponentName",
                .display_name = "DisplayName",
                .status = "Status",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .parameters = "Parameters",
                .input_artifacts = "InputArtifacts",
                .output_artifacts = "OutputArtifacts",
                .metadata_properties = "MetadataProperties",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "input_artifacts", field_name))
                return try serializeMap(self.input_artifacts, self.fieldNameFor("input_artifacts"), options, out_stream);
            if (std.mem.eql(u8, "output_artifacts", field_name))
                return try serializeMap(self.output_artifacts, self.fieldNameFor("output_artifacts"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trial_component) } {
            return .{ .service_metadata = service_metadata, .action = create_trial_component };
        }
    },
    Response: type = struct {
        trial_component_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_arn = "TrialComponentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const create_user_profile: struct {
    action_name: []const u8 = "CreateUserProfile",
    Request: type = struct {
        domain_id: []const u8,
        user_profile_name: []const u8,
        single_sign_on_user_identifier: ?[]const u8 = null,
        single_sign_on_user_value: ?[]const u8 = null,
        tags: ?[]Tag = null,
        user_settings: ?UserSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
                .single_sign_on_user_identifier = "SingleSignOnUserIdentifier",
                .single_sign_on_user_value = "SingleSignOnUserValue",
                .tags = "Tags",
                .user_settings = "UserSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_user_profile };
        }
    },
    Response: type = struct {
        user_profile_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_profile_arn = "UserProfileArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_workforce: struct {
    action_name: []const u8 = "CreateWorkforce",
    Request: type = struct {
        cognito_config: ?CognitoConfig = null,
        oidc_config: ?OidcConfig = null,
        source_ip_config: ?SourceIpConfig = null,
        workforce_name: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .cognito_config = "CognitoConfig",
                .oidc_config = "OidcConfig",
                .source_ip_config = "SourceIpConfig",
                .workforce_name = "WorkforceName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workforce) } {
            return .{ .service_metadata = service_metadata, .action = create_workforce };
        }
    },
    Response: type = struct {
        workforce_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workforce_arn = "WorkforceArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const create_workteam: struct {
    action_name: []const u8 = "CreateWorkteam",
    Request: type = struct {
        workteam_name: []const u8,
        workforce_name: ?[]const u8 = null,
        member_definitions: []MemberDefinition,
        description: []const u8,
        notification_configuration: ?NotificationConfiguration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam_name = "WorkteamName",
                .workforce_name = "WorkforceName",
                .member_definitions = "MemberDefinitions",
                .description = "Description",
                .notification_configuration = "NotificationConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workteam) } {
            return .{ .service_metadata = service_metadata, .action = create_workteam };
        }
    },
    Response: type = struct {
        workteam_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam_arn = "WorkteamArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
    },
} = .{};
pub const delete_action: struct {
    action_name: []const u8 = "DeleteAction",
    Request: type = struct {
        action_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "ActionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_action) } {
            return .{ .service_metadata = service_metadata, .action = delete_action };
        }
    },
    Response: type = struct {
        action_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_arn = "ActionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_algorithm: struct {
    action_name: []const u8 = "DeleteAlgorithm",
    Request: type = struct {
        algorithm_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .algorithm_name = "AlgorithmName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_algorithm) } {
            return .{ .service_metadata = service_metadata, .action = delete_algorithm };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_app: struct {
    action_name: []const u8 = "DeleteApp",
    Request: type = struct {
        domain_id: []const u8,
        user_profile_name: []const u8,
        app_type: []const u8,
        app_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
                .app_type = "AppType",
                .app_name = "AppName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app) } {
            return .{ .service_metadata = service_metadata, .action = delete_app };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_app_image_config: struct {
    action_name: []const u8 = "DeleteAppImageConfig",
    Request: type = struct {
        app_image_config_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_image_config_name = "AppImageConfigName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_app_image_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_app_image_config };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_artifact: struct {
    action_name: []const u8 = "DeleteArtifact",
    Request: type = struct {
        artifact_arn: ?[]const u8 = null,
        source: ?ArtifactSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_arn = "ArtifactArn",
                .source = "Source",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_artifact) } {
            return .{ .service_metadata = service_metadata, .action = delete_artifact };
        }
    },
    Response: type = struct {
        artifact_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_arn = "ArtifactArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_association: struct {
    action_name: []const u8 = "DeleteAssociation",
    Request: type = struct {
        source_arn: []const u8,
        destination_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_arn = "SourceArn",
                .destination_arn = "DestinationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_association) } {
            return .{ .service_metadata = service_metadata, .action = delete_association };
        }
    },
    Response: type = struct {
        source_arn: ?[]const u8 = null,
        destination_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_arn = "SourceArn",
                .destination_arn = "DestinationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_code_repository: struct {
    action_name: []const u8 = "DeleteCodeRepository",
    Request: type = struct {
        code_repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_repository_name = "CodeRepositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_code_repository) } {
            return .{ .service_metadata = service_metadata, .action = delete_code_repository };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_context: struct {
    action_name: []const u8 = "DeleteContext",
    Request: type = struct {
        context_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_name = "ContextName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_context) } {
            return .{ .service_metadata = service_metadata, .action = delete_context };
        }
    },
    Response: type = struct {
        context_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_arn = "ContextArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_data_quality_job_definition: struct {
    action_name: []const u8 = "DeleteDataQualityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_quality_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_quality_job_definition };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_device_fleet: struct {
    action_name: []const u8 = "DeleteDeviceFleet",
    Request: type = struct {
        device_fleet_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device_fleet) } {
            return .{ .service_metadata = service_metadata, .action = delete_device_fleet };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceInUse,
    },
} = .{};
pub const delete_domain: struct {
    action_name: []const u8 = "DeleteDomain",
    Request: type = struct {
        domain_id: []const u8,
        retention_policy: ?struct {
            home_efs_file_system: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .home_efs_file_system = "HomeEfsFileSystem",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .retention_policy = "RetentionPolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_endpoint: struct {
    action_name: []const u8 = "DeleteEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_endpoint_config: struct {
    action_name: []const u8 = "DeleteEndpointConfig",
    Request: type = struct {
        endpoint_config_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_config_name = "EndpointConfigName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_endpoint_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_endpoint_config };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_experiment: struct {
    action_name: []const u8 = "DeleteExperiment",
    Request: type = struct {
        experiment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_name = "ExperimentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_experiment) } {
            return .{ .service_metadata = service_metadata, .action = delete_experiment };
        }
    },
    Response: type = struct {
        experiment_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_arn = "ExperimentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_feature_group: struct {
    action_name: []const u8 = "DeleteFeatureGroup",
    Request: type = struct {
        feature_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_feature_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_feature_group };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_flow_definition: struct {
    action_name: []const u8 = "DeleteFlowDefinition",
    Request: type = struct {
        flow_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_definition_name = "FlowDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_flow_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_flow_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_human_task_ui: struct {
    action_name: []const u8 = "DeleteHumanTaskUi",
    Request: type = struct {
        human_task_ui_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_task_ui_name = "HumanTaskUiName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_human_task_ui) } {
            return .{ .service_metadata = service_metadata, .action = delete_human_task_ui };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_image: struct {
    action_name: []const u8 = "DeleteImage",
    Request: type = struct {
        image_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_name = "ImageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image) } {
            return .{ .service_metadata = service_metadata, .action = delete_image };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_image_version: struct {
    action_name: []const u8 = "DeleteImageVersion",
    Request: type = struct {
        image_name: []const u8,
        version: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_name = "ImageName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_image_version };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_model: struct {
    action_name: []const u8 = "DeleteModel",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_model };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_model_bias_job_definition: struct {
    action_name: []const u8 = "DeleteModelBiasJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model_bias_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_model_bias_job_definition };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_model_explainability_job_definition: struct {
    action_name: []const u8 = "DeleteModelExplainabilityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model_explainability_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_model_explainability_job_definition };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_model_package: struct {
    action_name: []const u8 = "DeleteModelPackage",
    Request: type = struct {
        model_package_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_name = "ModelPackageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model_package) } {
            return .{ .service_metadata = service_metadata, .action = delete_model_package };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
    },
} = .{};
pub const delete_model_package_group: struct {
    action_name: []const u8 = "DeleteModelPackageGroup",
    Request: type = struct {
        model_package_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_name = "ModelPackageGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model_package_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_model_package_group };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_model_package_group_policy: struct {
    action_name: []const u8 = "DeleteModelPackageGroupPolicy",
    Request: type = struct {
        model_package_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_name = "ModelPackageGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model_package_group_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_model_package_group_policy };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_model_quality_job_definition: struct {
    action_name: []const u8 = "DeleteModelQualityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model_quality_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_model_quality_job_definition };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_monitoring_schedule: struct {
    action_name: []const u8 = "DeleteMonitoringSchedule",
    Request: type = struct {
        monitoring_schedule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_name = "MonitoringScheduleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_monitoring_schedule) } {
            return .{ .service_metadata = service_metadata, .action = delete_monitoring_schedule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_notebook_instance: struct {
    action_name: []const u8 = "DeleteNotebookInstance",
    Request: type = struct {
        notebook_instance_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_name = "NotebookInstanceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_notebook_instance) } {
            return .{ .service_metadata = service_metadata, .action = delete_notebook_instance };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_notebook_instance_lifecycle_config: struct {
    action_name: []const u8 = "DeleteNotebookInstanceLifecycleConfig",
    Request: type = struct {
        notebook_instance_lifecycle_config_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_notebook_instance_lifecycle_config) } {
            return .{ .service_metadata = service_metadata, .action = delete_notebook_instance_lifecycle_config };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_pipeline: struct {
    action_name: []const u8 = "DeletePipeline",
    Request: type = struct {
        pipeline_name: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_pipeline };
        }
    },
    Response: type = struct {
        pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_arn = "PipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_project: struct {
    action_name: []const u8 = "DeleteProject",
    Request: type = struct {
        project_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_project) } {
            return .{ .service_metadata = service_metadata, .action = delete_project };
        }
    },
    Response: type = struct {},
} = .{};
pub const delete_tags: struct {
    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_trial: struct {
    action_name: []const u8 = "DeleteTrial",
    Request: type = struct {
        trial_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_name = "TrialName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trial) } {
            return .{ .service_metadata = service_metadata, .action = delete_trial };
        }
    },
    Response: type = struct {
        trial_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_arn = "TrialArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_trial_component: struct {
    action_name: []const u8 = "DeleteTrialComponent",
    Request: type = struct {
        trial_component_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_name = "TrialComponentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trial_component) } {
            return .{ .service_metadata = service_metadata, .action = delete_trial_component };
        }
    },
    Response: type = struct {
        trial_component_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_arn = "TrialComponentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_user_profile: struct {
    action_name: []const u8 = "DeleteUserProfile",
    Request: type = struct {
        domain_id: []const u8,
        user_profile_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_profile };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const delete_workforce: struct {
    action_name: []const u8 = "DeleteWorkforce",
    Request: type = struct {
        workforce_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workforce_name = "WorkforceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workforce) } {
            return .{ .service_metadata = service_metadata, .action = delete_workforce };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const delete_workteam: struct {
    action_name: []const u8 = "DeleteWorkteam",
    Request: type = struct {
        workteam_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam_name = "WorkteamName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workteam) } {
            return .{ .service_metadata = service_metadata, .action = delete_workteam };
        }
    },
    Response: type = struct {
        success: bool,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .success = "Success",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const deregister_devices: struct {
    action_name: []const u8 = "DeregisterDevices",
    Request: type = struct {
        device_fleet_name: []const u8,
        device_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
                .device_names = "DeviceNames",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_devices) } {
            return .{ .service_metadata = service_metadata, .action = deregister_devices };
        }
    },
    Response: type = struct {},
} = .{};
pub const describe_action: struct {
    action_name: []const u8 = "DescribeAction",
    Request: type = struct {
        action_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "ActionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_action) } {
            return .{ .service_metadata = service_metadata, .action = describe_action };
        }
    },
    Response: type = struct {
        action_name: ?[]const u8 = null,
        action_arn: ?[]const u8 = null,
        source: ?ActionSource = null,
        action_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        creation_time: ?i64 = null,
        created_by: ?UserContext = null,
        last_modified_time: ?i64 = null,
        last_modified_by: ?UserContext = null,
        metadata_properties: ?MetadataProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "ActionName",
                .action_arn = "ActionArn",
                .source = "Source",
                .action_type = "ActionType",
                .description = "Description",
                .status = "Status",
                .properties = "Properties",
                .creation_time = "CreationTime",
                .created_by = "CreatedBy",
                .last_modified_time = "LastModifiedTime",
                .last_modified_by = "LastModifiedBy",
                .metadata_properties = "MetadataProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_algorithm: struct {
    action_name: []const u8 = "DescribeAlgorithm",
    Request: type = struct {
        algorithm_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .algorithm_name = "AlgorithmName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_algorithm) } {
            return .{ .service_metadata = service_metadata, .action = describe_algorithm };
        }
    },
    Response: type = struct {
        algorithm_name: []const u8,
        algorithm_arn: []const u8,
        algorithm_description: ?[]const u8 = null,
        creation_time: i64,
        training_specification: TrainingSpecification,
        inference_specification: ?InferenceSpecification = null,
        validation_specification: ?AlgorithmValidationSpecification = null,
        algorithm_status: []const u8,
        algorithm_status_details: struct {
            validation_statuses: ?[]AlgorithmStatusItem = null,
            image_scan_statuses: ?[]AlgorithmStatusItem = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .validation_statuses = "ValidationStatuses",
                    .image_scan_statuses = "ImageScanStatuses",
                };
                return @field(mappings, field_name);
            }
        },
        product_id: ?[]const u8 = null,
        certify_for_marketplace: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .algorithm_name = "AlgorithmName",
                .algorithm_arn = "AlgorithmArn",
                .algorithm_description = "AlgorithmDescription",
                .creation_time = "CreationTime",
                .training_specification = "TrainingSpecification",
                .inference_specification = "InferenceSpecification",
                .validation_specification = "ValidationSpecification",
                .algorithm_status = "AlgorithmStatus",
                .algorithm_status_details = "AlgorithmStatusDetails",
                .product_id = "ProductId",
                .certify_for_marketplace = "CertifyForMarketplace",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_app: struct {
    action_name: []const u8 = "DescribeApp",
    Request: type = struct {
        domain_id: []const u8,
        user_profile_name: []const u8,
        app_type: []const u8,
        app_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
                .app_type = "AppType",
                .app_name = "AppName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app) } {
            return .{ .service_metadata = service_metadata, .action = describe_app };
        }
    },
    Response: type = struct {
        app_arn: ?[]const u8 = null,
        app_type: ?[]const u8 = null,
        app_name: ?[]const u8 = null,
        domain_id: ?[]const u8 = null,
        user_profile_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_health_check_timestamp: ?i64 = null,
        last_user_activity_timestamp: ?i64 = null,
        creation_time: ?i64 = null,
        failure_reason: ?[]const u8 = null,
        resource_spec: ?ResourceSpec = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_arn = "AppArn",
                .app_type = "AppType",
                .app_name = "AppName",
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
                .status = "Status",
                .last_health_check_timestamp = "LastHealthCheckTimestamp",
                .last_user_activity_timestamp = "LastUserActivityTimestamp",
                .creation_time = "CreationTime",
                .failure_reason = "FailureReason",
                .resource_spec = "ResourceSpec",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_app_image_config: struct {
    action_name: []const u8 = "DescribeAppImageConfig",
    Request: type = struct {
        app_image_config_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_image_config_name = "AppImageConfigName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_app_image_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_app_image_config };
        }
    },
    Response: type = struct {
        app_image_config_arn: ?[]const u8 = null,
        app_image_config_name: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        kernel_gateway_image_config: ?KernelGatewayImageConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_image_config_arn = "AppImageConfigArn",
                .app_image_config_name = "AppImageConfigName",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .kernel_gateway_image_config = "KernelGatewayImageConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_artifact: struct {
    action_name: []const u8 = "DescribeArtifact",
    Request: type = struct {
        artifact_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_arn = "ArtifactArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_artifact) } {
            return .{ .service_metadata = service_metadata, .action = describe_artifact };
        }
    },
    Response: type = struct {
        artifact_name: ?[]const u8 = null,
        artifact_arn: ?[]const u8 = null,
        source: ?ArtifactSource = null,
        artifact_type: ?[]const u8 = null,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        creation_time: ?i64 = null,
        created_by: ?UserContext = null,
        last_modified_time: ?i64 = null,
        last_modified_by: ?UserContext = null,
        metadata_properties: ?MetadataProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_name = "ArtifactName",
                .artifact_arn = "ArtifactArn",
                .source = "Source",
                .artifact_type = "ArtifactType",
                .properties = "Properties",
                .creation_time = "CreationTime",
                .created_by = "CreatedBy",
                .last_modified_time = "LastModifiedTime",
                .last_modified_by = "LastModifiedBy",
                .metadata_properties = "MetadataProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_auto_ml_job: struct {
    action_name: []const u8 = "DescribeAutoMLJob",
    Request: type = struct {
        auto_ml_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_ml_job_name = "AutoMLJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_auto_ml_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_auto_ml_job };
        }
    },
    Response: type = struct {
        auto_ml_job_name: []const u8,
        auto_ml_job_arn: []const u8,
        input_data_config: []AutoMLChannel,
        output_data_config: AutoMLOutputDataConfig,
        role_arn: []const u8,
        auto_ml_job_objective: ?AutoMLJobObjective = null,
        problem_type: ?[]const u8 = null,
        auto_ml_job_config: ?AutoMLJobConfig = null,
        creation_time: i64,
        end_time: ?i64 = null,
        last_modified_time: i64,
        failure_reason: ?[]const u8 = null,
        partial_failure_reasons: ?[]AutoMLPartialFailureReason = null,
        best_candidate: ?AutoMLCandidate = null,
        auto_ml_job_status: []const u8,
        auto_ml_job_secondary_status: []const u8,
        generate_candidate_definitions_only: ?bool = null,
        auto_ml_job_artifacts: ?struct {
            candidate_definition_notebook_location: ?[]const u8 = null,
            data_exploration_notebook_location: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .candidate_definition_notebook_location = "CandidateDefinitionNotebookLocation",
                    .data_exploration_notebook_location = "DataExplorationNotebookLocation",
                };
                return @field(mappings, field_name);
            }
        } = null,
        resolved_attributes: ?struct {
            auto_ml_job_objective: ?AutoMLJobObjective = null,
            problem_type: ?[]const u8 = null,
            completion_criteria: ?AutoMLJobCompletionCriteria = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_ml_job_objective = "AutoMLJobObjective",
                    .problem_type = "ProblemType",
                    .completion_criteria = "CompletionCriteria",
                };
                return @field(mappings, field_name);
            }
        } = null,
        model_deploy_config: ?ModelDeployConfig = null,
        model_deploy_result: ?struct {
            endpoint_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint_name = "EndpointName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_ml_job_name = "AutoMLJobName",
                .auto_ml_job_arn = "AutoMLJobArn",
                .input_data_config = "InputDataConfig",
                .output_data_config = "OutputDataConfig",
                .role_arn = "RoleArn",
                .auto_ml_job_objective = "AutoMLJobObjective",
                .problem_type = "ProblemType",
                .auto_ml_job_config = "AutoMLJobConfig",
                .creation_time = "CreationTime",
                .end_time = "EndTime",
                .last_modified_time = "LastModifiedTime",
                .failure_reason = "FailureReason",
                .partial_failure_reasons = "PartialFailureReasons",
                .best_candidate = "BestCandidate",
                .auto_ml_job_status = "AutoMLJobStatus",
                .auto_ml_job_secondary_status = "AutoMLJobSecondaryStatus",
                .generate_candidate_definitions_only = "GenerateCandidateDefinitionsOnly",
                .auto_ml_job_artifacts = "AutoMLJobArtifacts",
                .resolved_attributes = "ResolvedAttributes",
                .model_deploy_config = "ModelDeployConfig",
                .model_deploy_result = "ModelDeployResult",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_code_repository: struct {
    action_name: []const u8 = "DescribeCodeRepository",
    Request: type = struct {
        code_repository_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_repository_name = "CodeRepositoryName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_code_repository) } {
            return .{ .service_metadata = service_metadata, .action = describe_code_repository };
        }
    },
    Response: type = struct {
        code_repository_name: []const u8,
        code_repository_arn: []const u8,
        creation_time: i64,
        last_modified_time: i64,
        git_config: ?GitConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_repository_name = "CodeRepositoryName",
                .code_repository_arn = "CodeRepositoryArn",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .git_config = "GitConfig",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_compilation_job: struct {
    action_name: []const u8 = "DescribeCompilationJob",
    Request: type = struct {
        compilation_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compilation_job_name = "CompilationJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_compilation_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_compilation_job };
        }
    },
    Response: type = struct {
        compilation_job_name: []const u8,
        compilation_job_arn: []const u8,
        compilation_job_status: []const u8,
        compilation_start_time: ?i64 = null,
        compilation_end_time: ?i64 = null,
        stopping_condition: StoppingCondition,
        creation_time: i64,
        last_modified_time: i64,
        failure_reason: []const u8,
        model_artifacts: ModelArtifacts,
        model_digests: ?struct {
            artifact_digest: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .artifact_digest = "ArtifactDigest",
                };
                return @field(mappings, field_name);
            }
        } = null,
        role_arn: []const u8,
        input_config: InputConfig,
        output_config: OutputConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compilation_job_name = "CompilationJobName",
                .compilation_job_arn = "CompilationJobArn",
                .compilation_job_status = "CompilationJobStatus",
                .compilation_start_time = "CompilationStartTime",
                .compilation_end_time = "CompilationEndTime",
                .stopping_condition = "StoppingCondition",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .failure_reason = "FailureReason",
                .model_artifacts = "ModelArtifacts",
                .model_digests = "ModelDigests",
                .role_arn = "RoleArn",
                .input_config = "InputConfig",
                .output_config = "OutputConfig",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_context: struct {
    action_name: []const u8 = "DescribeContext",
    Request: type = struct {
        context_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_name = "ContextName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_context) } {
            return .{ .service_metadata = service_metadata, .action = describe_context };
        }
    },
    Response: type = struct {
        context_name: ?[]const u8 = null,
        context_arn: ?[]const u8 = null,
        source: ?ContextSource = null,
        context_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        creation_time: ?i64 = null,
        created_by: ?UserContext = null,
        last_modified_time: ?i64 = null,
        last_modified_by: ?UserContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_name = "ContextName",
                .context_arn = "ContextArn",
                .source = "Source",
                .context_type = "ContextType",
                .description = "Description",
                .properties = "Properties",
                .creation_time = "CreationTime",
                .created_by = "CreatedBy",
                .last_modified_time = "LastModifiedTime",
                .last_modified_by = "LastModifiedBy",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_data_quality_job_definition: struct {
    action_name: []const u8 = "DescribeDataQualityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_quality_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_quality_job_definition };
        }
    },
    Response: type = struct {
        job_definition_arn: []const u8,
        job_definition_name: []const u8,
        creation_time: i64,
        data_quality_baseline_config: ?DataQualityBaselineConfig = null,
        data_quality_app_specification: DataQualityAppSpecification,
        data_quality_job_input: DataQualityJobInput,
        data_quality_job_output_config: MonitoringOutputConfig,
        job_resources: MonitoringResources,
        network_config: ?MonitoringNetworkConfig = null,
        role_arn: []const u8,
        stopping_condition: ?MonitoringStoppingCondition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_arn = "JobDefinitionArn",
                .job_definition_name = "JobDefinitionName",
                .creation_time = "CreationTime",
                .data_quality_baseline_config = "DataQualityBaselineConfig",
                .data_quality_app_specification = "DataQualityAppSpecification",
                .data_quality_job_input = "DataQualityJobInput",
                .data_quality_job_output_config = "DataQualityJobOutputConfig",
                .job_resources = "JobResources",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .stopping_condition = "StoppingCondition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_device: struct {
    action_name: []const u8 = "DescribeDevice",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        device_name: []const u8,
        device_fleet_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .device_name = "DeviceName",
                .device_fleet_name = "DeviceFleetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_device) } {
            return .{ .service_metadata = service_metadata, .action = describe_device };
        }
    },
    Response: type = struct {
        device_arn: ?[]const u8 = null,
        device_name: []const u8,
        description: ?[]const u8 = null,
        device_fleet_name: []const u8,
        iot_thing_name: ?[]const u8 = null,
        registration_time: i64,
        latest_heartbeat: ?i64 = null,
        models: ?[]struct {
            model_name: []const u8,
            model_version: []const u8,
            latest_sample_time: ?i64 = null,
            latest_inference: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_version = "ModelVersion",
                    .latest_sample_time = "LatestSampleTime",
                    .latest_inference = "LatestInference",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_models: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_arn = "DeviceArn",
                .device_name = "DeviceName",
                .description = "Description",
                .device_fleet_name = "DeviceFleetName",
                .iot_thing_name = "IotThingName",
                .registration_time = "RegistrationTime",
                .latest_heartbeat = "LatestHeartbeat",
                .models = "Models",
                .max_models = "MaxModels",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_device_fleet: struct {
    action_name: []const u8 = "DescribeDeviceFleet",
    Request: type = struct {
        device_fleet_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_device_fleet) } {
            return .{ .service_metadata = service_metadata, .action = describe_device_fleet };
        }
    },
    Response: type = struct {
        device_fleet_name: []const u8,
        device_fleet_arn: []const u8,
        output_config: EdgeOutputConfig,
        description: ?[]const u8 = null,
        creation_time: i64,
        last_modified_time: i64,
        role_arn: ?[]const u8 = null,
        iot_role_alias: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
                .device_fleet_arn = "DeviceFleetArn",
                .output_config = "OutputConfig",
                .description = "Description",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .role_arn = "RoleArn",
                .iot_role_alias = "IotRoleAlias",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_domain: struct {
    action_name: []const u8 = "DescribeDomain",
    Request: type = struct {
        domain_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_domain) } {
            return .{ .service_metadata = service_metadata, .action = describe_domain };
        }
    },
    Response: type = struct {
        domain_arn: ?[]const u8 = null,
        domain_id: ?[]const u8 = null,
        domain_name: ?[]const u8 = null,
        home_efs_file_system_id: ?[]const u8 = null,
        single_sign_on_managed_application_instance_id: ?[]const u8 = null,
        status: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        failure_reason: ?[]const u8 = null,
        auth_mode: ?[]const u8 = null,
        default_user_settings: ?UserSettings = null,
        app_network_access_type: ?[]const u8 = null,
        home_efs_file_system_kms_key_id: ?[]const u8 = null,
        subnet_ids: ?[][]const u8 = null,
        url: ?[]const u8 = null,
        vpc_id: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_arn = "DomainArn",
                .domain_id = "DomainId",
                .domain_name = "DomainName",
                .home_efs_file_system_id = "HomeEfsFileSystemId",
                .single_sign_on_managed_application_instance_id = "SingleSignOnManagedApplicationInstanceId",
                .status = "Status",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .failure_reason = "FailureReason",
                .auth_mode = "AuthMode",
                .default_user_settings = "DefaultUserSettings",
                .app_network_access_type = "AppNetworkAccessType",
                .home_efs_file_system_kms_key_id = "HomeEfsFileSystemKmsKeyId",
                .subnet_ids = "SubnetIds",
                .url = "Url",
                .vpc_id = "VpcId",
                .kms_key_id = "KmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_edge_packaging_job: struct {
    action_name: []const u8 = "DescribeEdgePackagingJob",
    Request: type = struct {
        edge_packaging_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .edge_packaging_job_name = "EdgePackagingJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_edge_packaging_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_edge_packaging_job };
        }
    },
    Response: type = struct {
        edge_packaging_job_arn: []const u8,
        edge_packaging_job_name: []const u8,
        compilation_job_name: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        model_version: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        output_config: ?EdgeOutputConfig = null,
        resource_key: ?[]const u8 = null,
        edge_packaging_job_status: []const u8,
        edge_packaging_job_status_message: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        model_artifact: ?[]const u8 = null,
        model_signature: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .edge_packaging_job_arn = "EdgePackagingJobArn",
                .edge_packaging_job_name = "EdgePackagingJobName",
                .compilation_job_name = "CompilationJobName",
                .model_name = "ModelName",
                .model_version = "ModelVersion",
                .role_arn = "RoleArn",
                .output_config = "OutputConfig",
                .resource_key = "ResourceKey",
                .edge_packaging_job_status = "EdgePackagingJobStatus",
                .edge_packaging_job_status_message = "EdgePackagingJobStatusMessage",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .model_artifact = "ModelArtifact",
                .model_signature = "ModelSignature",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_endpoint: struct {
    action_name: []const u8 = "DescribeEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint };
        }
    },
    Response: type = struct {
        endpoint_name: []const u8,
        endpoint_arn: []const u8,
        endpoint_config_name: []const u8,
        production_variants: ?[]ProductionVariantSummary = null,
        data_capture_config: ?DataCaptureConfigSummary = null,
        endpoint_status: []const u8,
        failure_reason: ?[]const u8 = null,
        creation_time: i64,
        last_modified_time: i64,
        last_deployment_config: ?DeploymentConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .endpoint_arn = "EndpointArn",
                .endpoint_config_name = "EndpointConfigName",
                .production_variants = "ProductionVariants",
                .data_capture_config = "DataCaptureConfig",
                .endpoint_status = "EndpointStatus",
                .failure_reason = "FailureReason",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .last_deployment_config = "LastDeploymentConfig",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_endpoint_config: struct {
    action_name: []const u8 = "DescribeEndpointConfig",
    Request: type = struct {
        endpoint_config_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_config_name = "EndpointConfigName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_endpoint_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_endpoint_config };
        }
    },
    Response: type = struct {
        endpoint_config_name: []const u8,
        endpoint_config_arn: []const u8,
        production_variants: []ProductionVariant,
        data_capture_config: ?DataCaptureConfig = null,
        kms_key_id: ?[]const u8 = null,
        creation_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_config_name = "EndpointConfigName",
                .endpoint_config_arn = "EndpointConfigArn",
                .production_variants = "ProductionVariants",
                .data_capture_config = "DataCaptureConfig",
                .kms_key_id = "KmsKeyId",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_experiment: struct {
    action_name: []const u8 = "DescribeExperiment",
    Request: type = struct {
        experiment_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_name = "ExperimentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_experiment) } {
            return .{ .service_metadata = service_metadata, .action = describe_experiment };
        }
    },
    Response: type = struct {
        experiment_name: ?[]const u8 = null,
        experiment_arn: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        source: ?ExperimentSource = null,
        description: ?[]const u8 = null,
        creation_time: ?i64 = null,
        created_by: ?UserContext = null,
        last_modified_time: ?i64 = null,
        last_modified_by: ?UserContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_name = "ExperimentName",
                .experiment_arn = "ExperimentArn",
                .display_name = "DisplayName",
                .source = "Source",
                .description = "Description",
                .creation_time = "CreationTime",
                .created_by = "CreatedBy",
                .last_modified_time = "LastModifiedTime",
                .last_modified_by = "LastModifiedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_feature_group: struct {
    action_name: []const u8 = "DescribeFeatureGroup",
    Request: type = struct {
        feature_group_name: []const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_name = "FeatureGroupName",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_feature_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_feature_group };
        }
    },
    Response: type = struct {
        feature_group_arn: []const u8,
        feature_group_name: []const u8,
        record_identifier_feature_name: []const u8,
        event_time_feature_name: []const u8,
        feature_definitions: []FeatureDefinition,
        creation_time: i64,
        online_store_config: ?OnlineStoreConfig = null,
        offline_store_config: ?OfflineStoreConfig = null,
        role_arn: ?[]const u8 = null,
        feature_group_status: ?[]const u8 = null,
        offline_store_status: ?OfflineStoreStatus = null,
        failure_reason: ?[]const u8 = null,
        description: ?[]const u8 = null,
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_arn = "FeatureGroupArn",
                .feature_group_name = "FeatureGroupName",
                .record_identifier_feature_name = "RecordIdentifierFeatureName",
                .event_time_feature_name = "EventTimeFeatureName",
                .feature_definitions = "FeatureDefinitions",
                .creation_time = "CreationTime",
                .online_store_config = "OnlineStoreConfig",
                .offline_store_config = "OfflineStoreConfig",
                .role_arn = "RoleArn",
                .feature_group_status = "FeatureGroupStatus",
                .offline_store_status = "OfflineStoreStatus",
                .failure_reason = "FailureReason",
                .description = "Description",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_flow_definition: struct {
    action_name: []const u8 = "DescribeFlowDefinition",
    Request: type = struct {
        flow_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_definition_name = "FlowDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_flow_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_flow_definition };
        }
    },
    Response: type = struct {
        flow_definition_arn: []const u8,
        flow_definition_name: []const u8,
        flow_definition_status: []const u8,
        creation_time: i64,
        human_loop_request_source: ?HumanLoopRequestSource = null,
        human_loop_activation_config: ?HumanLoopActivationConfig = null,
        human_loop_config: HumanLoopConfig,
        output_config: FlowDefinitionOutputConfig,
        role_arn: []const u8,
        failure_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_definition_arn = "FlowDefinitionArn",
                .flow_definition_name = "FlowDefinitionName",
                .flow_definition_status = "FlowDefinitionStatus",
                .creation_time = "CreationTime",
                .human_loop_request_source = "HumanLoopRequestSource",
                .human_loop_activation_config = "HumanLoopActivationConfig",
                .human_loop_config = "HumanLoopConfig",
                .output_config = "OutputConfig",
                .role_arn = "RoleArn",
                .failure_reason = "FailureReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_human_task_ui: struct {
    action_name: []const u8 = "DescribeHumanTaskUi",
    Request: type = struct {
        human_task_ui_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_task_ui_name = "HumanTaskUiName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_human_task_ui) } {
            return .{ .service_metadata = service_metadata, .action = describe_human_task_ui };
        }
    },
    Response: type = struct {
        human_task_ui_arn: []const u8,
        human_task_ui_name: []const u8,
        human_task_ui_status: ?[]const u8 = null,
        creation_time: i64,
        ui_template: struct {
            url: ?[]const u8 = null,
            content_sha256: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .url = "Url",
                    .content_sha256 = "ContentSha256",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_task_ui_arn = "HumanTaskUiArn",
                .human_task_ui_name = "HumanTaskUiName",
                .human_task_ui_status = "HumanTaskUiStatus",
                .creation_time = "CreationTime",
                .ui_template = "UiTemplate",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_hyper_parameter_tuning_job: struct {
    action_name: []const u8 = "DescribeHyperParameterTuningJob",
    Request: type = struct {
        hyper_parameter_tuning_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hyper_parameter_tuning_job_name = "HyperParameterTuningJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_hyper_parameter_tuning_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_hyper_parameter_tuning_job };
        }
    },
    Response: type = struct {
        hyper_parameter_tuning_job_name: []const u8,
        hyper_parameter_tuning_job_arn: []const u8,
        hyper_parameter_tuning_job_config: HyperParameterTuningJobConfig,
        training_job_definition: ?HyperParameterTrainingJobDefinition = null,
        training_job_definitions: ?[]HyperParameterTrainingJobDefinition = null,
        hyper_parameter_tuning_job_status: []const u8,
        creation_time: i64,
        hyper_parameter_tuning_end_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        training_job_status_counters: TrainingJobStatusCounters,
        objective_status_counters: ObjectiveStatusCounters,
        best_training_job: ?HyperParameterTrainingJobSummary = null,
        overall_best_training_job: ?HyperParameterTrainingJobSummary = null,
        warm_start_config: ?HyperParameterTuningJobWarmStartConfig = null,
        failure_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hyper_parameter_tuning_job_name = "HyperParameterTuningJobName",
                .hyper_parameter_tuning_job_arn = "HyperParameterTuningJobArn",
                .hyper_parameter_tuning_job_config = "HyperParameterTuningJobConfig",
                .training_job_definition = "TrainingJobDefinition",
                .training_job_definitions = "TrainingJobDefinitions",
                .hyper_parameter_tuning_job_status = "HyperParameterTuningJobStatus",
                .creation_time = "CreationTime",
                .hyper_parameter_tuning_end_time = "HyperParameterTuningEndTime",
                .last_modified_time = "LastModifiedTime",
                .training_job_status_counters = "TrainingJobStatusCounters",
                .objective_status_counters = "ObjectiveStatusCounters",
                .best_training_job = "BestTrainingJob",
                .overall_best_training_job = "OverallBestTrainingJob",
                .warm_start_config = "WarmStartConfig",
                .failure_reason = "FailureReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_image: struct {
    action_name: []const u8 = "DescribeImage",
    Request: type = struct {
        image_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_name = "ImageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_image) } {
            return .{ .service_metadata = service_metadata, .action = describe_image };
        }
    },
    Response: type = struct {
        creation_time: ?i64 = null,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        image_arn: ?[]const u8 = null,
        image_name: ?[]const u8 = null,
        image_status: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time = "CreationTime",
                .description = "Description",
                .display_name = "DisplayName",
                .failure_reason = "FailureReason",
                .image_arn = "ImageArn",
                .image_name = "ImageName",
                .image_status = "ImageStatus",
                .last_modified_time = "LastModifiedTime",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_image_version: struct {
    action_name: []const u8 = "DescribeImageVersion",
    Request: type = struct {
        image_name: []const u8,
        version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_name = "ImageName",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_image_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_image_version };
        }
    },
    Response: type = struct {
        base_image: ?[]const u8 = null,
        container_image: ?[]const u8 = null,
        creation_time: ?i64 = null,
        failure_reason: ?[]const u8 = null,
        image_arn: ?[]const u8 = null,
        image_version_arn: ?[]const u8 = null,
        image_version_status: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        version: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .base_image = "BaseImage",
                .container_image = "ContainerImage",
                .creation_time = "CreationTime",
                .failure_reason = "FailureReason",
                .image_arn = "ImageArn",
                .image_version_arn = "ImageVersionArn",
                .image_version_status = "ImageVersionStatus",
                .last_modified_time = "LastModifiedTime",
                .version = "Version",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_labeling_job: struct {
    action_name: []const u8 = "DescribeLabelingJob",
    Request: type = struct {
        labeling_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labeling_job_name = "LabelingJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_labeling_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_labeling_job };
        }
    },
    Response: type = struct {
        labeling_job_status: []const u8,
        label_counters: LabelCounters,
        failure_reason: ?[]const u8 = null,
        creation_time: i64,
        last_modified_time: i64,
        job_reference_code: []const u8,
        labeling_job_name: []const u8,
        labeling_job_arn: []const u8,
        label_attribute_name: ?[]const u8 = null,
        input_config: LabelingJobInputConfig,
        output_config: LabelingJobOutputConfig,
        role_arn: []const u8,
        label_category_config_s3_uri: ?[]const u8 = null,
        stopping_conditions: ?LabelingJobStoppingConditions = null,
        labeling_job_algorithms_config: ?LabelingJobAlgorithmsConfig = null,
        human_task_config: HumanTaskConfig,
        tags: ?[]Tag = null,
        labeling_job_output: ?LabelingJobOutput = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labeling_job_status = "LabelingJobStatus",
                .label_counters = "LabelCounters",
                .failure_reason = "FailureReason",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .job_reference_code = "JobReferenceCode",
                .labeling_job_name = "LabelingJobName",
                .labeling_job_arn = "LabelingJobArn",
                .label_attribute_name = "LabelAttributeName",
                .input_config = "InputConfig",
                .output_config = "OutputConfig",
                .role_arn = "RoleArn",
                .label_category_config_s3_uri = "LabelCategoryConfigS3Uri",
                .stopping_conditions = "StoppingConditions",
                .labeling_job_algorithms_config = "LabelingJobAlgorithmsConfig",
                .human_task_config = "HumanTaskConfig",
                .tags = "Tags",
                .labeling_job_output = "LabelingJobOutput",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_model: struct {
    action_name: []const u8 = "DescribeModel",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_model };
        }
    },
    Response: type = struct {
        model_name: []const u8,
        primary_container: ?ContainerDefinition = null,
        containers: ?[]ContainerDefinition = null,
        inference_execution_config: ?InferenceExecutionConfig = null,
        execution_role_arn: []const u8,
        vpc_config: ?VpcConfig = null,
        creation_time: i64,
        model_arn: []const u8,
        enable_network_isolation: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .primary_container = "PrimaryContainer",
                .containers = "Containers",
                .inference_execution_config = "InferenceExecutionConfig",
                .execution_role_arn = "ExecutionRoleArn",
                .vpc_config = "VpcConfig",
                .creation_time = "CreationTime",
                .model_arn = "ModelArn",
                .enable_network_isolation = "EnableNetworkIsolation",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_model_bias_job_definition: struct {
    action_name: []const u8 = "DescribeModelBiasJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model_bias_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_model_bias_job_definition };
        }
    },
    Response: type = struct {
        job_definition_arn: []const u8,
        job_definition_name: []const u8,
        creation_time: i64,
        model_bias_baseline_config: ?ModelBiasBaselineConfig = null,
        model_bias_app_specification: ModelBiasAppSpecification,
        model_bias_job_input: ModelBiasJobInput,
        model_bias_job_output_config: MonitoringOutputConfig,
        job_resources: MonitoringResources,
        network_config: ?MonitoringNetworkConfig = null,
        role_arn: []const u8,
        stopping_condition: ?MonitoringStoppingCondition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_arn = "JobDefinitionArn",
                .job_definition_name = "JobDefinitionName",
                .creation_time = "CreationTime",
                .model_bias_baseline_config = "ModelBiasBaselineConfig",
                .model_bias_app_specification = "ModelBiasAppSpecification",
                .model_bias_job_input = "ModelBiasJobInput",
                .model_bias_job_output_config = "ModelBiasJobOutputConfig",
                .job_resources = "JobResources",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .stopping_condition = "StoppingCondition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_model_explainability_job_definition: struct {
    action_name: []const u8 = "DescribeModelExplainabilityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model_explainability_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_model_explainability_job_definition };
        }
    },
    Response: type = struct {
        job_definition_arn: []const u8,
        job_definition_name: []const u8,
        creation_time: i64,
        model_explainability_baseline_config: ?ModelExplainabilityBaselineConfig = null,
        model_explainability_app_specification: ModelExplainabilityAppSpecification,
        model_explainability_job_input: ModelExplainabilityJobInput,
        model_explainability_job_output_config: MonitoringOutputConfig,
        job_resources: MonitoringResources,
        network_config: ?MonitoringNetworkConfig = null,
        role_arn: []const u8,
        stopping_condition: ?MonitoringStoppingCondition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_arn = "JobDefinitionArn",
                .job_definition_name = "JobDefinitionName",
                .creation_time = "CreationTime",
                .model_explainability_baseline_config = "ModelExplainabilityBaselineConfig",
                .model_explainability_app_specification = "ModelExplainabilityAppSpecification",
                .model_explainability_job_input = "ModelExplainabilityJobInput",
                .model_explainability_job_output_config = "ModelExplainabilityJobOutputConfig",
                .job_resources = "JobResources",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .stopping_condition = "StoppingCondition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_model_package: struct {
    action_name: []const u8 = "DescribeModelPackage",
    Request: type = struct {
        model_package_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_name = "ModelPackageName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model_package) } {
            return .{ .service_metadata = service_metadata, .action = describe_model_package };
        }
    },
    Response: type = struct {
        model_package_name: []const u8,
        model_package_group_name: ?[]const u8 = null,
        model_package_version: ?i64 = null,
        model_package_arn: []const u8,
        model_package_description: ?[]const u8 = null,
        creation_time: i64,
        inference_specification: ?InferenceSpecification = null,
        source_algorithm_specification: ?SourceAlgorithmSpecification = null,
        validation_specification: ?ModelPackageValidationSpecification = null,
        model_package_status: []const u8,
        model_package_status_details: ModelPackageStatusDetails,
        certify_for_marketplace: ?bool = null,
        model_approval_status: ?[]const u8 = null,
        created_by: ?UserContext = null,
        metadata_properties: ?MetadataProperties = null,
        model_metrics: ?ModelMetrics = null,
        last_modified_time: ?i64 = null,
        last_modified_by: ?UserContext = null,
        approval_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_name = "ModelPackageName",
                .model_package_group_name = "ModelPackageGroupName",
                .model_package_version = "ModelPackageVersion",
                .model_package_arn = "ModelPackageArn",
                .model_package_description = "ModelPackageDescription",
                .creation_time = "CreationTime",
                .inference_specification = "InferenceSpecification",
                .source_algorithm_specification = "SourceAlgorithmSpecification",
                .validation_specification = "ValidationSpecification",
                .model_package_status = "ModelPackageStatus",
                .model_package_status_details = "ModelPackageStatusDetails",
                .certify_for_marketplace = "CertifyForMarketplace",
                .model_approval_status = "ModelApprovalStatus",
                .created_by = "CreatedBy",
                .metadata_properties = "MetadataProperties",
                .model_metrics = "ModelMetrics",
                .last_modified_time = "LastModifiedTime",
                .last_modified_by = "LastModifiedBy",
                .approval_description = "ApprovalDescription",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_model_package_group: struct {
    action_name: []const u8 = "DescribeModelPackageGroup",
    Request: type = struct {
        model_package_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_name = "ModelPackageGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model_package_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_model_package_group };
        }
    },
    Response: type = struct {
        model_package_group_name: []const u8,
        model_package_group_arn: []const u8,
        model_package_group_description: ?[]const u8 = null,
        creation_time: i64,
        created_by: UserContext,
        model_package_group_status: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_name = "ModelPackageGroupName",
                .model_package_group_arn = "ModelPackageGroupArn",
                .model_package_group_description = "ModelPackageGroupDescription",
                .creation_time = "CreationTime",
                .created_by = "CreatedBy",
                .model_package_group_status = "ModelPackageGroupStatus",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_model_quality_job_definition: struct {
    action_name: []const u8 = "DescribeModelQualityJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "JobDefinitionName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model_quality_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = describe_model_quality_job_definition };
        }
    },
    Response: type = struct {
        job_definition_arn: []const u8,
        job_definition_name: []const u8,
        creation_time: i64,
        model_quality_baseline_config: ?ModelQualityBaselineConfig = null,
        model_quality_app_specification: ModelQualityAppSpecification,
        model_quality_job_input: ModelQualityJobInput,
        model_quality_job_output_config: MonitoringOutputConfig,
        job_resources: MonitoringResources,
        network_config: ?MonitoringNetworkConfig = null,
        role_arn: []const u8,
        stopping_condition: ?MonitoringStoppingCondition = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_arn = "JobDefinitionArn",
                .job_definition_name = "JobDefinitionName",
                .creation_time = "CreationTime",
                .model_quality_baseline_config = "ModelQualityBaselineConfig",
                .model_quality_app_specification = "ModelQualityAppSpecification",
                .model_quality_job_input = "ModelQualityJobInput",
                .model_quality_job_output_config = "ModelQualityJobOutputConfig",
                .job_resources = "JobResources",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .stopping_condition = "StoppingCondition",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_monitoring_schedule: struct {
    action_name: []const u8 = "DescribeMonitoringSchedule",
    Request: type = struct {
        monitoring_schedule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_name = "MonitoringScheduleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_monitoring_schedule) } {
            return .{ .service_metadata = service_metadata, .action = describe_monitoring_schedule };
        }
    },
    Response: type = struct {
        monitoring_schedule_arn: []const u8,
        monitoring_schedule_name: []const u8,
        monitoring_schedule_status: []const u8,
        monitoring_type: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        creation_time: i64,
        last_modified_time: i64,
        monitoring_schedule_config: MonitoringScheduleConfig,
        endpoint_name: ?[]const u8 = null,
        last_monitoring_execution_summary: ?MonitoringExecutionSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_arn = "MonitoringScheduleArn",
                .monitoring_schedule_name = "MonitoringScheduleName",
                .monitoring_schedule_status = "MonitoringScheduleStatus",
                .monitoring_type = "MonitoringType",
                .failure_reason = "FailureReason",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .monitoring_schedule_config = "MonitoringScheduleConfig",
                .endpoint_name = "EndpointName",
                .last_monitoring_execution_summary = "LastMonitoringExecutionSummary",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_notebook_instance: struct {
    action_name: []const u8 = "DescribeNotebookInstance",
    Request: type = struct {
        notebook_instance_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_name = "NotebookInstanceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_notebook_instance) } {
            return .{ .service_metadata = service_metadata, .action = describe_notebook_instance };
        }
    },
    Response: type = struct {
        notebook_instance_arn: ?[]const u8 = null,
        notebook_instance_name: ?[]const u8 = null,
        notebook_instance_status: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        url: ?[]const u8 = null,
        instance_type: ?[]const u8 = null,
        subnet_id: ?[]const u8 = null,
        security_groups: ?[][]const u8 = null,
        role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        network_interface_id: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        creation_time: ?i64 = null,
        notebook_instance_lifecycle_config_name: ?[]const u8 = null,
        direct_internet_access: ?[]const u8 = null,
        volume_size_in_gb: ?i64 = null,
        accelerator_types: ?[][]const u8 = null,
        default_code_repository: ?[]const u8 = null,
        additional_code_repositories: ?[][]const u8 = null,
        root_access: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_arn = "NotebookInstanceArn",
                .notebook_instance_name = "NotebookInstanceName",
                .notebook_instance_status = "NotebookInstanceStatus",
                .failure_reason = "FailureReason",
                .url = "Url",
                .instance_type = "InstanceType",
                .subnet_id = "SubnetId",
                .security_groups = "SecurityGroups",
                .role_arn = "RoleArn",
                .kms_key_id = "KmsKeyId",
                .network_interface_id = "NetworkInterfaceId",
                .last_modified_time = "LastModifiedTime",
                .creation_time = "CreationTime",
                .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
                .direct_internet_access = "DirectInternetAccess",
                .volume_size_in_gb = "VolumeSizeInGB",
                .accelerator_types = "AcceleratorTypes",
                .default_code_repository = "DefaultCodeRepository",
                .additional_code_repositories = "AdditionalCodeRepositories",
                .root_access = "RootAccess",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_notebook_instance_lifecycle_config: struct {
    action_name: []const u8 = "DescribeNotebookInstanceLifecycleConfig",
    Request: type = struct {
        notebook_instance_lifecycle_config_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_notebook_instance_lifecycle_config) } {
            return .{ .service_metadata = service_metadata, .action = describe_notebook_instance_lifecycle_config };
        }
    },
    Response: type = struct {
        notebook_instance_lifecycle_config_arn: ?[]const u8 = null,
        notebook_instance_lifecycle_config_name: ?[]const u8 = null,
        on_create: ?[]NotebookInstanceLifecycleHook = null,
        on_start: ?[]NotebookInstanceLifecycleHook = null,
        last_modified_time: ?i64 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_lifecycle_config_arn = "NotebookInstanceLifecycleConfigArn",
                .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
                .on_create = "OnCreate",
                .on_start = "OnStart",
                .last_modified_time = "LastModifiedTime",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_pipeline: struct {
    action_name: []const u8 = "DescribePipeline",
    Request: type = struct {
        pipeline_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = describe_pipeline };
        }
    },
    Response: type = struct {
        pipeline_arn: ?[]const u8 = null,
        pipeline_name: ?[]const u8 = null,
        pipeline_display_name: ?[]const u8 = null,
        pipeline_definition: ?[]const u8 = null,
        pipeline_description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        pipeline_status: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        last_run_time: ?i64 = null,
        created_by: ?UserContext = null,
        last_modified_by: ?UserContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_arn = "PipelineArn",
                .pipeline_name = "PipelineName",
                .pipeline_display_name = "PipelineDisplayName",
                .pipeline_definition = "PipelineDefinition",
                .pipeline_description = "PipelineDescription",
                .role_arn = "RoleArn",
                .pipeline_status = "PipelineStatus",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .last_run_time = "LastRunTime",
                .created_by = "CreatedBy",
                .last_modified_by = "LastModifiedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_pipeline_definition_for_execution: struct {
    action_name: []const u8 = "DescribePipelineDefinitionForExecution",
    Request: type = struct {
        pipeline_execution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pipeline_definition_for_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_pipeline_definition_for_execution };
        }
    },
    Response: type = struct {
        pipeline_definition: ?[]const u8 = null,
        creation_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_definition = "PipelineDefinition",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_pipeline_execution: struct {
    action_name: []const u8 = "DescribePipelineExecution",
    Request: type = struct {
        pipeline_execution_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = describe_pipeline_execution };
        }
    },
    Response: type = struct {
        pipeline_arn: ?[]const u8 = null,
        pipeline_execution_arn: ?[]const u8 = null,
        pipeline_execution_display_name: ?[]const u8 = null,
        pipeline_execution_status: ?[]const u8 = null,
        pipeline_execution_description: ?[]const u8 = null,
        creation_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        created_by: ?UserContext = null,
        last_modified_by: ?UserContext = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_arn = "PipelineArn",
                .pipeline_execution_arn = "PipelineExecutionArn",
                .pipeline_execution_display_name = "PipelineExecutionDisplayName",
                .pipeline_execution_status = "PipelineExecutionStatus",
                .pipeline_execution_description = "PipelineExecutionDescription",
                .creation_time = "CreationTime",
                .last_modified_time = "LastModifiedTime",
                .created_by = "CreatedBy",
                .last_modified_by = "LastModifiedBy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_processing_job: struct {
    action_name: []const u8 = "DescribeProcessingJob",
    Request: type = struct {
        processing_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processing_job_name = "ProcessingJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_processing_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_processing_job };
        }
    },
    Response: type = struct {
        processing_inputs: ?[]ProcessingInput = null,
        processing_output_config: ?ProcessingOutputConfig = null,
        processing_job_name: []const u8,
        processing_resources: ProcessingResources,
        stopping_condition: ?ProcessingStoppingCondition = null,
        app_specification: AppSpecification,
        environment: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        network_config: ?NetworkConfig = null,
        role_arn: ?[]const u8 = null,
        experiment_config: ?ExperimentConfig = null,
        processing_job_arn: []const u8,
        processing_job_status: []const u8,
        exit_message: ?[]const u8 = null,
        failure_reason: ?[]const u8 = null,
        processing_end_time: ?i64 = null,
        processing_start_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        creation_time: i64,
        monitoring_schedule_arn: ?[]const u8 = null,
        auto_ml_job_arn: ?[]const u8 = null,
        training_job_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processing_inputs = "ProcessingInputs",
                .processing_output_config = "ProcessingOutputConfig",
                .processing_job_name = "ProcessingJobName",
                .processing_resources = "ProcessingResources",
                .stopping_condition = "StoppingCondition",
                .app_specification = "AppSpecification",
                .environment = "Environment",
                .network_config = "NetworkConfig",
                .role_arn = "RoleArn",
                .experiment_config = "ExperimentConfig",
                .processing_job_arn = "ProcessingJobArn",
                .processing_job_status = "ProcessingJobStatus",
                .exit_message = "ExitMessage",
                .failure_reason = "FailureReason",
                .processing_end_time = "ProcessingEndTime",
                .processing_start_time = "ProcessingStartTime",
                .last_modified_time = "LastModifiedTime",
                .creation_time = "CreationTime",
                .monitoring_schedule_arn = "MonitoringScheduleArn",
                .auto_ml_job_arn = "AutoMLJobArn",
                .training_job_arn = "TrainingJobArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment", field_name))
                return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_project: struct {
    action_name: []const u8 = "DescribeProject",
    Request: type = struct {
        project_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_name = "ProjectName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_project) } {
            return .{ .service_metadata = service_metadata, .action = describe_project };
        }
    },
    Response: type = struct {
        project_arn: []const u8,
        project_name: []const u8,
        project_id: []const u8,
        project_description: ?[]const u8 = null,
        service_catalog_provisioning_details: ServiceCatalogProvisioningDetails,
        service_catalog_provisioned_product_details: ?struct {
            provisioned_product_id: ?[]const u8 = null,
            provisioned_product_status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .provisioned_product_id = "ProvisionedProductId",
                    .provisioned_product_status_message = "ProvisionedProductStatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        project_status: []const u8,
        created_by: ?UserContext = null,
        creation_time: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_arn = "ProjectArn",
                .project_name = "ProjectName",
                .project_id = "ProjectId",
                .project_description = "ProjectDescription",
                .service_catalog_provisioning_details = "ServiceCatalogProvisioningDetails",
                .service_catalog_provisioned_product_details = "ServiceCatalogProvisionedProductDetails",
                .project_status = "ProjectStatus",
                .created_by = "CreatedBy",
                .creation_time = "CreationTime",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_subscribed_workteam: struct {
    action_name: []const u8 = "DescribeSubscribedWorkteam",
    Request: type = struct {
        workteam_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam_arn = "WorkteamArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_subscribed_workteam) } {
            return .{ .service_metadata = service_metadata, .action = describe_subscribed_workteam };
        }
    },
    Response: type = struct {
        subscribed_workteam: SubscribedWorkteam,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscribed_workteam = "SubscribedWorkteam",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_training_job: struct {
    action_name: []const u8 = "DescribeTrainingJob",
    Request: type = struct {
        training_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_name = "TrainingJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_training_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_training_job };
        }
    },
    Response: type = struct {
        training_job_name: []const u8,
        training_job_arn: []const u8,
        tuning_job_arn: ?[]const u8 = null,
        labeling_job_arn: ?[]const u8 = null,
        auto_ml_job_arn: ?[]const u8 = null,
        model_artifacts: ModelArtifacts,
        training_job_status: []const u8,
        secondary_status: []const u8,
        failure_reason: ?[]const u8 = null,
        hyper_parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        algorithm_specification: AlgorithmSpecification,
        role_arn: ?[]const u8 = null,
        input_data_config: ?[]Channel = null,
        output_data_config: ?OutputDataConfig = null,
        resource_config: ResourceConfig,
        vpc_config: ?VpcConfig = null,
        stopping_condition: StoppingCondition,
        creation_time: i64,
        training_start_time: ?i64 = null,
        training_end_time: ?i64 = null,
        last_modified_time: ?i64 = null,
        secondary_status_transitions: ?[]SecondaryStatusTransition = null,
        final_metric_data_list: ?[]MetricData = null,
        enable_network_isolation: ?bool = null,
        enable_inter_container_traffic_encryption: ?bool = null,
        enable_managed_spot_training: ?bool = null,
        checkpoint_config: ?CheckpointConfig = null,
        training_time_in_seconds: ?i64 = null,
        billable_time_in_seconds: ?i64 = null,
        debug_hook_config: ?DebugHookConfig = null,
        experiment_config: ?ExperimentConfig = null,
        debug_rule_configurations: ?[]DebugRuleConfiguration = null,
        tensor_board_output_config: ?TensorBoardOutputConfig = null,
        debug_rule_evaluation_statuses: ?[]DebugRuleEvaluationStatus = null,
        profiler_config: ?ProfilerConfig = null,
        profiler_rule_configurations: ?[]ProfilerRuleConfiguration = null,
        profiler_rule_evaluation_statuses: ?[]struct {
            rule_configuration_name: ?[]const u8 = null,
            rule_evaluation_job_arn: ?[]const u8 = null,
            rule_evaluation_status: ?[]const u8 = null,
            status_details: ?[]const u8 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rule_configuration_name = "RuleConfigurationName",
                    .rule_evaluation_job_arn = "RuleEvaluationJobArn",
                    .rule_evaluation_status = "RuleEvaluationStatus",
                    .status_details = "StatusDetails",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        profiling_status: ?[]const u8 = null,
        retry_strategy: ?RetryStrategy = null,
        environment: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_name = "TrainingJobName",
                .training_job_arn = "TrainingJobArn",
                .tuning_job_arn = "TuningJobArn",
                .labeling_job_arn = "LabelingJobArn",
                .auto_ml_job_arn = "AutoMLJobArn",
                .model_artifacts = "ModelArtifacts",
                .training_job_status = "TrainingJobStatus",
                .secondary_status = "SecondaryStatus",
                .failure_reason = "FailureReason",
                .hyper_parameters = "HyperParameters",
                .algorithm_specification = "AlgorithmSpecification",
                .role_arn = "RoleArn",
                .input_data_config = "InputDataConfig",
                .output_data_config = "OutputDataConfig",
                .resource_config = "ResourceConfig",
                .vpc_config = "VpcConfig",
                .stopping_condition = "StoppingCondition",
                .creation_time = "CreationTime",
                .training_start_time = "TrainingStartTime",
                .training_end_time = "TrainingEndTime",
                .last_modified_time = "LastModifiedTime",
                .secondary_status_transitions = "SecondaryStatusTransitions",
                .final_metric_data_list = "FinalMetricDataList",
                .enable_network_isolation = "EnableNetworkIsolation",
                .enable_inter_container_traffic_encryption = "EnableInterContainerTrafficEncryption",
                .enable_managed_spot_training = "EnableManagedSpotTraining",
                .checkpoint_config = "CheckpointConfig",
                .training_time_in_seconds = "TrainingTimeInSeconds",
                .billable_time_in_seconds = "BillableTimeInSeconds",
                .debug_hook_config = "DebugHookConfig",
                .experiment_config = "ExperimentConfig",
                .debug_rule_configurations = "DebugRuleConfigurations",
                .tensor_board_output_config = "TensorBoardOutputConfig",
                .debug_rule_evaluation_statuses = "DebugRuleEvaluationStatuses",
                .profiler_config = "ProfilerConfig",
                .profiler_rule_configurations = "ProfilerRuleConfigurations",
                .profiler_rule_evaluation_statuses = "ProfilerRuleEvaluationStatuses",
                .profiling_status = "ProfilingStatus",
                .retry_strategy = "RetryStrategy",
                .environment = "Environment",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "hyper_parameters", field_name))
                return try serializeMap(self.hyper_parameters, self.fieldNameFor("hyper_parameters"), options, out_stream);
            if (std.mem.eql(u8, "environment", field_name))
                return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_transform_job: struct {
    action_name: []const u8 = "DescribeTransformJob",
    Request: type = struct {
        transform_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_job_name = "TransformJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_transform_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_transform_job };
        }
    },
    Response: type = struct {
        transform_job_name: []const u8,
        transform_job_arn: []const u8,
        transform_job_status: []const u8,
        failure_reason: ?[]const u8 = null,
        model_name: []const u8,
        max_concurrent_transforms: ?i64 = null,
        model_client_config: ?ModelClientConfig = null,
        max_payload_in_mb: ?i64 = null,
        batch_strategy: ?[]const u8 = null,
        environment: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        transform_input: TransformInput,
        transform_output: ?TransformOutput = null,
        transform_resources: TransformResources,
        creation_time: i64,
        transform_start_time: ?i64 = null,
        transform_end_time: ?i64 = null,
        labeling_job_arn: ?[]const u8 = null,
        auto_ml_job_arn: ?[]const u8 = null,
        data_processing: ?DataProcessing = null,
        experiment_config: ?ExperimentConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_job_name = "TransformJobName",
                .transform_job_arn = "TransformJobArn",
                .transform_job_status = "TransformJobStatus",
                .failure_reason = "FailureReason",
                .model_name = "ModelName",
                .max_concurrent_transforms = "MaxConcurrentTransforms",
                .model_client_config = "ModelClientConfig",
                .max_payload_in_mb = "MaxPayloadInMB",
                .batch_strategy = "BatchStrategy",
                .environment = "Environment",
                .transform_input = "TransformInput",
                .transform_output = "TransformOutput",
                .transform_resources = "TransformResources",
                .creation_time = "CreationTime",
                .transform_start_time = "TransformStartTime",
                .transform_end_time = "TransformEndTime",
                .labeling_job_arn = "LabelingJobArn",
                .auto_ml_job_arn = "AutoMLJobArn",
                .data_processing = "DataProcessing",
                .experiment_config = "ExperimentConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "environment", field_name))
                return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_trial: struct {
    action_name: []const u8 = "DescribeTrial",
    Request: type = struct {
        trial_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_name = "TrialName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trial) } {
            return .{ .service_metadata = service_metadata, .action = describe_trial };
        }
    },
    Response: type = struct {
        trial_name: ?[]const u8 = null,
        trial_arn: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        experiment_name: ?[]const u8 = null,
        source: ?TrialSource = null,
        creation_time: ?i64 = null,
        created_by: ?UserContext = null,
        last_modified_time: ?i64 = null,
        last_modified_by: ?UserContext = null,
        metadata_properties: ?MetadataProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_name = "TrialName",
                .trial_arn = "TrialArn",
                .display_name = "DisplayName",
                .experiment_name = "ExperimentName",
                .source = "Source",
                .creation_time = "CreationTime",
                .created_by = "CreatedBy",
                .last_modified_time = "LastModifiedTime",
                .last_modified_by = "LastModifiedBy",
                .metadata_properties = "MetadataProperties",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_trial_component: struct {
    action_name: []const u8 = "DescribeTrialComponent",
    Request: type = struct {
        trial_component_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_name = "TrialComponentName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trial_component) } {
            return .{ .service_metadata = service_metadata, .action = describe_trial_component };
        }
    },
    Response: type = struct {
        trial_component_name: ?[]const u8 = null,
        trial_component_arn: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        source: ?TrialComponentSource = null,
        status: ?TrialComponentStatus = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        creation_time: ?i64 = null,
        created_by: ?UserContext = null,
        last_modified_time: ?i64 = null,
        last_modified_by: ?UserContext = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentParameterValue = null,
        } = null,
        input_artifacts: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentArtifact = null,
        } = null,
        output_artifacts: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentArtifact = null,
        } = null,
        metadata_properties: ?MetadataProperties = null,
        metrics: ?[]TrialComponentMetricSummary = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_name = "TrialComponentName",
                .trial_component_arn = "TrialComponentArn",
                .display_name = "DisplayName",
                .source = "Source",
                .status = "Status",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .creation_time = "CreationTime",
                .created_by = "CreatedBy",
                .last_modified_time = "LastModifiedTime",
                .last_modified_by = "LastModifiedBy",
                .parameters = "Parameters",
                .input_artifacts = "InputArtifacts",
                .output_artifacts = "OutputArtifacts",
                .metadata_properties = "MetadataProperties",
                .metrics = "Metrics",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "input_artifacts", field_name))
                return try serializeMap(self.input_artifacts, self.fieldNameFor("input_artifacts"), options, out_stream);
            if (std.mem.eql(u8, "output_artifacts", field_name))
                return try serializeMap(self.output_artifacts, self.fieldNameFor("output_artifacts"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_user_profile: struct {
    action_name: []const u8 = "DescribeUserProfile",
    Request: type = struct {
        domain_id: []const u8,
        user_profile_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = describe_user_profile };
        }
    },
    Response: type = struct {
        domain_id: ?[]const u8 = null,
        user_profile_arn: ?[]const u8 = null,
        user_profile_name: ?[]const u8 = null,
        home_efs_file_system_uid: ?[]const u8 = null,
        status: ?[]const u8 = null,
        last_modified_time: ?i64 = null,
        creation_time: ?i64 = null,
        failure_reason: ?[]const u8 = null,
        single_sign_on_user_identifier: ?[]const u8 = null,
        single_sign_on_user_value: ?[]const u8 = null,
        user_settings: ?UserSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_arn = "UserProfileArn",
                .user_profile_name = "UserProfileName",
                .home_efs_file_system_uid = "HomeEfsFileSystemUid",
                .status = "Status",
                .last_modified_time = "LastModifiedTime",
                .creation_time = "CreationTime",
                .failure_reason = "FailureReason",
                .single_sign_on_user_identifier = "SingleSignOnUserIdentifier",
                .single_sign_on_user_value = "SingleSignOnUserValue",
                .user_settings = "UserSettings",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_workforce: struct {
    action_name: []const u8 = "DescribeWorkforce",
    Request: type = struct {
        workforce_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workforce_name = "WorkforceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workforce) } {
            return .{ .service_metadata = service_metadata, .action = describe_workforce };
        }
    },
    Response: type = struct {
        workforce: Workforce,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workforce = "Workforce",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const describe_workteam: struct {
    action_name: []const u8 = "DescribeWorkteam",
    Request: type = struct {
        workteam_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam_name = "WorkteamName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workteam) } {
            return .{ .service_metadata = service_metadata, .action = describe_workteam };
        }
    },
    Response: type = struct {
        workteam: Workteam,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam = "Workteam",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disable_sagemaker_servicecatalog_portfolio: struct {
    action_name: []const u8 = "DisableSagemakerServicecatalogPortfolio",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disable_sagemaker_servicecatalog_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = disable_sagemaker_servicecatalog_portfolio };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const disassociate_trial_component: struct {
    action_name: []const u8 = "DisassociateTrialComponent",
    Request: type = struct {
        trial_component_name: []const u8,
        trial_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_name = "TrialComponentName",
                .trial_name = "TrialName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_trial_component) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_trial_component };
        }
    },
    Response: type = struct {
        trial_component_arn: ?[]const u8 = null,
        trial_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_arn = "TrialComponentArn",
                .trial_arn = "TrialArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const enable_sagemaker_servicecatalog_portfolio: struct {
    action_name: []const u8 = "EnableSagemakerServicecatalogPortfolio",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(enable_sagemaker_servicecatalog_portfolio) } {
            return .{ .service_metadata = service_metadata, .action = enable_sagemaker_servicecatalog_portfolio };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_device_fleet_report: struct {
    action_name: []const u8 = "GetDeviceFleetReport",
    Request: type = struct {
        device_fleet_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_fleet_report) } {
            return .{ .service_metadata = service_metadata, .action = get_device_fleet_report };
        }
    },
    Response: type = struct {
        device_fleet_arn: []const u8,
        device_fleet_name: []const u8,
        output_config: ?EdgeOutputConfig = null,
        description: ?[]const u8 = null,
        report_generated: ?i64 = null,
        device_stats: ?struct {
            connected_device_count: i64,
            registered_device_count: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connected_device_count = "ConnectedDeviceCount",
                    .registered_device_count = "RegisteredDeviceCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        agent_versions: ?[]struct {
            version: []const u8,
            agent_count: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version = "Version",
                    .agent_count = "AgentCount",
                };
                return @field(mappings, field_name);
            }
        } = null,
        model_stats: ?[]struct {
            model_name: []const u8,
            model_version: []const u8,
            offline_device_count: i64,
            connected_device_count: i64,
            active_device_count: i64,
            sampling_device_count: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_version = "ModelVersion",
                    .offline_device_count = "OfflineDeviceCount",
                    .connected_device_count = "ConnectedDeviceCount",
                    .active_device_count = "ActiveDeviceCount",
                    .sampling_device_count = "SamplingDeviceCount",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_arn = "DeviceFleetArn",
                .device_fleet_name = "DeviceFleetName",
                .output_config = "OutputConfig",
                .description = "Description",
                .report_generated = "ReportGenerated",
                .device_stats = "DeviceStats",
                .agent_versions = "AgentVersions",
                .model_stats = "ModelStats",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_model_package_group_policy: struct {
    action_name: []const u8 = "GetModelPackageGroupPolicy",
    Request: type = struct {
        model_package_group_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_name = "ModelPackageGroupName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_model_package_group_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_model_package_group_policy };
        }
    },
    Response: type = struct {
        resource_policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_sagemaker_servicecatalog_portfolio_status: struct {
    action_name: []const u8 = "GetSagemakerServicecatalogPortfolioStatus",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_sagemaker_servicecatalog_portfolio_status) } {
            return .{ .service_metadata = service_metadata, .action = get_sagemaker_servicecatalog_portfolio_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const get_search_suggestions: struct {
    action_name: []const u8 = "GetSearchSuggestions",
    Request: type = struct {
        resource: []const u8,
        suggestion_query: ?struct {
            property_name_query: ?struct {
                property_name_hint: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .property_name_hint = "PropertyNameHint",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .property_name_query = "PropertyNameQuery",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
                .suggestion_query = "SuggestionQuery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_search_suggestions) } {
            return .{ .service_metadata = service_metadata, .action = get_search_suggestions };
        }
    },
    Response: type = struct {
        property_name_suggestions: ?[]struct {
            property_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .property_name = "PropertyName",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .property_name_suggestions = "PropertyNameSuggestions",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_actions: struct {
    action_name: []const u8 = "ListActions",
    Request: type = struct {
        source_uri: ?[]const u8 = null,
        action_type: ?[]const u8 = null,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_uri = "SourceUri",
                .action_type = "ActionType",
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_actions) } {
            return .{ .service_metadata = service_metadata, .action = list_actions };
        }
    },
    Response: type = struct {
        action_summaries: ?[]struct {
            action_arn: ?[]const u8 = null,
            action_name: ?[]const u8 = null,
            source: ?ActionSource = null,
            action_type: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .action_arn = "ActionArn",
                    .action_name = "ActionName",
                    .source = "Source",
                    .action_type = "ActionType",
                    .status = "Status",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_summaries = "ActionSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_algorithms: struct {
    action_name: []const u8 = "ListAlgorithms",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_algorithms) } {
            return .{ .service_metadata = service_metadata, .action = list_algorithms };
        }
    },
    Response: type = struct {
        algorithm_summary_list: []struct {
            algorithm_name: []const u8,
            algorithm_arn: []const u8,
            algorithm_description: ?[]const u8 = null,
            creation_time: i64,
            algorithm_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .algorithm_name = "AlgorithmName",
                    .algorithm_arn = "AlgorithmArn",
                    .algorithm_description = "AlgorithmDescription",
                    .creation_time = "CreationTime",
                    .algorithm_status = "AlgorithmStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .algorithm_summary_list = "AlgorithmSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_app_image_configs: struct {
    action_name: []const u8 = "ListAppImageConfigs",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,
        modified_time_before: ?i64 = null,
        modified_time_after: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
                .modified_time_before = "ModifiedTimeBefore",
                .modified_time_after = "ModifiedTimeAfter",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_app_image_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_app_image_configs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        app_image_configs: ?[]struct {
            app_image_config_arn: ?[]const u8 = null,
            app_image_config_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            kernel_gateway_image_config: ?KernelGatewayImageConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_image_config_arn = "AppImageConfigArn",
                    .app_image_config_name = "AppImageConfigName",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .kernel_gateway_image_config = "KernelGatewayImageConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .app_image_configs = "AppImageConfigs",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_apps: struct {
    action_name: []const u8 = "ListApps",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_order: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        domain_id_equals: ?[]const u8 = null,
        user_profile_name_equals: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_order = "SortOrder",
                .sort_by = "SortBy",
                .domain_id_equals = "DomainIdEquals",
                .user_profile_name_equals = "UserProfileNameEquals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_apps) } {
            return .{ .service_metadata = service_metadata, .action = list_apps };
        }
    },
    Response: type = struct {
        apps: ?[]struct {
            domain_id: ?[]const u8 = null,
            user_profile_name: ?[]const u8 = null,
            app_type: ?[]const u8 = null,
            app_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "DomainId",
                    .user_profile_name = "UserProfileName",
                    .app_type = "AppType",
                    .app_name = "AppName",
                    .status = "Status",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .apps = "Apps",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_artifacts: struct {
    action_name: []const u8 = "ListArtifacts",
    Request: type = struct {
        source_uri: ?[]const u8 = null,
        artifact_type: ?[]const u8 = null,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_uri = "SourceUri",
                .artifact_type = "ArtifactType",
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_artifacts) } {
            return .{ .service_metadata = service_metadata, .action = list_artifacts };
        }
    },
    Response: type = struct {
        artifact_summaries: ?[]struct {
            artifact_arn: ?[]const u8 = null,
            artifact_name: ?[]const u8 = null,
            source: ?ArtifactSource = null,
            artifact_type: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .artifact_arn = "ArtifactArn",
                    .artifact_name = "ArtifactName",
                    .source = "Source",
                    .artifact_type = "ArtifactType",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_summaries = "ArtifactSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_associations: struct {
    action_name: []const u8 = "ListAssociations",
    Request: type = struct {
        source_arn: ?[]const u8 = null,
        destination_arn: ?[]const u8 = null,
        source_type: ?[]const u8 = null,
        destination_type: ?[]const u8 = null,
        association_type: ?[]const u8 = null,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_arn = "SourceArn",
                .destination_arn = "DestinationArn",
                .source_type = "SourceType",
                .destination_type = "DestinationType",
                .association_type = "AssociationType",
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_associations) } {
            return .{ .service_metadata = service_metadata, .action = list_associations };
        }
    },
    Response: type = struct {
        association_summaries: ?[]struct {
            source_arn: ?[]const u8 = null,
            destination_arn: ?[]const u8 = null,
            source_type: ?[]const u8 = null,
            destination_type: ?[]const u8 = null,
            association_type: ?[]const u8 = null,
            source_name: ?[]const u8 = null,
            destination_name: ?[]const u8 = null,
            creation_time: ?i64 = null,
            created_by: ?UserContext = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .source_arn = "SourceArn",
                    .destination_arn = "DestinationArn",
                    .source_type = "SourceType",
                    .destination_type = "DestinationType",
                    .association_type = "AssociationType",
                    .source_name = "SourceName",
                    .destination_name = "DestinationName",
                    .creation_time = "CreationTime",
                    .created_by = "CreatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .association_summaries = "AssociationSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_auto_ml_jobs: struct {
    action_name: []const u8 = "ListAutoMLJobs",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        name_contains: ?[]const u8 = null,
        status_equals: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .name_contains = "NameContains",
                .status_equals = "StatusEquals",
                .sort_order = "SortOrder",
                .sort_by = "SortBy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_auto_ml_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_auto_ml_jobs };
        }
    },
    Response: type = struct {
        auto_ml_job_summaries: []struct {
            auto_ml_job_name: []const u8,
            auto_ml_job_arn: []const u8,
            auto_ml_job_status: []const u8,
            auto_ml_job_secondary_status: []const u8,
            creation_time: i64,
            end_time: ?i64 = null,
            last_modified_time: i64,
            failure_reason: ?[]const u8 = null,
            partial_failure_reasons: ?[]AutoMLPartialFailureReason = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .auto_ml_job_name = "AutoMLJobName",
                    .auto_ml_job_arn = "AutoMLJobArn",
                    .auto_ml_job_status = "AutoMLJobStatus",
                    .auto_ml_job_secondary_status = "AutoMLJobSecondaryStatus",
                    .creation_time = "CreationTime",
                    .end_time = "EndTime",
                    .last_modified_time = "LastModifiedTime",
                    .failure_reason = "FailureReason",
                    .partial_failure_reasons = "PartialFailureReasons",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_ml_job_summaries = "AutoMLJobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_candidates_for_auto_ml_job: struct {
    action_name: []const u8 = "ListCandidatesForAutoMLJob",
    Request: type = struct {
        auto_ml_job_name: []const u8,
        status_equals: ?[]const u8 = null,
        candidate_name_equals: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_ml_job_name = "AutoMLJobName",
                .status_equals = "StatusEquals",
                .candidate_name_equals = "CandidateNameEquals",
                .sort_order = "SortOrder",
                .sort_by = "SortBy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_candidates_for_auto_ml_job) } {
            return .{ .service_metadata = service_metadata, .action = list_candidates_for_auto_ml_job };
        }
    },
    Response: type = struct {
        candidates: []AutoMLCandidate,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .candidates = "Candidates",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_code_repositories: struct {
    action_name: []const u8 = "ListCodeRepositories",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_code_repositories) } {
            return .{ .service_metadata = service_metadata, .action = list_code_repositories };
        }
    },
    Response: type = struct {
        code_repository_summary_list: []struct {
            code_repository_name: []const u8,
            code_repository_arn: []const u8,
            creation_time: i64,
            last_modified_time: i64,
            git_config: ?GitConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code_repository_name = "CodeRepositoryName",
                    .code_repository_arn = "CodeRepositoryArn",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .git_config = "GitConfig",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_repository_summary_list = "CodeRepositorySummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_compilation_jobs: struct {
    action_name: []const u8 = "ListCompilationJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        name_contains: ?[]const u8 = null,
        status_equals: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .name_contains = "NameContains",
                .status_equals = "StatusEquals",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_compilation_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_compilation_jobs };
        }
    },
    Response: type = struct {
        compilation_job_summaries: []struct {
            compilation_job_name: []const u8,
            compilation_job_arn: []const u8,
            creation_time: i64,
            compilation_start_time: ?i64 = null,
            compilation_end_time: ?i64 = null,
            compilation_target_device: ?[]const u8 = null,
            compilation_target_platform_os: ?[]const u8 = null,
            compilation_target_platform_arch: ?[]const u8 = null,
            compilation_target_platform_accelerator: ?[]const u8 = null,
            last_modified_time: ?i64 = null,
            compilation_job_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compilation_job_name = "CompilationJobName",
                    .compilation_job_arn = "CompilationJobArn",
                    .creation_time = "CreationTime",
                    .compilation_start_time = "CompilationStartTime",
                    .compilation_end_time = "CompilationEndTime",
                    .compilation_target_device = "CompilationTargetDevice",
                    .compilation_target_platform_os = "CompilationTargetPlatformOs",
                    .compilation_target_platform_arch = "CompilationTargetPlatformArch",
                    .compilation_target_platform_accelerator = "CompilationTargetPlatformAccelerator",
                    .last_modified_time = "LastModifiedTime",
                    .compilation_job_status = "CompilationJobStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compilation_job_summaries = "CompilationJobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_contexts: struct {
    action_name: []const u8 = "ListContexts",
    Request: type = struct {
        source_uri: ?[]const u8 = null,
        context_type: ?[]const u8 = null,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_uri = "SourceUri",
                .context_type = "ContextType",
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_contexts) } {
            return .{ .service_metadata = service_metadata, .action = list_contexts };
        }
    },
    Response: type = struct {
        context_summaries: ?[]struct {
            context_arn: ?[]const u8 = null,
            context_name: ?[]const u8 = null,
            source: ?ContextSource = null,
            context_type: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .context_arn = "ContextArn",
                    .context_name = "ContextName",
                    .source = "Source",
                    .context_type = "ContextType",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_summaries = "ContextSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_data_quality_job_definitions: struct {
    action_name: []const u8 = "ListDataQualityJobDefinitions",
    Request: type = struct {
        endpoint_name: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_quality_job_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_data_quality_job_definitions };
        }
    },
    Response: type = struct {
        job_definition_summaries: []MonitoringJobDefinitionSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_summaries = "JobDefinitionSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_device_fleets: struct {
    action_name: []const u8 = "ListDeviceFleets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        name_contains: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .name_contains = "NameContains",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_fleets) } {
            return .{ .service_metadata = service_metadata, .action = list_device_fleets };
        }
    },
    Response: type = struct {
        device_fleet_summaries: []struct {
            device_fleet_arn: []const u8,
            device_fleet_name: []const u8,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_fleet_arn = "DeviceFleetArn",
                    .device_fleet_name = "DeviceFleetName",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_summaries = "DeviceFleetSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_devices: struct {
    action_name: []const u8 = "ListDevices",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        latest_heartbeat_after: ?i64 = null,
        model_name: ?[]const u8 = null,
        device_fleet_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .latest_heartbeat_after = "LatestHeartbeatAfter",
                .model_name = "ModelName",
                .device_fleet_name = "DeviceFleetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_devices };
        }
    },
    Response: type = struct {
        device_summaries: []struct {
            device_name: []const u8,
            device_arn: []const u8,
            description: ?[]const u8 = null,
            device_fleet_name: ?[]const u8 = null,
            iot_thing_name: ?[]const u8 = null,
            registration_time: ?i64 = null,
            latest_heartbeat: ?i64 = null,
            models: ?[]struct {
                model_name: []const u8,
                model_version: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .model_name = "ModelName",
                        .model_version = "ModelVersion",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_name = "DeviceName",
                    .device_arn = "DeviceArn",
                    .description = "Description",
                    .device_fleet_name = "DeviceFleetName",
                    .iot_thing_name = "IotThingName",
                    .registration_time = "RegistrationTime",
                    .latest_heartbeat = "LatestHeartbeat",
                    .models = "Models",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_summaries = "DeviceSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_domains: struct {
    action_name: []const u8 = "ListDomains",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domains) } {
            return .{ .service_metadata = service_metadata, .action = list_domains };
        }
    },
    Response: type = struct {
        domains: ?[]struct {
            domain_arn: ?[]const u8 = null,
            domain_id: ?[]const u8 = null,
            domain_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            url: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_arn = "DomainArn",
                    .domain_id = "DomainId",
                    .domain_name = "DomainName",
                    .status = "Status",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .url = "Url",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domains = "Domains",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_edge_packaging_jobs: struct {
    action_name: []const u8 = "ListEdgePackagingJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        name_contains: ?[]const u8 = null,
        model_name_contains: ?[]const u8 = null,
        status_equals: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .name_contains = "NameContains",
                .model_name_contains = "ModelNameContains",
                .status_equals = "StatusEquals",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_edge_packaging_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_edge_packaging_jobs };
        }
    },
    Response: type = struct {
        edge_packaging_job_summaries: []struct {
            edge_packaging_job_arn: []const u8,
            edge_packaging_job_name: []const u8,
            edge_packaging_job_status: []const u8,
            compilation_job_name: ?[]const u8 = null,
            model_name: ?[]const u8 = null,
            model_version: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .edge_packaging_job_arn = "EdgePackagingJobArn",
                    .edge_packaging_job_name = "EdgePackagingJobName",
                    .edge_packaging_job_status = "EdgePackagingJobStatus",
                    .compilation_job_name = "CompilationJobName",
                    .model_name = "ModelName",
                    .model_version = "ModelVersion",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .edge_packaging_job_summaries = "EdgePackagingJobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_endpoint_configs: struct {
    action_name: []const u8 = "ListEndpointConfigs",
    Request: type = struct {
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_endpoint_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_endpoint_configs };
        }
    },
    Response: type = struct {
        endpoint_configs: []struct {
            endpoint_config_name: []const u8,
            endpoint_config_arn: []const u8,
            creation_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint_config_name = "EndpointConfigName",
                    .endpoint_config_arn = "EndpointConfigArn",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_configs = "EndpointConfigs",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_endpoints: struct {
    action_name: []const u8 = "ListEndpoints",
    Request: type = struct {
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        status_equals: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .status_equals = "StatusEquals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_endpoints) } {
            return .{ .service_metadata = service_metadata, .action = list_endpoints };
        }
    },
    Response: type = struct {
        endpoints: []struct {
            endpoint_name: []const u8,
            endpoint_arn: []const u8,
            creation_time: i64,
            last_modified_time: i64,
            endpoint_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .endpoint_name = "EndpointName",
                    .endpoint_arn = "EndpointArn",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .endpoint_status = "EndpointStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoints = "Endpoints",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_experiments: struct {
    action_name: []const u8 = "ListExperiments",
    Request: type = struct {
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_experiments) } {
            return .{ .service_metadata = service_metadata, .action = list_experiments };
        }
    },
    Response: type = struct {
        experiment_summaries: ?[]struct {
            experiment_arn: ?[]const u8 = null,
            experiment_name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            experiment_source: ?ExperimentSource = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .experiment_arn = "ExperimentArn",
                    .experiment_name = "ExperimentName",
                    .display_name = "DisplayName",
                    .experiment_source = "ExperimentSource",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_summaries = "ExperimentSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_feature_groups: struct {
    action_name: []const u8 = "ListFeatureGroups",
    Request: type = struct {
        name_contains: ?[]const u8 = null,
        feature_group_status_equals: ?[]const u8 = null,
        offline_store_status_equals: ?[]const u8 = null,
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        sort_order: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_contains = "NameContains",
                .feature_group_status_equals = "FeatureGroupStatusEquals",
                .offline_store_status_equals = "OfflineStoreStatusEquals",
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .sort_order = "SortOrder",
                .sort_by = "SortBy",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_feature_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_feature_groups };
        }
    },
    Response: type = struct {
        feature_group_summaries: []struct {
            feature_group_name: []const u8,
            feature_group_arn: []const u8,
            creation_time: i64,
            feature_group_status: ?[]const u8 = null,
            offline_store_status: ?OfflineStoreStatus = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .feature_group_name = "FeatureGroupName",
                    .feature_group_arn = "FeatureGroupArn",
                    .creation_time = "CreationTime",
                    .feature_group_status = "FeatureGroupStatus",
                    .offline_store_status = "OfflineStoreStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .feature_group_summaries = "FeatureGroupSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_flow_definitions: struct {
    action_name: []const u8 = "ListFlowDefinitions",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_flow_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_flow_definitions };
        }
    },
    Response: type = struct {
        flow_definition_summaries: []struct {
            flow_definition_name: []const u8,
            flow_definition_arn: []const u8,
            flow_definition_status: []const u8,
            creation_time: i64,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .flow_definition_name = "FlowDefinitionName",
                    .flow_definition_arn = "FlowDefinitionArn",
                    .flow_definition_status = "FlowDefinitionStatus",
                    .creation_time = "CreationTime",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .flow_definition_summaries = "FlowDefinitionSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_human_task_uis: struct {
    action_name: []const u8 = "ListHumanTaskUis",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_human_task_uis) } {
            return .{ .service_metadata = service_metadata, .action = list_human_task_uis };
        }
    },
    Response: type = struct {
        human_task_ui_summaries: []struct {
            human_task_ui_name: []const u8,
            human_task_ui_arn: []const u8,
            creation_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .human_task_ui_name = "HumanTaskUiName",
                    .human_task_ui_arn = "HumanTaskUiArn",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .human_task_ui_summaries = "HumanTaskUiSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_hyper_parameter_tuning_jobs: struct {
    action_name: []const u8 = "ListHyperParameterTuningJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        status_equals: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .name_contains = "NameContains",
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .status_equals = "StatusEquals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hyper_parameter_tuning_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_hyper_parameter_tuning_jobs };
        }
    },
    Response: type = struct {
        hyper_parameter_tuning_job_summaries: []struct {
            hyper_parameter_tuning_job_name: []const u8,
            hyper_parameter_tuning_job_arn: []const u8,
            hyper_parameter_tuning_job_status: []const u8,
            strategy: []const u8,
            creation_time: i64,
            hyper_parameter_tuning_end_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            training_job_status_counters: TrainingJobStatusCounters,
            objective_status_counters: ObjectiveStatusCounters,
            resource_limits: ?ResourceLimits = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .hyper_parameter_tuning_job_name = "HyperParameterTuningJobName",
                    .hyper_parameter_tuning_job_arn = "HyperParameterTuningJobArn",
                    .hyper_parameter_tuning_job_status = "HyperParameterTuningJobStatus",
                    .strategy = "Strategy",
                    .creation_time = "CreationTime",
                    .hyper_parameter_tuning_end_time = "HyperParameterTuningEndTime",
                    .last_modified_time = "LastModifiedTime",
                    .training_job_status_counters = "TrainingJobStatusCounters",
                    .objective_status_counters = "ObjectiveStatusCounters",
                    .resource_limits = "ResourceLimits",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hyper_parameter_tuning_job_summaries = "HyperParameterTuningJobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_images: struct {
    action_name: []const u8 = "ListImages",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_images) } {
            return .{ .service_metadata = service_metadata, .action = list_images };
        }
    },
    Response: type = struct {
        images: ?[]struct {
            creation_time: i64,
            description: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            image_arn: []const u8,
            image_name: []const u8,
            image_status: []const u8,
            last_modified_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "CreationTime",
                    .description = "Description",
                    .display_name = "DisplayName",
                    .failure_reason = "FailureReason",
                    .image_arn = "ImageArn",
                    .image_name = "ImageName",
                    .image_status = "ImageStatus",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .images = "Images",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_image_versions: struct {
    action_name: []const u8 = "ListImageVersions",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        image_name: []const u8,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .image_name = "ImageName",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_image_versions };
        }
    },
    Response: type = struct {
        image_versions: ?[]struct {
            creation_time: i64,
            failure_reason: ?[]const u8 = null,
            image_arn: []const u8,
            image_version_arn: []const u8,
            image_version_status: []const u8,
            last_modified_time: i64,
            version: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .creation_time = "CreationTime",
                    .failure_reason = "FailureReason",
                    .image_arn = "ImageArn",
                    .image_version_arn = "ImageVersionArn",
                    .image_version_status = "ImageVersionStatus",
                    .last_modified_time = "LastModifiedTime",
                    .version = "Version",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_versions = "ImageVersions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_labeling_jobs: struct {
    action_name: []const u8 = "ListLabelingJobs",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        status_equals: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .name_contains = "NameContains",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .status_equals = "StatusEquals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_labeling_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_labeling_jobs };
        }
    },
    Response: type = struct {
        labeling_job_summary_list: ?[]struct {
            labeling_job_name: []const u8,
            labeling_job_arn: []const u8,
            creation_time: i64,
            last_modified_time: i64,
            labeling_job_status: []const u8,
            label_counters: LabelCounters,
            workteam_arn: []const u8,
            pre_human_task_lambda_arn: []const u8,
            annotation_consolidation_lambda_arn: ?[]const u8 = null,
            failure_reason: ?[]const u8 = null,
            labeling_job_output: ?LabelingJobOutput = null,
            input_config: ?LabelingJobInputConfig = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .labeling_job_name = "LabelingJobName",
                    .labeling_job_arn = "LabelingJobArn",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .labeling_job_status = "LabelingJobStatus",
                    .label_counters = "LabelCounters",
                    .workteam_arn = "WorkteamArn",
                    .pre_human_task_lambda_arn = "PreHumanTaskLambdaArn",
                    .annotation_consolidation_lambda_arn = "AnnotationConsolidationLambdaArn",
                    .failure_reason = "FailureReason",
                    .labeling_job_output = "LabelingJobOutput",
                    .input_config = "InputConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labeling_job_summary_list = "LabelingJobSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_labeling_jobs_for_workteam: struct {
    action_name: []const u8 = "ListLabelingJobsForWorkteam",
    Request: type = struct {
        workteam_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        job_reference_code_contains: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam_arn = "WorkteamArn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .job_reference_code_contains = "JobReferenceCodeContains",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_labeling_jobs_for_workteam) } {
            return .{ .service_metadata = service_metadata, .action = list_labeling_jobs_for_workteam };
        }
    },
    Response: type = struct {
        labeling_job_summary_list: []struct {
            labeling_job_name: ?[]const u8 = null,
            job_reference_code: []const u8,
            work_requester_account_id: []const u8,
            creation_time: i64,
            label_counters: ?struct {
                human_labeled: ?i64 = null,
                pending_human: ?i64 = null,
                total: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .human_labeled = "HumanLabeled",
                        .pending_human = "PendingHuman",
                        .total = "Total",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            number_of_human_workers_per_data_object: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .labeling_job_name = "LabelingJobName",
                    .job_reference_code = "JobReferenceCode",
                    .work_requester_account_id = "WorkRequesterAccountId",
                    .creation_time = "CreationTime",
                    .label_counters = "LabelCounters",
                    .number_of_human_workers_per_data_object = "NumberOfHumanWorkersPerDataObject",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labeling_job_summary_list = "LabelingJobSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_model_bias_job_definitions: struct {
    action_name: []const u8 = "ListModelBiasJobDefinitions",
    Request: type = struct {
        endpoint_name: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_model_bias_job_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_model_bias_job_definitions };
        }
    },
    Response: type = struct {
        job_definition_summaries: []MonitoringJobDefinitionSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_summaries = "JobDefinitionSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_model_explainability_job_definitions: struct {
    action_name: []const u8 = "ListModelExplainabilityJobDefinitions",
    Request: type = struct {
        endpoint_name: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_model_explainability_job_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_model_explainability_job_definitions };
        }
    },
    Response: type = struct {
        job_definition_summaries: []MonitoringJobDefinitionSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_summaries = "JobDefinitionSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_model_package_groups: struct {
    action_name: []const u8 = "ListModelPackageGroups",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_model_package_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_model_package_groups };
        }
    },
    Response: type = struct {
        model_package_group_summary_list: []struct {
            model_package_group_name: []const u8,
            model_package_group_arn: []const u8,
            model_package_group_description: ?[]const u8 = null,
            creation_time: i64,
            model_package_group_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_package_group_name = "ModelPackageGroupName",
                    .model_package_group_arn = "ModelPackageGroupArn",
                    .model_package_group_description = "ModelPackageGroupDescription",
                    .creation_time = "CreationTime",
                    .model_package_group_status = "ModelPackageGroupStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_summary_list = "ModelPackageGroupSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_model_packages: struct {
    action_name: []const u8 = "ListModelPackages",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        model_approval_status: ?[]const u8 = null,
        model_package_group_name: ?[]const u8 = null,
        model_package_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .model_approval_status = "ModelApprovalStatus",
                .model_package_group_name = "ModelPackageGroupName",
                .model_package_type = "ModelPackageType",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_model_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_model_packages };
        }
    },
    Response: type = struct {
        model_package_summary_list: []struct {
            model_package_name: []const u8,
            model_package_group_name: ?[]const u8 = null,
            model_package_version: ?i64 = null,
            model_package_arn: []const u8,
            model_package_description: ?[]const u8 = null,
            creation_time: i64,
            model_package_status: []const u8,
            model_approval_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_package_name = "ModelPackageName",
                    .model_package_group_name = "ModelPackageGroupName",
                    .model_package_version = "ModelPackageVersion",
                    .model_package_arn = "ModelPackageArn",
                    .model_package_description = "ModelPackageDescription",
                    .creation_time = "CreationTime",
                    .model_package_status = "ModelPackageStatus",
                    .model_approval_status = "ModelApprovalStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_summary_list = "ModelPackageSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_model_quality_job_definitions: struct {
    action_name: []const u8 = "ListModelQualityJobDefinitions",
    Request: type = struct {
        endpoint_name: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_model_quality_job_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_model_quality_job_definitions };
        }
    },
    Response: type = struct {
        job_definition_summaries: []MonitoringJobDefinitionSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_summaries = "JobDefinitionSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_models: struct {
    action_name: []const u8 = "ListModels",
    Request: type = struct {
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_models) } {
            return .{ .service_metadata = service_metadata, .action = list_models };
        }
    },
    Response: type = struct {
        models: []struct {
            model_name: []const u8,
            model_arn: []const u8,
            creation_time: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .creation_time = "CreationTime",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .models = "Models",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_monitoring_executions: struct {
    action_name: []const u8 = "ListMonitoringExecutions",
    Request: type = struct {
        monitoring_schedule_name: ?[]const u8 = null,
        endpoint_name: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        scheduled_time_before: ?i64 = null,
        scheduled_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        status_equals: ?[]const u8 = null,
        monitoring_job_definition_name: ?[]const u8 = null,
        monitoring_type_equals: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_name = "MonitoringScheduleName",
                .endpoint_name = "EndpointName",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .scheduled_time_before = "ScheduledTimeBefore",
                .scheduled_time_after = "ScheduledTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .status_equals = "StatusEquals",
                .monitoring_job_definition_name = "MonitoringJobDefinitionName",
                .monitoring_type_equals = "MonitoringTypeEquals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_monitoring_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_monitoring_executions };
        }
    },
    Response: type = struct {
        monitoring_execution_summaries: []MonitoringExecutionSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_execution_summaries = "MonitoringExecutionSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_monitoring_schedules: struct {
    action_name: []const u8 = "ListMonitoringSchedules",
    Request: type = struct {
        endpoint_name: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        status_equals: ?[]const u8 = null,
        monitoring_job_definition_name: ?[]const u8 = null,
        monitoring_type_equals: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .status_equals = "StatusEquals",
                .monitoring_job_definition_name = "MonitoringJobDefinitionName",
                .monitoring_type_equals = "MonitoringTypeEquals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_monitoring_schedules) } {
            return .{ .service_metadata = service_metadata, .action = list_monitoring_schedules };
        }
    },
    Response: type = struct {
        monitoring_schedule_summaries: []struct {
            monitoring_schedule_name: []const u8,
            monitoring_schedule_arn: []const u8,
            creation_time: i64,
            last_modified_time: i64,
            monitoring_schedule_status: []const u8,
            endpoint_name: ?[]const u8 = null,
            monitoring_job_definition_name: ?[]const u8 = null,
            monitoring_type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .monitoring_schedule_name = "MonitoringScheduleName",
                    .monitoring_schedule_arn = "MonitoringScheduleArn",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .monitoring_schedule_status = "MonitoringScheduleStatus",
                    .endpoint_name = "EndpointName",
                    .monitoring_job_definition_name = "MonitoringJobDefinitionName",
                    .monitoring_type = "MonitoringType",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_summaries = "MonitoringScheduleSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_notebook_instance_lifecycle_configs: struct {
    action_name: []const u8 = "ListNotebookInstanceLifecycleConfigs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notebook_instance_lifecycle_configs) } {
            return .{ .service_metadata = service_metadata, .action = list_notebook_instance_lifecycle_configs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        notebook_instance_lifecycle_configs: ?[]struct {
            notebook_instance_lifecycle_config_name: []const u8,
            notebook_instance_lifecycle_config_arn: []const u8,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
                    .notebook_instance_lifecycle_config_arn = "NotebookInstanceLifecycleConfigArn",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .notebook_instance_lifecycle_configs = "NotebookInstanceLifecycleConfigs",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_notebook_instances: struct {
    action_name: []const u8 = "ListNotebookInstances",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,
        creation_time_before: ?i64 = null,
        creation_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        status_equals: ?[]const u8 = null,
        notebook_instance_lifecycle_config_name_contains: ?[]const u8 = null,
        default_code_repository_contains: ?[]const u8 = null,
        additional_code_repository_equals: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .name_contains = "NameContains",
                .creation_time_before = "CreationTimeBefore",
                .creation_time_after = "CreationTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .status_equals = "StatusEquals",
                .notebook_instance_lifecycle_config_name_contains = "NotebookInstanceLifecycleConfigNameContains",
                .default_code_repository_contains = "DefaultCodeRepositoryContains",
                .additional_code_repository_equals = "AdditionalCodeRepositoryEquals",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_notebook_instances) } {
            return .{ .service_metadata = service_metadata, .action = list_notebook_instances };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        notebook_instances: ?[]struct {
            notebook_instance_name: []const u8,
            notebook_instance_arn: []const u8,
            notebook_instance_status: ?[]const u8 = null,
            url: ?[]const u8 = null,
            instance_type: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            notebook_instance_lifecycle_config_name: ?[]const u8 = null,
            default_code_repository: ?[]const u8 = null,
            additional_code_repositories: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .notebook_instance_name = "NotebookInstanceName",
                    .notebook_instance_arn = "NotebookInstanceArn",
                    .notebook_instance_status = "NotebookInstanceStatus",
                    .url = "Url",
                    .instance_type = "InstanceType",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
                    .default_code_repository = "DefaultCodeRepository",
                    .additional_code_repositories = "AdditionalCodeRepositories",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .notebook_instances = "NotebookInstances",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_pipeline_executions: struct {
    action_name: []const u8 = "ListPipelineExecutions",
    Request: type = struct {
        pipeline_name: []const u8,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipeline_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_pipeline_executions };
        }
    },
    Response: type = struct {
        pipeline_execution_summaries: ?[]struct {
            pipeline_execution_arn: ?[]const u8 = null,
            start_time: ?i64 = null,
            pipeline_execution_status: ?[]const u8 = null,
            pipeline_execution_description: ?[]const u8 = null,
            pipeline_execution_display_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_execution_arn = "PipelineExecutionArn",
                    .start_time = "StartTime",
                    .pipeline_execution_status = "PipelineExecutionStatus",
                    .pipeline_execution_description = "PipelineExecutionDescription",
                    .pipeline_execution_display_name = "PipelineExecutionDisplayName",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_summaries = "PipelineExecutionSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_pipeline_execution_steps: struct {
    action_name: []const u8 = "ListPipelineExecutionSteps",
    Request: type = struct {
        pipeline_execution_arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipeline_execution_steps) } {
            return .{ .service_metadata = service_metadata, .action = list_pipeline_execution_steps };
        }
    },
    Response: type = struct {
        pipeline_execution_steps: ?[]struct {
            step_name: ?[]const u8 = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            step_status: ?[]const u8 = null,
            cache_hit_result: ?struct {
                source_pipeline_execution_arn: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .source_pipeline_execution_arn = "SourcePipelineExecutionArn",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            failure_reason: ?[]const u8 = null,
            metadata: ?struct {
                training_job: ?struct {
                    arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .arn = "Arn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                processing_job: ?struct {
                    arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .arn = "Arn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                transform_job: ?struct {
                    arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .arn = "Arn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                model: ?struct {
                    arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .arn = "Arn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                register_model: ?struct {
                    arn: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .arn = "Arn",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                condition: ?struct {
                    outcome: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .outcome = "Outcome",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .training_job = "TrainingJob",
                        .processing_job = "ProcessingJob",
                        .transform_job = "TransformJob",
                        .model = "Model",
                        .register_model = "RegisterModel",
                        .condition = "Condition",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .step_name = "StepName",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .step_status = "StepStatus",
                    .cache_hit_result = "CacheHitResult",
                    .failure_reason = "FailureReason",
                    .metadata = "Metadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_steps = "PipelineExecutionSteps",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_pipeline_parameters_for_execution: struct {
    action_name: []const u8 = "ListPipelineParametersForExecution",
    Request: type = struct {
        pipeline_execution_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipeline_parameters_for_execution) } {
            return .{ .service_metadata = service_metadata, .action = list_pipeline_parameters_for_execution };
        }
    },
    Response: type = struct {
        pipeline_parameters: ?[]Parameter = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_parameters = "PipelineParameters",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_pipelines: struct {
    action_name: []const u8 = "ListPipelines",
    Request: type = struct {
        pipeline_name_prefix: ?[]const u8 = null,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name_prefix = "PipelineNamePrefix",
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_pipelines };
        }
    },
    Response: type = struct {
        pipeline_summaries: ?[]struct {
            pipeline_arn: ?[]const u8 = null,
            pipeline_name: ?[]const u8 = null,
            pipeline_display_name: ?[]const u8 = null,
            pipeline_description: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            last_execution_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .pipeline_arn = "PipelineArn",
                    .pipeline_name = "PipelineName",
                    .pipeline_display_name = "PipelineDisplayName",
                    .pipeline_description = "PipelineDescription",
                    .role_arn = "RoleArn",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                    .last_execution_time = "LastExecutionTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_summaries = "PipelineSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_processing_jobs: struct {
    action_name: []const u8 = "ListProcessingJobs",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        name_contains: ?[]const u8 = null,
        status_equals: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .name_contains = "NameContains",
                .status_equals = "StatusEquals",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_processing_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_processing_jobs };
        }
    },
    Response: type = struct {
        processing_job_summaries: []struct {
            processing_job_name: []const u8,
            processing_job_arn: []const u8,
            creation_time: i64,
            processing_end_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            processing_job_status: []const u8,
            failure_reason: ?[]const u8 = null,
            exit_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .processing_job_name = "ProcessingJobName",
                    .processing_job_arn = "ProcessingJobArn",
                    .creation_time = "CreationTime",
                    .processing_end_time = "ProcessingEndTime",
                    .last_modified_time = "LastModifiedTime",
                    .processing_job_status = "ProcessingJobStatus",
                    .failure_reason = "FailureReason",
                    .exit_message = "ExitMessage",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processing_job_summaries = "ProcessingJobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_projects: struct {
    action_name: []const u8 = "ListProjects",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        max_results: ?i64 = null,
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .max_results = "MaxResults",
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_projects) } {
            return .{ .service_metadata = service_metadata, .action = list_projects };
        }
    },
    Response: type = struct {
        project_summary_list: []struct {
            project_name: []const u8,
            project_description: ?[]const u8 = null,
            project_arn: []const u8,
            project_id: []const u8,
            creation_time: i64,
            project_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .project_name = "ProjectName",
                    .project_description = "ProjectDescription",
                    .project_arn = "ProjectArn",
                    .project_id = "ProjectId",
                    .creation_time = "CreationTime",
                    .project_status = "ProjectStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .project_summary_list = "ProjectSummaryList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_subscribed_workteams: struct {
    action_name: []const u8 = "ListSubscribedWorkteams",
    Request: type = struct {
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_subscribed_workteams) } {
            return .{ .service_metadata = service_metadata, .action = list_subscribed_workteams };
        }
    },
    Response: type = struct {
        subscribed_workteams: []SubscribedWorkteam,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .subscribed_workteams = "SubscribedWorkteams",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_tags: struct {
    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource_arn: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_training_jobs: struct {
    action_name: []const u8 = "ListTrainingJobs",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        name_contains: ?[]const u8 = null,
        status_equals: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .name_contains = "NameContains",
                .status_equals = "StatusEquals",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_training_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_training_jobs };
        }
    },
    Response: type = struct {
        training_job_summaries: []struct {
            training_job_name: []const u8,
            training_job_arn: []const u8,
            creation_time: i64,
            training_end_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            training_job_status: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .training_job_name = "TrainingJobName",
                    .training_job_arn = "TrainingJobArn",
                    .creation_time = "CreationTime",
                    .training_end_time = "TrainingEndTime",
                    .last_modified_time = "LastModifiedTime",
                    .training_job_status = "TrainingJobStatus",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_summaries = "TrainingJobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_training_jobs_for_hyper_parameter_tuning_job: struct {
    action_name: []const u8 = "ListTrainingJobsForHyperParameterTuningJob",
    Request: type = struct {
        hyper_parameter_tuning_job_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status_equals: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hyper_parameter_tuning_job_name = "HyperParameterTuningJobName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status_equals = "StatusEquals",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_training_jobs_for_hyper_parameter_tuning_job) } {
            return .{ .service_metadata = service_metadata, .action = list_training_jobs_for_hyper_parameter_tuning_job };
        }
    },
    Response: type = struct {
        training_job_summaries: []HyperParameterTrainingJobSummary,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_summaries = "TrainingJobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_transform_jobs: struct {
    action_name: []const u8 = "ListTransformJobs",
    Request: type = struct {
        creation_time_after: ?i64 = null,
        creation_time_before: ?i64 = null,
        last_modified_time_after: ?i64 = null,
        last_modified_time_before: ?i64 = null,
        name_contains: ?[]const u8 = null,
        status_equals: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .creation_time_after = "CreationTimeAfter",
                .creation_time_before = "CreationTimeBefore",
                .last_modified_time_after = "LastModifiedTimeAfter",
                .last_modified_time_before = "LastModifiedTimeBefore",
                .name_contains = "NameContains",
                .status_equals = "StatusEquals",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_transform_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_transform_jobs };
        }
    },
    Response: type = struct {
        transform_job_summaries: []struct {
            transform_job_name: []const u8,
            transform_job_arn: []const u8,
            creation_time: i64,
            transform_end_time: ?i64 = null,
            last_modified_time: ?i64 = null,
            transform_job_status: []const u8,
            failure_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .transform_job_name = "TransformJobName",
                    .transform_job_arn = "TransformJobArn",
                    .creation_time = "CreationTime",
                    .transform_end_time = "TransformEndTime",
                    .last_modified_time = "LastModifiedTime",
                    .transform_job_status = "TransformJobStatus",
                    .failure_reason = "FailureReason",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_job_summaries = "TransformJobSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_trial_components: struct {
    action_name: []const u8 = "ListTrialComponents",
    Request: type = struct {
        experiment_name: ?[]const u8 = null,
        trial_name: ?[]const u8 = null,
        source_arn: ?[]const u8 = null,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_name = "ExperimentName",
                .trial_name = "TrialName",
                .source_arn = "SourceArn",
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_trial_components) } {
            return .{ .service_metadata = service_metadata, .action = list_trial_components };
        }
    },
    Response: type = struct {
        trial_component_summaries: ?[]struct {
            trial_component_name: ?[]const u8 = null,
            trial_component_arn: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            trial_component_source: ?TrialComponentSource = null,
            status: ?TrialComponentStatus = null,
            start_time: ?i64 = null,
            end_time: ?i64 = null,
            creation_time: ?i64 = null,
            created_by: ?UserContext = null,
            last_modified_time: ?i64 = null,
            last_modified_by: ?UserContext = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trial_component_name = "TrialComponentName",
                    .trial_component_arn = "TrialComponentArn",
                    .display_name = "DisplayName",
                    .trial_component_source = "TrialComponentSource",
                    .status = "Status",
                    .start_time = "StartTime",
                    .end_time = "EndTime",
                    .creation_time = "CreationTime",
                    .created_by = "CreatedBy",
                    .last_modified_time = "LastModifiedTime",
                    .last_modified_by = "LastModifiedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_summaries = "TrialComponentSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_trials: struct {
    action_name: []const u8 = "ListTrials",
    Request: type = struct {
        experiment_name: ?[]const u8 = null,
        trial_component_name: ?[]const u8 = null,
        created_after: ?i64 = null,
        created_before: ?i64 = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_name = "ExperimentName",
                .trial_component_name = "TrialComponentName",
                .created_after = "CreatedAfter",
                .created_before = "CreatedBefore",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_trials) } {
            return .{ .service_metadata = service_metadata, .action = list_trials };
        }
    },
    Response: type = struct {
        trial_summaries: ?[]struct {
            trial_arn: ?[]const u8 = null,
            trial_name: ?[]const u8 = null,
            display_name: ?[]const u8 = null,
            trial_source: ?TrialSource = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trial_arn = "TrialArn",
                    .trial_name = "TrialName",
                    .display_name = "DisplayName",
                    .trial_source = "TrialSource",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_summaries = "TrialSummaries",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const list_user_profiles: struct {
    action_name: []const u8 = "ListUserProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        sort_order: ?[]const u8 = null,
        sort_by: ?[]const u8 = null,
        domain_id_equals: ?[]const u8 = null,
        user_profile_name_contains: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .sort_order = "SortOrder",
                .sort_by = "SortBy",
                .domain_id_equals = "DomainIdEquals",
                .user_profile_name_contains = "UserProfileNameContains",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_user_profiles };
        }
    },
    Response: type = struct {
        user_profiles: ?[]struct {
            domain_id: ?[]const u8 = null,
            user_profile_name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            creation_time: ?i64 = null,
            last_modified_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_id = "DomainId",
                    .user_profile_name = "UserProfileName",
                    .status = "Status",
                    .creation_time = "CreationTime",
                    .last_modified_time = "LastModifiedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_profiles = "UserProfiles",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_workforces: struct {
    action_name: []const u8 = "ListWorkforces",
    Request: type = struct {
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workforces) } {
            return .{ .service_metadata = service_metadata, .action = list_workforces };
        }
    },
    Response: type = struct {
        workforces: []Workforce,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workforces = "Workforces",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_workteams: struct {
    action_name: []const u8 = "ListWorkteams",
    Request: type = struct {
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        name_contains: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .name_contains = "NameContains",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_workteams) } {
            return .{ .service_metadata = service_metadata, .action = list_workteams };
        }
    },
    Response: type = struct {
        workteams: []Workteam,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteams = "Workteams",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const put_model_package_group_policy: struct {
    action_name: []const u8 = "PutModelPackageGroupPolicy",
    Request: type = struct {
        model_package_group_name: []const u8,
        resource_policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_name = "ModelPackageGroupName",
                .resource_policy = "ResourcePolicy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_model_package_group_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_model_package_group_policy };
        }
    },
    Response: type = struct {
        model_package_group_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_group_arn = "ModelPackageGroupArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const register_devices: struct {
    action_name: []const u8 = "RegisterDevices",
    Request: type = struct {
        device_fleet_name: []const u8,
        devices: []Device,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
                .devices = "Devices",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_devices) } {
            return .{ .service_metadata = service_metadata, .action = register_devices };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const render_ui_template: struct {
    action_name: []const u8 = "RenderUiTemplate",
    Request: type = struct {
        ui_template: ?UiTemplate = null,
        task: struct {
            input: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .input = "Input",
                };
                return @field(mappings, field_name);
            }
        },
        role_arn: []const u8,
        human_task_ui_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ui_template = "UiTemplate",
                .task = "Task",
                .role_arn = "RoleArn",
                .human_task_ui_arn = "HumanTaskUiArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(render_ui_template) } {
            return .{ .service_metadata = service_metadata, .action = render_ui_template };
        }
    },
    Response: type = struct {
        rendered_content: []const u8,
        errors: []struct {
            code: []const u8,
            message: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .code = "Code",
                    .message = "Message",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rendered_content = "RenderedContent",
                .errors = "Errors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const search: struct {
    action_name: []const u8 = "Search",
    Request: type = struct {
        resource: []const u8,
        search_expression: ?SearchExpression = null,
        sort_by: ?[]const u8 = null,
        sort_order: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource = "Resource",
                .search_expression = "SearchExpression",
                .sort_by = "SortBy",
                .sort_order = "SortOrder",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search) } {
            return .{ .service_metadata = service_metadata, .action = search };
        }
    },
    Response: type = struct {
        results: ?[]struct {
            training_job: ?TrainingJob = null,
            experiment: ?struct {
                experiment_name: ?[]const u8 = null,
                experiment_arn: ?[]const u8 = null,
                display_name: ?[]const u8 = null,
                source: ?ExperimentSource = null,
                description: ?[]const u8 = null,
                creation_time: ?i64 = null,
                created_by: ?UserContext = null,
                last_modified_time: ?i64 = null,
                last_modified_by: ?UserContext = null,
                tags: ?[]Tag = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .experiment_name = "ExperimentName",
                        .experiment_arn = "ExperimentArn",
                        .display_name = "DisplayName",
                        .source = "Source",
                        .description = "Description",
                        .creation_time = "CreationTime",
                        .created_by = "CreatedBy",
                        .last_modified_time = "LastModifiedTime",
                        .last_modified_by = "LastModifiedBy",
                        .tags = "Tags",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            trial: ?struct {
                trial_name: ?[]const u8 = null,
                trial_arn: ?[]const u8 = null,
                display_name: ?[]const u8 = null,
                experiment_name: ?[]const u8 = null,
                source: ?TrialSource = null,
                creation_time: ?i64 = null,
                created_by: ?UserContext = null,
                last_modified_time: ?i64 = null,
                last_modified_by: ?UserContext = null,
                metadata_properties: ?MetadataProperties = null,
                tags: ?[]Tag = null,
                trial_component_summaries: ?[]struct {
                    trial_component_name: ?[]const u8 = null,
                    trial_component_arn: ?[]const u8 = null,
                    trial_component_source: ?TrialComponentSource = null,
                    creation_time: ?i64 = null,
                    created_by: ?UserContext = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .trial_component_name = "TrialComponentName",
                            .trial_component_arn = "TrialComponentArn",
                            .trial_component_source = "TrialComponentSource",
                            .creation_time = "CreationTime",
                            .created_by = "CreatedBy",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .trial_name = "TrialName",
                        .trial_arn = "TrialArn",
                        .display_name = "DisplayName",
                        .experiment_name = "ExperimentName",
                        .source = "Source",
                        .creation_time = "CreationTime",
                        .created_by = "CreatedBy",
                        .last_modified_time = "LastModifiedTime",
                        .last_modified_by = "LastModifiedBy",
                        .metadata_properties = "MetadataProperties",
                        .tags = "Tags",
                        .trial_component_summaries = "TrialComponentSummaries",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            trial_component: ?struct {
                trial_component_name: ?[]const u8 = null,
                display_name: ?[]const u8 = null,
                trial_component_arn: ?[]const u8 = null,
                source: ?TrialComponentSource = null,
                status: ?TrialComponentStatus = null,
                start_time: ?i64 = null,
                end_time: ?i64 = null,
                creation_time: ?i64 = null,
                created_by: ?UserContext = null,
                last_modified_time: ?i64 = null,
                last_modified_by: ?UserContext = null,
                parameters: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?TrialComponentParameterValue = null,
                } = null,
                input_artifacts: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?TrialComponentArtifact = null,
                } = null,
                output_artifacts: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?TrialComponentArtifact = null,
                } = null,
                metrics: ?[]TrialComponentMetricSummary = null,
                metadata_properties: ?MetadataProperties = null,
                source_detail: ?struct {
                    source_arn: ?[]const u8 = null,
                    training_job: ?TrainingJob = null,
                    processing_job: ?struct {
                        processing_inputs: ?[]ProcessingInput = null,
                        processing_output_config: ?ProcessingOutputConfig = null,
                        processing_job_name: ?[]const u8 = null,
                        processing_resources: ?ProcessingResources = null,
                        stopping_condition: ?ProcessingStoppingCondition = null,
                        app_specification: ?AppSpecification = null,
                        environment: ?[]struct {
                            key: ?[]const u8 = null,
                            value: ?[]const u8 = null,
                        } = null,
                        network_config: ?NetworkConfig = null,
                        role_arn: ?[]const u8 = null,
                        experiment_config: ?ExperimentConfig = null,
                        processing_job_arn: ?[]const u8 = null,
                        processing_job_status: ?[]const u8 = null,
                        exit_message: ?[]const u8 = null,
                        failure_reason: ?[]const u8 = null,
                        processing_end_time: ?i64 = null,
                        processing_start_time: ?i64 = null,
                        last_modified_time: ?i64 = null,
                        creation_time: ?i64 = null,
                        monitoring_schedule_arn: ?[]const u8 = null,
                        auto_ml_job_arn: ?[]const u8 = null,
                        training_job_arn: ?[]const u8 = null,
                        tags: ?[]Tag = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .processing_inputs = "ProcessingInputs",
                                .processing_output_config = "ProcessingOutputConfig",
                                .processing_job_name = "ProcessingJobName",
                                .processing_resources = "ProcessingResources",
                                .stopping_condition = "StoppingCondition",
                                .app_specification = "AppSpecification",
                                .environment = "Environment",
                                .network_config = "NetworkConfig",
                                .role_arn = "RoleArn",
                                .experiment_config = "ExperimentConfig",
                                .processing_job_arn = "ProcessingJobArn",
                                .processing_job_status = "ProcessingJobStatus",
                                .exit_message = "ExitMessage",
                                .failure_reason = "FailureReason",
                                .processing_end_time = "ProcessingEndTime",
                                .processing_start_time = "ProcessingStartTime",
                                .last_modified_time = "LastModifiedTime",
                                .creation_time = "CreationTime",
                                .monitoring_schedule_arn = "MonitoringScheduleArn",
                                .auto_ml_job_arn = "AutoMLJobArn",
                                .training_job_arn = "TrainingJobArn",
                                .tags = "Tags",
                            };
                            return @field(mappings, field_name);
                        }

                        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                            if (std.mem.eql(u8, "environment", field_name))
                                return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
                            return false;
                        }
                    } = null,
                    transform_job: ?struct {
                        transform_job_name: ?[]const u8 = null,
                        transform_job_arn: ?[]const u8 = null,
                        transform_job_status: ?[]const u8 = null,
                        failure_reason: ?[]const u8 = null,
                        model_name: ?[]const u8 = null,
                        max_concurrent_transforms: ?i64 = null,
                        model_client_config: ?ModelClientConfig = null,
                        max_payload_in_mb: ?i64 = null,
                        batch_strategy: ?[]const u8 = null,
                        environment: ?[]struct {
                            key: ?[]const u8 = null,
                            value: ?[]const u8 = null,
                        } = null,
                        transform_input: ?TransformInput = null,
                        transform_output: ?TransformOutput = null,
                        transform_resources: ?TransformResources = null,
                        creation_time: ?i64 = null,
                        transform_start_time: ?i64 = null,
                        transform_end_time: ?i64 = null,
                        labeling_job_arn: ?[]const u8 = null,
                        auto_ml_job_arn: ?[]const u8 = null,
                        data_processing: ?DataProcessing = null,
                        experiment_config: ?ExperimentConfig = null,
                        tags: ?[]Tag = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .transform_job_name = "TransformJobName",
                                .transform_job_arn = "TransformJobArn",
                                .transform_job_status = "TransformJobStatus",
                                .failure_reason = "FailureReason",
                                .model_name = "ModelName",
                                .max_concurrent_transforms = "MaxConcurrentTransforms",
                                .model_client_config = "ModelClientConfig",
                                .max_payload_in_mb = "MaxPayloadInMB",
                                .batch_strategy = "BatchStrategy",
                                .environment = "Environment",
                                .transform_input = "TransformInput",
                                .transform_output = "TransformOutput",
                                .transform_resources = "TransformResources",
                                .creation_time = "CreationTime",
                                .transform_start_time = "TransformStartTime",
                                .transform_end_time = "TransformEndTime",
                                .labeling_job_arn = "LabelingJobArn",
                                .auto_ml_job_arn = "AutoMLJobArn",
                                .data_processing = "DataProcessing",
                                .experiment_config = "ExperimentConfig",
                                .tags = "Tags",
                            };
                            return @field(mappings, field_name);
                        }

                        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                            if (std.mem.eql(u8, "environment", field_name))
                                return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
                            return false;
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .source_arn = "SourceArn",
                            .training_job = "TrainingJob",
                            .processing_job = "ProcessingJob",
                            .transform_job = "TransformJob",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                tags: ?[]Tag = null,
                parents: ?[]struct {
                    trial_name: ?[]const u8 = null,
                    experiment_name: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .trial_name = "TrialName",
                            .experiment_name = "ExperimentName",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .trial_component_name = "TrialComponentName",
                        .display_name = "DisplayName",
                        .trial_component_arn = "TrialComponentArn",
                        .source = "Source",
                        .status = "Status",
                        .start_time = "StartTime",
                        .end_time = "EndTime",
                        .creation_time = "CreationTime",
                        .created_by = "CreatedBy",
                        .last_modified_time = "LastModifiedTime",
                        .last_modified_by = "LastModifiedBy",
                        .parameters = "Parameters",
                        .input_artifacts = "InputArtifacts",
                        .output_artifacts = "OutputArtifacts",
                        .metrics = "Metrics",
                        .metadata_properties = "MetadataProperties",
                        .source_detail = "SourceDetail",
                        .tags = "Tags",
                        .parents = "Parents",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "parameters", field_name))
                        return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                    if (std.mem.eql(u8, "input_artifacts", field_name))
                        return try serializeMap(self.input_artifacts, self.fieldNameFor("input_artifacts"), options, out_stream);
                    if (std.mem.eql(u8, "output_artifacts", field_name))
                        return try serializeMap(self.output_artifacts, self.fieldNameFor("output_artifacts"), options, out_stream);
                    return false;
                }
            } = null,
            endpoint: ?struct {
                endpoint_name: []const u8,
                endpoint_arn: []const u8,
                endpoint_config_name: []const u8,
                production_variants: ?[]ProductionVariantSummary = null,
                data_capture_config: ?DataCaptureConfigSummary = null,
                endpoint_status: []const u8,
                failure_reason: ?[]const u8 = null,
                creation_time: i64,
                last_modified_time: i64,
                monitoring_schedules: ?[]struct {
                    monitoring_schedule_arn: ?[]const u8 = null,
                    monitoring_schedule_name: ?[]const u8 = null,
                    monitoring_schedule_status: ?[]const u8 = null,
                    monitoring_type: ?[]const u8 = null,
                    failure_reason: ?[]const u8 = null,
                    creation_time: ?i64 = null,
                    last_modified_time: ?i64 = null,
                    monitoring_schedule_config: ?MonitoringScheduleConfig = null,
                    endpoint_name: ?[]const u8 = null,
                    last_monitoring_execution_summary: ?MonitoringExecutionSummary = null,
                    tags: ?[]Tag = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .monitoring_schedule_arn = "MonitoringScheduleArn",
                            .monitoring_schedule_name = "MonitoringScheduleName",
                            .monitoring_schedule_status = "MonitoringScheduleStatus",
                            .monitoring_type = "MonitoringType",
                            .failure_reason = "FailureReason",
                            .creation_time = "CreationTime",
                            .last_modified_time = "LastModifiedTime",
                            .monitoring_schedule_config = "MonitoringScheduleConfig",
                            .endpoint_name = "EndpointName",
                            .last_monitoring_execution_summary = "LastMonitoringExecutionSummary",
                            .tags = "Tags",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                tags: ?[]Tag = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .endpoint_name = "EndpointName",
                        .endpoint_arn = "EndpointArn",
                        .endpoint_config_name = "EndpointConfigName",
                        .production_variants = "ProductionVariants",
                        .data_capture_config = "DataCaptureConfig",
                        .endpoint_status = "EndpointStatus",
                        .failure_reason = "FailureReason",
                        .creation_time = "CreationTime",
                        .last_modified_time = "LastModifiedTime",
                        .monitoring_schedules = "MonitoringSchedules",
                        .tags = "Tags",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            model_package: ?struct {
                model_package_name: ?[]const u8 = null,
                model_package_group_name: ?[]const u8 = null,
                model_package_version: ?i64 = null,
                model_package_arn: ?[]const u8 = null,
                model_package_description: ?[]const u8 = null,
                creation_time: ?i64 = null,
                inference_specification: ?InferenceSpecification = null,
                source_algorithm_specification: ?SourceAlgorithmSpecification = null,
                validation_specification: ?ModelPackageValidationSpecification = null,
                model_package_status: ?[]const u8 = null,
                model_package_status_details: ?ModelPackageStatusDetails = null,
                certify_for_marketplace: ?bool = null,
                model_approval_status: ?[]const u8 = null,
                created_by: ?UserContext = null,
                metadata_properties: ?MetadataProperties = null,
                model_metrics: ?ModelMetrics = null,
                last_modified_time: ?i64 = null,
                last_modified_by: ?UserContext = null,
                approval_description: ?[]const u8 = null,
                tags: ?[]Tag = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .model_package_name = "ModelPackageName",
                        .model_package_group_name = "ModelPackageGroupName",
                        .model_package_version = "ModelPackageVersion",
                        .model_package_arn = "ModelPackageArn",
                        .model_package_description = "ModelPackageDescription",
                        .creation_time = "CreationTime",
                        .inference_specification = "InferenceSpecification",
                        .source_algorithm_specification = "SourceAlgorithmSpecification",
                        .validation_specification = "ValidationSpecification",
                        .model_package_status = "ModelPackageStatus",
                        .model_package_status_details = "ModelPackageStatusDetails",
                        .certify_for_marketplace = "CertifyForMarketplace",
                        .model_approval_status = "ModelApprovalStatus",
                        .created_by = "CreatedBy",
                        .metadata_properties = "MetadataProperties",
                        .model_metrics = "ModelMetrics",
                        .last_modified_time = "LastModifiedTime",
                        .last_modified_by = "LastModifiedBy",
                        .approval_description = "ApprovalDescription",
                        .tags = "Tags",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            model_package_group: ?struct {
                model_package_group_name: ?[]const u8 = null,
                model_package_group_arn: ?[]const u8 = null,
                model_package_group_description: ?[]const u8 = null,
                creation_time: ?i64 = null,
                created_by: ?UserContext = null,
                model_package_group_status: ?[]const u8 = null,
                tags: ?[]Tag = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .model_package_group_name = "ModelPackageGroupName",
                        .model_package_group_arn = "ModelPackageGroupArn",
                        .model_package_group_description = "ModelPackageGroupDescription",
                        .creation_time = "CreationTime",
                        .created_by = "CreatedBy",
                        .model_package_group_status = "ModelPackageGroupStatus",
                        .tags = "Tags",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            pipeline: ?struct {
                pipeline_arn: ?[]const u8 = null,
                pipeline_name: ?[]const u8 = null,
                pipeline_display_name: ?[]const u8 = null,
                pipeline_description: ?[]const u8 = null,
                role_arn: ?[]const u8 = null,
                pipeline_status: ?[]const u8 = null,
                creation_time: ?i64 = null,
                last_modified_time: ?i64 = null,
                last_run_time: ?i64 = null,
                created_by: ?UserContext = null,
                last_modified_by: ?UserContext = null,
                tags: ?[]Tag = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pipeline_arn = "PipelineArn",
                        .pipeline_name = "PipelineName",
                        .pipeline_display_name = "PipelineDisplayName",
                        .pipeline_description = "PipelineDescription",
                        .role_arn = "RoleArn",
                        .pipeline_status = "PipelineStatus",
                        .creation_time = "CreationTime",
                        .last_modified_time = "LastModifiedTime",
                        .last_run_time = "LastRunTime",
                        .created_by = "CreatedBy",
                        .last_modified_by = "LastModifiedBy",
                        .tags = "Tags",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            pipeline_execution: ?struct {
                pipeline_arn: ?[]const u8 = null,
                pipeline_execution_arn: ?[]const u8 = null,
                pipeline_execution_display_name: ?[]const u8 = null,
                pipeline_execution_status: ?[]const u8 = null,
                pipeline_execution_description: ?[]const u8 = null,
                creation_time: ?i64 = null,
                last_modified_time: ?i64 = null,
                created_by: ?UserContext = null,
                last_modified_by: ?UserContext = null,
                pipeline_parameters: ?[]Parameter = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .pipeline_arn = "PipelineArn",
                        .pipeline_execution_arn = "PipelineExecutionArn",
                        .pipeline_execution_display_name = "PipelineExecutionDisplayName",
                        .pipeline_execution_status = "PipelineExecutionStatus",
                        .pipeline_execution_description = "PipelineExecutionDescription",
                        .creation_time = "CreationTime",
                        .last_modified_time = "LastModifiedTime",
                        .created_by = "CreatedBy",
                        .last_modified_by = "LastModifiedBy",
                        .pipeline_parameters = "PipelineParameters",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            feature_group: ?struct {
                feature_group_arn: ?[]const u8 = null,
                feature_group_name: ?[]const u8 = null,
                record_identifier_feature_name: ?[]const u8 = null,
                event_time_feature_name: ?[]const u8 = null,
                feature_definitions: ?[]FeatureDefinition = null,
                creation_time: ?i64 = null,
                online_store_config: ?OnlineStoreConfig = null,
                offline_store_config: ?OfflineStoreConfig = null,
                role_arn: ?[]const u8 = null,
                feature_group_status: ?[]const u8 = null,
                offline_store_status: ?OfflineStoreStatus = null,
                failure_reason: ?[]const u8 = null,
                description: ?[]const u8 = null,
                tags: ?[]Tag = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .feature_group_arn = "FeatureGroupArn",
                        .feature_group_name = "FeatureGroupName",
                        .record_identifier_feature_name = "RecordIdentifierFeatureName",
                        .event_time_feature_name = "EventTimeFeatureName",
                        .feature_definitions = "FeatureDefinitions",
                        .creation_time = "CreationTime",
                        .online_store_config = "OnlineStoreConfig",
                        .offline_store_config = "OfflineStoreConfig",
                        .role_arn = "RoleArn",
                        .feature_group_status = "FeatureGroupStatus",
                        .offline_store_status = "OfflineStoreStatus",
                        .failure_reason = "FailureReason",
                        .description = "Description",
                        .tags = "Tags",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .training_job = "TrainingJob",
                    .experiment = "Experiment",
                    .trial = "Trial",
                    .trial_component = "TrialComponent",
                    .endpoint = "Endpoint",
                    .model_package = "ModelPackage",
                    .model_package_group = "ModelPackageGroup",
                    .pipeline = "Pipeline",
                    .pipeline_execution = "PipelineExecution",
                    .feature_group = "FeatureGroup",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .results = "Results",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const start_monitoring_schedule: struct {
    action_name: []const u8 = "StartMonitoringSchedule",
    Request: type = struct {
        monitoring_schedule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_name = "MonitoringScheduleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_monitoring_schedule) } {
            return .{ .service_metadata = service_metadata, .action = start_monitoring_schedule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const start_notebook_instance: struct {
    action_name: []const u8 = "StartNotebookInstance",
    Request: type = struct {
        notebook_instance_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_name = "NotebookInstanceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_notebook_instance) } {
            return .{ .service_metadata = service_metadata, .action = start_notebook_instance };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const start_pipeline_execution: struct {
    action_name: []const u8 = "StartPipelineExecution",
    Request: type = struct {
        pipeline_name: []const u8,
        pipeline_execution_display_name: ?[]const u8 = null,
        pipeline_parameters: ?[]Parameter = null,
        pipeline_execution_description: ?[]const u8 = null,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
                .pipeline_execution_display_name = "PipelineExecutionDisplayName",
                .pipeline_parameters = "PipelineParameters",
                .pipeline_execution_description = "PipelineExecutionDescription",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_pipeline_execution };
        }
    },
    Response: type = struct {
        pipeline_execution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const stop_auto_ml_job: struct {
    action_name: []const u8 = "StopAutoMLJob",
    Request: type = struct {
        auto_ml_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_ml_job_name = "AutoMLJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_auto_ml_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_auto_ml_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const stop_compilation_job: struct {
    action_name: []const u8 = "StopCompilationJob",
    Request: type = struct {
        compilation_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compilation_job_name = "CompilationJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_compilation_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_compilation_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const stop_edge_packaging_job: struct {
    action_name: []const u8 = "StopEdgePackagingJob",
    Request: type = struct {
        edge_packaging_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .edge_packaging_job_name = "EdgePackagingJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_edge_packaging_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_edge_packaging_job };
        }
    },
    Response: type = struct {},
} = .{};
pub const stop_hyper_parameter_tuning_job: struct {
    action_name: []const u8 = "StopHyperParameterTuningJob",
    Request: type = struct {
        hyper_parameter_tuning_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hyper_parameter_tuning_job_name = "HyperParameterTuningJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_hyper_parameter_tuning_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_hyper_parameter_tuning_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const stop_labeling_job: struct {
    action_name: []const u8 = "StopLabelingJob",
    Request: type = struct {
        labeling_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .labeling_job_name = "LabelingJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_labeling_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_labeling_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const stop_monitoring_schedule: struct {
    action_name: []const u8 = "StopMonitoringSchedule",
    Request: type = struct {
        monitoring_schedule_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_name = "MonitoringScheduleName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_monitoring_schedule) } {
            return .{ .service_metadata = service_metadata, .action = stop_monitoring_schedule };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const stop_notebook_instance: struct {
    action_name: []const u8 = "StopNotebookInstance",
    Request: type = struct {
        notebook_instance_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_name = "NotebookInstanceName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_notebook_instance) } {
            return .{ .service_metadata = service_metadata, .action = stop_notebook_instance };
        }
    },
    Response: type = struct {},
} = .{};
pub const stop_pipeline_execution: struct {
    action_name: []const u8 = "StopPipelineExecution",
    Request: type = struct {
        pipeline_execution_arn: []const u8,
        client_request_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = stop_pipeline_execution };
        }
    },
    Response: type = struct {
        pipeline_execution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const stop_processing_job: struct {
    action_name: []const u8 = "StopProcessingJob",
    Request: type = struct {
        processing_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .processing_job_name = "ProcessingJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_processing_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_processing_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const stop_training_job: struct {
    action_name: []const u8 = "StopTrainingJob",
    Request: type = struct {
        training_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_name = "TrainingJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_training_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_training_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const stop_transform_job: struct {
    action_name: []const u8 = "StopTransformJob",
    Request: type = struct {
        transform_job_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .transform_job_name = "TransformJobName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_transform_job) } {
            return .{ .service_metadata = service_metadata, .action = stop_transform_job };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_action: struct {
    action_name: []const u8 = "UpdateAction",
    Request: type = struct {
        action_name: []const u8,
        description: ?[]const u8 = null,
        status: ?[]const u8 = null,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        properties_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_name = "ActionName",
                .description = "Description",
                .status = "Status",
                .properties = "Properties",
                .properties_to_remove = "PropertiesToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_action) } {
            return .{ .service_metadata = service_metadata, .action = update_action };
        }
    },
    Response: type = struct {
        action_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .action_arn = "ActionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
    },
} = .{};
pub const update_app_image_config: struct {
    action_name: []const u8 = "UpdateAppImageConfig",
    Request: type = struct {
        app_image_config_name: []const u8,
        kernel_gateway_image_config: ?KernelGatewayImageConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_image_config_name = "AppImageConfigName",
                .kernel_gateway_image_config = "KernelGatewayImageConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_app_image_config) } {
            return .{ .service_metadata = service_metadata, .action = update_app_image_config };
        }
    },
    Response: type = struct {
        app_image_config_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .app_image_config_arn = "AppImageConfigArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_artifact: struct {
    action_name: []const u8 = "UpdateArtifact",
    Request: type = struct {
        artifact_arn: []const u8,
        artifact_name: ?[]const u8 = null,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        properties_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_arn = "ArtifactArn",
                .artifact_name = "ArtifactName",
                .properties = "Properties",
                .properties_to_remove = "PropertiesToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_artifact) } {
            return .{ .service_metadata = service_metadata, .action = update_artifact };
        }
    },
    Response: type = struct {
        artifact_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .artifact_arn = "ArtifactArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
    },
} = .{};
pub const update_code_repository: struct {
    action_name: []const u8 = "UpdateCodeRepository",
    Request: type = struct {
        code_repository_name: []const u8,
        git_config: ?struct {
            secret_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .secret_arn = "SecretArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_repository_name = "CodeRepositoryName",
                .git_config = "GitConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_code_repository) } {
            return .{ .service_metadata = service_metadata, .action = update_code_repository };
        }
    },
    Response: type = struct {
        code_repository_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .code_repository_arn = "CodeRepositoryArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_context: struct {
    action_name: []const u8 = "UpdateContext",
    Request: type = struct {
        context_name: []const u8,
        description: ?[]const u8 = null,
        properties: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        properties_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_name = "ContextName",
                .description = "Description",
                .properties = "Properties",
                .properties_to_remove = "PropertiesToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "properties", field_name))
                return try serializeMap(self.properties, self.fieldNameFor("properties"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_context) } {
            return .{ .service_metadata = service_metadata, .action = update_context };
        }
    },
    Response: type = struct {
        context_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .context_arn = "ContextArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
    },
} = .{};
pub const update_device_fleet: struct {
    action_name: []const u8 = "UpdateDeviceFleet",
    Request: type = struct {
        device_fleet_name: []const u8,
        role_arn: ?[]const u8 = null,
        description: ?[]const u8 = null,
        output_config: EdgeOutputConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
                .role_arn = "RoleArn",
                .description = "Description",
                .output_config = "OutputConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_device_fleet) } {
            return .{ .service_metadata = service_metadata, .action = update_device_fleet };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        ResourceInUse,
    },
} = .{};
pub const update_devices: struct {
    action_name: []const u8 = "UpdateDevices",
    Request: type = struct {
        device_fleet_name: []const u8,
        devices: []Device,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .device_fleet_name = "DeviceFleetName",
                .devices = "Devices",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_devices) } {
            return .{ .service_metadata = service_metadata, .action = update_devices };
        }
    },
    Response: type = struct {},
} = .{};
pub const update_domain: struct {
    action_name: []const u8 = "UpdateDomain",
    Request: type = struct {
        domain_id: []const u8,
        default_user_settings: ?UserSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .default_user_settings = "DefaultUserSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain) } {
            return .{ .service_metadata = service_metadata, .action = update_domain };
        }
    },
    Response: type = struct {
        domain_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_arn = "DomainArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_endpoint: struct {
    action_name: []const u8 = "UpdateEndpoint",
    Request: type = struct {
        endpoint_name: []const u8,
        endpoint_config_name: []const u8,
        retain_all_variant_properties: ?bool = null,
        exclude_retained_variant_properties: ?[]struct {
            variant_property_type: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .variant_property_type = "VariantPropertyType",
                };
                return @field(mappings, field_name);
            }
        } = null,
        deployment_config: ?DeploymentConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .endpoint_config_name = "EndpointConfigName",
                .retain_all_variant_properties = "RetainAllVariantProperties",
                .exclude_retained_variant_properties = "ExcludeRetainedVariantProperties",
                .deployment_config = "DeploymentConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = update_endpoint };
        }
    },
    Response: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const update_endpoint_weights_and_capacities: struct {
    action_name: []const u8 = "UpdateEndpointWeightsAndCapacities",
    Request: type = struct {
        endpoint_name: []const u8,
        desired_weights_and_capacities: []struct {
            variant_name: []const u8,
            desired_weight: ?f32 = null,
            desired_instance_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .variant_name = "VariantName",
                    .desired_weight = "DesiredWeight",
                    .desired_instance_count = "DesiredInstanceCount",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_name = "EndpointName",
                .desired_weights_and_capacities = "DesiredWeightsAndCapacities",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_endpoint_weights_and_capacities) } {
            return .{ .service_metadata = service_metadata, .action = update_endpoint_weights_and_capacities };
        }
    },
    Response: type = struct {
        endpoint_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .endpoint_arn = "EndpointArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const update_experiment: struct {
    action_name: []const u8 = "UpdateExperiment",
    Request: type = struct {
        experiment_name: []const u8,
        display_name: ?[]const u8 = null,
        description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_name = "ExperimentName",
                .display_name = "DisplayName",
                .description = "Description",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_experiment) } {
            return .{ .service_metadata = service_metadata, .action = update_experiment };
        }
    },
    Response: type = struct {
        experiment_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .experiment_arn = "ExperimentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
    },
} = .{};
pub const update_image: struct {
    action_name: []const u8 = "UpdateImage",
    Request: type = struct {
        delete_properties: ?[][]const u8 = null,
        description: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        image_name: []const u8,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .delete_properties = "DeleteProperties",
                .description = "Description",
                .display_name = "DisplayName",
                .image_name = "ImageName",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_image) } {
            return .{ .service_metadata = service_metadata, .action = update_image };
        }
    },
    Response: type = struct {
        image_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_arn = "ImageArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceNotFound,
    },
} = .{};
pub const update_model_package: struct {
    action_name: []const u8 = "UpdateModelPackage",
    Request: type = struct {
        model_package_arn: []const u8,
        model_approval_status: []const u8,
        approval_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_arn = "ModelPackageArn",
                .model_approval_status = "ModelApprovalStatus",
                .approval_description = "ApprovalDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_model_package) } {
            return .{ .service_metadata = service_metadata, .action = update_model_package };
        }
    },
    Response: type = struct {
        model_package_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_package_arn = "ModelPackageArn",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_monitoring_schedule: struct {
    action_name: []const u8 = "UpdateMonitoringSchedule",
    Request: type = struct {
        monitoring_schedule_name: []const u8,
        monitoring_schedule_config: MonitoringScheduleConfig,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_name = "MonitoringScheduleName",
                .monitoring_schedule_config = "MonitoringScheduleConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_monitoring_schedule) } {
            return .{ .service_metadata = service_metadata, .action = update_monitoring_schedule };
        }
    },
    Response: type = struct {
        monitoring_schedule_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .monitoring_schedule_arn = "MonitoringScheduleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_notebook_instance: struct {
    action_name: []const u8 = "UpdateNotebookInstance",
    Request: type = struct {
        notebook_instance_name: []const u8,
        instance_type: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        lifecycle_config_name: ?[]const u8 = null,
        disassociate_lifecycle_config: ?bool = null,
        volume_size_in_gb: ?i64 = null,
        default_code_repository: ?[]const u8 = null,
        additional_code_repositories: ?[][]const u8 = null,
        accelerator_types: ?[][]const u8 = null,
        disassociate_accelerator_types: ?bool = null,
        disassociate_default_code_repository: ?bool = null,
        disassociate_additional_code_repositories: ?bool = null,
        root_access: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_name = "NotebookInstanceName",
                .instance_type = "InstanceType",
                .role_arn = "RoleArn",
                .lifecycle_config_name = "LifecycleConfigName",
                .disassociate_lifecycle_config = "DisassociateLifecycleConfig",
                .volume_size_in_gb = "VolumeSizeInGB",
                .default_code_repository = "DefaultCodeRepository",
                .additional_code_repositories = "AdditionalCodeRepositories",
                .accelerator_types = "AcceleratorTypes",
                .disassociate_accelerator_types = "DisassociateAcceleratorTypes",
                .disassociate_default_code_repository = "DisassociateDefaultCodeRepository",
                .disassociate_additional_code_repositories = "DisassociateAdditionalCodeRepositories",
                .root_access = "RootAccess",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_notebook_instance) } {
            return .{ .service_metadata = service_metadata, .action = update_notebook_instance };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const update_notebook_instance_lifecycle_config: struct {
    action_name: []const u8 = "UpdateNotebookInstanceLifecycleConfig",
    Request: type = struct {
        notebook_instance_lifecycle_config_name: []const u8,
        on_create: ?[]NotebookInstanceLifecycleHook = null,
        on_start: ?[]NotebookInstanceLifecycleHook = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .notebook_instance_lifecycle_config_name = "NotebookInstanceLifecycleConfigName",
                .on_create = "OnCreate",
                .on_start = "OnStart",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_notebook_instance_lifecycle_config) } {
            return .{ .service_metadata = service_metadata, .action = update_notebook_instance_lifecycle_config };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};
pub const update_pipeline: struct {
    action_name: []const u8 = "UpdatePipeline",
    Request: type = struct {
        pipeline_name: []const u8,
        pipeline_display_name: ?[]const u8 = null,
        pipeline_definition: ?[]const u8 = null,
        pipeline_description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_name = "PipelineName",
                .pipeline_display_name = "PipelineDisplayName",
                .pipeline_definition = "PipelineDefinition",
                .pipeline_description = "PipelineDescription",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = update_pipeline };
        }
    },
    Response: type = struct {
        pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_arn = "PipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_pipeline_execution: struct {
    action_name: []const u8 = "UpdatePipelineExecution",
    Request: type = struct {
        pipeline_execution_arn: []const u8,
        pipeline_execution_description: ?[]const u8 = null,
        pipeline_execution_display_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
                .pipeline_execution_description = "PipelineExecutionDescription",
                .pipeline_execution_display_name = "PipelineExecutionDisplayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = update_pipeline_execution };
        }
    },
    Response: type = struct {
        pipeline_execution_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .pipeline_execution_arn = "PipelineExecutionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_training_job: struct {
    action_name: []const u8 = "UpdateTrainingJob",
    Request: type = struct {
        training_job_name: []const u8,
        profiler_config: ?struct {
            s3_output_path: ?[]const u8 = null,
            profiling_interval_in_milliseconds: ?i64 = null,
            profiling_parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            disable_profiler: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .s3_output_path = "S3OutputPath",
                    .profiling_interval_in_milliseconds = "ProfilingIntervalInMilliseconds",
                    .profiling_parameters = "ProfilingParameters",
                    .disable_profiler = "DisableProfiler",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "profiling_parameters", field_name))
                    return try serializeMap(self.profiling_parameters, self.fieldNameFor("profiling_parameters"), options, out_stream);
                return false;
            }
        } = null,
        profiler_rule_configurations: ?[]ProfilerRuleConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_name = "TrainingJobName",
                .profiler_config = "ProfilerConfig",
                .profiler_rule_configurations = "ProfilerRuleConfigurations",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_training_job) } {
            return .{ .service_metadata = service_metadata, .action = update_training_job };
        }
    },
    Response: type = struct {
        training_job_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .training_job_arn = "TrainingJobArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_trial: struct {
    action_name: []const u8 = "UpdateTrial",
    Request: type = struct {
        trial_name: []const u8,
        display_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_name = "TrialName",
                .display_name = "DisplayName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_trial) } {
            return .{ .service_metadata = service_metadata, .action = update_trial };
        }
    },
    Response: type = struct {
        trial_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_arn = "TrialArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
    },
} = .{};
pub const update_trial_component: struct {
    action_name: []const u8 = "UpdateTrialComponent",
    Request: type = struct {
        trial_component_name: []const u8,
        display_name: ?[]const u8 = null,
        status: ?TrialComponentStatus = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentParameterValue = null,
        } = null,
        parameters_to_remove: ?[][]const u8 = null,
        input_artifacts: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentArtifact = null,
        } = null,
        input_artifacts_to_remove: ?[][]const u8 = null,
        output_artifacts: ?[]struct {
            key: ?[]const u8 = null,
            value: ?TrialComponentArtifact = null,
        } = null,
        output_artifacts_to_remove: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_name = "TrialComponentName",
                .display_name = "DisplayName",
                .status = "Status",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .parameters = "Parameters",
                .parameters_to_remove = "ParametersToRemove",
                .input_artifacts = "InputArtifacts",
                .input_artifacts_to_remove = "InputArtifactsToRemove",
                .output_artifacts = "OutputArtifacts",
                .output_artifacts_to_remove = "OutputArtifactsToRemove",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "input_artifacts", field_name))
                return try serializeMap(self.input_artifacts, self.fieldNameFor("input_artifacts"), options, out_stream);
            if (std.mem.eql(u8, "output_artifacts", field_name))
                return try serializeMap(self.output_artifacts, self.fieldNameFor("output_artifacts"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_trial_component) } {
            return .{ .service_metadata = service_metadata, .action = update_trial_component };
        }
    },
    Response: type = struct {
        trial_component_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trial_component_arn = "TrialComponentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
    },
} = .{};
pub const update_user_profile: struct {
    action_name: []const u8 = "UpdateUserProfile",
    Request: type = struct {
        domain_id: []const u8,
        user_profile_name: []const u8,
        user_settings: ?UserSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_id = "DomainId",
                .user_profile_name = "UserProfileName",
                .user_settings = "UserSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_user_profile };
        }
    },
    Response: type = struct {
        user_profile_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_profile_arn = "UserProfileArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceInUse,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_workforce: struct {
    action_name: []const u8 = "UpdateWorkforce",
    Request: type = struct {
        workforce_name: []const u8,
        source_ip_config: ?SourceIpConfig = null,
        oidc_config: ?OidcConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workforce_name = "WorkforceName",
                .source_ip_config = "SourceIpConfig",
                .oidc_config = "OidcConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workforce) } {
            return .{ .service_metadata = service_metadata, .action = update_workforce };
        }
    },
    Response: type = struct {
        workforce: Workforce,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workforce = "Workforce",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_workteam: struct {
    action_name: []const u8 = "UpdateWorkteam",
    Request: type = struct {
        workteam_name: []const u8,
        member_definitions: ?[]MemberDefinition = null,
        description: ?[]const u8 = null,
        notification_configuration: ?NotificationConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam_name = "WorkteamName",
                .member_definitions = "MemberDefinitions",
                .description = "Description",
                .notification_configuration = "NotificationConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workteam) } {
            return .{ .service_metadata = service_metadata, .action = update_workteam };
        }
    },
    Response: type = struct {
        workteam: Workteam,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workteam = "Workteam",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceLimitExceeded,
    },
} = .{};

pub const Workteam = struct {
    workteam_name: []const u8,
    member_definitions: []MemberDefinition,
    workteam_arn: []const u8,
    workforce_arn: ?[]const u8 = null,
    product_listing_ids: ?[][]const u8 = null,
    description: []const u8,
    sub_domain: ?[]const u8 = null,
    create_date: ?i64 = null,
    last_updated_date: ?i64 = null,
    notification_configuration: ?NotificationConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workteam_name = "WorkteamName",
            .member_definitions = "MemberDefinitions",
            .workteam_arn = "WorkteamArn",
            .workforce_arn = "WorkforceArn",
            .product_listing_ids = "ProductListingIds",
            .description = "Description",
            .sub_domain = "SubDomain",
            .create_date = "CreateDate",
            .last_updated_date = "LastUpdatedDate",
            .notification_configuration = "NotificationConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const NotificationConfiguration = struct {
    notification_topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notification_topic_arn = "NotificationTopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const MemberDefinition = struct {
    cognito_member_definition: ?CognitoMemberDefinition = null,
    oidc_member_definition: ?OidcMemberDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cognito_member_definition = "CognitoMemberDefinition",
            .oidc_member_definition = "OidcMemberDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const OidcMemberDefinition = struct {
    groups: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .groups = "Groups",
        };
        return @field(mappings, field_name);
    }
};

pub const CognitoMemberDefinition = struct {
    user_pool: []const u8,
    user_group: []const u8,
    client_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool = "UserPool",
            .user_group = "UserGroup",
            .client_id = "ClientId",
        };
        return @field(mappings, field_name);
    }
};

pub const Workforce = struct {
    workforce_name: []const u8,
    workforce_arn: []const u8,
    last_updated_date: ?i64 = null,
    source_ip_config: ?SourceIpConfig = null,
    sub_domain: ?[]const u8 = null,
    cognito_config: ?CognitoConfig = null,
    oidc_config: ?OidcConfigForResponse = null,
    create_date: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workforce_name = "WorkforceName",
            .workforce_arn = "WorkforceArn",
            .last_updated_date = "LastUpdatedDate",
            .source_ip_config = "SourceIpConfig",
            .sub_domain = "SubDomain",
            .cognito_config = "CognitoConfig",
            .oidc_config = "OidcConfig",
            .create_date = "CreateDate",
        };
        return @field(mappings, field_name);
    }
};

pub const OidcConfigForResponse = struct {
    client_id: ?[]const u8 = null,
    issuer: ?[]const u8 = null,
    authorization_endpoint: ?[]const u8 = null,
    token_endpoint: ?[]const u8 = null,
    user_info_endpoint: ?[]const u8 = null,
    logout_endpoint: ?[]const u8 = null,
    jwks_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "ClientId",
            .issuer = "Issuer",
            .authorization_endpoint = "AuthorizationEndpoint",
            .token_endpoint = "TokenEndpoint",
            .user_info_endpoint = "UserInfoEndpoint",
            .logout_endpoint = "LogoutEndpoint",
            .jwks_uri = "JwksUri",
        };
        return @field(mappings, field_name);
    }
};

pub const CognitoConfig = struct {
    user_pool: []const u8,
    client_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool = "UserPool",
            .client_id = "ClientId",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceIpConfig = struct {
    cidrs: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cidrs = "Cidrs",
        };
        return @field(mappings, field_name);
    }
};

pub const OidcConfig = struct {
    client_id: []const u8,
    client_secret: []const u8,
    issuer: []const u8,
    authorization_endpoint: []const u8,
    token_endpoint: []const u8,
    user_info_endpoint: []const u8,
    logout_endpoint: []const u8,
    jwks_uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .client_id = "ClientId",
            .client_secret = "ClientSecret",
            .issuer = "Issuer",
            .authorization_endpoint = "AuthorizationEndpoint",
            .token_endpoint = "TokenEndpoint",
            .user_info_endpoint = "UserInfoEndpoint",
            .logout_endpoint = "LogoutEndpoint",
            .jwks_uri = "JwksUri",
        };
        return @field(mappings, field_name);
    }
};

pub const UserSettings = struct {
    execution_role: ?[]const u8 = null,
    security_groups: ?[][]const u8 = null,
    sharing_settings: ?SharingSettings = null,
    jupyter_server_app_settings: ?JupyterServerAppSettings = null,
    kernel_gateway_app_settings: ?KernelGatewayAppSettings = null,
    tensor_board_app_settings: ?TensorBoardAppSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .execution_role = "ExecutionRole",
            .security_groups = "SecurityGroups",
            .sharing_settings = "SharingSettings",
            .jupyter_server_app_settings = "JupyterServerAppSettings",
            .kernel_gateway_app_settings = "KernelGatewayAppSettings",
            .tensor_board_app_settings = "TensorBoardAppSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const TensorBoardAppSettings = struct {
    default_resource_spec: ?ResourceSpec = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_resource_spec = "DefaultResourceSpec",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceSpec = struct {
    sage_maker_image_arn: ?[]const u8 = null,
    sage_maker_image_version_arn: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sage_maker_image_arn = "SageMakerImageArn",
            .sage_maker_image_version_arn = "SageMakerImageVersionArn",
            .instance_type = "InstanceType",
        };
        return @field(mappings, field_name);
    }
};

pub const KernelGatewayAppSettings = struct {
    default_resource_spec: ?ResourceSpec = null,
    custom_images: ?[]CustomImage = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_resource_spec = "DefaultResourceSpec",
            .custom_images = "CustomImages",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomImage = struct {
    image_name: []const u8,
    image_version_number: ?i64 = null,
    app_image_config_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_name = "ImageName",
            .image_version_number = "ImageVersionNumber",
            .app_image_config_name = "AppImageConfigName",
        };
        return @field(mappings, field_name);
    }
};

pub const JupyterServerAppSettings = struct {
    default_resource_spec: ?ResourceSpec = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_resource_spec = "DefaultResourceSpec",
        };
        return @field(mappings, field_name);
    }
};

pub const SharingSettings = struct {
    notebook_output_option: ?[]const u8 = null,
    s3_output_path: ?[]const u8 = null,
    s3_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .notebook_output_option = "NotebookOutputOption",
            .s3_output_path = "S3OutputPath",
            .s3_kms_key_id = "S3KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const TrialComponentArtifact = struct {
    media_type: ?[]const u8 = null,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .media_type = "MediaType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const TrialComponentParameterValue = union {
    string_value: ?[]const u8,
    number_value: ?f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_value = "StringValue",
            .number_value = "NumberValue",
        };
        return @field(mappings, field_name);
    }
};

pub const TrialComponentStatus = struct {
    primary_status: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_status = "PrimaryStatus",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const ProfilerRuleConfiguration = struct {
    rule_configuration_name: []const u8,
    local_path: ?[]const u8 = null,
    s3_output_path: ?[]const u8 = null,
    rule_evaluator_image: []const u8,
    instance_type: ?[]const u8 = null,
    volume_size_in_gb: ?i64 = null,
    rule_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_configuration_name = "RuleConfigurationName",
            .local_path = "LocalPath",
            .s3_output_path = "S3OutputPath",
            .rule_evaluator_image = "RuleEvaluatorImage",
            .instance_type = "InstanceType",
            .volume_size_in_gb = "VolumeSizeInGB",
            .rule_parameters = "RuleParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "rule_parameters", field_name))
            return try serializeMap(self.rule_parameters, self.fieldNameFor("rule_parameters"), options, out_stream);
        return false;
    }
};

pub const NotebookInstanceLifecycleHook = struct {
    content: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringScheduleConfig = struct {
    schedule_config: ?ScheduleConfig = null,
    monitoring_job_definition: ?MonitoringJobDefinition = null,
    monitoring_job_definition_name: ?[]const u8 = null,
    monitoring_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_config = "ScheduleConfig",
            .monitoring_job_definition = "MonitoringJobDefinition",
            .monitoring_job_definition_name = "MonitoringJobDefinitionName",
            .monitoring_type = "MonitoringType",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringJobDefinition = struct {
    baseline_config: ?MonitoringBaselineConfig = null,
    monitoring_inputs: []MonitoringInput,
    monitoring_output_config: MonitoringOutputConfig,
    monitoring_resources: MonitoringResources,
    monitoring_app_specification: MonitoringAppSpecification,
    stopping_condition: ?MonitoringStoppingCondition = null,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    network_config: ?NetworkConfig = null,
    role_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .baseline_config = "BaselineConfig",
            .monitoring_inputs = "MonitoringInputs",
            .monitoring_output_config = "MonitoringOutputConfig",
            .monitoring_resources = "MonitoringResources",
            .monitoring_app_specification = "MonitoringAppSpecification",
            .stopping_condition = "StoppingCondition",
            .environment = "Environment",
            .network_config = "NetworkConfig",
            .role_arn = "RoleArn",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const NetworkConfig = struct {
    enable_inter_container_traffic_encryption: ?bool = null,
    enable_network_isolation: ?bool = null,
    vpc_config: ?VpcConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_inter_container_traffic_encryption = "EnableInterContainerTrafficEncryption",
            .enable_network_isolation = "EnableNetworkIsolation",
            .vpc_config = "VpcConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConfig = struct {
    security_group_ids: [][]const u8,
    subnets: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_group_ids = "SecurityGroupIds",
            .subnets = "Subnets",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringStoppingCondition = struct {
    max_runtime_in_seconds: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_runtime_in_seconds = "MaxRuntimeInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringAppSpecification = struct {
    image_uri: []const u8,
    container_entrypoint: ?[][]const u8 = null,
    container_arguments: ?[][]const u8 = null,
    record_preprocessor_source_uri: ?[]const u8 = null,
    post_analytics_processor_source_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_uri = "ImageUri",
            .container_entrypoint = "ContainerEntrypoint",
            .container_arguments = "ContainerArguments",
            .record_preprocessor_source_uri = "RecordPreprocessorSourceUri",
            .post_analytics_processor_source_uri = "PostAnalyticsProcessorSourceUri",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringResources = struct {
    cluster_config: MonitoringClusterConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_config = "ClusterConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringClusterConfig = struct {
    instance_count: i64,
    instance_type: []const u8,
    volume_size_in_gb: i64,
    volume_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_count = "InstanceCount",
            .instance_type = "InstanceType",
            .volume_size_in_gb = "VolumeSizeInGB",
            .volume_kms_key_id = "VolumeKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringOutputConfig = struct {
    monitoring_outputs: []MonitoringOutput,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .monitoring_outputs = "MonitoringOutputs",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringOutput = struct {
    s3_output: MonitoringS3Output,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output = "S3Output",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringS3Output = struct {
    s3_uri: []const u8,
    local_path: []const u8,
    s3_upload_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .local_path = "LocalPath",
            .s3_upload_mode = "S3UploadMode",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringInput = struct {
    endpoint_input: EndpointInput,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_input = "EndpointInput",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointInput = struct {
    endpoint_name: []const u8,
    local_path: []const u8,
    s3_input_mode: ?[]const u8 = null,
    s3_data_distribution_type: ?[]const u8 = null,
    features_attribute: ?[]const u8 = null,
    inference_attribute: ?[]const u8 = null,
    probability_attribute: ?[]const u8 = null,
    probability_threshold_attribute: ?f64 = null,
    start_time_offset: ?[]const u8 = null,
    end_time_offset: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_name = "EndpointName",
            .local_path = "LocalPath",
            .s3_input_mode = "S3InputMode",
            .s3_data_distribution_type = "S3DataDistributionType",
            .features_attribute = "FeaturesAttribute",
            .inference_attribute = "InferenceAttribute",
            .probability_attribute = "ProbabilityAttribute",
            .probability_threshold_attribute = "ProbabilityThresholdAttribute",
            .start_time_offset = "StartTimeOffset",
            .end_time_offset = "EndTimeOffset",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringBaselineConfig = struct {
    baselining_job_name: ?[]const u8 = null,
    constraints_resource: ?MonitoringConstraintsResource = null,
    statistics_resource: ?MonitoringStatisticsResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .baselining_job_name = "BaseliningJobName",
            .constraints_resource = "ConstraintsResource",
            .statistics_resource = "StatisticsResource",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringStatisticsResource = struct {
    s3_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringConstraintsResource = struct {
    s3_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const ScheduleConfig = struct {
    schedule_expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "ScheduleExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const DeploymentConfig = struct {
    blue_green_update_policy: BlueGreenUpdatePolicy,
    auto_rollback_configuration: ?AutoRollbackConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .blue_green_update_policy = "BlueGreenUpdatePolicy",
            .auto_rollback_configuration = "AutoRollbackConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoRollbackConfig = struct {
    alarms: ?[]Alarm = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alarms = "Alarms",
        };
        return @field(mappings, field_name);
    }
};

pub const Alarm = struct {
    alarm_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alarm_name = "AlarmName",
        };
        return @field(mappings, field_name);
    }
};

pub const BlueGreenUpdatePolicy = struct {
    traffic_routing_configuration: TrafficRoutingConfig,
    termination_wait_in_seconds: ?i64 = null,
    maximum_execution_timeout_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .traffic_routing_configuration = "TrafficRoutingConfiguration",
            .termination_wait_in_seconds = "TerminationWaitInSeconds",
            .maximum_execution_timeout_in_seconds = "MaximumExecutionTimeoutInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const TrafficRoutingConfig = struct {
    type: []const u8,
    wait_interval_in_seconds: i64,
    canary_size: ?CapacitySize = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .wait_interval_in_seconds = "WaitIntervalInSeconds",
            .canary_size = "CanarySize",
        };
        return @field(mappings, field_name);
    }
};

pub const CapacitySize = struct {
    type: []const u8,
    value: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Device = struct {
    device_name: []const u8,
    description: ?[]const u8 = null,
    iot_thing_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "DeviceName",
            .description = "Description",
            .iot_thing_name = "IotThingName",
        };
        return @field(mappings, field_name);
    }
};

pub const EdgeOutputConfig = struct {
    s3_output_location: []const u8,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_location = "S3OutputLocation",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const KernelGatewayImageConfig = struct {
    kernel_specs: []KernelSpec,
    file_system_config: ?FileSystemConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kernel_specs = "KernelSpecs",
            .file_system_config = "FileSystemConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemConfig = struct {
    mount_path: ?[]const u8 = null,
    default_uid: ?i64 = null,
    default_gid: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mount_path = "MountPath",
            .default_uid = "DefaultUid",
            .default_gid = "DefaultGid",
        };
        return @field(mappings, field_name);
    }
};

pub const KernelSpec = struct {
    name: []const u8,
    display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .display_name = "DisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameter = struct {
    name: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const OfflineStoreStatus = struct {
    status: []const u8,
    blocked_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .blocked_reason = "BlockedReason",
        };
        return @field(mappings, field_name);
    }
};

pub const OfflineStoreConfig = struct {
    s3_storage_config: S3StorageConfig,
    disable_glue_table_creation: ?bool = null,
    data_catalog_config: ?DataCatalogConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_storage_config = "S3StorageConfig",
            .disable_glue_table_creation = "DisableGlueTableCreation",
            .data_catalog_config = "DataCatalogConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCatalogConfig = struct {
    table_name: []const u8,
    catalog: []const u8,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "TableName",
            .catalog = "Catalog",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const S3StorageConfig = struct {
    s3_uri: []const u8,
    kms_key_id: ?[]const u8 = null,
    resolved_output_s3_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .kms_key_id = "KmsKeyId",
            .resolved_output_s3_uri = "ResolvedOutputS3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const OnlineStoreConfig = struct {
    security_config: ?OnlineStoreSecurityConfig = null,
    enable_online_store: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .security_config = "SecurityConfig",
            .enable_online_store = "EnableOnlineStore",
        };
        return @field(mappings, field_name);
    }
};

pub const OnlineStoreSecurityConfig = struct {
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const FeatureDefinition = struct {
    feature_name: ?[]const u8 = null,
    feature_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .feature_name = "FeatureName",
            .feature_type = "FeatureType",
        };
        return @field(mappings, field_name);
    }
};

pub const UserContext = struct {
    user_profile_arn: ?[]const u8 = null,
    user_profile_name: ?[]const u8 = null,
    domain_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_profile_arn = "UserProfileArn",
            .user_profile_name = "UserProfileName",
            .domain_id = "DomainId",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelMetrics = struct {
    model_quality: ?ModelQuality = null,
    model_data_quality: ?ModelDataQuality = null,
    bias: ?Bias = null,
    explainability: ?Explainability = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .model_quality = "ModelQuality",
            .model_data_quality = "ModelDataQuality",
            .bias = "Bias",
            .explainability = "Explainability",
        };
        return @field(mappings, field_name);
    }
};

pub const Explainability = struct {
    report: ?MetricsSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report = "Report",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricsSource = struct {
    content_type: []const u8,
    content_digest: ?[]const u8 = null,
    s3_uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_type = "ContentType",
            .content_digest = "ContentDigest",
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const Bias = struct {
    report: ?MetricsSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report = "Report",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelDataQuality = struct {
    statistics: ?MetricsSource = null,
    constraints: ?MetricsSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statistics = "Statistics",
            .constraints = "Constraints",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelQuality = struct {
    statistics: ?MetricsSource = null,
    constraints: ?MetricsSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .statistics = "Statistics",
            .constraints = "Constraints",
        };
        return @field(mappings, field_name);
    }
};

pub const MetadataProperties = struct {
    commit_id: ?[]const u8 = null,
    repository: ?[]const u8 = null,
    generated_by: ?[]const u8 = null,
    project_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .commit_id = "CommitId",
            .repository = "Repository",
            .generated_by = "GeneratedBy",
            .project_id = "ProjectId",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelPackageStatusDetails = struct {
    validation_statuses: []ModelPackageStatusItem,
    image_scan_statuses: ?[]ModelPackageStatusItem = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .validation_statuses = "ValidationStatuses",
            .image_scan_statuses = "ImageScanStatuses",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelPackageStatusItem = struct {
    name: []const u8,
    status: []const u8,
    failure_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .failure_reason = "FailureReason",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelPackageValidationSpecification = struct {
    validation_role: []const u8,
    validation_profiles: []ModelPackageValidationProfile,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .validation_role = "ValidationRole",
            .validation_profiles = "ValidationProfiles",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelPackageValidationProfile = struct {
    profile_name: []const u8,
    transform_job_definition: TransformJobDefinition,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .profile_name = "ProfileName",
            .transform_job_definition = "TransformJobDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformJobDefinition = struct {
    max_concurrent_transforms: ?i64 = null,
    max_payload_in_mb: ?i64 = null,
    batch_strategy: ?[]const u8 = null,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    transform_input: TransformInput,
    transform_output: TransformOutput,
    transform_resources: TransformResources,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_concurrent_transforms = "MaxConcurrentTransforms",
            .max_payload_in_mb = "MaxPayloadInMB",
            .batch_strategy = "BatchStrategy",
            .environment = "Environment",
            .transform_input = "TransformInput",
            .transform_output = "TransformOutput",
            .transform_resources = "TransformResources",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const TransformResources = struct {
    instance_type: []const u8,
    instance_count: i64,
    volume_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "InstanceType",
            .instance_count = "InstanceCount",
            .volume_kms_key_id = "VolumeKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformOutput = struct {
    s3_output_path: []const u8,
    accept: ?[]const u8 = null,
    assemble_with: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_path = "S3OutputPath",
            .accept = "Accept",
            .assemble_with = "AssembleWith",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformInput = struct {
    data_source: TransformDataSource,
    content_type: ?[]const u8 = null,
    compression_type: ?[]const u8 = null,
    split_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source = "DataSource",
            .content_type = "ContentType",
            .compression_type = "CompressionType",
            .split_type = "SplitType",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformDataSource = struct {
    s3_data_source: TransformS3DataSource,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_source = "S3DataSource",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformS3DataSource = struct {
    s3_data_type: []const u8,
    s3_uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_type = "S3DataType",
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceAlgorithmSpecification = struct {
    source_algorithms: []SourceAlgorithm,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_algorithms = "SourceAlgorithms",
        };
        return @field(mappings, field_name);
    }
};

pub const SourceAlgorithm = struct {
    model_data_url: ?[]const u8 = null,
    algorithm_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .model_data_url = "ModelDataUrl",
            .algorithm_name = "AlgorithmName",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceSpecification = struct {
    containers: []ModelPackageContainerDefinition,
    supported_transform_instance_types: ?[][]const u8 = null,
    supported_realtime_inference_instance_types: ?[][]const u8 = null,
    supported_content_types: [][]const u8,
    supported_response_mime_types: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .containers = "Containers",
            .supported_transform_instance_types = "SupportedTransformInstanceTypes",
            .supported_realtime_inference_instance_types = "SupportedRealtimeInferenceInstanceTypes",
            .supported_content_types = "SupportedContentTypes",
            .supported_response_mime_types = "SupportedResponseMIMETypes",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelPackageContainerDefinition = struct {
    container_hostname: ?[]const u8 = null,
    image: []const u8,
    image_digest: ?[]const u8 = null,
    model_data_url: ?[]const u8 = null,
    product_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_hostname = "ContainerHostname",
            .image = "Image",
            .image_digest = "ImageDigest",
            .model_data_url = "ModelDataUrl",
            .product_id = "ProductId",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringExecutionSummary = struct {
    monitoring_schedule_name: []const u8,
    scheduled_time: i64,
    creation_time: i64,
    last_modified_time: i64,
    monitoring_execution_status: []const u8,
    processing_job_arn: ?[]const u8 = null,
    endpoint_name: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    monitoring_job_definition_name: ?[]const u8 = null,
    monitoring_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .monitoring_schedule_name = "MonitoringScheduleName",
            .scheduled_time = "ScheduledTime",
            .creation_time = "CreationTime",
            .last_modified_time = "LastModifiedTime",
            .monitoring_execution_status = "MonitoringExecutionStatus",
            .processing_job_arn = "ProcessingJobArn",
            .endpoint_name = "EndpointName",
            .failure_reason = "FailureReason",
            .monitoring_job_definition_name = "MonitoringJobDefinitionName",
            .monitoring_type = "MonitoringType",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCaptureConfigSummary = struct {
    enable_capture: bool,
    capture_status: []const u8,
    current_sampling_percentage: i64,
    destination_s3_uri: []const u8,
    kms_key_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_capture = "EnableCapture",
            .capture_status = "CaptureStatus",
            .current_sampling_percentage = "CurrentSamplingPercentage",
            .destination_s3_uri = "DestinationS3Uri",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductionVariantSummary = struct {
    variant_name: []const u8,
    deployed_images: ?[]DeployedImage = null,
    current_weight: ?f32 = null,
    desired_weight: ?f32 = null,
    current_instance_count: ?i64 = null,
    desired_instance_count: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .variant_name = "VariantName",
            .deployed_images = "DeployedImages",
            .current_weight = "CurrentWeight",
            .desired_weight = "DesiredWeight",
            .current_instance_count = "CurrentInstanceCount",
            .desired_instance_count = "DesiredInstanceCount",
        };
        return @field(mappings, field_name);
    }
};

pub const DeployedImage = struct {
    specified_image: ?[]const u8 = null,
    resolved_image: ?[]const u8 = null,
    resolution_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .specified_image = "SpecifiedImage",
            .resolved_image = "ResolvedImage",
            .resolution_time = "ResolutionTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperimentConfig = struct {
    experiment_name: ?[]const u8 = null,
    trial_name: ?[]const u8 = null,
    trial_component_display_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .experiment_name = "ExperimentName",
            .trial_name = "TrialName",
            .trial_component_display_name = "TrialComponentDisplayName",
        };
        return @field(mappings, field_name);
    }
};

pub const DataProcessing = struct {
    input_filter: ?[]const u8 = null,
    output_filter: ?[]const u8 = null,
    join_source: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_filter = "InputFilter",
            .output_filter = "OutputFilter",
            .join_source = "JoinSource",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelClientConfig = struct {
    invocations_timeout_in_seconds: ?i64 = null,
    invocations_max_retries: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .invocations_timeout_in_seconds = "InvocationsTimeoutInSeconds",
            .invocations_max_retries = "InvocationsMaxRetries",
        };
        return @field(mappings, field_name);
    }
};

pub const AppSpecification = struct {
    image_uri: []const u8,
    container_entrypoint: ?[][]const u8 = null,
    container_arguments: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_uri = "ImageUri",
            .container_entrypoint = "ContainerEntrypoint",
            .container_arguments = "ContainerArguments",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingStoppingCondition = struct {
    max_runtime_in_seconds: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_runtime_in_seconds = "MaxRuntimeInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingResources = struct {
    cluster_config: ProcessingClusterConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_config = "ClusterConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingClusterConfig = struct {
    instance_count: i64,
    instance_type: []const u8,
    volume_size_in_gb: i64,
    volume_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_count = "InstanceCount",
            .instance_type = "InstanceType",
            .volume_size_in_gb = "VolumeSizeInGB",
            .volume_kms_key_id = "VolumeKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingOutputConfig = struct {
    outputs: []ProcessingOutput,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .outputs = "Outputs",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingOutput = struct {
    output_name: []const u8,
    s3_output: ?ProcessingS3Output = null,
    feature_store_output: ?ProcessingFeatureStoreOutput = null,
    app_managed: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_name = "OutputName",
            .s3_output = "S3Output",
            .feature_store_output = "FeatureStoreOutput",
            .app_managed = "AppManaged",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingFeatureStoreOutput = struct {
    feature_group_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .feature_group_name = "FeatureGroupName",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingS3Output = struct {
    s3_uri: []const u8,
    local_path: []const u8,
    s3_upload_mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .local_path = "LocalPath",
            .s3_upload_mode = "S3UploadMode",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingInput = struct {
    input_name: []const u8,
    app_managed: ?bool = null,
    s3_input: ?ProcessingS3Input = null,
    dataset_definition: ?DatasetDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .input_name = "InputName",
            .app_managed = "AppManaged",
            .s3_input = "S3Input",
            .dataset_definition = "DatasetDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetDefinition = struct {
    athena_dataset_definition: ?AthenaDatasetDefinition = null,
    redshift_dataset_definition: ?RedshiftDatasetDefinition = null,
    local_path: ?[]const u8 = null,
    data_distribution_type: ?[]const u8 = null,
    input_mode: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .athena_dataset_definition = "AthenaDatasetDefinition",
            .redshift_dataset_definition = "RedshiftDatasetDefinition",
            .local_path = "LocalPath",
            .data_distribution_type = "DataDistributionType",
            .input_mode = "InputMode",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftDatasetDefinition = struct {
    cluster_id: []const u8,
    database: []const u8,
    db_user: []const u8,
    query_string: []const u8,
    cluster_role_arn: []const u8,
    output_s3_uri: []const u8,
    kms_key_id: ?[]const u8 = null,
    output_format: []const u8,
    output_compression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cluster_id = "ClusterId",
            .database = "Database",
            .db_user = "DbUser",
            .query_string = "QueryString",
            .cluster_role_arn = "ClusterRoleArn",
            .output_s3_uri = "OutputS3Uri",
            .kms_key_id = "KmsKeyId",
            .output_format = "OutputFormat",
            .output_compression = "OutputCompression",
        };
        return @field(mappings, field_name);
    }
};

pub const AthenaDatasetDefinition = struct {
    catalog: []const u8,
    database: []const u8,
    query_string: []const u8,
    work_group: ?[]const u8 = null,
    output_s3_uri: []const u8,
    kms_key_id: ?[]const u8 = null,
    output_format: []const u8,
    output_compression: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .catalog = "Catalog",
            .database = "Database",
            .query_string = "QueryString",
            .work_group = "WorkGroup",
            .output_s3_uri = "OutputS3Uri",
            .kms_key_id = "KmsKeyId",
            .output_format = "OutputFormat",
            .output_compression = "OutputCompression",
        };
        return @field(mappings, field_name);
    }
};

pub const ProcessingS3Input = struct {
    s3_uri: []const u8,
    local_path: ?[]const u8 = null,
    s3_data_type: []const u8,
    s3_input_mode: ?[]const u8 = null,
    s3_data_distribution_type: ?[]const u8 = null,
    s3_compression_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .local_path = "LocalPath",
            .s3_data_type = "S3DataType",
            .s3_input_mode = "S3InputMode",
            .s3_data_distribution_type = "S3DataDistributionType",
            .s3_compression_type = "S3CompressionType",
        };
        return @field(mappings, field_name);
    }
};

pub const TrainingJob = struct {
    training_job_name: ?[]const u8 = null,
    training_job_arn: ?[]const u8 = null,
    tuning_job_arn: ?[]const u8 = null,
    labeling_job_arn: ?[]const u8 = null,
    auto_ml_job_arn: ?[]const u8 = null,
    model_artifacts: ?ModelArtifacts = null,
    training_job_status: ?[]const u8 = null,
    secondary_status: ?[]const u8 = null,
    failure_reason: ?[]const u8 = null,
    hyper_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    algorithm_specification: ?AlgorithmSpecification = null,
    role_arn: ?[]const u8 = null,
    input_data_config: ?[]Channel = null,
    output_data_config: ?OutputDataConfig = null,
    resource_config: ?ResourceConfig = null,
    vpc_config: ?VpcConfig = null,
    stopping_condition: ?StoppingCondition = null,
    creation_time: ?i64 = null,
    training_start_time: ?i64 = null,
    training_end_time: ?i64 = null,
    last_modified_time: ?i64 = null,
    secondary_status_transitions: ?[]SecondaryStatusTransition = null,
    final_metric_data_list: ?[]MetricData = null,
    enable_network_isolation: ?bool = null,
    enable_inter_container_traffic_encryption: ?bool = null,
    enable_managed_spot_training: ?bool = null,
    checkpoint_config: ?CheckpointConfig = null,
    training_time_in_seconds: ?i64 = null,
    billable_time_in_seconds: ?i64 = null,
    debug_hook_config: ?DebugHookConfig = null,
    experiment_config: ?ExperimentConfig = null,
    debug_rule_configurations: ?[]DebugRuleConfiguration = null,
    tensor_board_output_config: ?TensorBoardOutputConfig = null,
    debug_rule_evaluation_statuses: ?[]DebugRuleEvaluationStatus = null,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    retry_strategy: ?RetryStrategy = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .training_job_name = "TrainingJobName",
            .training_job_arn = "TrainingJobArn",
            .tuning_job_arn = "TuningJobArn",
            .labeling_job_arn = "LabelingJobArn",
            .auto_ml_job_arn = "AutoMLJobArn",
            .model_artifacts = "ModelArtifacts",
            .training_job_status = "TrainingJobStatus",
            .secondary_status = "SecondaryStatus",
            .failure_reason = "FailureReason",
            .hyper_parameters = "HyperParameters",
            .algorithm_specification = "AlgorithmSpecification",
            .role_arn = "RoleArn",
            .input_data_config = "InputDataConfig",
            .output_data_config = "OutputDataConfig",
            .resource_config = "ResourceConfig",
            .vpc_config = "VpcConfig",
            .stopping_condition = "StoppingCondition",
            .creation_time = "CreationTime",
            .training_start_time = "TrainingStartTime",
            .training_end_time = "TrainingEndTime",
            .last_modified_time = "LastModifiedTime",
            .secondary_status_transitions = "SecondaryStatusTransitions",
            .final_metric_data_list = "FinalMetricDataList",
            .enable_network_isolation = "EnableNetworkIsolation",
            .enable_inter_container_traffic_encryption = "EnableInterContainerTrafficEncryption",
            .enable_managed_spot_training = "EnableManagedSpotTraining",
            .checkpoint_config = "CheckpointConfig",
            .training_time_in_seconds = "TrainingTimeInSeconds",
            .billable_time_in_seconds = "BillableTimeInSeconds",
            .debug_hook_config = "DebugHookConfig",
            .experiment_config = "ExperimentConfig",
            .debug_rule_configurations = "DebugRuleConfigurations",
            .tensor_board_output_config = "TensorBoardOutputConfig",
            .debug_rule_evaluation_statuses = "DebugRuleEvaluationStatuses",
            .environment = "Environment",
            .retry_strategy = "RetryStrategy",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "hyper_parameters", field_name))
            return try serializeMap(self.hyper_parameters, self.fieldNameFor("hyper_parameters"), options, out_stream);
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const RetryStrategy = struct {
    maximum_retry_attempts: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .maximum_retry_attempts = "MaximumRetryAttempts",
        };
        return @field(mappings, field_name);
    }
};

pub const DebugRuleEvaluationStatus = struct {
    rule_configuration_name: ?[]const u8 = null,
    rule_evaluation_job_arn: ?[]const u8 = null,
    rule_evaluation_status: ?[]const u8 = null,
    status_details: ?[]const u8 = null,
    last_modified_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_configuration_name = "RuleConfigurationName",
            .rule_evaluation_job_arn = "RuleEvaluationJobArn",
            .rule_evaluation_status = "RuleEvaluationStatus",
            .status_details = "StatusDetails",
            .last_modified_time = "LastModifiedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const TensorBoardOutputConfig = struct {
    local_path: ?[]const u8 = null,
    s3_output_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_path = "LocalPath",
            .s3_output_path = "S3OutputPath",
        };
        return @field(mappings, field_name);
    }
};

pub const DebugRuleConfiguration = struct {
    rule_configuration_name: []const u8,
    local_path: ?[]const u8 = null,
    s3_output_path: ?[]const u8 = null,
    rule_evaluator_image: []const u8,
    instance_type: ?[]const u8 = null,
    volume_size_in_gb: ?i64 = null,
    rule_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rule_configuration_name = "RuleConfigurationName",
            .local_path = "LocalPath",
            .s3_output_path = "S3OutputPath",
            .rule_evaluator_image = "RuleEvaluatorImage",
            .instance_type = "InstanceType",
            .volume_size_in_gb = "VolumeSizeInGB",
            .rule_parameters = "RuleParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "rule_parameters", field_name))
            return try serializeMap(self.rule_parameters, self.fieldNameFor("rule_parameters"), options, out_stream);
        return false;
    }
};

pub const DebugHookConfig = struct {
    local_path: ?[]const u8 = null,
    s3_output_path: []const u8,
    hook_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    collection_configurations: ?[]CollectionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .local_path = "LocalPath",
            .s3_output_path = "S3OutputPath",
            .hook_parameters = "HookParameters",
            .collection_configurations = "CollectionConfigurations",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "hook_parameters", field_name))
            return try serializeMap(self.hook_parameters, self.fieldNameFor("hook_parameters"), options, out_stream);
        return false;
    }
};

pub const CollectionConfiguration = struct {
    collection_name: ?[]const u8 = null,
    collection_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .collection_name = "CollectionName",
            .collection_parameters = "CollectionParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "collection_parameters", field_name))
            return try serializeMap(self.collection_parameters, self.fieldNameFor("collection_parameters"), options, out_stream);
        return false;
    }
};

pub const CheckpointConfig = struct {
    s3_uri: []const u8,
    local_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .local_path = "LocalPath",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricData = struct {
    metric_name: ?[]const u8 = null,
    value: ?f32 = null,
    timestamp: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .value = "Value",
            .timestamp = "Timestamp",
        };
        return @field(mappings, field_name);
    }
};

pub const SecondaryStatusTransition = struct {
    status: []const u8,
    start_time: i64,
    end_time: ?i64 = null,
    status_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "Status",
            .start_time = "StartTime",
            .end_time = "EndTime",
            .status_message = "StatusMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const StoppingCondition = struct {
    max_runtime_in_seconds: ?i64 = null,
    max_wait_time_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_runtime_in_seconds = "MaxRuntimeInSeconds",
            .max_wait_time_in_seconds = "MaxWaitTimeInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceConfig = struct {
    instance_type: []const u8,
    instance_count: i64,
    volume_size_in_gb: i64,
    volume_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_type = "InstanceType",
            .instance_count = "InstanceCount",
            .volume_size_in_gb = "VolumeSizeInGB",
            .volume_kms_key_id = "VolumeKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputDataConfig = struct {
    kms_key_id: ?[]const u8 = null,
    s3_output_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "KmsKeyId",
            .s3_output_path = "S3OutputPath",
        };
        return @field(mappings, field_name);
    }
};

pub const Channel = struct {
    channel_name: []const u8,
    data_source: DataSource,
    content_type: ?[]const u8 = null,
    compression_type: ?[]const u8 = null,
    record_wrapper_type: ?[]const u8 = null,
    input_mode: ?[]const u8 = null,
    shuffle_config: ?ShuffleConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .channel_name = "ChannelName",
            .data_source = "DataSource",
            .content_type = "ContentType",
            .compression_type = "CompressionType",
            .record_wrapper_type = "RecordWrapperType",
            .input_mode = "InputMode",
            .shuffle_config = "ShuffleConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ShuffleConfig = struct {
    seed: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .seed = "Seed",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSource = struct {
    s3_data_source: ?S3DataSource = null,
    file_system_data_source: ?FileSystemDataSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_source = "S3DataSource",
            .file_system_data_source = "FileSystemDataSource",
        };
        return @field(mappings, field_name);
    }
};

pub const FileSystemDataSource = struct {
    file_system_id: []const u8,
    file_system_access_mode: []const u8,
    file_system_type: []const u8,
    directory_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_system_id = "FileSystemId",
            .file_system_access_mode = "FileSystemAccessMode",
            .file_system_type = "FileSystemType",
            .directory_path = "DirectoryPath",
        };
        return @field(mappings, field_name);
    }
};

pub const S3DataSource = struct {
    s3_data_type: []const u8,
    s3_uri: []const u8,
    s3_data_distribution_type: ?[]const u8 = null,
    attribute_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_type = "S3DataType",
            .s3_uri = "S3Uri",
            .s3_data_distribution_type = "S3DataDistributionType",
            .attribute_names = "AttributeNames",
        };
        return @field(mappings, field_name);
    }
};

pub const AlgorithmSpecification = struct {
    training_image: ?[]const u8 = null,
    algorithm_name: ?[]const u8 = null,
    training_input_mode: []const u8,
    metric_definitions: ?[]MetricDefinition = null,
    enable_sage_maker_metrics_time_series: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .training_image = "TrainingImage",
            .algorithm_name = "AlgorithmName",
            .training_input_mode = "TrainingInputMode",
            .metric_definitions = "MetricDefinitions",
            .enable_sage_maker_metrics_time_series = "EnableSageMakerMetricsTimeSeries",
        };
        return @field(mappings, field_name);
    }
};

pub const MetricDefinition = struct {
    name: []const u8,
    regex: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .regex = "Regex",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelArtifacts = struct {
    s3_model_artifacts: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_model_artifacts = "S3ModelArtifacts",
        };
        return @field(mappings, field_name);
    }
};

pub const TrialComponentMetricSummary = struct {
    metric_name: ?[]const u8 = null,
    source_arn: ?[]const u8 = null,
    time_stamp: ?i64 = null,
    max: ?f64 = null,
    min: ?f64 = null,
    last: ?f64 = null,
    count: ?i64 = null,
    avg: ?f64 = null,
    std_dev: ?f64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
            .source_arn = "SourceArn",
            .time_stamp = "TimeStamp",
            .max = "Max",
            .min = "Min",
            .last = "Last",
            .count = "Count",
            .avg = "Avg",
            .std_dev = "StdDev",
        };
        return @field(mappings, field_name);
    }
};

pub const TrialComponentSource = struct {
    source_arn: []const u8,
    source_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_arn = "SourceArn",
            .source_type = "SourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const TrialSource = struct {
    source_arn: []const u8,
    source_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_arn = "SourceArn",
            .source_type = "SourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const ExperimentSource = struct {
    source_arn: []const u8,
    source_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_arn = "SourceArn",
            .source_type = "SourceType",
        };
        return @field(mappings, field_name);
    }
};

pub const SearchExpression = struct {
    filters: ?[]Filter = null,
    nested_filters: ?[]struct {
        nested_property_name: []const u8,
        filters: []Filter,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .nested_property_name = "NestedPropertyName",
                .filters = "Filters",
            };
            return @field(mappings, field_name);
        }
    } = null,
    sub_expressions: ?[]SearchExpression = null,
    operator: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .filters = "Filters",
            .nested_filters = "NestedFilters",
            .sub_expressions = "SubExpressions",
            .operator = "Operator",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: []const u8,
    operator: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .operator = "Operator",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const UiTemplate = struct {
    content: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content = "Content",
        };
        return @field(mappings, field_name);
    }
};

pub const HyperParameterTrainingJobSummary = struct {
    training_job_definition_name: ?[]const u8 = null,
    training_job_name: []const u8,
    training_job_arn: []const u8,
    tuning_job_name: ?[]const u8 = null,
    creation_time: i64,
    training_start_time: ?i64 = null,
    training_end_time: ?i64 = null,
    training_job_status: []const u8,
    tuned_hyper_parameters: []struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    },
    failure_reason: ?[]const u8 = null,
    final_hyper_parameter_tuning_job_objective_metric: ?FinalHyperParameterTuningJobObjectiveMetric = null,
    objective_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .training_job_definition_name = "TrainingJobDefinitionName",
            .training_job_name = "TrainingJobName",
            .training_job_arn = "TrainingJobArn",
            .tuning_job_name = "TuningJobName",
            .creation_time = "CreationTime",
            .training_start_time = "TrainingStartTime",
            .training_end_time = "TrainingEndTime",
            .training_job_status = "TrainingJobStatus",
            .tuned_hyper_parameters = "TunedHyperParameters",
            .failure_reason = "FailureReason",
            .final_hyper_parameter_tuning_job_objective_metric = "FinalHyperParameterTuningJobObjectiveMetric",
            .objective_status = "ObjectiveStatus",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tuned_hyper_parameters", field_name))
            return try serializeMap(self.tuned_hyper_parameters, self.fieldNameFor("tuned_hyper_parameters"), options, out_stream);
        return false;
    }
};

pub const FinalHyperParameterTuningJobObjectiveMetric = struct {
    type: ?[]const u8 = null,
    metric_name: []const u8,
    value: f32,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .metric_name = "MetricName",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SubscribedWorkteam = struct {
    workteam_arn: []const u8,
    marketplace_title: ?[]const u8 = null,
    seller_name: ?[]const u8 = null,
    marketplace_description: ?[]const u8 = null,
    listing_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workteam_arn = "WorkteamArn",
            .marketplace_title = "MarketplaceTitle",
            .seller_name = "SellerName",
            .marketplace_description = "MarketplaceDescription",
            .listing_id = "ListingId",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringJobDefinitionSummary = struct {
    monitoring_job_definition_name: []const u8,
    monitoring_job_definition_arn: []const u8,
    creation_time: i64,
    endpoint_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .monitoring_job_definition_name = "MonitoringJobDefinitionName",
            .monitoring_job_definition_arn = "MonitoringJobDefinitionArn",
            .creation_time = "CreationTime",
            .endpoint_name = "EndpointName",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobInputConfig = struct {
    data_source: LabelingJobDataSource,
    data_attributes: ?LabelingJobDataAttributes = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source = "DataSource",
            .data_attributes = "DataAttributes",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobDataAttributes = struct {
    content_classifiers: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content_classifiers = "ContentClassifiers",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobDataSource = struct {
    s3_data_source: ?LabelingJobS3DataSource = null,
    sns_data_source: ?LabelingJobSnsDataSource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_source = "S3DataSource",
            .sns_data_source = "SnsDataSource",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobSnsDataSource = struct {
    sns_topic_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sns_topic_arn = "SnsTopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobS3DataSource = struct {
    manifest_s3_uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_s3_uri = "ManifestS3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobOutput = struct {
    output_dataset_s3_uri: []const u8,
    final_active_learning_model_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .output_dataset_s3_uri = "OutputDatasetS3Uri",
            .final_active_learning_model_arn = "FinalActiveLearningModelArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelCounters = struct {
    total_labeled: ?i64 = null,
    human_labeled: ?i64 = null,
    machine_labeled: ?i64 = null,
    failed_non_retryable_error: ?i64 = null,
    unlabeled: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .total_labeled = "TotalLabeled",
            .human_labeled = "HumanLabeled",
            .machine_labeled = "MachineLabeled",
            .failed_non_retryable_error = "FailedNonRetryableError",
            .unlabeled = "Unlabeled",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceLimits = struct {
    max_number_of_training_jobs: i64,
    max_parallel_training_jobs: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_number_of_training_jobs = "MaxNumberOfTrainingJobs",
            .max_parallel_training_jobs = "MaxParallelTrainingJobs",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectiveStatusCounters = struct {
    succeeded: ?i64 = null,
    pending: ?i64 = null,
    failed: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .succeeded = "Succeeded",
            .pending = "Pending",
            .failed = "Failed",
        };
        return @field(mappings, field_name);
    }
};

pub const TrainingJobStatusCounters = struct {
    completed: ?i64 = null,
    in_progress: ?i64 = null,
    retryable_error: ?i64 = null,
    non_retryable_error: ?i64 = null,
    stopped: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .completed = "Completed",
            .in_progress = "InProgress",
            .retryable_error = "RetryableError",
            .non_retryable_error = "NonRetryableError",
            .stopped = "Stopped",
        };
        return @field(mappings, field_name);
    }
};

pub const ContextSource = struct {
    source_uri: []const u8,
    source_type: ?[]const u8 = null,
    source_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_uri = "SourceUri",
            .source_type = "SourceType",
            .source_id = "SourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const GitConfig = struct {
    repository_url: []const u8,
    branch: ?[]const u8 = null,
    secret_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_url = "RepositoryUrl",
            .branch = "Branch",
            .secret_arn = "SecretArn",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLCandidate = struct {
    candidate_name: []const u8,
    final_auto_ml_job_objective_metric: ?FinalAutoMLJobObjectiveMetric = null,
    objective_status: []const u8,
    candidate_steps: []AutoMLCandidateStep,
    candidate_status: []const u8,
    inference_containers: ?[]AutoMLContainerDefinition = null,
    creation_time: i64,
    end_time: ?i64 = null,
    last_modified_time: i64,
    failure_reason: ?[]const u8 = null,
    candidate_properties: ?CandidateProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .candidate_name = "CandidateName",
            .final_auto_ml_job_objective_metric = "FinalAutoMLJobObjectiveMetric",
            .objective_status = "ObjectiveStatus",
            .candidate_steps = "CandidateSteps",
            .candidate_status = "CandidateStatus",
            .inference_containers = "InferenceContainers",
            .creation_time = "CreationTime",
            .end_time = "EndTime",
            .last_modified_time = "LastModifiedTime",
            .failure_reason = "FailureReason",
            .candidate_properties = "CandidateProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const CandidateProperties = struct {
    candidate_artifact_locations: ?CandidateArtifactLocations = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .candidate_artifact_locations = "CandidateArtifactLocations",
        };
        return @field(mappings, field_name);
    }
};

pub const CandidateArtifactLocations = struct {
    explainability: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .explainability = "Explainability",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLContainerDefinition = struct {
    image: []const u8,
    model_data_url: []const u8,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image = "Image",
            .model_data_url = "ModelDataUrl",
            .environment = "Environment",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const AutoMLCandidateStep = struct {
    candidate_step_type: []const u8,
    candidate_step_arn: []const u8,
    candidate_step_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .candidate_step_type = "CandidateStepType",
            .candidate_step_arn = "CandidateStepArn",
            .candidate_step_name = "CandidateStepName",
        };
        return @field(mappings, field_name);
    }
};

pub const FinalAutoMLJobObjectiveMetric = struct {
    type: ?[]const u8 = null,
    metric_name: []const u8,
    value: f32,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .metric_name = "MetricName",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLPartialFailureReason = struct {
    partial_failure_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .partial_failure_message = "PartialFailureMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactSource = struct {
    source_uri: []const u8,
    source_types: ?[]ArtifactSourceType = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_uri = "SourceUri",
            .source_types = "SourceTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const ArtifactSourceType = struct {
    source_id_type: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_id_type = "SourceIdType",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const ActionSource = struct {
    source_uri: []const u8,
    source_type: ?[]const u8 = null,
    source_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_uri = "SourceUri",
            .source_type = "SourceType",
            .source_id = "SourceId",
        };
        return @field(mappings, field_name);
    }
};

pub const ProfilerConfig = struct {
    s3_output_path: []const u8,
    profiling_interval_in_milliseconds: ?i64 = null,
    profiling_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_path = "S3OutputPath",
            .profiling_interval_in_milliseconds = "ProfilingIntervalInMilliseconds",
            .profiling_parameters = "ProfilingParameters",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "profiling_parameters", field_name))
            return try serializeMap(self.profiling_parameters, self.fieldNameFor("profiling_parameters"), options, out_stream);
        return false;
    }
};

pub const ServiceCatalogProvisioningDetails = struct {
    product_id: []const u8,
    provisioning_artifact_id: []const u8,
    path_id: ?[]const u8 = null,
    provisioning_parameters: ?[]ProvisioningParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .product_id = "ProductId",
            .provisioning_artifact_id = "ProvisioningArtifactId",
            .path_id = "PathId",
            .provisioning_parameters = "ProvisioningParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const ProvisioningParameter = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringNetworkConfig = struct {
    enable_inter_container_traffic_encryption: ?bool = null,
    enable_network_isolation: ?bool = null,
    vpc_config: ?VpcConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_inter_container_traffic_encryption = "EnableInterContainerTrafficEncryption",
            .enable_network_isolation = "EnableNetworkIsolation",
            .vpc_config = "VpcConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelQualityJobInput = struct {
    endpoint_input: EndpointInput,
    ground_truth_s3_input: MonitoringGroundTruthS3Input,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_input = "EndpointInput",
            .ground_truth_s3_input = "GroundTruthS3Input",
        };
        return @field(mappings, field_name);
    }
};

pub const MonitoringGroundTruthS3Input = struct {
    s3_uri: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelQualityAppSpecification = struct {
    image_uri: []const u8,
    container_entrypoint: ?[][]const u8 = null,
    container_arguments: ?[][]const u8 = null,
    record_preprocessor_source_uri: ?[]const u8 = null,
    post_analytics_processor_source_uri: ?[]const u8 = null,
    problem_type: ?[]const u8 = null,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_uri = "ImageUri",
            .container_entrypoint = "ContainerEntrypoint",
            .container_arguments = "ContainerArguments",
            .record_preprocessor_source_uri = "RecordPreprocessorSourceUri",
            .post_analytics_processor_source_uri = "PostAnalyticsProcessorSourceUri",
            .problem_type = "ProblemType",
            .environment = "Environment",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const ModelQualityBaselineConfig = struct {
    baselining_job_name: ?[]const u8 = null,
    constraints_resource: ?MonitoringConstraintsResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .baselining_job_name = "BaseliningJobName",
            .constraints_resource = "ConstraintsResource",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelExplainabilityJobInput = struct {
    endpoint_input: EndpointInput,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_input = "EndpointInput",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelExplainabilityAppSpecification = struct {
    image_uri: []const u8,
    config_uri: []const u8,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_uri = "ImageUri",
            .config_uri = "ConfigUri",
            .environment = "Environment",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const ModelExplainabilityBaselineConfig = struct {
    baselining_job_name: ?[]const u8 = null,
    constraints_resource: ?MonitoringConstraintsResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .baselining_job_name = "BaseliningJobName",
            .constraints_resource = "ConstraintsResource",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelBiasJobInput = struct {
    endpoint_input: EndpointInput,
    ground_truth_s3_input: MonitoringGroundTruthS3Input,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_input = "EndpointInput",
            .ground_truth_s3_input = "GroundTruthS3Input",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelBiasAppSpecification = struct {
    image_uri: []const u8,
    config_uri: []const u8,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_uri = "ImageUri",
            .config_uri = "ConfigUri",
            .environment = "Environment",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const ModelBiasBaselineConfig = struct {
    baselining_job_name: ?[]const u8 = null,
    constraints_resource: ?MonitoringConstraintsResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .baselining_job_name = "BaseliningJobName",
            .constraints_resource = "ConstraintsResource",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceExecutionConfig = struct {
    mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .mode = "Mode",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerDefinition = struct {
    container_hostname: ?[]const u8 = null,
    image: ?[]const u8 = null,
    image_config: ?ImageConfig = null,
    mode: ?[]const u8 = null,
    model_data_url: ?[]const u8 = null,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    model_package_name: ?[]const u8 = null,
    multi_model_config: ?MultiModelConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_hostname = "ContainerHostname",
            .image = "Image",
            .image_config = "ImageConfig",
            .mode = "Mode",
            .model_data_url = "ModelDataUrl",
            .environment = "Environment",
            .model_package_name = "ModelPackageName",
            .multi_model_config = "MultiModelConfig",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const MultiModelConfig = struct {
    model_cache_setting: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .model_cache_setting = "ModelCacheSetting",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageConfig = struct {
    repository_access_mode: []const u8,
    repository_auth_config: ?RepositoryAuthConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_access_mode = "RepositoryAccessMode",
            .repository_auth_config = "RepositoryAuthConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const RepositoryAuthConfig = struct {
    repository_credentials_provider_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .repository_credentials_provider_arn = "RepositoryCredentialsProviderArn",
        };
        return @field(mappings, field_name);
    }
};

pub const HumanTaskConfig = struct {
    workteam_arn: []const u8,
    ui_config: UiConfig,
    pre_human_task_lambda_arn: []const u8,
    task_keywords: ?[][]const u8 = null,
    task_title: []const u8,
    task_description: []const u8,
    number_of_human_workers_per_data_object: i64,
    task_time_limit_in_seconds: i64,
    task_availability_lifetime_in_seconds: ?i64 = null,
    max_concurrent_task_count: ?i64 = null,
    annotation_consolidation_config: AnnotationConsolidationConfig,
    public_workforce_task_price: ?PublicWorkforceTaskPrice = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workteam_arn = "WorkteamArn",
            .ui_config = "UiConfig",
            .pre_human_task_lambda_arn = "PreHumanTaskLambdaArn",
            .task_keywords = "TaskKeywords",
            .task_title = "TaskTitle",
            .task_description = "TaskDescription",
            .number_of_human_workers_per_data_object = "NumberOfHumanWorkersPerDataObject",
            .task_time_limit_in_seconds = "TaskTimeLimitInSeconds",
            .task_availability_lifetime_in_seconds = "TaskAvailabilityLifetimeInSeconds",
            .max_concurrent_task_count = "MaxConcurrentTaskCount",
            .annotation_consolidation_config = "AnnotationConsolidationConfig",
            .public_workforce_task_price = "PublicWorkforceTaskPrice",
        };
        return @field(mappings, field_name);
    }
};

pub const PublicWorkforceTaskPrice = struct {
    amount_in_usd: ?USD = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amount_in_usd = "AmountInUsd",
        };
        return @field(mappings, field_name);
    }
};

pub const USD = struct {
    dollars: ?i64 = null,
    cents: ?i64 = null,
    tenth_fractions_of_a_cent: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dollars = "Dollars",
            .cents = "Cents",
            .tenth_fractions_of_a_cent = "TenthFractionsOfACent",
        };
        return @field(mappings, field_name);
    }
};

pub const AnnotationConsolidationConfig = struct {
    annotation_consolidation_lambda_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .annotation_consolidation_lambda_arn = "AnnotationConsolidationLambdaArn",
        };
        return @field(mappings, field_name);
    }
};

pub const UiConfig = struct {
    ui_template_s3_uri: ?[]const u8 = null,
    human_task_ui_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ui_template_s3_uri = "UiTemplateS3Uri",
            .human_task_ui_arn = "HumanTaskUiArn",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobAlgorithmsConfig = struct {
    labeling_job_algorithm_specification_arn: []const u8,
    initial_active_learning_model_arn: ?[]const u8 = null,
    labeling_job_resource_config: ?LabelingJobResourceConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .labeling_job_algorithm_specification_arn = "LabelingJobAlgorithmSpecificationArn",
            .initial_active_learning_model_arn = "InitialActiveLearningModelArn",
            .labeling_job_resource_config = "LabelingJobResourceConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobResourceConfig = struct {
    volume_kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_kms_key_id = "VolumeKmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobStoppingConditions = struct {
    max_human_labeled_object_count: ?i64 = null,
    max_percentage_of_input_dataset_labeled: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_human_labeled_object_count = "MaxHumanLabeledObjectCount",
            .max_percentage_of_input_dataset_labeled = "MaxPercentageOfInputDatasetLabeled",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelingJobOutputConfig = struct {
    s3_output_path: []const u8,
    kms_key_id: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_path = "S3OutputPath",
            .kms_key_id = "KmsKeyId",
            .sns_topic_arn = "SnsTopicArn",
        };
        return @field(mappings, field_name);
    }
};

pub const HyperParameterTuningJobWarmStartConfig = struct {
    parent_hyper_parameter_tuning_jobs: []ParentHyperParameterTuningJob,
    warm_start_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .parent_hyper_parameter_tuning_jobs = "ParentHyperParameterTuningJobs",
            .warm_start_type = "WarmStartType",
        };
        return @field(mappings, field_name);
    }
};

pub const ParentHyperParameterTuningJob = struct {
    hyper_parameter_tuning_job_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hyper_parameter_tuning_job_name = "HyperParameterTuningJobName",
        };
        return @field(mappings, field_name);
    }
};

pub const HyperParameterTrainingJobDefinition = struct {
    definition_name: ?[]const u8 = null,
    tuning_objective: ?HyperParameterTuningJobObjective = null,
    hyper_parameter_ranges: ?ParameterRanges = null,
    static_hyper_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    algorithm_specification: HyperParameterAlgorithmSpecification,
    role_arn: []const u8,
    input_data_config: ?[]Channel = null,
    vpc_config: ?VpcConfig = null,
    output_data_config: OutputDataConfig,
    resource_config: ResourceConfig,
    stopping_condition: StoppingCondition,
    enable_network_isolation: ?bool = null,
    enable_inter_container_traffic_encryption: ?bool = null,
    enable_managed_spot_training: ?bool = null,
    checkpoint_config: ?CheckpointConfig = null,
    retry_strategy: ?RetryStrategy = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .definition_name = "DefinitionName",
            .tuning_objective = "TuningObjective",
            .hyper_parameter_ranges = "HyperParameterRanges",
            .static_hyper_parameters = "StaticHyperParameters",
            .algorithm_specification = "AlgorithmSpecification",
            .role_arn = "RoleArn",
            .input_data_config = "InputDataConfig",
            .vpc_config = "VpcConfig",
            .output_data_config = "OutputDataConfig",
            .resource_config = "ResourceConfig",
            .stopping_condition = "StoppingCondition",
            .enable_network_isolation = "EnableNetworkIsolation",
            .enable_inter_container_traffic_encryption = "EnableInterContainerTrafficEncryption",
            .enable_managed_spot_training = "EnableManagedSpotTraining",
            .checkpoint_config = "CheckpointConfig",
            .retry_strategy = "RetryStrategy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "static_hyper_parameters", field_name))
            return try serializeMap(self.static_hyper_parameters, self.fieldNameFor("static_hyper_parameters"), options, out_stream);
        return false;
    }
};

pub const HyperParameterAlgorithmSpecification = struct {
    training_image: ?[]const u8 = null,
    training_input_mode: []const u8,
    algorithm_name: ?[]const u8 = null,
    metric_definitions: ?[]MetricDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .training_image = "TrainingImage",
            .training_input_mode = "TrainingInputMode",
            .algorithm_name = "AlgorithmName",
            .metric_definitions = "MetricDefinitions",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterRanges = struct {
    integer_parameter_ranges: ?[]IntegerParameterRange = null,
    continuous_parameter_ranges: ?[]ContinuousParameterRange = null,
    categorical_parameter_ranges: ?[]CategoricalParameterRange = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .integer_parameter_ranges = "IntegerParameterRanges",
            .continuous_parameter_ranges = "ContinuousParameterRanges",
            .categorical_parameter_ranges = "CategoricalParameterRanges",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoricalParameterRange = struct {
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ContinuousParameterRange = struct {
    name: []const u8,
    min_value: []const u8,
    max_value: []const u8,
    scaling_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .min_value = "MinValue",
            .max_value = "MaxValue",
            .scaling_type = "ScalingType",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerParameterRange = struct {
    name: []const u8,
    min_value: []const u8,
    max_value: []const u8,
    scaling_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .min_value = "MinValue",
            .max_value = "MaxValue",
            .scaling_type = "ScalingType",
        };
        return @field(mappings, field_name);
    }
};

pub const HyperParameterTuningJobObjective = struct {
    type: []const u8,
    metric_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .metric_name = "MetricName",
        };
        return @field(mappings, field_name);
    }
};

pub const HyperParameterTuningJobConfig = struct {
    strategy: []const u8,
    hyper_parameter_tuning_job_objective: ?HyperParameterTuningJobObjective = null,
    resource_limits: ResourceLimits,
    parameter_ranges: ?ParameterRanges = null,
    training_job_early_stopping_type: ?[]const u8 = null,
    tuning_job_completion_criteria: ?TuningJobCompletionCriteria = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .strategy = "Strategy",
            .hyper_parameter_tuning_job_objective = "HyperParameterTuningJobObjective",
            .resource_limits = "ResourceLimits",
            .parameter_ranges = "ParameterRanges",
            .training_job_early_stopping_type = "TrainingJobEarlyStoppingType",
            .tuning_job_completion_criteria = "TuningJobCompletionCriteria",
        };
        return @field(mappings, field_name);
    }
};

pub const TuningJobCompletionCriteria = struct {
    target_objective_metric_value: f32,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_objective_metric_value = "TargetObjectiveMetricValue",
        };
        return @field(mappings, field_name);
    }
};

pub const FlowDefinitionOutputConfig = struct {
    s3_output_path: []const u8,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_path = "S3OutputPath",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const HumanLoopConfig = struct {
    workteam_arn: []const u8,
    human_task_ui_arn: []const u8,
    task_title: []const u8,
    task_description: []const u8,
    task_count: i64,
    task_availability_lifetime_in_seconds: ?i64 = null,
    task_time_limit_in_seconds: ?i64 = null,
    task_keywords: ?[][]const u8 = null,
    public_workforce_task_price: ?PublicWorkforceTaskPrice = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workteam_arn = "WorkteamArn",
            .human_task_ui_arn = "HumanTaskUiArn",
            .task_title = "TaskTitle",
            .task_description = "TaskDescription",
            .task_count = "TaskCount",
            .task_availability_lifetime_in_seconds = "TaskAvailabilityLifetimeInSeconds",
            .task_time_limit_in_seconds = "TaskTimeLimitInSeconds",
            .task_keywords = "TaskKeywords",
            .public_workforce_task_price = "PublicWorkforceTaskPrice",
        };
        return @field(mappings, field_name);
    }
};

pub const HumanLoopActivationConfig = struct {
    human_loop_activation_conditions_config: HumanLoopActivationConditionsConfig,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .human_loop_activation_conditions_config = "HumanLoopActivationConditionsConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const HumanLoopActivationConditionsConfig = struct {
    human_loop_activation_conditions: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .human_loop_activation_conditions = "HumanLoopActivationConditions",
        };
        return @field(mappings, field_name);
    }
};

pub const HumanLoopRequestSource = struct {
    aws_managed_human_loop_request_source: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_managed_human_loop_request_source = "AwsManagedHumanLoopRequestSource",
        };
        return @field(mappings, field_name);
    }
};

pub const DataCaptureConfig = struct {
    enable_capture: ?bool = null,
    initial_sampling_percentage: i64,
    destination_s3_uri: []const u8,
    kms_key_id: ?[]const u8 = null,
    capture_options: []CaptureOption,
    capture_content_type_header: ?CaptureContentTypeHeader = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enable_capture = "EnableCapture",
            .initial_sampling_percentage = "InitialSamplingPercentage",
            .destination_s3_uri = "DestinationS3Uri",
            .kms_key_id = "KmsKeyId",
            .capture_options = "CaptureOptions",
            .capture_content_type_header = "CaptureContentTypeHeader",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptureContentTypeHeader = struct {
    csv_content_types: ?[][]const u8 = null,
    json_content_types: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .csv_content_types = "CsvContentTypes",
            .json_content_types = "JsonContentTypes",
        };
        return @field(mappings, field_name);
    }
};

pub const CaptureOption = struct {
    capture_mode: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capture_mode = "CaptureMode",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductionVariant = struct {
    variant_name: []const u8,
    model_name: []const u8,
    initial_instance_count: i64,
    instance_type: []const u8,
    initial_variant_weight: ?f32 = null,
    accelerator_type: ?[]const u8 = null,
    core_dump_config: ?ProductionVariantCoreDumpConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .variant_name = "VariantName",
            .model_name = "ModelName",
            .initial_instance_count = "InitialInstanceCount",
            .instance_type = "InstanceType",
            .initial_variant_weight = "InitialVariantWeight",
            .accelerator_type = "AcceleratorType",
            .core_dump_config = "CoreDumpConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const ProductionVariantCoreDumpConfig = struct {
    destination_s3_uri: []const u8,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .destination_s3_uri = "DestinationS3Uri",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const DataQualityJobInput = struct {
    endpoint_input: EndpointInput,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint_input = "EndpointInput",
        };
        return @field(mappings, field_name);
    }
};

pub const DataQualityAppSpecification = struct {
    image_uri: []const u8,
    container_entrypoint: ?[][]const u8 = null,
    container_arguments: ?[][]const u8 = null,
    record_preprocessor_source_uri: ?[]const u8 = null,
    post_analytics_processor_source_uri: ?[]const u8 = null,
    environment: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_uri = "ImageUri",
            .container_entrypoint = "ContainerEntrypoint",
            .container_arguments = "ContainerArguments",
            .record_preprocessor_source_uri = "RecordPreprocessorSourceUri",
            .post_analytics_processor_source_uri = "PostAnalyticsProcessorSourceUri",
            .environment = "Environment",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "environment", field_name))
            return try serializeMap(self.environment, self.fieldNameFor("environment"), options, out_stream);
        return false;
    }
};

pub const DataQualityBaselineConfig = struct {
    baselining_job_name: ?[]const u8 = null,
    constraints_resource: ?MonitoringConstraintsResource = null,
    statistics_resource: ?MonitoringStatisticsResource = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .baselining_job_name = "BaseliningJobName",
            .constraints_resource = "ConstraintsResource",
            .statistics_resource = "StatisticsResource",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputConfig = struct {
    s3_output_location: []const u8,
    target_device: ?[]const u8 = null,
    target_platform: ?TargetPlatform = null,
    compiler_options: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_location = "S3OutputLocation",
            .target_device = "TargetDevice",
            .target_platform = "TargetPlatform",
            .compiler_options = "CompilerOptions",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetPlatform = struct {
    os: []const u8,
    arch: []const u8,
    accelerator: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .os = "Os",
            .arch = "Arch",
            .accelerator = "Accelerator",
        };
        return @field(mappings, field_name);
    }
};

pub const InputConfig = struct {
    s3_uri: []const u8,
    data_input_config: []const u8,
    framework: []const u8,
    framework_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_uri = "S3Uri",
            .data_input_config = "DataInputConfig",
            .framework = "Framework",
            .framework_version = "FrameworkVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ModelDeployConfig = struct {
    auto_generate_endpoint_name: ?bool = null,
    endpoint_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .auto_generate_endpoint_name = "AutoGenerateEndpointName",
            .endpoint_name = "EndpointName",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLJobCompletionCriteria = struct {
    max_candidates: ?i64 = null,
    max_runtime_per_training_job_in_seconds: ?i64 = null,
    max_auto_ml_job_runtime_in_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .max_candidates = "MaxCandidates",
            .max_runtime_per_training_job_in_seconds = "MaxRuntimePerTrainingJobInSeconds",
            .max_auto_ml_job_runtime_in_seconds = "MaxAutoMLJobRuntimeInSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLJobObjective = struct {
    metric_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .metric_name = "MetricName",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLJobConfig = struct {
    completion_criteria: ?AutoMLJobCompletionCriteria = null,
    security_config: ?AutoMLSecurityConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .completion_criteria = "CompletionCriteria",
            .security_config = "SecurityConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLSecurityConfig = struct {
    volume_kms_key_id: ?[]const u8 = null,
    enable_inter_container_traffic_encryption: ?bool = null,
    vpc_config: ?VpcConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .volume_kms_key_id = "VolumeKmsKeyId",
            .enable_inter_container_traffic_encryption = "EnableInterContainerTrafficEncryption",
            .vpc_config = "VpcConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLOutputDataConfig = struct {
    kms_key_id: ?[]const u8 = null,
    s3_output_path: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_id = "KmsKeyId",
            .s3_output_path = "S3OutputPath",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLChannel = struct {
    data_source: AutoMLDataSource,
    compression_type: ?[]const u8 = null,
    target_attribute_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source = "DataSource",
            .compression_type = "CompressionType",
            .target_attribute_name = "TargetAttributeName",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLDataSource = struct {
    s3_data_source: AutoMLS3DataSource,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_source = "S3DataSource",
        };
        return @field(mappings, field_name);
    }
};

pub const AutoMLS3DataSource = struct {
    s3_data_type: []const u8,
    s3_uri: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_data_type = "S3DataType",
            .s3_uri = "S3Uri",
        };
        return @field(mappings, field_name);
    }
};

pub const AlgorithmStatusItem = struct {
    name: []const u8,
    status: []const u8,
    failure_reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .status = "Status",
            .failure_reason = "FailureReason",
        };
        return @field(mappings, field_name);
    }
};

pub const AlgorithmValidationSpecification = struct {
    validation_role: []const u8,
    validation_profiles: []AlgorithmValidationProfile,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .validation_role = "ValidationRole",
            .validation_profiles = "ValidationProfiles",
        };
        return @field(mappings, field_name);
    }
};

pub const AlgorithmValidationProfile = struct {
    profile_name: []const u8,
    training_job_definition: TrainingJobDefinition,
    transform_job_definition: ?TransformJobDefinition = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .profile_name = "ProfileName",
            .training_job_definition = "TrainingJobDefinition",
            .transform_job_definition = "TransformJobDefinition",
        };
        return @field(mappings, field_name);
    }
};

pub const TrainingJobDefinition = struct {
    training_input_mode: []const u8,
    hyper_parameters: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    input_data_config: []Channel,
    output_data_config: OutputDataConfig,
    resource_config: ResourceConfig,
    stopping_condition: StoppingCondition,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .training_input_mode = "TrainingInputMode",
            .hyper_parameters = "HyperParameters",
            .input_data_config = "InputDataConfig",
            .output_data_config = "OutputDataConfig",
            .resource_config = "ResourceConfig",
            .stopping_condition = "StoppingCondition",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "hyper_parameters", field_name))
            return try serializeMap(self.hyper_parameters, self.fieldNameFor("hyper_parameters"), options, out_stream);
        return false;
    }
};

pub const TrainingSpecification = struct {
    training_image: []const u8,
    training_image_digest: ?[]const u8 = null,
    supported_hyper_parameters: ?[]HyperParameterSpecification = null,
    supported_training_instance_types: [][]const u8,
    supports_distributed_training: ?bool = null,
    metric_definitions: ?[]MetricDefinition = null,
    training_channels: []ChannelSpecification,
    supported_tuning_job_objective_metrics: ?[]HyperParameterTuningJobObjective = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .training_image = "TrainingImage",
            .training_image_digest = "TrainingImageDigest",
            .supported_hyper_parameters = "SupportedHyperParameters",
            .supported_training_instance_types = "SupportedTrainingInstanceTypes",
            .supports_distributed_training = "SupportsDistributedTraining",
            .metric_definitions = "MetricDefinitions",
            .training_channels = "TrainingChannels",
            .supported_tuning_job_objective_metrics = "SupportedTuningJobObjectiveMetrics",
        };
        return @field(mappings, field_name);
    }
};

pub const ChannelSpecification = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    is_required: ?bool = null,
    supported_content_types: [][]const u8,
    supported_compression_types: ?[][]const u8 = null,
    supported_input_modes: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .is_required = "IsRequired",
            .supported_content_types = "SupportedContentTypes",
            .supported_compression_types = "SupportedCompressionTypes",
            .supported_input_modes = "SupportedInputModes",
        };
        return @field(mappings, field_name);
    }
};

pub const HyperParameterSpecification = struct {
    name: []const u8,
    description: ?[]const u8 = null,
    type: []const u8,
    range: ?ParameterRange = null,
    is_tunable: ?bool = null,
    is_required: ?bool = null,
    default_value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .description = "Description",
            .type = "Type",
            .range = "Range",
            .is_tunable = "IsTunable",
            .is_required = "IsRequired",
            .default_value = "DefaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const ParameterRange = struct {
    integer_parameter_range_specification: ?IntegerParameterRangeSpecification = null,
    continuous_parameter_range_specification: ?ContinuousParameterRangeSpecification = null,
    categorical_parameter_range_specification: ?CategoricalParameterRangeSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .integer_parameter_range_specification = "IntegerParameterRangeSpecification",
            .continuous_parameter_range_specification = "ContinuousParameterRangeSpecification",
            .categorical_parameter_range_specification = "CategoricalParameterRangeSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const CategoricalParameterRangeSpecification = struct {
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const ContinuousParameterRangeSpecification = struct {
    min_value: []const u8,
    max_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_value = "MinValue",
            .max_value = "MaxValue",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerParameterRangeSpecification = struct {
    min_value: []const u8,
    max_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .min_value = "MinValue",
            .max_value = "MaxValue",
        };
        return @field(mappings, field_name);
    }
};
